/* Generated by Cython 3.2.3 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/usr/include/proj.h",
            "/usr/include/proj_experimental.h"
        ],
        "include_dirs": [
            "/usr/include"
        ],
        "libraries": [
            "proj"
        ],
        "library_dirs": [
            "/usr/lib",
            "/usr/lib64"
        ],
        "name": "pyproj._crs",
        "sources": [
            "pyproj/_crs.pyx"
        ]
    },
    "module_name": "pyproj._crs"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_3"
#define CYTHON_HEX_VERSION 0x030203F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__pyproj___crs
#define __PYX_HAVE_API__pyproj___crs
/* Early includes */
#include "proj.h"
#include <string.h>
#include <stdio.h>

    #if __PYX_LIMITED_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE PyObject *
    __Pyx_CAPI_PyList_GetItemRef(PyObject *list, Py_ssize_t index)
    {
        PyObject *item = PyList_GetItem(list, index);
        Py_XINCREF(item);
        return item;
    }
    #else
    #define __Pyx_CAPI_PyList_GetItemRef PyList_GetItemRef
    #endif

    #if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int
    __Pyx_CAPI_PyList_Extend(PyObject *list, PyObject *iterable)
    {
        return PyList_SetSlice(list, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, iterable);
    }

    static CYTHON_INLINE int
    __Pyx_CAPI_PyList_Clear(PyObject *list)
    {
        return PyList_SetSlice(list, 0, PY_SSIZE_T_MAX, NULL);
    }
    #else
    #define __Pyx_CAPI_PyList_Extend PyList_Extend
    #define __Pyx_CAPI_PyList_Clear PyList_Clear
    #endif
    

    #if PY_MAJOR_VERSION >= 3
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj)
    #else
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj, NULL)
    #endif
    
#include <stddef.h>

    #if PY_MAJOR_VERSION <= 2
    #define PyDict_GetItemWithError _PyDict_GetItemWithError
    #endif

    #if __PYX_LIMITED_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int
    __Pyx_CAPI_PyDict_GetItemStringRef(PyObject *mp, const char *key, PyObject **result)
    {
        int res;
        PyObject *key_obj = PyUnicode_FromString(key);
        if (key_obj == NULL) {
            *result = NULL;
            return -1;
        }
        res = __Pyx_PyDict_GetItemRef(mp, key_obj, result);
        Py_DECREF(key_obj);
        return res;
    }
    #else
    #define __Pyx_CAPI_PyDict_GetItemStringRef PyDict_GetItemStringRef
    #endif
    #if PY_VERSION_HEX < 0x030d0000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030F0000)
    static CYTHON_INLINE int
    __Pyx_CAPI_PyDict_SetDefaultRef(PyObject *d, PyObject *key, PyObject *default_value,
                        PyObject **result)
    {
        PyObject *value;
        if (__Pyx_PyDict_GetItemRef(d, key, &value) < 0) {
            // get error
            if (result) {
                *result = NULL;
            }
            return -1;
        }
        if (value != NULL) {
            // present
            if (result) {
                *result = value;
            }
            else {
                Py_DECREF(value);
            }
            return 1;
        }

        // missing: set the item
        if (PyDict_SetItem(d, key, default_value) < 0) {
            // set error
            if (result) {
                *result = NULL;
            }
            return -1;
        }
        if (result) {
            Py_INCREF(default_value);
            *result = default_value;
        }
        return 0;
    }
    #else
    #define __Pyx_CAPI_PyDict_SetDefaultRef PyDict_SetDefaultRef
    #endif
    

    #if PY_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int __Pyx_PyWeakref_GetRef(PyObject *ref, PyObject **pobj)
    {
        PyObject *obj = PyWeakref_GetObject(ref);
        if (obj == NULL) {
            // SystemError if ref is NULL
            *pobj = NULL;
            return -1;
        }
        if (obj == Py_None) {
            *pobj = NULL;
            return 0;
        }
        Py_INCREF(obj);
        *pobj = obj;
        return 1;
    }
    #else
    #define __Pyx_PyWeakref_GetRef PyWeakref_GetRef
    #endif
    
#include "pythread.h"

    #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM < 0x07030600) && !defined(PyContextVar_Get)
    #define PyContextVar_Get(var, d, v)         ((d) ?             ((void)(var), Py_INCREF(d), (v)[0] = (d), 0) :             ((v)[0] = NULL, 0)         )
    #endif
    
#include "proj_experimental.h"

    #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    #ifdef _MSC_VER
    #pragma message ("This module uses CPython specific internals of 'array.array', which are not available in PyPy or the limited API.")
    #else
    #warning This module uses CPython specific internals of 'array.array', which are not available in PyPy or the limited API.
    #endif
    #endif
    
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING "utf-8"
#define __Pyx_PyObject_FromString __Pyx_PyUnicode_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "pyproj/_crs.pyx",
  "cpython/contextvars.pxd",
  "array.pxd",
  "pyproj/_crs.pxd",
  "<stringsource>",
  "cpython/type.pxd",
  "cpython/bool.pxd",
  "cpython/complex.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
#ifndef _ARRAYARRAY_H
struct arrayobject;
typedef struct arrayobject arrayobject;
#endif
struct __pyx_obj_6pyproj_4_crs_Axis;
struct __pyx_obj_6pyproj_4_crs_Base;
struct __pyx_obj_6pyproj_4_crs__CRSParts;
struct __pyx_obj_6pyproj_4_crs_Ellipsoid;
struct __pyx_obj_6pyproj_4_crs_PrimeMeridian;
struct __pyx_obj_6pyproj_4_crs_Datum;
struct __pyx_obj_6pyproj_4_crs_CoordinateSystem;
struct __pyx_obj_6pyproj_4_crs_Param;
struct __pyx_obj_6pyproj_4_crs_Grid;
struct __pyx_obj_6pyproj_4_crs_CoordinateOperation;
struct __pyx_obj_6pyproj_4_crs__CRS;
struct __pyx_opt_args_7cpython_11contextvars_get_value;
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default;

/* "cpython/contextvars.pxd":116
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
*/
struct __pyx_opt_args_7cpython_11contextvars_get_value {
  int __pyx_n;
  PyObject *default_value;
};

/* "cpython/contextvars.pxd":134
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
*/
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default {
  int __pyx_n;
  PyObject *default_value;
};
struct __pyx_opt_args_6pyproj_4_crs__to_wkt;

/* "pyproj/_crs.pxd":25
 *     bint pretty,
 * )
 * cdef _to_wkt(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context,
 *     PJ* projobj,
*/
struct __pyx_opt_args_6pyproj_4_crs__to_wkt {
  int __pyx_n;
  PyLongObject *output_axis_rule;
};

/* "pyproj/_crs.pxd":33
 * )
 * 
 * cdef class Axis:             # <<<<<<<<<<<<<<
 *     cdef readonly str name
 *     cdef readonly str abbrev
*/
struct __pyx_obj_6pyproj_4_crs_Axis {
  PyObject_HEAD
  struct __pyx_vtabstruct_6pyproj_4_crs_Axis *__pyx_vtab;
  PyObject *name;
  PyObject *abbrev;
  PyObject *direction;
  double unit_conversion_factor;
  PyObject *unit_name;
  PyObject *unit_auth_code;
  PyObject *unit_code;
};


/* "pyproj/_crs.pxd":47
 * cdef create_area_of_use(PJ_CONTEXT* context, PJ* projobj)
 * 
 * cdef class Base:             # <<<<<<<<<<<<<<
 *     cdef PJ *projobj
 *     cdef PJ_CONTEXT* context
*/
struct __pyx_obj_6pyproj_4_crs_Base {
  PyObject_HEAD
  struct __pyx_vtabstruct_6pyproj_4_crs_Base *__pyx_vtab;
  PJ *projobj;
  PJ_CONTEXT *context;
  PyObject *_context_manager;
  PyObject *name;
  PyObject *_remarks;
  PyObject *_scope;
};


/* "pyproj/_crs.pxd":56
 *     cdef _set_base_info(self)
 * 
 * cdef class _CRSParts(Base):             # <<<<<<<<<<<<<<
 *     pass
 * 
*/
struct __pyx_obj_6pyproj_4_crs__CRSParts {
  struct __pyx_obj_6pyproj_4_crs_Base __pyx_base;
};


/* "pyproj/_crs.pxd":60
 * 
 * 
 * cdef class Ellipsoid(_CRSParts):             # <<<<<<<<<<<<<<
 *     cdef readonly double semi_major_metre
 *     cdef readonly double semi_minor_metre
*/
struct __pyx_obj_6pyproj_4_crs_Ellipsoid {
  struct __pyx_obj_6pyproj_4_crs__CRSParts __pyx_base;
  double semi_major_metre;
  double semi_minor_metre;
  int is_semi_minor_computed;
  double inverse_flattening;
};


/* "pyproj/_crs.pxd":70
 * 
 * 
 * cdef class PrimeMeridian(_CRSParts):             # <<<<<<<<<<<<<<
 *     cdef readonly double longitude
 *     cdef readonly double unit_conversion_factor
*/
struct __pyx_obj_6pyproj_4_crs_PrimeMeridian {
  struct __pyx_obj_6pyproj_4_crs__CRSParts __pyx_base;
  double longitude;
  double unit_conversion_factor;
  PyObject *unit_name;
};


/* "pyproj/_crs.pxd":79
 * 
 * 
 * cdef class Datum(_CRSParts):             # <<<<<<<<<<<<<<
 *     cdef readonly str type_name
 *     cdef readonly object _ellipsoid
*/
struct __pyx_obj_6pyproj_4_crs_Datum {
  struct __pyx_obj_6pyproj_4_crs__CRSParts __pyx_base;
  PyObject *type_name;
  PyObject *_ellipsoid;
  PyObject *_prime_meridian;
};


/* "pyproj/_crs.pxd":88
 * 
 * 
 * cdef class CoordinateSystem(_CRSParts):             # <<<<<<<<<<<<<<
 *     cdef readonly list _axis_list
 * 
*/
struct __pyx_obj_6pyproj_4_crs_CoordinateSystem {
  struct __pyx_obj_6pyproj_4_crs__CRSParts __pyx_base;
  PyObject *_axis_list;
};


/* "pyproj/_crs.pxd":95
 * 
 * 
 * cdef class Param:             # <<<<<<<<<<<<<<
 *     cdef readonly str name
 *     cdef readonly str auth_name
*/
struct __pyx_obj_6pyproj_4_crs_Param {
  PyObject_HEAD
  struct __pyx_vtabstruct_6pyproj_4_crs_Param *__pyx_vtab;
  PyObject *name;
  PyObject *auth_name;
  PyObject *code;
  PyObject *value;
  double unit_conversion_factor;
  PyObject *unit_name;
  PyObject *unit_auth_name;
  PyObject *unit_code;
  PyObject *unit_category;
};


/* "pyproj/_crs.pxd":110
 * 
 * 
 * cdef class Grid:             # <<<<<<<<<<<<<<
 *     cdef readonly str short_name
 *     cdef readonly str full_name
*/
struct __pyx_obj_6pyproj_4_crs_Grid {
  PyObject_HEAD
  struct __pyx_vtabstruct_6pyproj_4_crs_Grid *__pyx_vtab;
  PyObject *short_name;
  PyObject *full_name;
  PyObject *package_name;
  PyObject *url;
  int direct_download;
  int open_license;
  int available;
};


/* "pyproj/_crs.pxd":123
 * 
 * 
 * cdef class CoordinateOperation(_CRSParts):             # <<<<<<<<<<<<<<
 *     cdef readonly list _params
 *     cdef readonly list _grids
*/
struct __pyx_obj_6pyproj_4_crs_CoordinateOperation {
  struct __pyx_obj_6pyproj_4_crs__CRSParts __pyx_base;
  PyObject *_params;
  PyObject *_grids;
  PyObject *_area_of_use;
  PyObject *method_name;
  PyObject *method_auth_name;
  PyObject *method_code;
  double accuracy;
  int is_instantiable;
  int has_ballpark_transformation;
  PyObject *_towgs84;
  PyObject *_operations;
  PyObject *type_name;
};


/* "pyproj/_crs.pxd":141
 * 
 * 
 * cdef class _CRS(Base):             # <<<<<<<<<<<<<<
 *     cdef PJ_TYPE _type
 *     cdef PJ_PROJ_INFO projpj_info
*/
struct __pyx_obj_6pyproj_4_crs__CRS {
  struct __pyx_obj_6pyproj_4_crs_Base __pyx_base;
  PJ_TYPE _type;
  PJ_PROJ_INFO projpj_info;
  PyObject *srs;
  PyObject *_type_name;
  struct __pyx_obj_6pyproj_4_crs_Ellipsoid *_ellipsoid;
  PyObject *_area_of_use;
  struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *_prime_meridian;
  struct __pyx_obj_6pyproj_4_crs_Datum *_datum;
  PyObject *_sub_crs_list;
  struct __pyx_obj_6pyproj_4_crs__CRS *_source_crs;
  struct __pyx_obj_6pyproj_4_crs__CRS *_target_crs;
  struct __pyx_obj_6pyproj_4_crs__CRS *_geodetic_crs;
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *_coordinate_system;
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *_coordinate_operation;
};



/* "pyproj/_crs.pyx":259
 * 
 * 
 * cdef class Axis:             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_Axis {
  struct __pyx_obj_6pyproj_4_crs_Axis *(*create)(PJ_CONTEXT *, PJ *, int);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_Axis *__pyx_vtabptr_6pyproj_4_crs_Axis;


/* "pyproj/_crs.pyx":353
 * 
 * 
 * cdef class Base:             # <<<<<<<<<<<<<<
 *     def __cinit__(self):
 *         self.projobj = NULL
*/

struct __pyx_vtabstruct_6pyproj_4_crs_Base {
  PyObject *(*_set_base_info)(struct __pyx_obj_6pyproj_4_crs_Base *);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_Base *__pyx_vtabptr_6pyproj_4_crs_Base;


/* "pyproj/_crs.pyx":505
 * 
 * 
 * cdef class _CRSParts(Base):             # <<<<<<<<<<<<<<
 *     @classmethod
 *     def from_user_input(cls, user_input):
*/

struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts {
  struct __pyx_vtabstruct_6pyproj_4_crs_Base __pyx_base;
};
static struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts *__pyx_vtabptr_6pyproj_4_crs__CRSParts;


/* "pyproj/_crs.pyx":783
 * 
 * 
 * cdef class Ellipsoid(_CRSParts):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_Ellipsoid {
  struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts __pyx_base;
  struct __pyx_obj_6pyproj_4_crs_Ellipsoid *(*create)(PJ_CONTEXT *, PJ *);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_Ellipsoid *__pyx_vtabptr_6pyproj_4_crs_Ellipsoid;


/* "pyproj/_crs.pyx":1070
 * 
 * 
 * cdef class PrimeMeridian(_CRSParts):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_PrimeMeridian {
  struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts __pyx_base;
  struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *(*create)(PJ_CONTEXT *, PJ *);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_PrimeMeridian *__pyx_vtabptr_6pyproj_4_crs_PrimeMeridian;


/* "pyproj/_crs.pyx":1329
 * 
 * 
 * cdef class Datum(_CRSParts):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_Datum {
  struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts __pyx_base;
  struct __pyx_obj_6pyproj_4_crs_Datum *(*create)(PJ_CONTEXT *, PJ *);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_Datum *__pyx_vtabptr_6pyproj_4_crs_Datum;


/* "pyproj/_crs.pyx":568
 * }
 * 
 * cdef class CoordinateSystem(_CRSParts):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateSystem {
  struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts __pyx_base;
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *(*create)(PJ_CONTEXT *, PJ *);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateSystem *__pyx_vtabptr_6pyproj_4_crs_CoordinateSystem;


/* "pyproj/_crs.pyx":1667
 * 
 * 
 * cdef class Param:             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_Param {
  struct __pyx_obj_6pyproj_4_crs_Param *(*create)(PJ_CONTEXT *, PJ *, int);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_Param *__pyx_vtabptr_6pyproj_4_crs_Param;


/* "pyproj/_crs.pyx":1760
 * 
 * 
 * cdef class Grid:             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_Grid {
  struct __pyx_obj_6pyproj_4_crs_Grid *(*create)(PJ_CONTEXT *, PJ *, int);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_Grid *__pyx_vtabptr_6pyproj_4_crs_Grid;


/* "pyproj/_crs.pyx":1855
 * }
 * 
 * cdef class CoordinateOperation(_CRSParts):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateOperation {
  struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts __pyx_base;
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *(*create)(PJ_CONTEXT *, PJ *);
};
static struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateOperation *__pyx_vtabptr_6pyproj_4_crs_CoordinateOperation;


/* "pyproj/_crs.pyx":2334
 * 
 * 
 * cdef class _CRS(Base):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/

struct __pyx_vtabstruct_6pyproj_4_crs__CRS {
  struct __pyx_vtabstruct_6pyproj_4_crs_Base __pyx_base;
};
static struct __pyx_vtabstruct_6pyproj_4_crs__CRS *__pyx_vtabptr_6pyproj_4_crs__CRS;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* PyDictVersioning.proto (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* pybytes_as_double.proto (used by pyunicode_as_double) */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj);
static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length);
static CYTHON_INLINE double __Pyx_PyBytes_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    as_c_string = PyBytes_AS_STRING(obj);
    size = PyBytes_GET_SIZE(obj);
#else
    if (PyBytes_AsStringAndSize(obj, &as_c_string, &size) < 0) {
        return (double)-1;
    }
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}
static CYTHON_INLINE double __Pyx_PyByteArray_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    as_c_string = PyByteArray_AS_STRING(obj);
    size = PyByteArray_GET_SIZE(obj);
#else
    as_c_string = PyByteArray_AsString(obj);
    if (as_c_string == NULL) {
        return (double)-1;
    }
    size = PyByteArray_Size(obj);
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}

/* pyunicode_as_double.proto */
#if !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
static const char* __Pyx__PyUnicode_AsDouble_Copy(const void* data, const int kind, char* buffer, Py_ssize_t start, Py_ssize_t end) {
    int last_was_punctuation;
    Py_ssize_t i;
    last_was_punctuation = 1;
    for (i=start; i <= end; i++) {
        Py_UCS4 chr = PyUnicode_READ(kind, data, i);
        int is_punctuation = (chr == '_') | (chr == '.');
        *buffer = (char)chr;
        buffer += (chr != '_');
        if (unlikely(chr > 127)) goto parse_failure;
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyUnicode_AsDouble_inf_nan(const void* data, int kind, Py_ssize_t start, Py_ssize_t length) {
    int matches = 1;
    Py_UCS4 chr;
    Py_UCS4 sign = PyUnicode_READ(kind, data, start);
    int is_signed = (sign == '-') | (sign == '+');
    start += is_signed;
    length -= is_signed;
    switch (PyUnicode_READ(kind, data, start)) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'a') | (chr == 'A');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'n') | (chr == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'f') | (chr == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+3);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+4);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+5);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+6);
            matches &= (chr == 't') | (chr == 'T');
            chr = PyUnicode_READ(kind, data, start+7);
            matches &= (chr == 'y') | (chr == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static double __Pyx_PyUnicode_AsDouble_WithSpaces(PyObject *obj) {
    double value;
    const char *last;
    char *end;
    Py_ssize_t start, length = PyUnicode_GET_LENGTH(obj);
    const int kind = PyUnicode_KIND(obj);
    const void* data = PyUnicode_DATA(obj);
    start = 0;
    while (Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, start)))
        start++;
    while (start < length - 1 && Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, length - 1)))
        length--;
    length -= start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyUnicode_AsDouble_inf_nan(data, kind, start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    if (length < 40) {
        char number[40];
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((length + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}
#endif
static CYTHON_INLINE double __Pyx_PyUnicode_AsDouble(PyObject *obj) {
#if !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(__Pyx_PyUnicode_READY(obj) == -1))
        return (double)-1;
    if (likely(PyUnicode_IS_ASCII(obj))) {
        const char *s;
        Py_ssize_t length;
        s = PyUnicode_AsUTF8AndSize(obj, &length);
        return __Pyx__PyBytes_AsDouble(obj, s, length);
    }
    return __Pyx_PyUnicode_AsDouble_WithSpaces(obj);
#else
    return __Pyx_SlowPyString_AsDouble(obj);
#endif
}

/* FloatExceptionCheck.proto */
#define __PYX_CHECK_FLOAT_EXCEPTION(value, error_value)\
    ((error_value) == (error_value) ?\
     (value) == (error_value) :\
     (value) != (value))

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* PyObjectVectorCallKwBuilder.proto */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectFormat.proto */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* s, PyObject* f);
#else
#define __Pyx_PyObject_Format(s, f) PyObject_Format(s, f)
#endif

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* PyRuntimeError_Check.proto */
#define __Pyx_PyExc_RuntimeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_RuntimeError)

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared)
    #endif
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_OwnStrongReference)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_SharedReference)
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right))

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CythonFunctionShared) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* PyObjectCall2Args.proto (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* CallUnboundCMethod1.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* IterFinish.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod0.proto (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
    PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple);
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* CBIntToPyUnicode.proto */
#define __Pyx_PyUnicode_FromBInt_bint(value)\
    ((value) ? __Pyx_NewRef(__pyx_mstate_global->__pyx_n_u_True) : __Pyx_NewRef(__pyx_mstate_global->__pyx_n_u_False))

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00a2
    return PyList_Extend(L, v);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* PyIndexError_Check.proto */
#define __Pyx_PyExc_IndexError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_IndexError)

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig);

/* GetApiDict.proto */
static PyObject *__Pyx_ApiExport_GetApiDict(void);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* DelItemOnTypeDict.proto (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k);
#define __Pyx_DelItemOnTypeDict(tp, k) __Pyx__DelItemOnTypeDict((PyTypeObject*)tp, k)

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_3
#define __PYX_HAVE_RT_ImportType_proto_3_2_3
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_3(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_3(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_3 {
   __Pyx_ImportType_CheckSize_Error_3_2_3 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_3 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_3 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_3(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_3 check_size);
#endif

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_3(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* ClassMethod.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include "descrobject.h"
#endif
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* ListPack.proto */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...);

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* ArrayAPI.proto */
#ifndef _ARRAYARRAY_H
#define _ARRAYARRAY_H
typedef struct arraydescr {
    int typecode;
    int itemsize;
    PyObject * (*getitem)(struct arrayobject *, Py_ssize_t);
    int (*setitem)(struct arrayobject *, Py_ssize_t, PyObject *);
    char *formats;
} arraydescr;
typedef union {
    char *ob_item;
    float *as_floats;
    double *as_doubles;
    int *as_ints;
    unsigned int *as_uints;
    unsigned char *as_uchars;
    signed char *as_schars;
    char *as_chars;
    unsigned long *as_ulongs;
    long *as_longs;
    unsigned long long *as_ulonglongs;
    long long *as_longlongs;
    short *as_shorts;
    unsigned short *as_ushorts;
    #if PY_VERSION_HEX >= 0x030d0000
    Py_DEPRECATED(3.13)
    #endif
        wchar_t *as_pyunicodes;
    void *as_voidptr;
} __Pyx_data_union;
struct arrayobject {
    PyObject_HEAD
    Py_ssize_t ob_size;
    __Pyx_data_union data;
    Py_ssize_t allocated;
    struct arraydescr *ob_descr;
    PyObject *weakreflist;
    int ob_exports;
};
#ifndef NO_NEWARRAY_INLINE
static CYTHON_INLINE PyObject * newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr) {
    arrayobject *op;
    size_t nbytes;
    if (size < 0) {
        PyErr_BadInternalCall();
        return NULL;
    }
    nbytes = size * descr->itemsize;
    if (nbytes / descr->itemsize != (size_t)size) {
        return PyErr_NoMemory();
    }
    op = (arrayobject *) type->tp_alloc(type, 0);
    if (op == NULL) {
        return NULL;
    }
    op->ob_descr = descr;
    op->allocated = size;
    op->weakreflist = NULL;
    __Pyx_SET_SIZE(op, size);
    if (size <= 0) {
        op->data.ob_item = NULL;
    }
    else {
        op->data.ob_item = PyMem_NEW(char, nbytes);
        if (op->data.ob_item == NULL) {
            Py_DECREF(op);
            return PyErr_NoMemory();
        }
    }
    return (PyObject *) op;
}
#else
PyObject* newarrayobject(PyTypeObject *type, Py_ssize_t size,
    struct arraydescr *descr);
#endif
static CYTHON_INLINE __Pyx_data_union __Pyx_PyArray_Data(arrayobject *self) {
#if CYTHON_COMPILING_IN_GRAAL
    __Pyx_data_union data;
    data.ob_item = GraalPyArray_Data((PyObject*)self);
    return data;
#else
    return self->data;
#endif
}
static CYTHON_INLINE int resize(arrayobject *self, Py_ssize_t n) {
#if CYTHON_COMPILING_IN_GRAAL
    return GraalPyArray_Resize((PyObject*)self, n);
#else
    void *items = (void*) self->data.ob_item;
    PyMem_Resize(items, char, (size_t)(n * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    __Pyx_SET_SIZE(self, n);
    self->allocated = n;
    return 0;
#endif
}
static CYTHON_INLINE int resize_smart(arrayobject *self, Py_ssize_t n) {
#if CYTHON_COMPILING_IN_GRAAL
    return GraalPyArray_Resize((PyObject*)self, n);
#else
    void *items = (void*) self->data.ob_item;
    Py_ssize_t newsize;
    if (n < self->allocated && n*4 > self->allocated) {
        __Pyx_SET_SIZE(self, n);
        return 0;
    }
    newsize = n + (n / 2) + 1;
    if (newsize <= n) {
        PyErr_NoMemory();
        return -1;
    }
    PyMem_Resize(items, char, (size_t)(newsize * self->ob_descr->itemsize));
    if (items == NULL) {
        PyErr_NoMemory();
        return -1;
    }
    self->data.ob_item = (char*) items;
    __Pyx_SET_SIZE(self, n);
    self->allocated = newsize;
    return 0;
#endif
}
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_COORDINATE_SYSTEM_TYPE value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE value);

/* CIntFromPy.proto */
static CYTHON_INLINE PJ_CATEGORY __Pyx_PyLong_As_PJ_CATEGORY(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT_TYPE value);

/* CIntFromPy.proto */
static CYTHON_INLINE PJ_WKT_TYPE __Pyx_PyLong_As_PJ_WKT_TYPE(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_PROJ_STRING_TYPE(PJ_PROJ_STRING_TYPE value);

/* CIntFromPy.proto */
static CYTHON_INLINE PJ_PROJ_STRING_TYPE __Pyx_PyLong_As_PJ_PROJ_STRING_TYPE(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_CATEGORY(PJ_CATEGORY value);

/* CIntFromPy.proto */
static CYTHON_INLINE PJ_TYPE __Pyx_PyLong_As_PJ_TYPE(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self); /* proto*/
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self); /* proto*/
#endif
static CYTHON_INLINE __Pyx_data_union __pyx_f_7cpython_5array_5array_4data_data(arrayobject *__pyx_v_self); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_f_6pyproj_4_crs_4Axis_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, int __pyx_v_index); /* proto*/
static PyObject *__pyx_f_6pyproj_4_crs_4Base__set_base_info(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_f_6pyproj_4_crs_16CoordinateSystem_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_coord_system_pj); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_f_6pyproj_4_crs_9Ellipsoid_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_ellipsoid_pj); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_prime_meridian_pj); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_f_6pyproj_4_crs_5Datum_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_datum_pj); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_Param *__pyx_f_6pyproj_4_crs_5Param_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, int __pyx_v_param_idx); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_f_6pyproj_4_crs_4Grid_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, int __pyx_v_grid_idx); /* proto*/
static struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_coord_operation_pj); /* proto*/

/* Module declarations from "cpython.version" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "cpython.exc" */

/* Module declarations from "cpython.module" */

/* Module declarations from "cpython.mem" */

/* Module declarations from "cpython.tuple" */

/* Module declarations from "cpython.list" */

/* Module declarations from "cpython.sequence" */

/* Module declarations from "cpython.mapping" */

/* Module declarations from "cpython.iterator" */

/* Module declarations from "cpython.number" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.bool" */

/* Module declarations from "cpython.long" */

/* Module declarations from "cpython.float" */

/* Module declarations from "cython" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.complex" */

/* Module declarations from "libc.stddef" */

/* Module declarations from "cpython.unicode" */

/* Module declarations from "cpython.pyport" */

/* Module declarations from "cpython.dict" */

/* Module declarations from "cpython.instance" */

/* Module declarations from "cpython.function" */

/* Module declarations from "cpython.method" */

/* Module declarations from "cpython.weakref" */

/* Module declarations from "cpython.getargs" */

/* Module declarations from "cpython.pythread" */

/* Module declarations from "cpython.pystate" */

/* Module declarations from "cpython.set" */

/* Module declarations from "cpython.buffer" */

/* Module declarations from "cpython.bytes" */

/* Module declarations from "cpython.pycapsule" */

/* Module declarations from "cpython.contextvars" */

/* Module declarations from "cpython" */

/* Module declarations from "array" */

/* Module declarations from "cpython.array" */
static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *, char *, Py_ssize_t); /*proto*/

/* Module declarations from "pyproj._compat" */
static PyObject *(*__pyx_f_6pyproj_7_compat_cstrdecode)(char const *); /*proto*/
static PyObject *(*__pyx_f_6pyproj_7_compat_cstrencode)(PyObject *, int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "pyproj._context" */
static void (*__pyx_f_6pyproj_8_context__clear_proj_error)(int __pyx_skip_dispatch); /*proto*/
static PJ_CONTEXT *(*__pyx_f_6pyproj_8_context_pyproj_context_create)(void); /*proto*/

/* Module declarations from "pyproj._crs" */
static PyObject *__pyx_v_6pyproj_4_crs__PJ_ELLPS_NAME_MAP = 0;
static PyObject *__pyx_v_6pyproj_4_crs__COORD_SYSTEM_TYPE_MAP = 0;
static PyObject *__pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP = 0;
static PyObject *__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP = 0;
static PyObject *__pyx_v_6pyproj_4_crs__COORDINATE_OPERATION_TYPE_MAP = 0;
static PyObject *__pyx_v_6pyproj_4_crs__PJ_COORDINATE_OPERATION_TYPE_MAP = 0;
static PyObject *__pyx_v_6pyproj_4_crs__CRS_TYPE_MAP = 0;
static PyObject *__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id;
static PyObject *__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps;
static PyObject *__pyx_f_6pyproj_4_crs__get_concatenated_operations(PJ_CONTEXT *, PJ *); /*proto*/
static PyObject *__pyx_f_6pyproj_4_crs__to_proj4(PJ_CONTEXT *, PJ *, PyObject *, int); /*proto*/
static PyObject *__pyx_f_6pyproj_4_crs__to_wkt(PJ_CONTEXT *, PJ *, PyObject *, int, struct __pyx_opt_args_6pyproj_4_crs__to_wkt *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pyproj_4_crs_create_area_of_use(PJ_CONTEXT *, PJ *); /*proto*/
static PyObject *__pyx_f_6pyproj_4_crs_decode_or_undefined(char const *); /*proto*/
static PJ *__pyx_f_6pyproj_4_crs__from_name(PJ_CONTEXT *, PyObject *, PyObject *, PJ_TYPE); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "pyproj._crs"
extern int __pyx_module_is_main_pyproj___crs;
int __pyx_module_is_main_pyproj___crs = 0;

/* Implementation of "pyproj._crs" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_staticmethod;
/* #### Code section: string_decls ### */
/* #### Code section: decls ### */
static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags); /* proto */
static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_is_wkt(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_proj_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_2is_proj(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_proj_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_load_proj_json(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_in_proj_json); /* proto */
static int __pyx_pf_6pyproj_4_crs_4Axis___cinit__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_2__str__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_4__repr__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_4name___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_6abbrev___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_9direction___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_22unit_conversion_factor___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_9unit_name___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_14unit_auth_code___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_9unit_code___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_4Base___cinit__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static void __pyx_pf_6pyproj_4_crs_4Base_2__dealloc__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_7remarks___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_5scope___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_4to_wkt(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, PyObject *__pyx_v_version, PyObject *__pyx_v_pretty, PyObject *__pyx_v_output_axis_rule); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_6to_json(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, int __pyx_v_pretty, int __pyx_v_indentation); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_8to_json_dict(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_10__str__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_12__repr__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_14_is_exact_same(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_16_is_equivalent(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_18__eq__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_20is_exact_same(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_16_context_manager___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_4name___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_8_remarks___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_6_scope___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Base_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_from_user_input(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_user_input); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_2__eq__(struct __pyx_obj_6pyproj_4_crs__CRSParts *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRSParts *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRSParts *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_16CoordinateSystem___cinit__(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self); /* proto */
static int __pyx_pf_6pyproj_4_crs_16CoordinateSystem_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_9axis_list___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_4from_string(PyObject *__pyx_v_coordinate_system_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_6from_json_dict(PyObject *__pyx_v_coordinate_system_dict); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_8from_json(PyObject *__pyx_v_coordinate_system_json_str); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_5to_cf_get_linear_unit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_axis); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_10to_cf(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self, int __pyx_v_rotated_pole); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_10_axis_list___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_12__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_14__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_9Ellipsoid___cinit__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static int __pyx_pf_6pyproj_4_crs_9Ellipsoid_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_4from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_6from_epsg(PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_8_from_string(PyObject *__pyx_v_ellipsoid_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_10from_string(PyObject *__pyx_v_ellipsoid_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_12from_json_dict(PyObject *__pyx_v_ellipsoid_dict); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_14from_json(PyObject *__pyx_v_ellipsoid_json_str); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_16_from_name(PyObject *__pyx_v_ellipsoid_name, PyObject *__pyx_v_auth_name); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_18from_name(PyObject *__pyx_v_ellipsoid_name, PyObject *__pyx_v_auth_name); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_16semi_major_metre___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_16semi_minor_metre___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_22is_semi_minor_computed___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_18inverse_flattening___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_20__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_22__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_13PrimeMeridian___cinit__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self); /* proto */
static int __pyx_pf_6pyproj_4_crs_13PrimeMeridian_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_4from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_6from_epsg(PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_8_from_string(PyObject *__pyx_v_prime_meridian_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_10from_string(PyObject *__pyx_v_prime_meridian_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_12from_json_dict(PyObject *__pyx_v_prime_meridian_dict); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_14from_json(PyObject *__pyx_v_prime_meridian_json_str); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_16from_name(PyObject *__pyx_v_prime_meridian_name, PyObject *__pyx_v_auth_name); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_9longitude___get__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_22unit_conversion_factor___get__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_9unit_name___get__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_18__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_20__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_5Datum___cinit__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static int __pyx_pf_6pyproj_4_crs_5Datum_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_4_from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code, PJ_CATEGORY __pyx_v_category); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_6from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_8from_epsg(PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_10_from_string(PyObject *__pyx_v_datum_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_12from_string(PyObject *__pyx_v_datum_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_14_from_name(PyObject *__pyx_v_datum_name, PyObject *__pyx_v_auth_name, PyObject *__pyx_v_datum_type); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_16from_name(PyObject *__pyx_v_datum_name, PyObject *__pyx_v_auth_name, PyObject *__pyx_v_datum_type); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_18from_json_dict(PyObject *__pyx_v_datum_dict); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_20from_json(PyObject *__pyx_v_datum_json_str); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_9ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_14prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_9type_name___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_10_ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_15_prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_5Param___cinit__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_2__str__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_4__repr__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_4name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_9auth_name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_4code___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_5value___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_22unit_conversion_factor___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_9unit_name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_14unit_auth_name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_9unit_code___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_13unit_category___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_5Param_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_4Grid___cinit__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_2__str__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_4__repr__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_10short_name___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_9full_name___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_12package_name___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_3url___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_15direct_download___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_12open_license___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_9available___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_19CoordinateOperation___cinit__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static int __pyx_pf_6pyproj_4_crs_19CoordinateOperation_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_4from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code, int __pyx_v_use_proj_alternative_grid_names); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_6from_epsg(PyObject *__pyx_v_code, int __pyx_v_use_proj_alternative_grid_names); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_8_from_string(PyObject *__pyx_v_coordinate_operation_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_10from_string(PyObject *__pyx_v_coordinate_operation_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_12from_json_dict(PyObject *__pyx_v_coordinate_operation_dict); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_14from_json(PyObject *__pyx_v_coordinate_operation_json_str); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_16from_name(PyObject *__pyx_v_coordinate_operation_name, PyObject *__pyx_v_auth_name, PyObject *__pyx_v_coordinate_operation_type); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_6params___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_5grids___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11area_of_use___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_18to_proj4(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self, PyObject *__pyx_v_version, int __pyx_v_pretty); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_7towgs84___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_10operations___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_20__repr__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_7_params___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_6_grids___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_12_area_of_use___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11method_name___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_16method_auth_name___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11method_code___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_8accuracy___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_15is_instantiable___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_27has_ballpark_transformation___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_8_towgs84___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11_operations___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_9type_name___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pyproj_4_crs_4_CRS___cinit__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static int __pyx_pf_6pyproj_4_crs_4_CRS_2__init__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_proj_string); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_9type_name___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_9axis_info___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11area_of_use___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_9ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_14prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_5datum___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_17coordinate_system___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_20coordinate_operation___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10source_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10target_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12sub_crs_list___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12geodetic_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_4to_proj4(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_version); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_6to_epsg(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, int __pyx_v_min_confidence); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_8to_authority(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_auth_name, int __pyx_v_min_confidence); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10list_authority(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_auth_name, int __pyx_v_min_confidence); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12to_3d(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_14to_2d(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_16_is_crs_property(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_property_name, PyObject *__pyx_v_property_types, int __pyx_v_sub_crs_index); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13is_geographic___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12is_projected___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11is_vertical___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_8is_bound___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11is_compound___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_14is_engineering___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13is_geocentric___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10is_derived___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_18_equals(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_other, int __pyx_v_ignore_axis_order); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_20equals(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_ignore_axis_order); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13is_deprecated___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_22get_non_deprecated(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_3srs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10_type_name___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10_ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12_area_of_use___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_15_prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_6_datum___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13_sub_crs_list___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11_source_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11_target_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13_geodetic_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_18_coordinate_system___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_21_coordinate_operation___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_24__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_26__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_6pyproj_4_crs_Axis(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_Base(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs__CRSParts(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_Ellipsoid(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_PrimeMeridian(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_Datum(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_CoordinateSystem(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_Param(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_Grid(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs_CoordinateOperation(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pyproj_4_crs__CRS(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_7cpython_4bool_bool;
  PyTypeObject *__pyx_ptype_7cpython_7complex_complex;
  PyTypeObject *__pyx_ptype_7cpython_5array_array;
  PyObject *__pyx_type_6pyproj_4_crs_Axis;
  PyObject *__pyx_type_6pyproj_4_crs_Base;
  PyObject *__pyx_type_6pyproj_4_crs__CRSParts;
  PyObject *__pyx_type_6pyproj_4_crs_Ellipsoid;
  PyObject *__pyx_type_6pyproj_4_crs_PrimeMeridian;
  PyObject *__pyx_type_6pyproj_4_crs_Datum;
  PyObject *__pyx_type_6pyproj_4_crs_CoordinateSystem;
  PyObject *__pyx_type_6pyproj_4_crs_Param;
  PyObject *__pyx_type_6pyproj_4_crs_Grid;
  PyObject *__pyx_type_6pyproj_4_crs_CoordinateOperation;
  PyObject *__pyx_type_6pyproj_4_crs__CRS;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_Axis;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_Base;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs__CRSParts;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_Ellipsoid;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_PrimeMeridian;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_Datum;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_CoordinateSystem;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_Param;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_Grid;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs_CoordinateOperation;
  PyTypeObject *__pyx_ptype_6pyproj_4_crs__CRS;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type__lower;
  PyObject *__pyx_k__7;
  PyObject *__pyx_k__10;
  PyObject *__pyx_k__11;
  PyObject *__pyx_k__12;
  PyObject *__pyx_tuple[15];
  PyObject *__pyx_codeobj_tab[79];
  PyObject *__pyx_string_tab[528];
  PyObject *__pyx_number_tab[4];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;

/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_ __pyx_string_tab[0]
#define __pyx_kp_u_0f __pyx_string_tab[1]
#define __pyx_kp_u_Area_of_Use __pyx_string_tab[2]
#define __pyx_kp_u_Axis_name __pyx_string_tab[3]
#define __pyx_kp_u_Bound_CRS __pyx_string_tab[4]
#define __pyx_kp_u_CRS_list_authority_line_2810 __pyx_string_tab[5]
#define __pyx_kp_u_CRS_to_authority_line_2764 __pyx_string_tab[6]
#define __pyx_kp_u_CRS_to_epsg_line_2721 __pyx_string_tab[7]
#define __pyx_kp_u_Compound_CRS __pyx_string_tab[8]
#define __pyx_kp_u_Concatenated_Operation __pyx_string_tab[9]
#define __pyx_kp_u_CoordinateOperation_can_only_be __pyx_string_tab[10]
#define __pyx_kp_u_CoordinateSystem_is_not_initiali __pyx_string_tab[11]
#define __pyx_kp_u_Coordinate_Operation __pyx_string_tab[12]
#define __pyx_kp_u_Datum_Ensemble __pyx_string_tab[13]
#define __pyx_kp_u_Datum_can_only_be_initialized_li __pyx_string_tab[14]
#define __pyx_kp_u_Derived __pyx_string_tab[15]
#define __pyx_kp_u_Derived_Projected_CRS __pyx_string_tab[16]
#define __pyx_kp_u_Dynamic_Geodetic_Reference_Frame __pyx_string_tab[17]
#define __pyx_kp_u_Dynamic_Vertical_Reference_Frame __pyx_string_tab[18]
#define __pyx_kp_u_Ellipsoid_can_only_be_initialize __pyx_string_tab[19]
#define __pyx_kp_u_Engineering_CRS __pyx_string_tab[20]
#define __pyx_kp_u_Engineering_Datum __pyx_string_tab[21]
#define __pyx_kp_u_Geocentric_CRS __pyx_string_tab[22]
#define __pyx_kp_u_Geodetic_CRS __pyx_string_tab[23]
#define __pyx_kp_u_Geodetic_Reference_Frame __pyx_string_tab[24]
#define __pyx_kp_u_Geographic_2D_CRS __pyx_string_tab[25]
#define __pyx_kp_u_Geographic_3D_CRS __pyx_string_tab[26]
#define __pyx_kp_u_Geographic_CRS __pyx_string_tab[27]
#define __pyx_kp_u_Grid_short_name __pyx_string_tab[28]
#define __pyx_kp_u_INDENTATION_WIDTH __pyx_string_tab[29]
#define __pyx_kp_u_Input_is_not_a_CRS __pyx_string_tab[30]
#define __pyx_kp_u_Invalid __pyx_string_tab[31]
#define __pyx_kp_u_Invalid_JSON __pyx_string_tab[32]
#define __pyx_kp_u_Invalid_authority_or_code __pyx_string_tab[33]
#define __pyx_kp_u_Invalid_coordinate_operation_nam __pyx_string_tab[34]
#define __pyx_kp_u_Invalid_coordinate_operation_str __pyx_string_tab[35]
#define __pyx_kp_u_Invalid_coordinate_system_string __pyx_string_tab[36]
#define __pyx_kp_u_Invalid_datum_name __pyx_string_tab[37]
#define __pyx_kp_u_Invalid_datum_string __pyx_string_tab[38]
#define __pyx_kp_u_Invalid_ellipsoid_name __pyx_string_tab[39]
#define __pyx_kp_u_Invalid_ellipsoid_string __pyx_string_tab[40]
#define __pyx_kp_u_Invalid_prime_meridian_name __pyx_string_tab[41]
#define __pyx_kp_u_Invalid_prime_meridian_string __pyx_string_tab[42]
#define __pyx_kp_u_Invalid_projection __pyx_string_tab[43]
#define __pyx_kp_u_Method __pyx_string_tab[44]
#define __pyx_kp_u_Name __pyx_string_tab[45]
#define __pyx_kp_u_None __pyx_string_tab[46]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[47]
#define __pyx_kp_u_Other_CRS __pyx_string_tab[48]
#define __pyx_kp_u_Other_Coordinate_Operation __pyx_string_tab[49]
#define __pyx_kp_u_Param_name __pyx_string_tab[50]
#define __pyx_kp_u_Parametric_Datum __pyx_string_tab[51]
#define __pyx_kp_u_PrimeMeridian_can_only_be_initia __pyx_string_tab[52]
#define __pyx_kp_u_Projected_CRS __pyx_string_tab[53]
#define __pyx_kp_u_Return_the_EPSG_code_best_match __pyx_string_tab[54]
#define __pyx_kp_u_Scale_difference __pyx_string_tab[55]
#define __pyx_kp_u_Temporal_CRS __pyx_string_tab[56]
#define __pyx_kp_u_Temporal_Datum __pyx_string_tab[57]
#define __pyx_kp_u_Unknown_CRS __pyx_string_tab[58]
#define __pyx_kp_u_Vertical_CRS __pyx_string_tab[59]
#define __pyx_kp_u_Vertical_Reference_Frame __pyx_string_tab[60]
#define __pyx_kp_u_X_axis_rotation __pyx_string_tab[61]
#define __pyx_kp_u_X_axis_translation __pyx_string_tab[62]
#define __pyx_kp_u_Y_axis_rotation __pyx_string_tab[63]
#define __pyx_kp_u_Y_axis_translation __pyx_string_tab[64]
#define __pyx_kp_u_You_will_likely_lose_important_p __pyx_string_tab[65]
#define __pyx_kp_u_Z_axis_rotation __pyx_string_tab[66]
#define __pyx_kp_u_Z_axis_translation __pyx_string_tab[67]
#define __pyx_kp_u__13 __pyx_string_tab[68]
#define __pyx_kp_u__14 __pyx_string_tab[69]
#define __pyx_kp_u__2 __pyx_string_tab[70]
#define __pyx_kp_u__3 __pyx_string_tab[71]
#define __pyx_kp_u__4 __pyx_string_tab[72]
#define __pyx_kp_u__5 __pyx_string_tab[73]
#define __pyx_kp_u__6 __pyx_string_tab[74]
#define __pyx_kp_u__8 __pyx_string_tab[75]
#define __pyx_kp_u__9 __pyx_string_tab[76]
#define __pyx_kp_u_abbrev __pyx_string_tab[77]
#define __pyx_kp_u_add_note __pyx_string_tab[78]
#define __pyx_kp_u_auth_name_2 __pyx_string_tab[79]
#define __pyx_kp_u_available __pyx_string_tab[80]
#define __pyx_kp_u_code_2 __pyx_string_tab[81]
#define __pyx_kp_u_coordinate_2 __pyx_string_tab[82]
#define __pyx_kp_u_direct_download __pyx_string_tab[83]
#define __pyx_kp_u_direction __pyx_string_tab[84]
#define __pyx_kp_u_disable __pyx_string_tab[85]
#define __pyx_kp_u_enable __pyx_string_tab[86]
#define __pyx_kp_u_full_name __pyx_string_tab[87]
#define __pyx_kp_u_gc __pyx_string_tab[88]
#define __pyx_kp_u_in_rotated_pole_grid __pyx_string_tab[89]
#define __pyx_kp_u_input __pyx_string_tab[90]
#define __pyx_kp_u_isenabled __pyx_string_tab[91]
#define __pyx_kp_u_metre __pyx_string_tab[92]
#define __pyx_kp_u_no_default___reduce___due_to_non __pyx_string_tab[93]
#define __pyx_kp_u_open_license __pyx_string_tab[94]
#define __pyx_kp_u_package_name __pyx_string_tab[95]
#define __pyx_kp_u_pyproj__crs_pyx __pyx_string_tab[96]
#define __pyx_kp_u_stringsource __pyx_string_tab[97]
#define __pyx_kp_u_undefined_2 __pyx_string_tab[98]
#define __pyx_kp_u_unit_auth_code __pyx_string_tab[99]
#define __pyx_kp_u_unit_auth_name __pyx_string_tab[100]
#define __pyx_kp_u_unit_category __pyx_string_tab[101]
#define __pyx_kp_u_unit_code __pyx_string_tab[102]
#define __pyx_kp_u_unit_name __pyx_string_tab[103]
#define __pyx_kp_u_url __pyx_string_tab[104]
#define __pyx_kp_u_value __pyx_string_tab[105]
#define __pyx_kp_u_versionadded_2_2_0_Return_the_a __pyx_string_tab[106]
#define __pyx_kp_u_versionadded_3_2_0_CRS_Authorit __pyx_string_tab[107]
#define __pyx_kp_u_versionadded_3_2_0_Return_the_a __pyx_string_tab[108]
#define __pyx_n_u_AreaOfUse __pyx_string_tab[109]
#define __pyx_n_u_AuthorityMatchInfo __pyx_string_tab[110]
#define __pyx_n_u_Axis __pyx_string_tab[111]
#define __pyx_n_u_Axis___reduce_cython __pyx_string_tab[112]
#define __pyx_n_u_Axis___setstate_cython __pyx_string_tab[113]
#define __pyx_n_u_Base __pyx_string_tab[114]
#define __pyx_n_u_Base___reduce_cython __pyx_string_tab[115]
#define __pyx_n_u_Base___setstate_cython __pyx_string_tab[116]
#define __pyx_n_u_Base__is_equivalent __pyx_string_tab[117]
#define __pyx_n_u_Base__is_exact_same __pyx_string_tab[118]
#define __pyx_n_u_Base_is_exact_same __pyx_string_tab[119]
#define __pyx_n_u_Base_to_json __pyx_string_tab[120]
#define __pyx_n_u_Base_to_json_dict __pyx_string_tab[121]
#define __pyx_n_u_Base_to_wkt __pyx_string_tab[122]
#define __pyx_n_u_CONCATENATED_OPERATION __pyx_string_tab[123]
#define __pyx_n_u_CONVERSION __pyx_string_tab[124]
#define __pyx_n_u_CRS __pyx_string_tab[125]
#define __pyx_n_u_CRSError __pyx_string_tab[126]
#define __pyx_n_u_CRSParts __pyx_string_tab[127]
#define __pyx_n_u_CRSParts___reduce_cython __pyx_string_tab[128]
#define __pyx_n_u_CRSParts___setstate_cython __pyx_string_tab[129]
#define __pyx_n_u_CRSParts_from_user_input __pyx_string_tab[130]
#define __pyx_n_u_CRS_2 __pyx_string_tab[131]
#define __pyx_n_u_CRS___reduce_cython __pyx_string_tab[132]
#define __pyx_n_u_CRS___setstate_cython __pyx_string_tab[133]
#define __pyx_n_u_CRS__equals __pyx_string_tab[134]
#define __pyx_n_u_CRS__is_crs_property __pyx_string_tab[135]
#define __pyx_n_u_CRS_equals __pyx_string_tab[136]
#define __pyx_n_u_CRS_get_non_deprecated __pyx_string_tab[137]
#define __pyx_n_u_CRS_list_authority __pyx_string_tab[138]
#define __pyx_n_u_CRS_to_2d __pyx_string_tab[139]
#define __pyx_n_u_CRS_to_3d __pyx_string_tab[140]
#define __pyx_n_u_CRS_to_authority __pyx_string_tab[141]
#define __pyx_n_u_CRS_to_epsg __pyx_string_tab[142]
#define __pyx_n_u_CRS_to_proj4 __pyx_string_tab[143]
#define __pyx_n_u_Conversion __pyx_string_tab[144]
#define __pyx_n_u_CoordinateOperation __pyx_string_tab[145]
#define __pyx_n_u_CoordinateOperationType __pyx_string_tab[146]
#define __pyx_n_u_CoordinateOperation___reduce_cyt __pyx_string_tab[147]
#define __pyx_n_u_CoordinateOperation___setstate_c __pyx_string_tab[148]
#define __pyx_n_u_CoordinateOperation__from_string __pyx_string_tab[149]
#define __pyx_n_u_CoordinateOperation_from_authori __pyx_string_tab[150]
#define __pyx_n_u_CoordinateOperation_from_epsg __pyx_string_tab[151]
#define __pyx_n_u_CoordinateOperation_from_json __pyx_string_tab[152]
#define __pyx_n_u_CoordinateOperation_from_json_di __pyx_string_tab[153]
#define __pyx_n_u_CoordinateOperation_from_name __pyx_string_tab[154]
#define __pyx_n_u_CoordinateOperation_from_string __pyx_string_tab[155]
#define __pyx_n_u_CoordinateOperation_to_proj4 __pyx_string_tab[156]
#define __pyx_n_u_CoordinateSystem __pyx_string_tab[157]
#define __pyx_n_u_CoordinateSystem___reduce_cython __pyx_string_tab[158]
#define __pyx_n_u_CoordinateSystem___setstate_cyth __pyx_string_tab[159]
#define __pyx_n_u_CoordinateSystem_from_json __pyx_string_tab[160]
#define __pyx_n_u_CoordinateSystem_from_json_dict __pyx_string_tab[161]
#define __pyx_n_u_CoordinateSystem_from_string __pyx_string_tab[162]
#define __pyx_n_u_CoordinateSystem_to_cf __pyx_string_tab[163]
#define __pyx_n_u_CustomEllipsoid __pyx_string_tab[164]
#define __pyx_n_u_D __pyx_string_tab[165]
#define __pyx_n_u_DATUM_ENSEMBLE __pyx_string_tab[166]
#define __pyx_n_u_DYNAMIC_GEODETIC_REFERENCE_FRAME __pyx_string_tab[167]
#define __pyx_n_u_DYNAMIC_VERTICAL_REFERENCE_FRAME __pyx_string_tab[168]
#define __pyx_n_u_Datum __pyx_string_tab[169]
#define __pyx_n_u_DatumType __pyx_string_tab[170]
#define __pyx_n_u_Datum___reduce_cython __pyx_string_tab[171]
#define __pyx_n_u_Datum___setstate_cython __pyx_string_tab[172]
#define __pyx_n_u_Datum__from_authority __pyx_string_tab[173]
#define __pyx_n_u_Datum__from_name __pyx_string_tab[174]
#define __pyx_n_u_Datum__from_string __pyx_string_tab[175]
#define __pyx_n_u_Datum_from_authority __pyx_string_tab[176]
#define __pyx_n_u_Datum_from_epsg __pyx_string_tab[177]
#define __pyx_n_u_Datum_from_json __pyx_string_tab[178]
#define __pyx_n_u_Datum_from_json_dict __pyx_string_tab[179]
#define __pyx_n_u_Datum_from_name __pyx_string_tab[180]
#define __pyx_n_u_Datum_from_string __pyx_string_tab[181]
#define __pyx_n_u_EPSG __pyx_string_tab[182]
#define __pyx_n_u_Ellipsoid __pyx_string_tab[183]
#define __pyx_n_u_Ellipsoid___reduce_cython __pyx_string_tab[184]
#define __pyx_n_u_Ellipsoid___setstate_cython __pyx_string_tab[185]
#define __pyx_n_u_Ellipsoid__from_name __pyx_string_tab[186]
#define __pyx_n_u_Ellipsoid__from_string __pyx_string_tab[187]
#define __pyx_n_u_Ellipsoid_from_authority __pyx_string_tab[188]
#define __pyx_n_u_Ellipsoid_from_epsg __pyx_string_tab[189]
#define __pyx_n_u_Ellipsoid_from_json __pyx_string_tab[190]
#define __pyx_n_u_Ellipsoid_from_json_dict __pyx_string_tab[191]
#define __pyx_n_u_Ellipsoid_from_name __pyx_string_tab[192]
#define __pyx_n_u_Ellipsoid_from_string __pyx_string_tab[193]
#define __pyx_n_u_False __pyx_string_tab[194]
#define __pyx_n_u_GEODETIC_REFERENCE_FRAME __pyx_string_tab[195]
#define __pyx_n_u_Grid __pyx_string_tab[196]
#define __pyx_n_u_Grid___reduce_cython __pyx_string_tab[197]
#define __pyx_n_u_Grid___setstate_cython __pyx_string_tab[198]
#define __pyx_n_u_H __pyx_string_tab[199]
#define __pyx_n_u_NaN __pyx_string_tab[200]
#define __pyx_n_u_NumpyEncoder __pyx_string_tab[201]
#define __pyx_n_u_OTHER_COORDINATE_OPERATION __pyx_string_tab[202]
#define __pyx_n_u_OrderedDict __pyx_string_tab[203]
#define __pyx_n_u_PROJ __pyx_string_tab[204]
#define __pyx_n_u_PROJ_4 __pyx_string_tab[205]
#define __pyx_n_u_PROJ_5 __pyx_string_tab[206]
#define __pyx_n_u_Param __pyx_string_tab[207]
#define __pyx_n_u_Param___reduce_cython __pyx_string_tab[208]
#define __pyx_n_u_Param___setstate_cython __pyx_string_tab[209]
#define __pyx_n_u_PrimeMeridian __pyx_string_tab[210]
#define __pyx_n_u_PrimeMeridian___reduce_cython __pyx_string_tab[211]
#define __pyx_n_u_PrimeMeridian___setstate_cython __pyx_string_tab[212]
#define __pyx_n_u_PrimeMeridian__from_string __pyx_string_tab[213]
#define __pyx_n_u_PrimeMeridian_from_authority __pyx_string_tab[214]
#define __pyx_n_u_PrimeMeridian_from_epsg __pyx_string_tab[215]
#define __pyx_n_u_PrimeMeridian_from_json __pyx_string_tab[216]
#define __pyx_n_u_PrimeMeridian_from_json_dict __pyx_string_tab[217]
#define __pyx_n_u_PrimeMeridian_from_name __pyx_string_tab[218]
#define __pyx_n_u_PrimeMeridian_from_string __pyx_string_tab[219]
#define __pyx_n_u_ProjVersion __pyx_string_tab[220]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[221]
#define __pyx_n_u_TRANSFORMATION __pyx_string_tab[222]
#define __pyx_n_u_Transformation __pyx_string_tab[223]
#define __pyx_n_u_True __pyx_string_tab[224]
#define __pyx_n_u_Unknown __pyx_string_tab[225]
#define __pyx_n_u_VERTICAL_REFERENCE_FRAME __pyx_string_tab[226]
#define __pyx_n_u_WKT1_ESRI __pyx_string_tab[227]
#define __pyx_n_u_WKT1_GDAL __pyx_string_tab[228]
#define __pyx_n_u_WKT2_2015 __pyx_string_tab[229]
#define __pyx_n_u_WKT2_2015_SIMPLIFIED __pyx_string_tab[230]
#define __pyx_n_u_WKT2_2018 __pyx_string_tab[231]
#define __pyx_n_u_WKT2_2018_SIMPLIFIED __pyx_string_tab[232]
#define __pyx_n_u_WKT2_2019 __pyx_string_tab[233]
#define __pyx_n_u_WKT2_2019_SIMPLIFIED __pyx_string_tab[234]
#define __pyx_n_u_WktVersion __pyx_string_tab[235]
#define __pyx_n_u_X __pyx_string_tab[236]
#define __pyx_n_u_Y __pyx_string_tab[237]
#define __pyx_n_u_Z __pyx_string_tab[238]
#define __pyx_n_u_a __pyx_string_tab[239]
#define __pyx_n_u_abbreviation __pyx_string_tab[240]
#define __pyx_n_u_area_of_use __pyx_string_tab[241]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[242]
#define __pyx_n_u_auth_code __pyx_string_tab[243]
#define __pyx_n_u_auth_info __pyx_string_tab[244]
#define __pyx_n_u_auth_name __pyx_string_tab[245]
#define __pyx_n_u_authority __pyx_string_tab[246]
#define __pyx_n_u_authority_list __pyx_string_tab[247]
#define __pyx_n_u_axis __pyx_string_tab[248]
#define __pyx_n_u_axis_info __pyx_string_tab[249]
#define __pyx_n_u_axis_list __pyx_string_tab[250]
#define __pyx_n_u_b __pyx_string_tab[251]
#define __pyx_n_u_b_auth_name __pyx_string_tab[252]
#define __pyx_n_u_b_name __pyx_string_tab[253]
#define __pyx_n_u_b_proj_string __pyx_string_tab[254]
#define __pyx_n_u_c_name __pyx_string_tab[255]
#define __pyx_n_u_c_out_confidence_list __pyx_string_tab[256]
#define __pyx_n_u_cartesian __pyx_string_tab[257]
#define __pyx_n_u_category __pyx_string_tab[258]
#define __pyx_n_u_cf_axis __pyx_string_tab[259]
#define __pyx_n_u_cf_params __pyx_string_tab[260]
#define __pyx_n_u_class_getitem __pyx_string_tab[261]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[262]
#define __pyx_n_u_cls __pyx_string_tab[263]
#define __pyx_n_u_code __pyx_string_tab[264]
#define __pyx_n_u_collections __pyx_string_tab[265]
#define __pyx_n_u_confidence __pyx_string_tab[266]
#define __pyx_n_u_context __pyx_string_tab[267]
#define __pyx_n_u_conversion_factor __pyx_string_tab[268]
#define __pyx_n_u_coord_operation_pj __pyx_string_tab[269]
#define __pyx_n_u_coordinate __pyx_string_tab[270]
#define __pyx_n_u_coordinate_operation_dict __pyx_string_tab[271]
#define __pyx_n_u_coordinate_operation_json_str __pyx_string_tab[272]
#define __pyx_n_u_coordinate_operation_name __pyx_string_tab[273]
#define __pyx_n_u_coordinate_operation_pj __pyx_string_tab[274]
#define __pyx_n_u_coordinate_operation_string __pyx_string_tab[275]
#define __pyx_n_u_coordinate_operation_type __pyx_string_tab[276]
#define __pyx_n_u_coordinate_system __pyx_string_tab[277]
#define __pyx_n_u_coordinate_system_dict __pyx_string_tab[278]
#define __pyx_n_u_coordinate_system_json_str __pyx_string_tab[279]
#define __pyx_n_u_coordinate_system_pj __pyx_string_tab[280]
#define __pyx_n_u_coordinate_system_string __pyx_string_tab[281]
#define __pyx_n_u_create __pyx_string_tab[282]
#define __pyx_n_u_crs_2d __pyx_string_tab[283]
#define __pyx_n_u_crs_3d __pyx_string_tab[284]
#define __pyx_n_u_crs_err __pyx_string_tab[285]
#define __pyx_n_u_datetimetemporal __pyx_string_tab[286]
#define __pyx_n_u_datum_dict __pyx_string_tab[287]
#define __pyx_n_u_datum_json_str __pyx_string_tab[288]
#define __pyx_n_u_datum_name __pyx_string_tab[289]
#define __pyx_n_u_datum_pj __pyx_string_tab[290]
#define __pyx_n_u_datum_string __pyx_string_tab[291]
#define __pyx_n_u_datum_type __pyx_string_tab[292]
#define __pyx_n_u_degrees __pyx_string_tab[293]
#define __pyx_n_u_degrees_2 __pyx_string_tab[294]
#define __pyx_n_u_description __pyx_string_tab[295]
#define __pyx_n_u_dict __pyx_string_tab[296]
#define __pyx_n_u_direction_2 __pyx_string_tab[297]
#define __pyx_n_u_doc __pyx_string_tab[298]
#define __pyx_n_u_dumps __pyx_string_tab[299]
#define __pyx_n_u_east __pyx_string_tab[300]
#define __pyx_n_u_easting __pyx_string_tab[301]
#define __pyx_n_u_ellipsoid_dict __pyx_string_tab[302]
#define __pyx_n_u_ellipsoid_json_str __pyx_string_tab[303]
#define __pyx_n_u_ellipsoid_name __pyx_string_tab[304]
#define __pyx_n_u_ellipsoid_params __pyx_string_tab[305]
#define __pyx_n_u_ellipsoid_pj __pyx_string_tab[306]
#define __pyx_n_u_ellipsoid_string __pyx_string_tab[307]
#define __pyx_n_u_ellipsoidal __pyx_string_tab[308]
#define __pyx_n_u_equals __pyx_string_tab[309]
#define __pyx_n_u_equals_2 __pyx_string_tab[310]
#define __pyx_n_u_err __pyx_string_tab[311]
#define __pyx_n_u_first_error __pyx_string_tab[312]
#define __pyx_n_u_from_authority __pyx_string_tab[313]
#define __pyx_n_u_from_authority_2 __pyx_string_tab[314]
#define __pyx_n_u_from_epsg __pyx_string_tab[315]
#define __pyx_n_u_from_json __pyx_string_tab[316]
#define __pyx_n_u_from_json_dict __pyx_string_tab[317]
#define __pyx_n_u_from_name __pyx_string_tab[318]
#define __pyx_n_u_from_name_2 __pyx_string_tab[319]
#define __pyx_n_u_from_string __pyx_string_tab[320]
#define __pyx_n_u_from_string_2 __pyx_string_tab[321]
#define __pyx_n_u_from_user_input __pyx_string_tab[322]
#define __pyx_n_u_func __pyx_string_tab[323]
#define __pyx_n_u_get __pyx_string_tab[324]
#define __pyx_n_u_get_context_manager __pyx_string_tab[325]
#define __pyx_n_u_get_linear_unit __pyx_string_tab[326]
#define __pyx_n_u_get_non_deprecated __pyx_string_tab[327]
#define __pyx_n_u_getstate __pyx_string_tab[328]
#define __pyx_n_u_grid __pyx_string_tab[329]
#define __pyx_n_u_height_above_reference_ellipsoid __pyx_string_tab[330]
#define __pyx_n_u_ignore_axis_order __pyx_string_tab[331]
#define __pyx_n_u_iii __pyx_string_tab[332]
#define __pyx_n_u_in_proj_json __pyx_string_tab[333]
#define __pyx_n_u_indentation __pyx_string_tab[334]
#define __pyx_n_u_indentation_width __pyx_string_tab[335]
#define __pyx_n_u_inverse_flattening __pyx_string_tab[336]
#define __pyx_n_u_is_bound __pyx_string_tab[337]
#define __pyx_n_u_is_compound __pyx_string_tab[338]
#define __pyx_n_u_is_coroutine __pyx_string_tab[339]
#define __pyx_n_u_is_crs_property __pyx_string_tab[340]
#define __pyx_n_u_is_derived __pyx_string_tab[341]
#define __pyx_n_u_is_equivalent __pyx_string_tab[342]
#define __pyx_n_u_is_exact_same __pyx_string_tab[343]
#define __pyx_n_u_is_exact_same_2 __pyx_string_tab[344]
#define __pyx_n_u_is_geocentric __pyx_string_tab[345]
#define __pyx_n_u_is_geographic __pyx_string_tab[346]
#define __pyx_n_u_is_proj __pyx_string_tab[347]
#define __pyx_n_u_is_projected __pyx_string_tab[348]
#define __pyx_n_u_is_property __pyx_string_tab[349]
#define __pyx_n_u_is_vertical __pyx_string_tab[350]
#define __pyx_n_u_is_wkt __pyx_string_tab[351]
#define __pyx_n_u_items __pyx_string_tab[352]
#define __pyx_n_u_json __pyx_string_tab[353]
#define __pyx_n_u_latitude __pyx_string_tab[354]
#define __pyx_n_u_list_authority __pyx_string_tab[355]
#define __pyx_n_u_load_proj_json __pyx_string_tab[356]
#define __pyx_n_u_loads __pyx_string_tab[357]
#define __pyx_n_u_long_name __pyx_string_tab[358]
#define __pyx_n_u_longitude __pyx_string_tab[359]
#define __pyx_n_u_lower __pyx_string_tab[360]
#define __pyx_n_u_main __pyx_string_tab[361]
#define __pyx_n_u_min_confidence __pyx_string_tab[362]
#define __pyx_n_u_module __pyx_string_tab[363]
#define __pyx_n_u_multiline __pyx_string_tab[364]
#define __pyx_n_u_name __pyx_string_tab[365]
#define __pyx_n_u_name_2 __pyx_string_tab[366]
#define __pyx_n_u_namedtuple __pyx_string_tab[367]
#define __pyx_n_u_nan __pyx_string_tab[368]
#define __pyx_n_u_non_deprecated __pyx_string_tab[369]
#define __pyx_n_u_north __pyx_string_tab[370]
#define __pyx_n_u_num_proj_objects __pyx_string_tab[371]
#define __pyx_n_u_options __pyx_string_tab[372]
#define __pyx_n_u_ordinal __pyx_string_tab[373]
#define __pyx_n_u_other __pyx_string_tab[374]
#define __pyx_n_u_out_auth_name __pyx_string_tab[375]
#define __pyx_n_u_out_confidence_list __pyx_string_tab[376]
#define __pyx_n_u_output_axis_rule __pyx_string_tab[377]
#define __pyx_n_u_parametric __pyx_string_tab[378]
#define __pyx_n_u_params __pyx_string_tab[379]
#define __pyx_n_u_pj_coordinate_operation_type __pyx_string_tab[380]
#define __pyx_n_u_pj_datum_type __pyx_string_tab[381]
#define __pyx_n_u_pj_ellps __pyx_string_tab[382]
#define __pyx_n_u_pop __pyx_string_tab[383]
#define __pyx_n_u_positive __pyx_string_tab[384]
#define __pyx_n_u_prepared __pyx_string_tab[385]
#define __pyx_n_u_pretty __pyx_string_tab[386]
#define __pyx_n_u_prime_meridian_dict __pyx_string_tab[387]
#define __pyx_n_u_prime_meridian_json_str __pyx_string_tab[388]
#define __pyx_n_u_prime_meridian_name __pyx_string_tab[389]
#define __pyx_n_u_prime_meridian_pj __pyx_string_tab[390]
#define __pyx_n_u_prime_meridian_string __pyx_string_tab[391]
#define __pyx_n_u_proj __pyx_string_tab[392]
#define __pyx_n_u_proj_json_string __pyx_string_tab[393]
#define __pyx_n_u_proj_list __pyx_string_tab[394]
#define __pyx_n_u_proj_string __pyx_string_tab[395]
#define __pyx_n_u_projection __pyx_string_tab[396]
#define __pyx_n_u_projobj __pyx_string_tab[397]
#define __pyx_n_u_property_name __pyx_string_tab[398]
#define __pyx_n_u_property_types __pyx_string_tab[399]
#define __pyx_n_u_pyproj__context __pyx_string_tab[400]
#define __pyx_n_u_pyproj__crs __pyx_string_tab[401]
#define __pyx_n_u_pyproj_aoi __pyx_string_tab[402]
#define __pyx_n_u_pyproj_crs_datum __pyx_string_tab[403]
#define __pyx_n_u_pyproj_crs_enums __pyx_string_tab[404]
#define __pyx_n_u_pyproj_enums __pyx_string_tab[405]
#define __pyx_n_u_pyproj_exceptions __pyx_string_tab[406]
#define __pyx_n_u_pyproj_geod __pyx_string_tab[407]
#define __pyx_n_u_pyproj_utils __pyx_string_tab[408]
#define __pyx_n_u_pyx_capi __pyx_string_tab[409]
#define __pyx_n_u_pyx_state __pyx_string_tab[410]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[411]
#define __pyx_n_u_qualname __pyx_string_tab[412]
#define __pyx_n_u_re __pyx_string_tab[413]
#define __pyx_n_u_reduce __pyx_string_tab[414]
#define __pyx_n_u_reduce_cython __pyx_string_tab[415]
#define __pyx_n_u_reduce_ex __pyx_string_tab[416]
#define __pyx_n_u_rf __pyx_string_tab[417]
#define __pyx_n_u_rotated_pole __pyx_string_tab[418]
#define __pyx_n_u_self __pyx_string_tab[419]
#define __pyx_n_u_semi_major_axis __pyx_string_tab[420]
#define __pyx_n_u_semi_minor_axis __pyx_string_tab[421]
#define __pyx_n_u_set_name __pyx_string_tab[422]
#define __pyx_n_u_setdefault __pyx_string_tab[423]
#define __pyx_n_u_setstate __pyx_string_tab[424]
#define __pyx_n_u_setstate_cython __pyx_string_tab[425]
#define __pyx_n_u_source_crs __pyx_string_tab[426]
#define __pyx_n_u_south __pyx_string_tab[427]
#define __pyx_n_u_spherical __pyx_string_tab[428]
#define __pyx_n_u_standard_name __pyx_string_tab[429]
#define __pyx_n_u_staticmethod __pyx_string_tab[430]
#define __pyx_n_u_sub_crs __pyx_string_tab[431]
#define __pyx_n_u_sub_crs_index __pyx_string_tab[432]
#define __pyx_n_u_sub_crs_list __pyx_string_tab[433]
#define __pyx_n_u_temporalcount __pyx_string_tab[434]
#define __pyx_n_u_temporalmeasure __pyx_string_tab[435]
#define __pyx_n_u_test __pyx_string_tab[436]
#define __pyx_n_u_to_2d __pyx_string_tab[437]
#define __pyx_n_u_to_3d __pyx_string_tab[438]
#define __pyx_n_u_to_authority __pyx_string_tab[439]
#define __pyx_n_u_to_cf __pyx_string_tab[440]
#define __pyx_n_u_to_cf_locals_get_linear_unit __pyx_string_tab[441]
#define __pyx_n_u_to_epsg __pyx_string_tab[442]
#define __pyx_n_u_to_json __pyx_string_tab[443]
#define __pyx_n_u_to_json_dict __pyx_string_tab[444]
#define __pyx_n_u_to_proj4 __pyx_string_tab[445]
#define __pyx_n_u_to_wkt __pyx_string_tab[446]
#define __pyx_n_u_undefined __pyx_string_tab[447]
#define __pyx_n_u_unit __pyx_string_tab[448]
#define __pyx_n_u_units __pyx_string_tab[449]
#define __pyx_n_u_unknown __pyx_string_tab[450]
#define __pyx_n_u_upper __pyx_string_tab[451]
#define __pyx_n_u_use_proj_alternative_grid_names __pyx_string_tab[452]
#define __pyx_n_u_user_auth_name __pyx_string_tab[453]
#define __pyx_n_u_user_input __pyx_string_tab[454]
#define __pyx_n_u_value_2 __pyx_string_tab[455]
#define __pyx_n_u_values __pyx_string_tab[456]
#define __pyx_n_u_version __pyx_string_tab[457]
#define __pyx_n_u_vertical __pyx_string_tab[458]
#define __pyx_n_u_warn __pyx_string_tab[459]
#define __pyx_n_u_warnings __pyx_string_tab[460]
#define __pyx_n_u_west __pyx_string_tab[461]
#define __pyx_kp_b_MULTILINE_NO __pyx_string_tab[462]
#define __pyx_kp_b_MULTILINE_YES __pyx_string_tab[463]
#define __pyx_kp_b_OUTPUT_AXIS_AUTO __pyx_string_tab[464]
#define __pyx_kp_b_OUTPUT_AXIS_NO __pyx_string_tab[465]
#define __pyx_kp_b_OUTPUT_AXIS_YES __pyx_string_tab[466]
#define __pyx_kp_b_PJ_CONTEXT_void_void_int___pyx_s __pyx_string_tab[467]
#define __pyx_kp_b_PyObject_PJ_CONTEXT_PJ_PyObject __pyx_string_tab[468]
#define __pyx_kp_b_PyObject_PyObject_int___pyx_skip __pyx_string_tab[469]
#define __pyx_kp_b_iso88591_3H_y_Zt_MQ __pyx_string_tab[470]
#define __pyx_kp_b_iso88591_4vQm4t3a __pyx_string_tab[471]
#define __pyx_kp_b_iso88591_9_A_1_Ja_1Kq_q_Q_q_Q_q_Q_A_z __pyx_string_tab[472]
#define __pyx_kp_b_iso88591_A2_1_8_Ja_Q_9Cq_1_G1IQ __pyx_string_tab[473]
#define __pyx_kp_b_iso88591_AGH_F __pyx_string_tab[474]
#define __pyx_kp_b_iso88591_AIJ0_4q_d_q_wa_gQg_gQiq_m1_gS_q __pyx_string_tab[475]
#define __pyx_kp_b_iso88591_A_1A __pyx_string_tab[476]
#define __pyx_kp_b_iso88591_A_1_1_A_A_Q_t_1 __pyx_string_tab[477]
#define __pyx_kp_b_iso88591_A_1_a_t1 __pyx_string_tab[478]
#define __pyx_kp_b_iso88591_A_2_c_a_5_1_1_1_3a_a_YgQa_uKq_q __pyx_string_tab[479]
#define __pyx_kp_b_iso88591_A_4z_1_t_1 __pyx_string_tab[480]
#define __pyx_kp_b_iso88591_A_5_F_5_F __pyx_string_tab[481]
#define __pyx_kp_b_iso88591_A_5_Qa_1_uJaq_a __pyx_string_tab[482]
#define __pyx_kp_b_iso88591_A_8_1_5Qa_q __pyx_string_tab[483]
#define __pyx_kp_b_iso88591_A_8_1_aq_5_1_Q_way __pyx_string_tab[484]
#define __pyx_kp_b_iso88591_A_8_1_aq_5_s_Q_q __pyx_string_tab[485]
#define __pyx_kp_b_iso88591_A_8_5Q_aq_as_1_9Cq_9_Qa_G1IQ __pyx_string_tab[486]
#define __pyx_kp_b_iso88591_A_8_9_aq_as_1_1_9_Qa_q __pyx_string_tab[487]
#define __pyx_kp_b_iso88591_A_8_Kq_aq_S_Q_WA_4A_G1IQ __pyx_string_tab[488]
#define __pyx_kp_b_iso88591_A_8_Zq_S_0_G1IQ __pyx_string_tab[489]
#define __pyx_kp_b_iso88591_A_8_a_aq_as_1_S_9_Qa_G1IQ __pyx_string_tab[490]
#define __pyx_kp_b_iso88591_A_8_aq_c_a_S_2_G1IQ __pyx_string_tab[491]
#define __pyx_kp_b_iso88591_A_8_k_aq_s_q_a_1 __pyx_string_tab[492]
#define __pyx_kp_b_iso88591_A_8_q_aq_as_1_c_9_Qa_1 __pyx_string_tab[493]
#define __pyx_kp_b_iso88591_A_9Kq_q_z_xq_a_7q_6a_a_AQ_D_t1A __pyx_string_tab[494]
#define __pyx_kp_b_iso88591_A_9M_1_y_1_a __pyx_string_tab[495]
#define __pyx_kp_b_iso88591_A_B_2_H_7_1_8_Q_Q_3a_1 __pyx_string_tab[496]
#define __pyx_kp_b_iso88591_A_M_a_D __pyx_string_tab[497]
#define __pyx_kp_b_iso88591_A_O1HA __pyx_string_tab[498]
#define __pyx_kp_b_iso88591_A_O1O1A __pyx_string_tab[499]
#define __pyx_kp_b_iso88591_A_Q_j_Z7Gs __pyx_string_tab[500]
#define __pyx_kp_b_iso88591_A_Q_j_Z7K3a __pyx_string_tab[501]
#define __pyx_kp_b_iso88591_A_Qa_1_Jaq_a __pyx_string_tab[502]
#define __pyx_kp_b_iso88591_A_Ql_s_aq_q_A_s_q_E_WAU_s_AQ_a_F __pyx_string_tab[503]
#define __pyx_kp_b_iso88591_A_a_1A __pyx_string_tab[504]
#define __pyx_kp_b_iso88591_A_a_A_1_S_2_1_uAQ_AT_a_gQd_7_a_A __pyx_string_tab[505]
#define __pyx_kp_b_iso88591_A_m1A_1_AQ_a __pyx_string_tab[506]
#define __pyx_kp_b_iso88591_A_q_a_2_a __pyx_string_tab[507]
#define __pyx_kp_b_iso88591_A_t6_ha __pyx_string_tab[508]
#define __pyx_kp_b_iso88591_A_uM_fA_Q __pyx_string_tab[509]
#define __pyx_kp_b_iso88591_A_uO1HA __pyx_string_tab[510]
#define __pyx_kp_b_iso88591_A_uO1O1A __pyx_string_tab[511]
#define __pyx_kp_b_iso88591_A_y_Qd_1A_Q __pyx_string_tab[512]
#define __pyx_kp_b_iso88591_A_y_q __pyx_string_tab[513]
#define __pyx_kp_b_iso88591_A_y_q_q __pyx_string_tab[514]
#define __pyx_kp_b_iso88591_B_L_O1__A_a_9L_1 __pyx_string_tab[515]
#define __pyx_kp_b_iso88591_DAN_a_Q_A_q_WA_AQ_Q_a_Q_A_A_z_A __pyx_string_tab[516]
#define __pyx_kp_b_iso88591_F_D_Q_a_1_WE_Yar_s_Q_3ay_q __pyx_string_tab[517]
#define __pyx_kp_b_iso88591_Q __pyx_string_tab[518]
#define __pyx_kp_b_iso88591_Q_A_5_q_Zq_Q_1_a_83a_1_T_A_q __pyx_string_tab[519]
#define __pyx_kp_b_iso88591_Q_A_5_q_Zq_Q_2_a_83a_1_T_A_q __pyx_string_tab[520]
#define __pyx_kp_b_iso88591_Q_y_Zt_MQ __pyx_string_tab[521]
#define __pyx_kp_b_iso88591_Z_RRS8_wat_T_3CC __pyx_string_tab[522]
#define __pyx_kp_b_iso88591_a_4z_1_t81G_5Q __pyx_string_tab[523]
#define __pyx_kp_b_iso88591_a_D_Rq_A_4vS_4q_vS_1_a_a_d_1_vQ __pyx_string_tab[524]
#define __pyx_kp_b_iso88591_r_awaq_t1A __pyx_string_tab[525]
#define __pyx_kp_b_iso88591_t6_haq __pyx_string_tab[526]
#define __pyx_kp_b_iso88591_z_s __pyx_string_tab[527]
#define __pyx_int_0 __pyx_number_tab[0]
#define __pyx_int_1 __pyx_number_tab[1]
#define __pyx_int_2 __pyx_number_tab[2]
#define __pyx_int_70 __pyx_number_tab[3]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_5array_array);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_Axis);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_Axis);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_Base);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_Base);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs__CRSParts);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs__CRSParts);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_Ellipsoid);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_PrimeMeridian);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_Datum);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_Datum);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_CoordinateSystem);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_CoordinateSystem);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_Param);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_Param);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_Grid);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_Grid);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs_CoordinateOperation);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pyproj_4_crs__CRS);
  Py_CLEAR(clear_module_state->__pyx_type_6pyproj_4_crs__CRS);
  Py_CLEAR(clear_module_state->__pyx_k__7);
  Py_CLEAR(clear_module_state->__pyx_k__10);
  Py_CLEAR(clear_module_state->__pyx_k__11);
  Py_CLEAR(clear_module_state->__pyx_k__12);
  for (int i=0; i<15; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<79; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<528; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<4; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_5array_array);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_Axis);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_Axis);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_Base);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_Base);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs__CRSParts);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs__CRSParts);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_Ellipsoid);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_PrimeMeridian);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_Datum);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_Datum);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_CoordinateSystem);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_CoordinateSystem);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_Param);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_Param);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_Grid);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_Grid);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs_CoordinateOperation);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pyproj_4_crs__CRS);
  Py_VISIT(traverse_module_state->__pyx_type_6pyproj_4_crs__CRS);
  Py_VISIT(traverse_module_state->__pyx_k__7);
  Py_VISIT(traverse_module_state->__pyx_k__10);
  Py_VISIT(traverse_module_state->__pyx_k__11);
  Py_VISIT(traverse_module_state->__pyx_k__12);
  for (int i=0; i<15; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<79; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<528; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<4; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "cpython/complex.pxd":20
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self) {
  double __pyx_r;

  /* "cpython/complex.pxd":23
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
 *             return self.cval.real             # <<<<<<<<<<<<<<
 * 
 *         # unavailable in limited API
*/
  __pyx_r = __pyx_v_self->cval.real;
  goto __pyx_L0;

  /* "cpython/complex.pxd":20
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/complex.pxd":26
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self) {
  double __pyx_r;

  /* "cpython/complex.pxd":29
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
 *             return self.cval.imag             # <<<<<<<<<<<<<<
 * 
 *     # PyTypeObject PyComplex_Type
*/
  __pyx_r = __pyx_v_self->cval.imag;
  goto __pyx_L0;

  /* "cpython/complex.pxd":26
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/contextvars.pxd":115
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value *__pyx_optional_args) {

  /* "cpython/contextvars.pxd":116
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
*/
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value;
  PyObject *__pyx_v_pyvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }

  /* "cpython/contextvars.pxd":121
 *     or None if no such value or default was found.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:
*/
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":122
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)             # <<<<<<<<<<<<<<
 *     if value is NULL:
 *         # context variable does not have a default
*/
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, NULL, (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(1, 122, __pyx_L1_error)

  /* "cpython/contextvars.pxd":123
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
*/
  __pyx_t_2 = (__pyx_v_value == NULL);
  if (__pyx_t_2) {

    /* "cpython/contextvars.pxd":125
 *     if value is NULL:
 *         # context variable does not have a default
 *         pyvalue = default_value             # <<<<<<<<<<<<<<
 *     else:
 *         # value or default value of context variable
*/
    __Pyx_INCREF(__pyx_v_default_value);
    __pyx_v_pyvalue = __pyx_v_default_value;

    /* "cpython/contextvars.pxd":123
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
*/
    goto __pyx_L3;
  }

  /* "cpython/contextvars.pxd":128
 *     else:
 *         # value or default value of context variable
 *         pyvalue = <object>value             # <<<<<<<<<<<<<<
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_value);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_pyvalue = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cpython/contextvars.pxd":129
 *         # value or default value of context variable
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
 * 
*/
    Py_XDECREF(__pyx_v_value);
  }
  __pyx_L3:;

  /* "cpython/contextvars.pxd":130
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyvalue);
  __pyx_r = __pyx_v_pyvalue;
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":115
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.contextvars.get_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/contextvars.pxd":133
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value_no_default(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value_no_default(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default *__pyx_optional_args) {

  /* "cpython/contextvars.pxd":134
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
*/
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value;
  PyObject *__pyx_v_pyvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value_no_default", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }

  /* "cpython/contextvars.pxd":140
 *     Ignores the default value of the context variable, if any.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
*/
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":141
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)             # <<<<<<<<<<<<<<
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
*/
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, ((PyObject *)__pyx_v_default_value), (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(1, 141, __pyx_L1_error)

  /* "cpython/contextvars.pxd":143
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value             # <<<<<<<<<<<<<<
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_value);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_pyvalue = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cpython/contextvars.pxd":144
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
*/
  Py_XDECREF(__pyx_v_value);

  /* "cpython/contextvars.pxd":145
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyvalue);
  __pyx_r = __pyx_v_pyvalue;
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":133
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value_no_default(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.contextvars.get_value_no_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "array.pxd":103
 *             arraydescr* ob_descr    # struct arraydescr *ob_descr;
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline __data_union data(self) nogil:
 *             return __Pyx_PyArray_Data(self)
*/

static CYTHON_INLINE __Pyx_data_union __pyx_f_7cpython_5array_5array_4data_data(arrayobject *__pyx_v_self) {
  __Pyx_data_union __pyx_r;

  /* "array.pxd":105
 *         @property
 *         cdef inline __data_union data(self) nogil:
 *             return __Pyx_PyArray_Data(self)             # <<<<<<<<<<<<<<
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):
*/
  __pyx_r = __Pyx_PyArray_Data(__pyx_v_self);
  goto __pyx_L0;

  /* "array.pxd":103
 *             arraydescr* ob_descr    # struct arraydescr *ob_descr;
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline __data_union data(self) nogil:
 *             return __Pyx_PyArray_Data(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "array.pxd":107
 *             return __Pyx_PyArray_Data(self)
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
*/

/* Python wrapper */
CYTHON_UNUSED static int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_pw_7cpython_5array_5array_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_7cpython_5array_5array___getbuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_7cpython_5array_5array___getbuffer__(arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info, CYTHON_UNUSED int __pyx_v_flags) {
  PyObject *__pyx_v_item_count = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_data_union __pyx_t_2;
  char *__pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  char __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "array.pxd":112
 *             # In particular strided access is always provided regardless
 *             # of flags
 *             item_count = Py_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *             info.suboffsets = NULL
*/
  __pyx_t_1 = PyLong_FromSsize_t(Py_SIZE(((PyObject *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_item_count = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "array.pxd":114
 *             item_count = Py_SIZE(self)
 * 
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
*/
  __pyx_v_info->suboffsets = NULL;

  /* "array.pxd":115
 * 
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars             # <<<<<<<<<<<<<<
 *             info.readonly = 0
 *             info.ndim = 1
*/
  __pyx_t_2 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 115, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_2.as_chars;
  __pyx_v_info->buf = __pyx_t_3;

  /* "array.pxd":116
 *             info.suboffsets = NULL
 *             info.buf = self.data.as_chars
 *             info.readonly = 0             # <<<<<<<<<<<<<<
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
*/
  __pyx_v_info->readonly = 0;

  /* "array.pxd":117
 *             info.buf = self.data.as_chars
 *             info.readonly = 0
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 *             info.len = info.itemsize * item_count
*/
  __pyx_v_info->ndim = 1;

  /* "array.pxd":118
 *             info.readonly = 0
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)             # <<<<<<<<<<<<<<
 *             info.len = info.itemsize * item_count
 * 
*/
  __pyx_t_4 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_info->itemsize = __pyx_t_4;

  /* "array.pxd":119
 *             info.ndim = 1
 *             info.itemsize = self.ob_descr.itemsize   # e.g. sizeof(float)
 *             info.len = info.itemsize * item_count             # <<<<<<<<<<<<<<
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
*/
  __pyx_t_1 = PyLong_FromSsize_t(__pyx_v_info->itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyNumber_Multiply(__pyx_t_1, __pyx_v_item_count); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_info->len = __pyx_t_6;

  /* "array.pxd":121
 *             info.len = info.itemsize * item_count
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)             # <<<<<<<<<<<<<<
 *             if not info.shape:
 *                 raise MemoryError()
*/
  __pyx_v_info->shape = ((Py_ssize_t *)PyObject_Malloc(((sizeof(Py_ssize_t)) + 2)));

  /* "array.pxd":122
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
*/
  __pyx_t_7 = (!(__pyx_v_info->shape != 0));
  if (unlikely(__pyx_t_7)) {

    /* "array.pxd":123
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:
 *                 raise MemoryError()             # <<<<<<<<<<<<<<
 *             info.shape[0] = item_count      # constant regardless of resizing
 *             info.strides = &info.itemsize
*/
    PyErr_NoMemory(); __PYX_ERR(2, 123, __pyx_L1_error)

    /* "array.pxd":122
 * 
 *             info.shape = <Py_ssize_t*> PyObject_Malloc(sizeof(Py_ssize_t) + 2)
 *             if not info.shape:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
*/
  }

  /* "array.pxd":124
 *             if not info.shape:
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing             # <<<<<<<<<<<<<<
 *             info.strides = &info.itemsize
 * 
*/
  __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_v_item_count); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 124, __pyx_L1_error)
  (__pyx_v_info->shape[0]) = __pyx_t_6;

  /* "array.pxd":125
 *                 raise MemoryError()
 *             info.shape[0] = item_count      # constant regardless of resizing
 *             info.strides = &info.itemsize             # <<<<<<<<<<<<<<
 * 
 *             info.format = <char*> (info.shape + 1)
*/
  __pyx_v_info->strides = (&__pyx_v_info->itemsize);

  /* "array.pxd":127
 *             info.strides = &info.itemsize
 * 
 *             info.format = <char*> (info.shape + 1)             # <<<<<<<<<<<<<<
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
*/
  __pyx_v_info->format = ((char *)(__pyx_v_info->shape + 1));

  /* "array.pxd":128
 * 
 *             info.format = <char*> (info.shape + 1)
 *             info.format[0] = self.ob_descr.typecode             # <<<<<<<<<<<<<<
 *             info.format[1] = 0
 *             info.obj = self
*/
  __pyx_t_8 = __pyx_v_self->ob_descr->typecode;
  (__pyx_v_info->format[0]) = __pyx_t_8;

  /* "array.pxd":129
 *             info.format = <char*> (info.shape + 1)
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0             # <<<<<<<<<<<<<<
 *             info.obj = self
 * 
*/
  (__pyx_v_info->format[1]) = 0;

  /* "array.pxd":130
 *             info.format[0] = self.ob_descr.typecode
 *             info.format[1] = 0
 *             info.obj = self             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(self, Py_buffer* info):
*/
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "array.pxd":107
 *             return __Pyx_PyArray_Data(self)
 * 
 *         def __getbuffer__(self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("cpython.array.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_item_count);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":132
 *             info.obj = self
 * 
 *         def __releasebuffer__(self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             PyObject_Free(info.shape)
 * 
*/

/* Python wrapper */
CYTHON_UNUSED static void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
CYTHON_UNUSED static void __pyx_pw_7cpython_5array_5array_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_7cpython_5array_5array_2__releasebuffer__(((arrayobject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_7cpython_5array_5array_2__releasebuffer__(CYTHON_UNUSED arrayobject *__pyx_v_self, Py_buffer *__pyx_v_info) {

  /* "array.pxd":133
 * 
 *         def __releasebuffer__(self, Py_buffer* info):
 *             PyObject_Free(info.shape)             # <<<<<<<<<<<<<<
 * 
 *     array newarrayobject(PyTypeObject* type, Py_ssize_t size, arraydescr *descr)
*/
  PyObject_Free(__pyx_v_info->shape);

  /* "array.pxd":132
 *             info.obj = self
 * 
 *         def __releasebuffer__(self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             PyObject_Free(info.shape)
 * 
*/

  /* function exit code */
}

/* "array.pxd":145
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
*/

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_clone(arrayobject *__pyx_v_template, Py_ssize_t __pyx_v_length, int __pyx_v_zero) {
  arrayobject *__pyx_v_op = 0;
  arrayobject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_data_union __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("clone", 0);

  /* "array.pxd":149
 *     type will be same as template.
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)             # <<<<<<<<<<<<<<
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
*/
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_template)), __pyx_v_length, __pyx_v_template->ob_descr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "array.pxd":150
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
*/
  if (__pyx_v_zero) {
  } else {
    __pyx_t_2 = __pyx_v_zero;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (((PyObject *)__pyx_v_op) != Py_None);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "array.pxd":151
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
*/
    __pyx_t_4 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_op); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 151, __pyx_L1_error)
    (void)(memset(__pyx_t_4.as_chars, 0, (__pyx_v_length * __pyx_v_op->ob_descr->itemsize)));

    /* "array.pxd":150
 *     if zero is true, new array will be initialized with zeroes."""
 *     cdef array op = newarrayobject(Py_TYPE(template), length, template.ob_descr)
 *     if zero and op is not None:             # <<<<<<<<<<<<<<
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op
*/
  }

  /* "array.pxd":152
 *     if zero and op is not None:
 *         memset(op.data.as_chars, 0, length * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline array copy(array self):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_op);
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "array.pxd":145
 * 
 * 
 * cdef inline array clone(array template, Py_ssize_t length, bint zero):             # <<<<<<<<<<<<<<
 *     """ fast creation of a new array, given a template array.
 *     type will be same as template.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.clone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":154
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
*/

static CYTHON_INLINE arrayobject *__pyx_f_7cpython_5array_copy(arrayobject *__pyx_v_self) {
  arrayobject *__pyx_v_op = 0;
  arrayobject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_data_union __pyx_t_2;
  __Pyx_data_union __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 0);

  /* "array.pxd":156
 * cdef inline array copy(array self):
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)             # <<<<<<<<<<<<<<
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op
*/
  __pyx_t_1 = ((PyObject *)newarrayobject(Py_TYPE(((PyObject *)__pyx_v_self)), Py_SIZE(((PyObject *)__pyx_v_self)), __pyx_v_self->ob_descr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_op = ((arrayobject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "array.pxd":157
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)             # <<<<<<<<<<<<<<
 *     return op
 * 
*/
  __pyx_t_2 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_op); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 157, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 157, __pyx_L1_error)
  (void)(memcpy(__pyx_t_2.as_chars, __pyx_t_3.as_chars, (Py_SIZE(((PyObject *)__pyx_v_op)) * __pyx_v_op->ob_descr->itemsize)));

  /* "array.pxd":158
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
 *     memcpy(op.data.as_chars, self.data.as_chars, Py_SIZE(op) * op.ob_descr.itemsize)
 *     return op             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_op);
  __pyx_r = __pyx_v_op;
  goto __pyx_L0;

  /* "array.pxd":154
 *     return op
 * 
 * cdef inline array copy(array self):             # <<<<<<<<<<<<<<
 *     """ make a copy of an array. """
 *     cdef array op = newarrayobject(Py_TYPE(self), Py_SIZE(self), self.ob_descr)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.array.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_op);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "array.pxd":160
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
*/

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend_buffer(arrayobject *__pyx_v_self, char *__pyx_v_stuff, Py_ssize_t __pyx_v_n) {
  Py_ssize_t __pyx_v_itemsize;
  Py_ssize_t __pyx_v_origsize;
  int __pyx_r;
  int __pyx_t_1;
  __Pyx_data_union __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "array.pxd":164
 *     (e.g. of same array type)
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)
*/
  __pyx_t_1 = __pyx_v_self->ob_descr->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "array.pxd":165
 *     n: number of elements (not number of bytes!) """
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t origsize = Py_SIZE(self)             # <<<<<<<<<<<<<<
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
*/
  __pyx_v_origsize = Py_SIZE(((PyObject *)__pyx_v_self));

  /* "array.pxd":166
 *     cdef Py_ssize_t itemsize = self.ob_descr.itemsize
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)             # <<<<<<<<<<<<<<
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 *     return 0
*/
  __pyx_t_1 = resize_smart(__pyx_v_self, (__pyx_v_origsize + __pyx_v_n)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 166, __pyx_L1_error)

  /* "array.pxd":167
 *     cdef Py_ssize_t origsize = Py_SIZE(self)
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)             # <<<<<<<<<<<<<<
 *     return 0
 * 
*/
  __pyx_t_2 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 167, __pyx_L1_error)
  (void)(memcpy((__pyx_t_2.as_chars + (__pyx_v_origsize * __pyx_v_itemsize)), __pyx_v_stuff, (__pyx_v_n * __pyx_v_itemsize)));

  /* "array.pxd":168
 *     resize_smart(self, origsize + n)
 *     memcpy(self.data.as_chars + origsize * itemsize, stuff, n * itemsize)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * cdef inline int extend(array self, array other) except -1:
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "array.pxd":160
 *     return op
 * 
 * cdef inline int extend_buffer(array self, char* stuff, Py_ssize_t n) except -1:             # <<<<<<<<<<<<<<
 *     """ efficient appending of new stuff of same type
 *     (e.g. of same array type)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cpython.array.extend_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "array.pxd":170
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
*/

static CYTHON_INLINE int __pyx_f_7cpython_5array_extend(arrayobject *__pyx_v_self, arrayobject *__pyx_v_other) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_data_union __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "array.pxd":172
 * cdef inline int extend(array self, array other) except -1:
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
*/
  __pyx_t_1 = (__pyx_v_self->ob_descr->typecode != __pyx_v_other->ob_descr->typecode);
  if (__pyx_t_1) {

    /* "array.pxd":173
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 *         PyErr_BadArgument()             # <<<<<<<<<<<<<<
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
*/
    __pyx_t_2 = PyErr_BadArgument(); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(2, 173, __pyx_L1_error)

    /* "array.pxd":172
 * cdef inline int extend(array self, array other) except -1:
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:             # <<<<<<<<<<<<<<
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
*/
  }

  /* "array.pxd":174
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
 *         PyErr_BadArgument()
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))             # <<<<<<<<<<<<<<
 * 
 * cdef inline void zero(array self) noexcept:
*/
  __pyx_t_3 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_other); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 174, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_7cpython_5array_extend_buffer(__pyx_v_self, __pyx_t_3.as_chars, Py_SIZE(((PyObject *)__pyx_v_other))); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 174, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "array.pxd":170
 *     return 0
 * 
 * cdef inline int extend(array self, array other) except -1:             # <<<<<<<<<<<<<<
 *     """ extend array with data from another array; types must match. """
 *     if self.ob_descr.typecode != other.ob_descr.typecode:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("cpython.array.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "array.pxd":176
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self) noexcept:             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
*/

static CYTHON_INLINE void __pyx_f_7cpython_5array_zero(arrayobject *__pyx_v_self) {
  __Pyx_data_union __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "array.pxd":178
 * cdef inline void zero(array self) noexcept:
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_f_7cpython_5array_5array_4data_data(__pyx_v_self); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 178, __pyx_L1_error)
  (void)(memset(__pyx_t_1.as_chars, 0, (Py_SIZE(((PyObject *)__pyx_v_self)) * __pyx_v_self->ob_descr->itemsize)));

  /* "array.pxd":176
 *     return extend_buffer(self, other.data.as_chars, Py_SIZE(other))
 * 
 * cdef inline void zero(array self) noexcept:             # <<<<<<<<<<<<<<
 *     """ set all elements of array to zero. """
 *     memset(self.data.as_chars, 0, Py_SIZE(self) * self.ob_descr.itemsize)
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("cpython.array.zero", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
}

/* "pyproj/_crs.pyx":26
 * 
 * 
 * cdef str decode_or_undefined(const char* instring):             # <<<<<<<<<<<<<<
 *     pystr = cstrdecode(instring)
 *     if pystr is None:
*/

static PyObject *__pyx_f_6pyproj_4_crs_decode_or_undefined(char const *__pyx_v_instring) {
  PyObject *__pyx_v_pystr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("decode_or_undefined", 0);

  /* "pyproj/_crs.pyx":27
 * 
 * cdef str decode_or_undefined(const char* instring):
 *     pystr = cstrdecode(instring)             # <<<<<<<<<<<<<<
 *     if pystr is None:
 *         return "undefined"
*/
  __pyx_t_1 = __pyx_f_6pyproj_7_compat_cstrdecode(__pyx_v_instring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pystr = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":28
 * cdef str decode_or_undefined(const char* instring):
 *     pystr = cstrdecode(instring)
 *     if pystr is None:             # <<<<<<<<<<<<<<
 *         return "undefined"
 *     return pystr
*/
  __pyx_t_2 = (__pyx_v_pystr == ((PyObject*)Py_None));
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":29
 *     pystr = cstrdecode(instring)
 *     if pystr is None:
 *         return "undefined"             # <<<<<<<<<<<<<<
 *     return pystr
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
    __pyx_r = __pyx_mstate_global->__pyx_n_u_undefined;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":28
 * cdef str decode_or_undefined(const char* instring):
 *     pystr = cstrdecode(instring)
 *     if pystr is None:             # <<<<<<<<<<<<<<
 *         return "undefined"
 *     return pystr
*/
  }

  /* "pyproj/_crs.pyx":30
 *     if pystr is None:
 *         return "undefined"
 *     return pystr             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pystr);
  __pyx_r = __pyx_v_pystr;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":26
 * 
 * 
 * cdef str decode_or_undefined(const char* instring):             # <<<<<<<<<<<<<<
 *     pystr = cstrdecode(instring)
 *     if pystr is None:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.decode_or_undefined", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pystr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":33
 * 
 * 
 * def is_wkt(str proj_string not None):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_1is_wkt(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_is_wkt, "is_wkt(str proj_string)\n\n.. versionadded:: 2.0.0\n\nCheck if the input projection string is in the Well-Known Text format.\n\nParameters\n----------\nproj_string: str\n    The projection string.\n\nReturns\n-------\nbool: True if the string is in the Well-Known Text format");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_1is_wkt = {"is_wkt", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_1is_wkt, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_is_wkt};
static PyObject *__pyx_pw_6pyproj_4_crs_1is_wkt(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_proj_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_wkt (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_proj_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 33, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 33, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "is_wkt", 0) < (0)) __PYX_ERR(0, 33, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("is_wkt", 1, 1, 1, i); __PYX_ERR(0, 33, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 33, __pyx_L3_error)
    }
    __pyx_v_proj_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_wkt", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 33, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.is_wkt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_proj_string), (&PyUnicode_Type), 0, "proj_string", 1))) __PYX_ERR(0, 33, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_is_wkt(__pyx_self, __pyx_v_proj_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_is_wkt(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_proj_string) {
  PyObject *__pyx_v_b_proj_string = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char const *__pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_wkt", 0);

  /* "pyproj/_crs.pyx":48
 *     bool: True if the string is in the Well-Known Text format
 *     """
 *     cdef bytes b_proj_string = cstrencode(proj_string)             # <<<<<<<<<<<<<<
 *     return proj_context_guess_wkt_dialect(NULL, b_proj_string) != PJ_GUESSED_NOT_WKT
 * 
*/
  __pyx_t_1 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_proj_string, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_b_proj_string = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":49
 *     """
 *     cdef bytes b_proj_string = cstrencode(proj_string)
 *     return proj_context_guess_wkt_dialect(NULL, b_proj_string) != PJ_GUESSED_NOT_WKT             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_b_proj_string == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 49, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyBytes_AsString(__pyx_v_b_proj_string); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(0, 49, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyBool_FromLong((proj_context_guess_wkt_dialect(NULL, __pyx_t_2) != PJ_GUESSED_NOT_WKT)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":33
 * 
 * 
 * def is_wkt(str proj_string not None):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.is_wkt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_b_proj_string);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":52
 * 
 * 
 * def is_proj(str proj_string not None):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.2
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_3is_proj(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_2is_proj, "is_proj(str proj_string)\n\n.. versionadded:: 2.2.2\n\nCheck if the input projection string is in the PROJ format.\n\nParameters\n----------\nproj_string: str\n    The projection string.\n\nReturns\n-------\nbool: True if the string is in the PROJ format");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_3is_proj = {"is_proj", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_3is_proj, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_2is_proj};
static PyObject *__pyx_pw_6pyproj_4_crs_3is_proj(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_proj_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_proj (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_proj_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 52, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 52, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "is_proj", 0) < (0)) __PYX_ERR(0, 52, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("is_proj", 1, 1, 1, i); __PYX_ERR(0, 52, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 52, __pyx_L3_error)
    }
    __pyx_v_proj_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_proj", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 52, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.is_proj", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_proj_string), (&PyUnicode_Type), 0, "proj_string", 1))) __PYX_ERR(0, 52, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_2is_proj(__pyx_self, __pyx_v_proj_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_2is_proj(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_proj_string) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_proj", 0);

  /* "pyproj/_crs.pyx":67
 *     bool: True if the string is in the PROJ format
 *     """
 *     return not is_wkt(proj_string) and "=" in proj_string             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_is_wkt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_proj_string};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = (!__pyx_t_6);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_kp_u_, __pyx_v_proj_string, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 67, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":52
 * 
 * 
 * def is_proj(str proj_string not None):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.2
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs.is_proj", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":70
 * 
 * 
 * cdef _to_wkt(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context,
 *     PJ* projobj,
*/

static PyObject *__pyx_f_6pyproj_4_crs__to_wkt(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, PyObject *__pyx_v_version, int __pyx_v_pretty, struct __pyx_opt_args_6pyproj_4_crs__to_wkt *__pyx_optional_args) {

  /* "pyproj/_crs.pyx":75
 *     object version,
 *     bint pretty,
 *     bool output_axis_rule=None,             # <<<<<<<<<<<<<<
 * ):
 *     """
*/
  PyLongObject *__pyx_v_output_axis_rule = ((PyLongObject *)Py_None);
  PyObject *__pyx_v_supported_wkt_types = NULL;
  PJ_WKT_TYPE __pyx_v_wkt_out_type;
  char const *__pyx_v_options_wkt[3];
  PyObject *__pyx_v_multiline = 0;
  PyObject *__pyx_v_output_axis = 0;
  char const *__pyx_v_proj_string;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PJ_WKT_TYPE __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_to_wkt", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_output_axis_rule = __pyx_optional_args->output_axis_rule;
    }
  }

  /* "pyproj/_crs.pyx":94
 *     # get the output WKT format
 *     supported_wkt_types = {
 *         WktVersion.WKT2_2015: PJ_WKT2_2015,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT2_2015_SIMPLIFIED: PJ_WKT2_2015_SIMPLIFIED,
 *         WktVersion.WKT2_2018: PJ_WKT2_2019,
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2015); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT2_2015); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":95
 *     supported_wkt_types = {
 *         WktVersion.WKT2_2015: PJ_WKT2_2015,
 *         WktVersion.WKT2_2015_SIMPLIFIED: PJ_WKT2_2015_SIMPLIFIED,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT2_2018: PJ_WKT2_2019,
 *         WktVersion.WKT2_2018_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2015_SIMPLIFIED); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT2_2015_SIMPLIFIED); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":96
 *         WktVersion.WKT2_2015: PJ_WKT2_2015,
 *         WktVersion.WKT2_2015_SIMPLIFIED: PJ_WKT2_2015_SIMPLIFIED,
 *         WktVersion.WKT2_2018: PJ_WKT2_2019,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT2_2018_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
 *         WktVersion.WKT2_2019: PJ_WKT2_2019,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2018); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT2_2019); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":97
 *         WktVersion.WKT2_2015_SIMPLIFIED: PJ_WKT2_2015_SIMPLIFIED,
 *         WktVersion.WKT2_2018: PJ_WKT2_2019,
 *         WktVersion.WKT2_2018_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT2_2019: PJ_WKT2_2019,
 *         WktVersion.WKT2_2019_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2018_SIMPLIFIED); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT2_2019_SIMPLIFIED); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":98
 *         WktVersion.WKT2_2018: PJ_WKT2_2019,
 *         WktVersion.WKT2_2018_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
 *         WktVersion.WKT2_2019: PJ_WKT2_2019,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT2_2019_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
 *         WktVersion.WKT1_GDAL: PJ_WKT1_GDAL,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT2_2019); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":99
 *         WktVersion.WKT2_2018_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
 *         WktVersion.WKT2_2019: PJ_WKT2_2019,
 *         WktVersion.WKT2_2019_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT1_GDAL: PJ_WKT1_GDAL,
 *         WktVersion.WKT1_ESRI: PJ_WKT1_ESRI
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2019_SIMPLIFIED); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT2_2019_SIMPLIFIED); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":100
 *         WktVersion.WKT2_2019: PJ_WKT2_2019,
 *         WktVersion.WKT2_2019_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
 *         WktVersion.WKT1_GDAL: PJ_WKT1_GDAL,             # <<<<<<<<<<<<<<
 *         WktVersion.WKT1_ESRI: PJ_WKT1_ESRI
 *     }
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT1_GDAL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT1_GDAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":101
 *         WktVersion.WKT2_2019_SIMPLIFIED: PJ_WKT2_2019_SIMPLIFIED,
 *         WktVersion.WKT1_GDAL: PJ_WKT1_GDAL,
 *         WktVersion.WKT1_ESRI: PJ_WKT1_ESRI             # <<<<<<<<<<<<<<
 *     }
 *     cdef PJ_WKT_TYPE wkt_out_type
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT1_ESRI); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT1_ESRI); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_supported_wkt_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":104
 *     }
 *     cdef PJ_WKT_TYPE wkt_out_type
 *     wkt_out_type = supported_wkt_types[WktVersion.create(version)]             # <<<<<<<<<<<<<<
 * 
 *     cdef const char* options_wkt[3]
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_create); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_version};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_supported_wkt_types, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = ((PJ_WKT_TYPE)__Pyx_PyLong_As_PJ_WKT_TYPE(__pyx_t_4)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_wkt_out_type = __pyx_t_6;

  /* "pyproj/_crs.pyx":107
 * 
 *     cdef const char* options_wkt[3]
 *     cdef bytes multiline = b"MULTILINE=NO"             # <<<<<<<<<<<<<<
 *     if pretty:
 *         multiline = b"MULTILINE=YES"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_MULTILINE_NO);
  __pyx_v_multiline = __pyx_mstate_global->__pyx_kp_b_MULTILINE_NO;

  /* "pyproj/_crs.pyx":108
 *     cdef const char* options_wkt[3]
 *     cdef bytes multiline = b"MULTILINE=NO"
 *     if pretty:             # <<<<<<<<<<<<<<
 *         multiline = b"MULTILINE=YES"
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"
*/
  if (__pyx_v_pretty) {

    /* "pyproj/_crs.pyx":109
 *     cdef bytes multiline = b"MULTILINE=NO"
 *     if pretty:
 *         multiline = b"MULTILINE=YES"             # <<<<<<<<<<<<<<
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"
 *     if output_axis_rule is False:
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_MULTILINE_YES);
    __Pyx_DECREF_SET(__pyx_v_multiline, __pyx_mstate_global->__pyx_kp_b_MULTILINE_YES);

    /* "pyproj/_crs.pyx":108
 *     cdef const char* options_wkt[3]
 *     cdef bytes multiline = b"MULTILINE=NO"
 *     if pretty:             # <<<<<<<<<<<<<<
 *         multiline = b"MULTILINE=YES"
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"
*/
  }

  /* "pyproj/_crs.pyx":110
 *     if pretty:
 *         multiline = b"MULTILINE=YES"
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"             # <<<<<<<<<<<<<<
 *     if output_axis_rule is False:
 *         output_axis = b"OUTPUT_AXIS=NO"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_OUTPUT_AXIS_AUTO);
  __pyx_v_output_axis = __pyx_mstate_global->__pyx_kp_b_OUTPUT_AXIS_AUTO;

  /* "pyproj/_crs.pyx":111
 *         multiline = b"MULTILINE=YES"
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"
 *     if output_axis_rule is False:             # <<<<<<<<<<<<<<
 *         output_axis = b"OUTPUT_AXIS=NO"
 *     elif output_axis_rule is True:
*/
  __pyx_t_7 = (((PyObject *)__pyx_v_output_axis_rule) == Py_False);
  if (__pyx_t_7) {

    /* "pyproj/_crs.pyx":112
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"
 *     if output_axis_rule is False:
 *         output_axis = b"OUTPUT_AXIS=NO"             # <<<<<<<<<<<<<<
 *     elif output_axis_rule is True:
 *         output_axis = b"OUTPUT_AXIS=YES"
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_OUTPUT_AXIS_NO);
    __Pyx_DECREF_SET(__pyx_v_output_axis, __pyx_mstate_global->__pyx_kp_b_OUTPUT_AXIS_NO);

    /* "pyproj/_crs.pyx":111
 *         multiline = b"MULTILINE=YES"
 *     cdef bytes output_axis = b"OUTPUT_AXIS=AUTO"
 *     if output_axis_rule is False:             # <<<<<<<<<<<<<<
 *         output_axis = b"OUTPUT_AXIS=NO"
 *     elif output_axis_rule is True:
*/
    goto __pyx_L4;
  }

  /* "pyproj/_crs.pyx":113
 *     if output_axis_rule is False:
 *         output_axis = b"OUTPUT_AXIS=NO"
 *     elif output_axis_rule is True:             # <<<<<<<<<<<<<<
 *         output_axis = b"OUTPUT_AXIS=YES"
 *     options_wkt[0] = multiline
*/
  __pyx_t_7 = (((PyObject *)__pyx_v_output_axis_rule) == Py_True);
  if (__pyx_t_7) {

    /* "pyproj/_crs.pyx":114
 *         output_axis = b"OUTPUT_AXIS=NO"
 *     elif output_axis_rule is True:
 *         output_axis = b"OUTPUT_AXIS=YES"             # <<<<<<<<<<<<<<
 *     options_wkt[0] = multiline
 *     options_wkt[1] = output_axis
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_OUTPUT_AXIS_YES);
    __Pyx_DECREF_SET(__pyx_v_output_axis, __pyx_mstate_global->__pyx_kp_b_OUTPUT_AXIS_YES);

    /* "pyproj/_crs.pyx":113
 *     if output_axis_rule is False:
 *         output_axis = b"OUTPUT_AXIS=NO"
 *     elif output_axis_rule is True:             # <<<<<<<<<<<<<<
 *         output_axis = b"OUTPUT_AXIS=YES"
 *     options_wkt[0] = multiline
*/
  }
  __pyx_L4:;

  /* "pyproj/_crs.pyx":115
 *     elif output_axis_rule is True:
 *         output_axis = b"OUTPUT_AXIS=YES"
 *     options_wkt[0] = multiline             # <<<<<<<<<<<<<<
 *     options_wkt[1] = output_axis
 *     options_wkt[2] = NULL
*/
  __pyx_t_8 = __Pyx_PyBytes_AsString(__pyx_v_multiline); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) __PYX_ERR(0, 115, __pyx_L1_error)
  (__pyx_v_options_wkt[0]) = __pyx_t_8;

  /* "pyproj/_crs.pyx":116
 *         output_axis = b"OUTPUT_AXIS=YES"
 *     options_wkt[0] = multiline
 *     options_wkt[1] = output_axis             # <<<<<<<<<<<<<<
 *     options_wkt[2] = NULL
 *     cdef const char* proj_string
*/
  __pyx_t_8 = __Pyx_PyBytes_AsString(__pyx_v_output_axis); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) __PYX_ERR(0, 116, __pyx_L1_error)
  (__pyx_v_options_wkt[1]) = __pyx_t_8;

  /* "pyproj/_crs.pyx":117
 *     options_wkt[0] = multiline
 *     options_wkt[1] = output_axis
 *     options_wkt[2] = NULL             # <<<<<<<<<<<<<<
 *     cdef const char* proj_string
 *     proj_string = proj_as_wkt(
*/
  (__pyx_v_options_wkt[2]) = NULL;

  /* "pyproj/_crs.pyx":119
 *     options_wkt[2] = NULL
 *     cdef const char* proj_string
 *     proj_string = proj_as_wkt(             # <<<<<<<<<<<<<<
 *         context,
 *         projobj,
*/
  __pyx_v_proj_string = proj_as_wkt(__pyx_v_context, __pyx_v_projobj, __pyx_v_wkt_out_type, __pyx_v_options_wkt);

  /* "pyproj/_crs.pyx":125
 *         options_wkt,
 *     )
 *     _clear_proj_error()             # <<<<<<<<<<<<<<
 *     return cstrdecode(proj_string)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":126
 *     )
 *     _clear_proj_error()
 *     return cstrdecode(proj_string)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_f_6pyproj_7_compat_cstrdecode(__pyx_v_proj_string); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":70
 * 
 * 
 * cdef _to_wkt(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context,
 *     PJ* projobj,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs._to_wkt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_supported_wkt_types);
  __Pyx_XDECREF(__pyx_v_multiline);
  __Pyx_XDECREF(__pyx_v_output_axis);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":129
 * 
 * 
 * cdef _to_proj4(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context,
 *     PJ* projobj,
*/

static PyObject *__pyx_f_6pyproj_4_crs__to_proj4(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, PyObject *__pyx_v_version, int __pyx_v_pretty) {
  PyObject *__pyx_v_supported_prj_types = NULL;
  PJ_PROJ_STRING_TYPE __pyx_v_proj_out_type;
  char const *__pyx_v_options[2];
  PyObject *__pyx_v_multiline = 0;
  char const *__pyx_v_proj_string;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PJ_PROJ_STRING_TYPE __pyx_t_6;
  char const *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_to_proj4", 0);

  /* "pyproj/_crs.pyx":152
 *     # get the output PROJ string format
 *     supported_prj_types = {
 *         ProjVersion.PROJ_4: PJ_PROJ_4,             # <<<<<<<<<<<<<<
 *         ProjVersion.PROJ_5: PJ_PROJ_5,
 *     }
*/
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_PROJ_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_PROJ_STRING_TYPE(PJ_PROJ_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":153
 *     supported_prj_types = {
 *         ProjVersion.PROJ_4: PJ_PROJ_4,
 *         ProjVersion.PROJ_5: PJ_PROJ_5,             # <<<<<<<<<<<<<<
 *     }
 *     cdef PJ_PROJ_STRING_TYPE proj_out_type
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_PROJ_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_PROJ_STRING_TYPE(PJ_PROJ_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_t_3, __pyx_t_2) < (0)) __PYX_ERR(0, 152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_supported_prj_types = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":156
 *     }
 *     cdef PJ_PROJ_STRING_TYPE proj_out_type
 *     proj_out_type = supported_prj_types[ProjVersion.create(version)]             # <<<<<<<<<<<<<<
 * 
 *     cdef const char* options[2]
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_create); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_version};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_supported_prj_types, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = ((PJ_PROJ_STRING_TYPE)__Pyx_PyLong_As_PJ_PROJ_STRING_TYPE(__pyx_t_4)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_proj_out_type = __pyx_t_6;

  /* "pyproj/_crs.pyx":159
 * 
 *     cdef const char* options[2]
 *     cdef bytes multiline = b"MULTILINE=NO"             # <<<<<<<<<<<<<<
 *     if pretty:
 *         multiline = b"MULTILINE=YES"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_MULTILINE_NO);
  __pyx_v_multiline = __pyx_mstate_global->__pyx_kp_b_MULTILINE_NO;

  /* "pyproj/_crs.pyx":160
 *     cdef const char* options[2]
 *     cdef bytes multiline = b"MULTILINE=NO"
 *     if pretty:             # <<<<<<<<<<<<<<
 *         multiline = b"MULTILINE=YES"
 *     options[0] = multiline
*/
  if (__pyx_v_pretty) {

    /* "pyproj/_crs.pyx":161
 *     cdef bytes multiline = b"MULTILINE=NO"
 *     if pretty:
 *         multiline = b"MULTILINE=YES"             # <<<<<<<<<<<<<<
 *     options[0] = multiline
 *     options[1] = NULL
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_MULTILINE_YES);
    __Pyx_DECREF_SET(__pyx_v_multiline, __pyx_mstate_global->__pyx_kp_b_MULTILINE_YES);

    /* "pyproj/_crs.pyx":160
 *     cdef const char* options[2]
 *     cdef bytes multiline = b"MULTILINE=NO"
 *     if pretty:             # <<<<<<<<<<<<<<
 *         multiline = b"MULTILINE=YES"
 *     options[0] = multiline
*/
  }

  /* "pyproj/_crs.pyx":162
 *     if pretty:
 *         multiline = b"MULTILINE=YES"
 *     options[0] = multiline             # <<<<<<<<<<<<<<
 *     options[1] = NULL
 * 
*/
  __pyx_t_7 = __Pyx_PyBytes_AsString(__pyx_v_multiline); if (unlikely((!__pyx_t_7) && PyErr_Occurred())) __PYX_ERR(0, 162, __pyx_L1_error)
  (__pyx_v_options[0]) = __pyx_t_7;

  /* "pyproj/_crs.pyx":163
 *         multiline = b"MULTILINE=YES"
 *     options[0] = multiline
 *     options[1] = NULL             # <<<<<<<<<<<<<<
 * 
 *     # convert projection to string
*/
  (__pyx_v_options[1]) = NULL;

  /* "pyproj/_crs.pyx":167
 *     # convert projection to string
 *     cdef const char* proj_string
 *     proj_string = proj_as_proj_string(             # <<<<<<<<<<<<<<
 *         context,
 *         projobj,
*/
  __pyx_v_proj_string = proj_as_proj_string(__pyx_v_context, __pyx_v_projobj, __pyx_v_proj_out_type, __pyx_v_options);

  /* "pyproj/_crs.pyx":173
 *         options,
 *     )
 *     _clear_proj_error()             # <<<<<<<<<<<<<<
 *     return cstrdecode(proj_string)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":174
 *     )
 *     _clear_proj_error()
 *     return cstrdecode(proj_string)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_f_6pyproj_7_compat_cstrdecode(__pyx_v_proj_string); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":129
 * 
 * 
 * cdef _to_proj4(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context,
 *     PJ* projobj,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs._to_proj4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_supported_prj_types);
  __Pyx_XDECREF(__pyx_v_multiline);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":177
 * 
 * 
 * cdef tuple _get_concatenated_operations(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context, PJ* concatenated_operation
 * ):
*/

static PyObject *__pyx_f_6pyproj_4_crs__get_concatenated_operations(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_concatenated_operation) {
  int __pyx_v_step_count;
  PJ *__pyx_v_operation;
  PJ_CONTEXT *__pyx_v_sub_context;
  int __pyx_v_iii;
  PyObject *__pyx_v_operations = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PJ_CONTEXT *__pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_concatenated_operations", 0);

  /* "pyproj/_crs.pyx":183
 *     For a PJ* of type concatenated operation, get the operations
 *     """
 *     cdef int step_count = proj_concatoperation_get_step_count(             # <<<<<<<<<<<<<<
 *         context,
 *         concatenated_operation,
*/
  __pyx_v_step_count = proj_concatoperation_get_step_count(__pyx_v_context, __pyx_v_concatenated_operation);

  /* "pyproj/_crs.pyx":187
 *         concatenated_operation,
 *     )
 *     cdef PJ* operation = NULL             # <<<<<<<<<<<<<<
 *     cdef PJ_CONTEXT* sub_context = NULL
 *     cdef int iii = 0
*/
  __pyx_v_operation = NULL;

  /* "pyproj/_crs.pyx":188
 *     )
 *     cdef PJ* operation = NULL
 *     cdef PJ_CONTEXT* sub_context = NULL             # <<<<<<<<<<<<<<
 *     cdef int iii = 0
 *     operations = []
*/
  __pyx_v_sub_context = NULL;

  /* "pyproj/_crs.pyx":189
 *     cdef PJ* operation = NULL
 *     cdef PJ_CONTEXT* sub_context = NULL
 *     cdef int iii = 0             # <<<<<<<<<<<<<<
 *     operations = []
 *     for iii in range(step_count):
*/
  __pyx_v_iii = 0;

  /* "pyproj/_crs.pyx":190
 *     cdef PJ_CONTEXT* sub_context = NULL
 *     cdef int iii = 0
 *     operations = []             # <<<<<<<<<<<<<<
 *     for iii in range(step_count):
 *         sub_context = pyproj_context_create()
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_operations = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":191
 *     cdef int iii = 0
 *     operations = []
 *     for iii in range(step_count):             # <<<<<<<<<<<<<<
 *         sub_context = pyproj_context_create()
 *         operation = proj_concatoperation_get_step(
*/
  __pyx_t_2 = __pyx_v_step_count;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_iii = __pyx_t_4;

    /* "pyproj/_crs.pyx":192
 *     operations = []
 *     for iii in range(step_count):
 *         sub_context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         operation = proj_concatoperation_get_step(
 *             sub_context,
*/
    __pyx_t_5 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 192, __pyx_L1_error)
    __pyx_v_sub_context = __pyx_t_5;

    /* "pyproj/_crs.pyx":193
 *     for iii in range(step_count):
 *         sub_context = pyproj_context_create()
 *         operation = proj_concatoperation_get_step(             # <<<<<<<<<<<<<<
 *             sub_context,
 *             concatenated_operation,
*/
    __pyx_v_operation = proj_concatoperation_get_step(__pyx_v_sub_context, __pyx_v_concatenated_operation, __pyx_v_iii);

    /* "pyproj/_crs.pyx":198
 *             iii,
 *         )
 *         operations.append(CoordinateOperation.create(sub_context, operation))             # <<<<<<<<<<<<<<
 *     _clear_proj_error()
 *     return tuple(operations)
*/
    __pyx_t_1 = ((PyObject *)__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(__pyx_v_sub_context, __pyx_v_operation)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_operations, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "pyproj/_crs.pyx":199
 *         )
 *         operations.append(CoordinateOperation.create(sub_context, operation))
 *     _clear_proj_error()             # <<<<<<<<<<<<<<
 *     return tuple(operations)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":200
 *         operations.append(CoordinateOperation.create(sub_context, operation))
 *     _clear_proj_error()
 *     return tuple(operations)             # <<<<<<<<<<<<<<
 * 
 * cdef PJ * _from_name(
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyList_AsTuple(__pyx_v_operations); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":177
 * 
 * 
 * cdef tuple _get_concatenated_operations(             # <<<<<<<<<<<<<<
 *     PJ_CONTEXT* context, PJ* concatenated_operation
 * ):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs._get_concatenated_operations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_operations);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":202
 *     return tuple(operations)
 * 
 * cdef PJ * _from_name(             # <<<<<<<<<<<<<<
 *         PJ_CONTEXT* context,
 *         str name_string,
*/

static PJ *__pyx_f_6pyproj_4_crs__from_name(PJ_CONTEXT *__pyx_v_context, PyObject *__pyx_v_name_string, PyObject *__pyx_v_auth_name, PJ_TYPE __pyx_v_pj_type) {
  PJ_TYPE __pyx_v_pj_types[1];
  char *__pyx_v_c_auth_name;
  PyObject *__pyx_v_b_auth_name = 0;
  PJ_OBJ_LIST *__pyx_v_pj_list;
  PJ *__pyx_v_datum_pj;
  PJ *__pyx_r;
  __Pyx_RefNannyDeclarations
  PJ_TYPE __pyx_t_1[1];
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  char *__pyx_t_4;
  char const *__pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 0);

  /* "pyproj/_crs.pyx":227
 *         PJ *
 *         """
 *         cdef PJ_TYPE[1] pj_types = [pj_type]             # <<<<<<<<<<<<<<
 *         cdef char* c_auth_name = NULL
 *         cdef bytes b_auth_name
*/
  __pyx_t_1[0] = __pyx_v_pj_type;
  memcpy(&(__pyx_v_pj_types[0]), __pyx_t_1, sizeof(__pyx_v_pj_types[0]) * (1));

  /* "pyproj/_crs.pyx":228
 *         """
 *         cdef PJ_TYPE[1] pj_types = [pj_type]
 *         cdef char* c_auth_name = NULL             # <<<<<<<<<<<<<<
 *         cdef bytes b_auth_name
 *         if auth_name is not None:
*/
  __pyx_v_c_auth_name = NULL;

  /* "pyproj/_crs.pyx":230
 *         cdef char* c_auth_name = NULL
 *         cdef bytes b_auth_name
 *         if auth_name is not None:             # <<<<<<<<<<<<<<
 *             b_auth_name = cstrencode(auth_name)
 *             c_auth_name = b_auth_name
*/
  __pyx_t_2 = (__pyx_v_auth_name != ((PyObject*)Py_None));
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":231
 *         cdef bytes b_auth_name
 *         if auth_name is not None:
 *             b_auth_name = cstrencode(auth_name)             # <<<<<<<<<<<<<<
 *             c_auth_name = b_auth_name
 * 
*/
    __pyx_t_3 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_auth_name, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_b_auth_name = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyproj/_crs.pyx":232
 *         if auth_name is not None:
 *             b_auth_name = cstrencode(auth_name)
 *             c_auth_name = b_auth_name             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ_OBJ_LIST *pj_list = proj_create_from_name(
*/
    if (unlikely(__pyx_v_b_auth_name == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 232, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyBytes_AsWritableString(__pyx_v_b_auth_name); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 232, __pyx_L1_error)
    __pyx_v_c_auth_name = __pyx_t_4;

    /* "pyproj/_crs.pyx":230
 *         cdef char* c_auth_name = NULL
 *         cdef bytes b_auth_name
 *         if auth_name is not None:             # <<<<<<<<<<<<<<
 *             b_auth_name = cstrencode(auth_name)
 *             c_auth_name = b_auth_name
*/
  }

  /* "pyproj/_crs.pyx":237
 *             context,
 *             c_auth_name,
 *             cstrencode(name_string),             # <<<<<<<<<<<<<<
 *             <PJ_TYPE*>&pj_types,
 *             1,
*/
  __pyx_t_3 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_name_string, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 237, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyBytes_AsString(__pyx_t_3); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) __PYX_ERR(0, 237, __pyx_L1_error)

  /* "pyproj/_crs.pyx":234
 *             c_auth_name = b_auth_name
 * 
 *         cdef PJ_OBJ_LIST *pj_list = proj_create_from_name(             # <<<<<<<<<<<<<<
 *             context,
 *             c_auth_name,
*/
  __pyx_v_pj_list = proj_create_from_name(__pyx_v_context, __pyx_v_c_auth_name, __pyx_t_5, ((PJ_TYPE *)(&__pyx_v_pj_types)), 1, 0, 1, NULL);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyproj/_crs.pyx":244
 *             NULL,
 *         )
 *         if pj_list == NULL or proj_list_get_count(pj_list) <= 0:             # <<<<<<<<<<<<<<
 *             proj_list_destroy(pj_list)
 *             return NULL
*/
  __pyx_t_6 = (__pyx_v_pj_list == NULL);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_2 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_6 = (proj_list_get_count(__pyx_v_pj_list) <= 0);
  __pyx_t_2 = __pyx_t_6;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":245
 *         )
 *         if pj_list == NULL or proj_list_get_count(pj_list) <= 0:
 *             proj_list_destroy(pj_list)             # <<<<<<<<<<<<<<
 *             return NULL
 *         cdef PJ* datum_pj = proj_list_get(context, pj_list, 0)
*/
    proj_list_destroy(__pyx_v_pj_list);

    /* "pyproj/_crs.pyx":246
 *         if pj_list == NULL or proj_list_get_count(pj_list) <= 0:
 *             proj_list_destroy(pj_list)
 *             return NULL             # <<<<<<<<<<<<<<
 *         cdef PJ* datum_pj = proj_list_get(context, pj_list, 0)
 *         proj_list_destroy(pj_list)
*/
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":244
 *             NULL,
 *         )
 *         if pj_list == NULL or proj_list_get_count(pj_list) <= 0:             # <<<<<<<<<<<<<<
 *             proj_list_destroy(pj_list)
 *             return NULL
*/
  }

  /* "pyproj/_crs.pyx":247
 *             proj_list_destroy(pj_list)
 *             return NULL
 *         cdef PJ* datum_pj = proj_list_get(context, pj_list, 0)             # <<<<<<<<<<<<<<
 *         proj_list_destroy(pj_list)
 *         return datum_pj
*/
  __pyx_v_datum_pj = proj_list_get(__pyx_v_context, __pyx_v_pj_list, 0);

  /* "pyproj/_crs.pyx":248
 *             return NULL
 *         cdef PJ* datum_pj = proj_list_get(context, pj_list, 0)
 *         proj_list_destroy(pj_list)             # <<<<<<<<<<<<<<
 *         return datum_pj
 * 
*/
  proj_list_destroy(__pyx_v_pj_list);

  /* "pyproj/_crs.pyx":249
 *         cdef PJ* datum_pj = proj_list_get(context, pj_list, 0)
 *         proj_list_destroy(pj_list)
 *         return datum_pj             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = __pyx_v_datum_pj;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":202
 *     return tuple(operations)
 * 
 * cdef PJ * _from_name(             # <<<<<<<<<<<<<<
 *         PJ_CONTEXT* context,
 *         str name_string,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_b_auth_name);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":252
 * 
 * 
 * def _load_proj_json(str in_proj_json):             # <<<<<<<<<<<<<<
 *     try:
 *         return json.loads(in_proj_json)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5_load_proj_json(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_load_proj_json, "_load_proj_json(str in_proj_json)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5_load_proj_json = {"_load_proj_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5_load_proj_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_load_proj_json};
static PyObject *__pyx_pw_6pyproj_4_crs_5_load_proj_json(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_in_proj_json = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_load_proj_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_in_proj_json,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 252, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 252, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_load_proj_json", 0) < (0)) __PYX_ERR(0, 252, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_load_proj_json", 1, 1, 1, i); __PYX_ERR(0, 252, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 252, __pyx_L3_error)
    }
    __pyx_v_in_proj_json = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_load_proj_json", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 252, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._load_proj_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_in_proj_json), (&PyUnicode_Type), 1, "in_proj_json", 1))) __PYX_ERR(0, 252, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_load_proj_json(__pyx_self, __pyx_v_in_proj_json);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_load_proj_json(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_in_proj_json) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_load_proj_json", 0);

  /* "pyproj/_crs.pyx":253
 * 
 * def _load_proj_json(str in_proj_json):
 *     try:             # <<<<<<<<<<<<<<
 *         return json.loads(in_proj_json)
 *     except ValueError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":254
 * def _load_proj_json(str in_proj_json):
 *     try:
 *         return json.loads(in_proj_json)             # <<<<<<<<<<<<<<
 *     except ValueError:
 *         raise CRSError("Invalid JSON")
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 254, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_loads); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 254, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_in_proj_json};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 254, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":253
 * 
 * def _load_proj_json(str in_proj_json):
 *     try:             # <<<<<<<<<<<<<<
 *         return json.loads(in_proj_json)
 *     except ValueError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "pyproj/_crs.pyx":255
 *     try:
 *         return json.loads(in_proj_json)
 *     except ValueError:             # <<<<<<<<<<<<<<
 *         raise CRSError("Invalid JSON")
 * 
*/
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs._load_proj_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 255, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);

      /* "pyproj/_crs.pyx":256
 *         return json.loads(in_proj_json)
 *     except ValueError:
 *         raise CRSError("Invalid JSON")             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_10 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 256, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
        assert(__pyx_t_10);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_Invalid_JSON};
        __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 256, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 256, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":253
 * 
 * def _load_proj_json(str in_proj_json):
 *     try:             # <<<<<<<<<<<<<<
 *         return json.loads(in_proj_json)
 *     except ValueError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":252
 * 
 * 
 * def _load_proj_json(str in_proj_json):             # <<<<<<<<<<<<<<
 *     try:
 *         return json.loads(in_proj_json)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pyproj._crs._load_proj_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":276
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.name = "undefined"
 *         self.abbrev = "undefined"
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_4Axis_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_4Axis_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis___cinit__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_4Axis___cinit__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":277
 *     """
 *     def __cinit__(self):
 *         self.name = "undefined"             # <<<<<<<<<<<<<<
 *         self.abbrev = "undefined"
 *         self.direction = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":278
 *     def __cinit__(self):
 *         self.name = "undefined"
 *         self.abbrev = "undefined"             # <<<<<<<<<<<<<<
 *         self.direction = "undefined"
 *         self.unit_conversion_factor = float("NaN")
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->abbrev);
  __Pyx_DECREF(__pyx_v_self->abbrev);
  __pyx_v_self->abbrev = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":279
 *         self.name = "undefined"
 *         self.abbrev = "undefined"
 *         self.direction = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_conversion_factor = float("NaN")
 *         self.unit_name = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->direction);
  __Pyx_DECREF(__pyx_v_self->direction);
  __pyx_v_self->direction = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":280
 *         self.abbrev = "undefined"
 *         self.direction = "undefined"
 *         self.unit_conversion_factor = float("NaN")             # <<<<<<<<<<<<<<
 *         self.unit_name = "undefined"
 *         self.unit_auth_code = "undefined"
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_NaN); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 280, __pyx_L1_error)
  __pyx_v_self->unit_conversion_factor = __pyx_t_1;

  /* "pyproj/_crs.pyx":281
 *         self.direction = "undefined"
 *         self.unit_conversion_factor = float("NaN")
 *         self.unit_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_auth_code = "undefined"
 *         self.unit_code = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_name);
  __Pyx_DECREF(__pyx_v_self->unit_name);
  __pyx_v_self->unit_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":282
 *         self.unit_conversion_factor = float("NaN")
 *         self.unit_name = "undefined"
 *         self.unit_auth_code = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_code = "undefined"
 * 
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_auth_code);
  __Pyx_DECREF(__pyx_v_self->unit_auth_code);
  __pyx_v_self->unit_auth_code = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":283
 *         self.unit_name = "undefined"
 *         self.unit_auth_code = "undefined"
 *         self.unit_code = "undefined"             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_code);
  __Pyx_DECREF(__pyx_v_self->unit_code);
  __pyx_v_self->unit_code = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":276
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.name = "undefined"
 *         self.abbrev = "undefined"
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Axis.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":285
 *         self.unit_code = "undefined"
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return f"{self.abbrev}[{self.direction}]: {self.name} ({self.unit_name})"
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_3__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_3__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_2__str__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_2__str__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5[8];
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "pyproj/_crs.pyx":286
 * 
 *     def __str__(self):
 *         return f"{self.abbrev}[{self.direction}]: {self.name} ({self.unit_name})"             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->abbrev); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_self->direction); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_self->name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5[0] = __pyx_t_1;
  __pyx_t_5[1] = __pyx_mstate_global->__pyx_kp_u__2;
  __pyx_t_5[2] = __pyx_t_2;
  __pyx_t_5[3] = __pyx_mstate_global->__pyx_kp_u__3;
  __pyx_t_5[4] = __pyx_t_3;
  __pyx_t_5[5] = __pyx_mstate_global->__pyx_kp_u__4;
  __pyx_t_5[6] = __pyx_t_4;
  __pyx_t_5[7] = __pyx_mstate_global->__pyx_kp_u__5;
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_5, 8, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 1 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":285
 *         self.unit_code = "undefined"
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return f"{self.abbrev}[{self.direction}]: {self.name} ({self.unit_name})"
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyproj._crs.Axis.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":288
 *         return f"{self.abbrev}[{self.direction}]: {self.name} ({self.unit_name})"
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_5__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_4__repr__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_4__repr__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7[13];
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyproj/_crs.pyx":289
 * 
 *     def __repr__(self):
 *         return (             # <<<<<<<<<<<<<<
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "
 *             f"direction={self.direction}, unit_auth_code={self.unit_auth_code}, "
*/
  __Pyx_XDECREF(__pyx_r);

  /* "pyproj/_crs.pyx":290
 *     def __repr__(self):
 *         return (
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "             # <<<<<<<<<<<<<<
 *             f"direction={self.direction}, unit_auth_code={self.unit_auth_code}, "
 *             f"unit_code={self.unit_code}, unit_name={self.unit_name})"
*/
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_self->abbrev); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":291
 *         return (
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "
 *             f"direction={self.direction}, unit_auth_code={self.unit_auth_code}, "             # <<<<<<<<<<<<<<
 *             f"unit_code={self.unit_code}, unit_name={self.unit_name})"
 *         )
*/
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_self->direction); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_auth_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pyproj/_crs.pyx":292
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "
 *             f"direction={self.direction}, unit_auth_code={self.unit_auth_code}, "
 *             f"unit_code={self.unit_code}, unit_name={self.unit_name})"             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_5 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_code); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_Axis_name;
  __pyx_t_7[1] = __pyx_t_1;
  __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u_abbrev;
  __pyx_t_7[3] = __pyx_t_2;
  __pyx_t_7[4] = __pyx_mstate_global->__pyx_kp_u_direction;
  __pyx_t_7[5] = __pyx_t_3;
  __pyx_t_7[6] = __pyx_mstate_global->__pyx_kp_u_unit_auth_code;
  __pyx_t_7[7] = __pyx_t_4;
  __pyx_t_7[8] = __pyx_mstate_global->__pyx_kp_u_unit_code;
  __pyx_t_7[9] = __pyx_t_5;
  __pyx_t_7[10] = __pyx_mstate_global->__pyx_kp_u_unit_name;
  __pyx_t_7[11] = __pyx_t_6;
  __pyx_t_7[12] = __pyx_mstate_global->__pyx_kp_u__5;

  /* "pyproj/_crs.pyx":290
 *     def __repr__(self):
 *         return (
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "             # <<<<<<<<<<<<<<
 *             f"direction={self.direction}, unit_auth_code={self.unit_auth_code}, "
 *             f"unit_code={self.unit_code}, unit_name={self.unit_name})"
*/
  __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_7, 13, 10 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 12 * 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_8;
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":288
 *         return f"{self.abbrev}[{self.direction}]: {self.name} ({self.unit_name})"
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"Axis(name={self.name}, abbrev={self.abbrev}, "
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.Axis.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":295
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Axis create(PJ_CONTEXT* context, PJ* projobj, int index):
 *         cdef:
*/

static struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_f_6pyproj_4_crs_4Axis_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, int __pyx_v_index) {
  struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_axis_info = 0;
  char const *__pyx_v_name;
  char const *__pyx_v_abbrev;
  char const *__pyx_v_direction;
  char const *__pyx_v_unit_name;
  char const *__pyx_v_unit_auth_code;
  char const *__pyx_v_unit_code;
  struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":298
 *     cdef Axis create(PJ_CONTEXT* context, PJ* projobj, int index):
 *         cdef:
 *             Axis axis_info = Axis()             # <<<<<<<<<<<<<<
 *             const char * name = NULL
 *             const char * abbrev = NULL
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Axis, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 298, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_axis_info = ((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":299
 *         cdef:
 *             Axis axis_info = Axis()
 *             const char * name = NULL             # <<<<<<<<<<<<<<
 *             const char * abbrev = NULL
 *             const char * direction = NULL
*/
  __pyx_v_name = NULL;

  /* "pyproj/_crs.pyx":300
 *             Axis axis_info = Axis()
 *             const char * name = NULL
 *             const char * abbrev = NULL             # <<<<<<<<<<<<<<
 *             const char * direction = NULL
 *             const char * unit_name = NULL
*/
  __pyx_v_abbrev = NULL;

  /* "pyproj/_crs.pyx":301
 *             const char * name = NULL
 *             const char * abbrev = NULL
 *             const char * direction = NULL             # <<<<<<<<<<<<<<
 *             const char * unit_name = NULL
 *             const char * unit_auth_code = NULL
*/
  __pyx_v_direction = NULL;

  /* "pyproj/_crs.pyx":302
 *             const char * abbrev = NULL
 *             const char * direction = NULL
 *             const char * unit_name = NULL             # <<<<<<<<<<<<<<
 *             const char * unit_auth_code = NULL
 *             const char * unit_code = NULL
*/
  __pyx_v_unit_name = NULL;

  /* "pyproj/_crs.pyx":303
 *             const char * direction = NULL
 *             const char * unit_name = NULL
 *             const char * unit_auth_code = NULL             # <<<<<<<<<<<<<<
 *             const char * unit_code = NULL
 * 
*/
  __pyx_v_unit_auth_code = NULL;

  /* "pyproj/_crs.pyx":304
 *             const char * unit_name = NULL
 *             const char * unit_auth_code = NULL
 *             const char * unit_code = NULL             # <<<<<<<<<<<<<<
 * 
 *         if not proj_cs_get_axis_info(
*/
  __pyx_v_unit_code = NULL;

  /* "pyproj/_crs.pyx":306
 *             const char * unit_code = NULL
 * 
 *         if not proj_cs_get_axis_info(             # <<<<<<<<<<<<<<
 *                 context,
 *                 projobj,
*/
  __pyx_t_4 = (!(proj_cs_get_axis_info(__pyx_v_context, __pyx_v_projobj, __pyx_v_index, (&__pyx_v_name), (&__pyx_v_abbrev), (&__pyx_v_direction), (&__pyx_v_axis_info->unit_conversion_factor), (&__pyx_v_unit_name), (&__pyx_v_unit_auth_code), (&__pyx_v_unit_code)) != 0));
  if (__pyx_t_4) {

    /* "pyproj/_crs.pyx":317
 *                 &unit_auth_code,
 *                 &unit_code):
 *             return None             # <<<<<<<<<<<<<<
 *         axis_info.name = decode_or_undefined(name)
 *         axis_info.abbrev = decode_or_undefined(abbrev)
*/
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_r = ((struct __pyx_obj_6pyproj_4_crs_Axis *)Py_None); __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":306
 *             const char * unit_code = NULL
 * 
 *         if not proj_cs_get_axis_info(             # <<<<<<<<<<<<<<
 *                 context,
 *                 projobj,
*/
  }

  /* "pyproj/_crs.pyx":318
 *                 &unit_code):
 *             return None
 *         axis_info.name = decode_or_undefined(name)             # <<<<<<<<<<<<<<
 *         axis_info.abbrev = decode_or_undefined(abbrev)
 *         axis_info.direction = decode_or_undefined(direction)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_axis_info->name);
  __Pyx_DECREF(__pyx_v_axis_info->name);
  __pyx_v_axis_info->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":319
 *             return None
 *         axis_info.name = decode_or_undefined(name)
 *         axis_info.abbrev = decode_or_undefined(abbrev)             # <<<<<<<<<<<<<<
 *         axis_info.direction = decode_or_undefined(direction)
 *         axis_info.unit_name = decode_or_undefined(unit_name)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_abbrev); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_axis_info->abbrev);
  __Pyx_DECREF(__pyx_v_axis_info->abbrev);
  __pyx_v_axis_info->abbrev = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":320
 *         axis_info.name = decode_or_undefined(name)
 *         axis_info.abbrev = decode_or_undefined(abbrev)
 *         axis_info.direction = decode_or_undefined(direction)             # <<<<<<<<<<<<<<
 *         axis_info.unit_name = decode_or_undefined(unit_name)
 *         axis_info.unit_auth_code = decode_or_undefined(unit_auth_code)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_direction); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_axis_info->direction);
  __Pyx_DECREF(__pyx_v_axis_info->direction);
  __pyx_v_axis_info->direction = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":321
 *         axis_info.abbrev = decode_or_undefined(abbrev)
 *         axis_info.direction = decode_or_undefined(direction)
 *         axis_info.unit_name = decode_or_undefined(unit_name)             # <<<<<<<<<<<<<<
 *         axis_info.unit_auth_code = decode_or_undefined(unit_auth_code)
 *         axis_info.unit_code = decode_or_undefined(unit_code)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_unit_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_axis_info->unit_name);
  __Pyx_DECREF(__pyx_v_axis_info->unit_name);
  __pyx_v_axis_info->unit_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":322
 *         axis_info.direction = decode_or_undefined(direction)
 *         axis_info.unit_name = decode_or_undefined(unit_name)
 *         axis_info.unit_auth_code = decode_or_undefined(unit_auth_code)             # <<<<<<<<<<<<<<
 *         axis_info.unit_code = decode_or_undefined(unit_code)
 *         return axis_info
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_unit_auth_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_axis_info->unit_auth_code);
  __Pyx_DECREF(__pyx_v_axis_info->unit_auth_code);
  __pyx_v_axis_info->unit_auth_code = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":323
 *         axis_info.unit_name = decode_or_undefined(unit_name)
 *         axis_info.unit_auth_code = decode_or_undefined(unit_auth_code)
 *         axis_info.unit_code = decode_or_undefined(unit_code)             # <<<<<<<<<<<<<<
 *         return axis_info
 * 
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_unit_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_axis_info->unit_code);
  __Pyx_DECREF(__pyx_v_axis_info->unit_code);
  __pyx_v_axis_info->unit_code = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":324
 *         axis_info.unit_auth_code = decode_or_undefined(unit_auth_code)
 *         axis_info.unit_code = decode_or_undefined(unit_code)
 *         return axis_info             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_axis_info);
  __pyx_r = __pyx_v_axis_info;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":295
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Axis create(PJ_CONTEXT* context, PJ* projobj, int index):
 *         cdef:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Axis.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_axis_info);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":34
 * 
 * cdef class Axis:
 *     cdef readonly str name             # <<<<<<<<<<<<<<
 *     cdef readonly str abbrev
 *     cdef readonly str direction
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_4name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_4name___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_4name___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":35
 * cdef class Axis:
 *     cdef readonly str name
 *     cdef readonly str abbrev             # <<<<<<<<<<<<<<
 *     cdef readonly str direction
 *     cdef readonly double unit_conversion_factor
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_6abbrev_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_6abbrev_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_6abbrev___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_6abbrev___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->abbrev);
  __pyx_r = __pyx_v_self->abbrev;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":36
 *     cdef readonly str name
 *     cdef readonly str abbrev
 *     cdef readonly str direction             # <<<<<<<<<<<<<<
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9direction_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9direction_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_9direction___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_9direction___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->direction);
  __pyx_r = __pyx_v_self->direction;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":37
 *     cdef readonly str abbrev
 *     cdef readonly str direction
 *     cdef readonly double unit_conversion_factor             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_name
 *     cdef readonly str unit_auth_code
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_22unit_conversion_factor_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_22unit_conversion_factor_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_22unit_conversion_factor___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_22unit_conversion_factor___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->unit_conversion_factor); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Axis.unit_conversion_factor.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":38
 *     cdef readonly str direction
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_auth_code
 *     cdef readonly str unit_code
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9unit_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9unit_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_9unit_name___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_9unit_name___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_name);
  __pyx_r = __pyx_v_self->unit_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":39
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name
 *     cdef readonly str unit_auth_code             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_code
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_14unit_auth_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_14unit_auth_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_14unit_auth_code___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_14unit_auth_code___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_auth_code);
  __pyx_r = __pyx_v_self->unit_auth_code;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":40
 *     cdef readonly str unit_name
 *     cdef readonly str unit_auth_code
 *     cdef readonly str unit_code             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9unit_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9unit_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_9unit_code___get__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_9unit_code___get__(struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_code);
  __pyx_r = __pyx_v_self->unit_code;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Axis_6__reduce_cython__, "Axis.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Axis_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Axis_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Axis_6__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_6__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Axis.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Axis_8__setstate_cython__, "Axis.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Axis_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Axis_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Axis_8__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4Axis_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Axis.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Axis_8__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_Axis *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Axis_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Axis *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Axis.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":327
 * 
 * 
 * cdef create_area_of_use(PJ_CONTEXT* context, PJ* projobj):             # <<<<<<<<<<<<<<
 *     cdef:
 *         double west = float("nan")
*/

static PyObject *__pyx_f_6pyproj_4_crs_create_area_of_use(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj) {
  double __pyx_v_west;
  double __pyx_v_south;
  double __pyx_v_east;
  double __pyx_v_north;
  char const *__pyx_v_area_name;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_area_of_use", 0);

  /* "pyproj/_crs.pyx":329
 * cdef create_area_of_use(PJ_CONTEXT* context, PJ* projobj):
 *     cdef:
 *         double west = float("nan")             # <<<<<<<<<<<<<<
 *         double south = float("nan")
 *         double east = float("nan")
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_nan); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 329, __pyx_L1_error)
  __pyx_v_west = __pyx_t_1;

  /* "pyproj/_crs.pyx":330
 *     cdef:
 *         double west = float("nan")
 *         double south = float("nan")             # <<<<<<<<<<<<<<
 *         double east = float("nan")
 *         double north = float("nan")
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_nan); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 330, __pyx_L1_error)
  __pyx_v_south = __pyx_t_1;

  /* "pyproj/_crs.pyx":331
 *         double west = float("nan")
 *         double south = float("nan")
 *         double east = float("nan")             # <<<<<<<<<<<<<<
 *         double north = float("nan")
 *         const char * area_name = NULL
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_nan); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 331, __pyx_L1_error)
  __pyx_v_east = __pyx_t_1;

  /* "pyproj/_crs.pyx":332
 *         double south = float("nan")
 *         double east = float("nan")
 *         double north = float("nan")             # <<<<<<<<<<<<<<
 *         const char * area_name = NULL
 * 
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_nan); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 332, __pyx_L1_error)
  __pyx_v_north = __pyx_t_1;

  /* "pyproj/_crs.pyx":333
 *         double east = float("nan")
 *         double north = float("nan")
 *         const char * area_name = NULL             # <<<<<<<<<<<<<<
 * 
 *     if not proj_get_area_of_use(
*/
  __pyx_v_area_name = NULL;

  /* "pyproj/_crs.pyx":335
 *         const char * area_name = NULL
 * 
 *     if not proj_get_area_of_use(             # <<<<<<<<<<<<<<
 *             context,
 *             projobj,
*/
  __pyx_t_2 = (!(proj_get_area_of_use(__pyx_v_context, __pyx_v_projobj, (&__pyx_v_west), (&__pyx_v_south), (&__pyx_v_east), (&__pyx_v_north), (&__pyx_v_area_name)) != 0));
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":343
 *             &north,
 *             &area_name):
 *         return None             # <<<<<<<<<<<<<<
 *     return AreaOfUse(
 *         west=west,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":335
 *         const char * area_name = NULL
 * 
 *     if not proj_get_area_of_use(             # <<<<<<<<<<<<<<
 *             context,
 *             projobj,
*/
  }

  /* "pyproj/_crs.pyx":344
 *             &area_name):
 *         return None
 *     return AreaOfUse(             # <<<<<<<<<<<<<<
 *         west=west,
 *         south=south,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_AreaOfUse); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pyproj/_crs.pyx":345
 *         return None
 *     return AreaOfUse(
 *         west=west,             # <<<<<<<<<<<<<<
 *         south=south,
 *         east=east,
*/
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_west); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 345, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "pyproj/_crs.pyx":346
 *     return AreaOfUse(
 *         west=west,
 *         south=south,             # <<<<<<<<<<<<<<
 *         east=east,
 *         north=north,
*/
  __pyx_t_7 = PyFloat_FromDouble(__pyx_v_south); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "pyproj/_crs.pyx":347
 *         west=west,
 *         south=south,
 *         east=east,             # <<<<<<<<<<<<<<
 *         north=north,
 *         name=decode_or_undefined(area_name),
*/
  __pyx_t_8 = PyFloat_FromDouble(__pyx_v_east); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "pyproj/_crs.pyx":348
 *         south=south,
 *         east=east,
 *         north=north,             # <<<<<<<<<<<<<<
 *         name=decode_or_undefined(area_name),
 *     )
*/
  __pyx_t_9 = PyFloat_FromDouble(__pyx_v_north); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "pyproj/_crs.pyx":349
 *         east=east,
 *         north=north,
 *         name=decode_or_undefined(area_name),             # <<<<<<<<<<<<<<
 *     )
 * 
*/
  __pyx_t_10 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_area_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_11 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 5 : 0)] = {__pyx_t_4, NULL};
    __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_west, __pyx_t_6, __pyx_t_12, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 344, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_south, __pyx_t_7, __pyx_t_12, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 344, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_east, __pyx_t_8, __pyx_t_12, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 344, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_north, __pyx_t_9, __pyx_t_12, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 344, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_t_10, __pyx_t_12, __pyx_callargs+1, 4) < (0)) __PYX_ERR(0, 344, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_11, (1-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":327
 * 
 * 
 * cdef create_area_of_use(PJ_CONTEXT* context, PJ* projobj):             # <<<<<<<<<<<<<<
 *     cdef:
 *         double west = float("nan")
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("pyproj._crs.create_area_of_use", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":354
 * 
 * cdef class Base:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.projobj = NULL
 *         self.context = NULL
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_4Base_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_4Base_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base___cinit__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_4Base___cinit__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":355
 * cdef class Base:
 *     def __cinit__(self):
 *         self.projobj = NULL             # <<<<<<<<<<<<<<
 *         self.context = NULL
 *         self.name = "undefined"
*/
  __pyx_v_self->projobj = NULL;

  /* "pyproj/_crs.pyx":356
 *     def __cinit__(self):
 *         self.projobj = NULL
 *         self.context = NULL             # <<<<<<<<<<<<<<
 *         self.name = "undefined"
 *         self._scope = None
*/
  __pyx_v_self->context = NULL;

  /* "pyproj/_crs.pyx":357
 *         self.projobj = NULL
 *         self.context = NULL
 *         self.name = "undefined"             # <<<<<<<<<<<<<<
 *         self._scope = None
 *         self._remarks = None
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":358
 *         self.context = NULL
 *         self.name = "undefined"
 *         self._scope = None             # <<<<<<<<<<<<<<
 *         self._remarks = None
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_scope);
  __Pyx_DECREF(__pyx_v_self->_scope);
  __pyx_v_self->_scope = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":359
 *         self.name = "undefined"
 *         self._scope = None
 *         self._remarks = None             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_remarks);
  __Pyx_DECREF(__pyx_v_self->_remarks);
  __pyx_v_self->_remarks = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":354
 * 
 * cdef class Base:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.projobj = NULL
 *         self.context = NULL
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":361
 *         self._remarks = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         """destroy projection definition"""
 *         if self.projobj != NULL:
*/

/* Python wrapper */
static void __pyx_pw_6pyproj_4_crs_4Base_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pyproj_4_crs_4Base_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pyproj_4_crs_4Base_2__dealloc__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pyproj_4_crs_4Base_2__dealloc__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  int __pyx_t_1;

  /* "pyproj/_crs.pyx":363
 *     def __dealloc__(self):
 *         """destroy projection definition"""
 *         if self.projobj != NULL:             # <<<<<<<<<<<<<<
 *             proj_destroy(self.projobj)
 * 
*/
  __pyx_t_1 = (__pyx_v_self->projobj != NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":364
 *         """destroy projection definition"""
 *         if self.projobj != NULL:
 *             proj_destroy(self.projobj)             # <<<<<<<<<<<<<<
 * 
 *     cdef _set_base_info(self):
*/
    proj_destroy(__pyx_v_self->projobj);

    /* "pyproj/_crs.pyx":363
 *     def __dealloc__(self):
 *         """destroy projection definition"""
 *         if self.projobj != NULL:             # <<<<<<<<<<<<<<
 *             proj_destroy(self.projobj)
 * 
*/
  }

  /* "pyproj/_crs.pyx":361
 *         self._remarks = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         """destroy projection definition"""
 *         if self.projobj != NULL:
*/

  /* function exit code */
}

/* "pyproj/_crs.pyx":366
 *             proj_destroy(self.projobj)
 * 
 *     cdef _set_base_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Set the name of the PJ
*/

static PyObject *__pyx_f_6pyproj_4_crs_4Base__set_base_info(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  char const *__pyx_v_proj_name;
  char const *__pyx_v_scope;
  char const *__pyx_v_remarks;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_set_base_info", 0);

  /* "pyproj/_crs.pyx":371
 *         """
 *         # get proj information
 *         cdef const char* proj_name = proj_get_name(self.projobj)             # <<<<<<<<<<<<<<
 *         self.name = decode_or_undefined(proj_name)
 *         cdef const char* scope = proj_get_scope(self.projobj)
*/
  __pyx_v_proj_name = proj_get_name(__pyx_v_self->projobj);

  /* "pyproj/_crs.pyx":372
 *         # get proj information
 *         cdef const char* proj_name = proj_get_name(self.projobj)
 *         self.name = decode_or_undefined(proj_name)             # <<<<<<<<<<<<<<
 *         cdef const char* scope = proj_get_scope(self.projobj)
 *         if scope != NULL and scope != "":
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_proj_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":373
 *         cdef const char* proj_name = proj_get_name(self.projobj)
 *         self.name = decode_or_undefined(proj_name)
 *         cdef const char* scope = proj_get_scope(self.projobj)             # <<<<<<<<<<<<<<
 *         if scope != NULL and scope != "":
 *             self._scope = scope
*/
  __pyx_v_scope = proj_get_scope(__pyx_v_self->projobj);

  /* "pyproj/_crs.pyx":374
 *         self.name = decode_or_undefined(proj_name)
 *         cdef const char* scope = proj_get_scope(self.projobj)
 *         if scope != NULL and scope != "":             # <<<<<<<<<<<<<<
 *             self._scope = scope
 *         cdef const char* remarks = proj_get_remarks(self.projobj)
*/
  __pyx_t_3 = (__pyx_v_scope != NULL);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyUnicode_FromString(__pyx_v_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__6, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":375
 *         cdef const char* scope = proj_get_scope(self.projobj)
 *         if scope != NULL and scope != "":
 *             self._scope = scope             # <<<<<<<<<<<<<<
 *         cdef const char* remarks = proj_get_remarks(self.projobj)
 *         if remarks != NULL and remarks != "":
*/
    __pyx_t_1 = __Pyx_PyUnicode_FromString(__pyx_v_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_scope);
    __Pyx_DECREF(__pyx_v_self->_scope);
    __pyx_v_self->_scope = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pyproj/_crs.pyx":374
 *         self.name = decode_or_undefined(proj_name)
 *         cdef const char* scope = proj_get_scope(self.projobj)
 *         if scope != NULL and scope != "":             # <<<<<<<<<<<<<<
 *             self._scope = scope
 *         cdef const char* remarks = proj_get_remarks(self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":376
 *         if scope != NULL and scope != "":
 *             self._scope = scope
 *         cdef const char* remarks = proj_get_remarks(self.projobj)             # <<<<<<<<<<<<<<
 *         if remarks != NULL and remarks != "":
 *             self._remarks = remarks
*/
  __pyx_v_remarks = proj_get_remarks(__pyx_v_self->projobj);

  /* "pyproj/_crs.pyx":377
 *             self._scope = scope
 *         cdef const char* remarks = proj_get_remarks(self.projobj)
 *         if remarks != NULL and remarks != "":             # <<<<<<<<<<<<<<
 *             self._remarks = remarks
 * 
*/
  __pyx_t_3 = (__pyx_v_remarks != NULL);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyUnicode_FromString(__pyx_v_remarks); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u__6, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":378
 *         cdef const char* remarks = proj_get_remarks(self.projobj)
 *         if remarks != NULL and remarks != "":
 *             self._remarks = remarks             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
    __pyx_t_1 = __Pyx_PyUnicode_FromString(__pyx_v_remarks); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_remarks);
    __Pyx_DECREF(__pyx_v_self->_remarks);
    __pyx_v_self->_remarks = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pyproj/_crs.pyx":377
 *             self._scope = scope
 *         cdef const char* remarks = proj_get_remarks(self.projobj)
 *         if remarks != NULL and remarks != "":             # <<<<<<<<<<<<<<
 *             self._remarks = remarks
 * 
*/
  }

  /* "pyproj/_crs.pyx":366
 *             proj_destroy(self.projobj)
 * 
 *     cdef _set_base_info(self):             # <<<<<<<<<<<<<<
 *         """
 *         Set the name of the PJ
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Base._set_base_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":380
 *             self._remarks = remarks
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def remarks(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_7remarks_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_7remarks_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_7remarks___get__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_7remarks___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":390
 *             Remarks about object.
 *         """
 *         return self._remarks             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_remarks);
  __pyx_r = __pyx_v_self->_remarks;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":380
 *             self._remarks = remarks
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def remarks(self):
 *         """
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":392
 *         return self._remarks
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def scope(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_5scope_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_5scope_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_5scope___get__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_5scope___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":402
 *             Scope of object.
 *         """
 *         return self._scope             # <<<<<<<<<<<<<<
 * 
 *     def to_wkt(self, version=WktVersion.WKT2_2019, pretty=False, output_axis_rule=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_scope);
  __pyx_r = __pyx_v_self->_scope;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":392
 *         return self._remarks
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def scope(self):
 *         """
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":404
 *         return self._scope
 * 
 *     def to_wkt(self, version=WktVersion.WKT2_2019, pretty=False, output_axis_rule=None):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a WKT string.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_5to_wkt(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_4to_wkt, "Base.to_wkt(self, version=WktVersion.WKT2_2019, pretty=False, output_axis_rule=None)\n\nConvert the projection to a WKT string.\n\nVersion options:\n  - WKT2_2015\n  - WKT2_2015_SIMPLIFIED\n  - WKT2_2019\n  - WKT2_2019_SIMPLIFIED\n  - WKT1_GDAL\n  - WKT1_ESRI\n\n.. versionadded:: 3.6.0 output_axis_rule\n\nParameters\n----------\nversion: pyproj.enums.WktVersion, default=pyproj.enums.WktVersion.WKT2_2019\n    The version of the WKT output.\npretty: bool, default=False\n    If True, it will set the output to be a multiline string.\noutput_axis_rule: bool, optional, default=None\n    If True, it will set the axis rule on any case. If false, never.\n    None for AUTO, that depends on the CRS and version.\n\nReturns\n-------\nstr");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_5to_wkt = {"to_wkt", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_5to_wkt, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_4to_wkt};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_5to_wkt(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_pretty = 0;
  PyObject *__pyx_v_output_axis_rule = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_wkt (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_version,&__pyx_mstate_global->__pyx_n_u_pretty,&__pyx_mstate_global->__pyx_n_u_output_axis_rule,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 404, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 404, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 404, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 404, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_wkt", 0) < (0)) __PYX_ERR(0, 404, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__7);
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_False));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 404, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 404, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 404, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__7);
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_False));
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_version = values[0];
    __pyx_v_pretty = values[1];
    __pyx_v_output_axis_rule = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_wkt", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 404, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Base.to_wkt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_4to_wkt(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), __pyx_v_version, __pyx_v_pretty, __pyx_v_output_axis_rule);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_4to_wkt(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, PyObject *__pyx_v_version, PyObject *__pyx_v_pretty, PyObject *__pyx_v_output_axis_rule) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pyproj_4_crs__to_wkt __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_wkt", 0);

  /* "pyproj/_crs.pyx":432
 *         str
 *         """
 *         return _to_wkt(self.context, self.projobj, version, pretty=pretty, output_axis_rule=output_axis_rule)             # <<<<<<<<<<<<<<
 * 
 *     def to_json(self, bint pretty=False, int indentation=2):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_pretty); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 432, __pyx_L1_error)
  if (!(likely(((__pyx_v_output_axis_rule) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_output_axis_rule, __pyx_mstate_global->__pyx_ptype_7cpython_4bool_bool))))) __PYX_ERR(0, 432, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.output_axis_rule = ((PyLongObject *)__pyx_v_output_axis_rule);
  __pyx_t_2 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->context, __pyx_v_self->projobj, __pyx_v_version, __pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":404
 *         return self._scope
 * 
 *     def to_wkt(self, version=WktVersion.WKT2_2019, pretty=False, output_axis_rule=None):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a WKT string.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Base.to_wkt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":434
 *         return _to_wkt(self.context, self.projobj, version, pretty=pretty, output_axis_rule=output_axis_rule)
 * 
 *     def to_json(self, bint pretty=False, int indentation=2):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_7to_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_6to_json, "Base.to_json(self, bool pretty=False, int indentation=2)\n\n.. versionadded:: 2.4.0\n\nConvert the object to a JSON string.\n\nParameters\n----------\npretty: bool, default=False\n    If True, it will set the output to be a multiline string.\nindentation: int, default=2\n    If pretty is True, it will set the width of the indentation.\n\nReturns\n-------\nstr");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_7to_json = {"to_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_7to_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_6to_json};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_7to_json(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_pretty;
  int __pyx_v_indentation;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pretty,&__pyx_mstate_global->__pyx_n_u_indentation,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 434, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 434, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 434, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_json", 0) < (0)) __PYX_ERR(0, 434, __pyx_L3_error)
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 434, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 434, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_pretty = __Pyx_PyObject_IsTrue(values[0]); if (unlikely((__pyx_v_pretty == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 434, __pyx_L3_error)
    } else {
      __pyx_v_pretty = ((int)0);
    }
    if (values[1]) {
      __pyx_v_indentation = __Pyx_PyLong_As_int(values[1]); if (unlikely((__pyx_v_indentation == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 434, __pyx_L3_error)
    } else {
      __pyx_v_indentation = ((int)2);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_json", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 434, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Base.to_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_6to_json(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), __pyx_v_pretty, __pyx_v_indentation);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_6to_json(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, int __pyx_v_pretty, int __pyx_v_indentation) {
  char const *__pyx_v_options[3];
  PyObject *__pyx_v_multiline = NULL;
  PyObject *__pyx_v_indentation_width = NULL;
  char const *__pyx_v_proj_json_string;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_json", 0);

  /* "pyproj/_crs.pyx":452
 *         """
 *         cdef const char* options[3]
 *         multiline = b"MULTILINE=NO"             # <<<<<<<<<<<<<<
 *         if pretty:
 *             multiline = b"MULTILINE=YES"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_MULTILINE_NO);
  __pyx_v_multiline = __pyx_mstate_global->__pyx_kp_b_MULTILINE_NO;

  /* "pyproj/_crs.pyx":453
 *         cdef const char* options[3]
 *         multiline = b"MULTILINE=NO"
 *         if pretty:             # <<<<<<<<<<<<<<
 *             multiline = b"MULTILINE=YES"
 *         indentation_width = cstrencode(f"INDENTATION_WIDTH={indentation:.0f}")
*/
  if (__pyx_v_pretty) {

    /* "pyproj/_crs.pyx":454
 *         multiline = b"MULTILINE=NO"
 *         if pretty:
 *             multiline = b"MULTILINE=YES"             # <<<<<<<<<<<<<<
 *         indentation_width = cstrencode(f"INDENTATION_WIDTH={indentation:.0f}")
 *         options[0] = multiline
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_MULTILINE_YES);
    __Pyx_DECREF_SET(__pyx_v_multiline, __pyx_mstate_global->__pyx_kp_b_MULTILINE_YES);

    /* "pyproj/_crs.pyx":453
 *         cdef const char* options[3]
 *         multiline = b"MULTILINE=NO"
 *         if pretty:             # <<<<<<<<<<<<<<
 *             multiline = b"MULTILINE=YES"
 *         indentation_width = cstrencode(f"INDENTATION_WIDTH={indentation:.0f}")
*/
  }

  /* "pyproj/_crs.pyx":455
 *         if pretty:
 *             multiline = b"MULTILINE=YES"
 *         indentation_width = cstrencode(f"INDENTATION_WIDTH={indentation:.0f}")             # <<<<<<<<<<<<<<
 *         options[0] = multiline
 *         options[1] = indentation_width
*/
  __pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_indentation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Format(__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_0f); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_INDENTATION_WIDTH, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(((PyObject*)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_indentation_width = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":456
 *             multiline = b"MULTILINE=YES"
 *         indentation_width = cstrencode(f"INDENTATION_WIDTH={indentation:.0f}")
 *         options[0] = multiline             # <<<<<<<<<<<<<<
 *         options[1] = indentation_width
 *         options[2] = NULL
*/
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_v_multiline); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 456, __pyx_L1_error)
  (__pyx_v_options[0]) = __pyx_t_3;

  /* "pyproj/_crs.pyx":457
 *         indentation_width = cstrencode(f"INDENTATION_WIDTH={indentation:.0f}")
 *         options[0] = multiline
 *         options[1] = indentation_width             # <<<<<<<<<<<<<<
 *         options[2] = NULL
 * 
*/
  if (unlikely(__pyx_v_indentation_width == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 457, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_v_indentation_width); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 457, __pyx_L1_error)
  (__pyx_v_options[1]) = __pyx_t_3;

  /* "pyproj/_crs.pyx":458
 *         options[0] = multiline
 *         options[1] = indentation_width
 *         options[2] = NULL             # <<<<<<<<<<<<<<
 * 
 *         cdef const char* proj_json_string = proj_as_projjson(
*/
  (__pyx_v_options[2]) = NULL;

  /* "pyproj/_crs.pyx":460
 *         options[2] = NULL
 * 
 *         cdef const char* proj_json_string = proj_as_projjson(             # <<<<<<<<<<<<<<
 *             self.context,
 *             self.projobj,
*/
  __pyx_v_proj_json_string = proj_as_projjson(__pyx_v_self->context, __pyx_v_self->projobj, __pyx_v_options);

  /* "pyproj/_crs.pyx":465
 *             options,
 *         )
 *         return cstrdecode(proj_json_string)             # <<<<<<<<<<<<<<
 * 
 *     def to_json_dict(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrdecode(__pyx_v_proj_json_string); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":434
 *         return _to_wkt(self.context, self.projobj, version, pretty=pretty, output_axis_rule=output_axis_rule)
 * 
 *     def to_json(self, bint pretty=False, int indentation=2):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Base.to_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_multiline);
  __Pyx_XDECREF(__pyx_v_indentation_width);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":467
 *         return cstrdecode(proj_json_string)
 * 
 *     def to_json_dict(self):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_9to_json_dict(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_8to_json_dict, "Base.to_json_dict(self)\n\n.. versionadded:: 2.4.0\n\nConvert the object to a JSON dictionary.\n\nReturns\n-------\ndict");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_9to_json_dict = {"to_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_9to_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_8to_json_dict};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_9to_json_dict(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_json_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("to_json_dict", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("to_json_dict", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_8to_json_dict(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_8to_json_dict(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_json_dict", 0);

  /* "pyproj/_crs.pyx":477
 *         dict
 *         """
 *         return json.loads(self.to_json())             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_loads); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_to_json, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":467
 *         return cstrdecode(proj_json_string)
 * 
 *     def to_json_dict(self):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.Base.to_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":479
 *         return json.loads(self.to_json())
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_11__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_11__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_10__str__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_10__str__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "pyproj/_crs.pyx":480
 * 
 *     def __str__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":479
 *         return json.loads(self.to_json())
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":482
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.to_wkt(pretty=True)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_13__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_13__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_12__repr__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_12__repr__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyproj/_crs.pyx":483
 * 
 *     def __repr__(self):
 *         return self.to_wkt(pretty=True)             # <<<<<<<<<<<<<<
 * 
 *     def _is_exact_same(self, Base other):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_4 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pretty, Py_True, __pyx_t_4, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 483, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_to_wkt, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":482
 *         return self.name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.to_wkt(pretty=True)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs.Base.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":485
 *         return self.to_wkt(pretty=True)
 * 
 *     def _is_exact_same(self, Base other):             # <<<<<<<<<<<<<<
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_15_is_exact_same(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_14_is_exact_same, "Base._is_exact_same(self, Base other)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_15_is_exact_same = {"_is_exact_same", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_15_is_exact_same, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_14_is_exact_same};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_15_is_exact_same(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_is_exact_same (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 485, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 485, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_is_exact_same", 0) < (0)) __PYX_ERR(0, 485, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_is_exact_same", 1, 1, 1, i); __PYX_ERR(0, 485, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 485, __pyx_L3_error)
    }
    __pyx_v_other = ((struct __pyx_obj_6pyproj_4_crs_Base *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_is_exact_same", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 485, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Base._is_exact_same", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, 1, "other", 0))) __PYX_ERR(0, 485, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_14_is_exact_same(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_14_is_exact_same(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_exact_same", 0);

  /* "pyproj/_crs.pyx":486
 * 
 *     def _is_exact_same(self, Base other):
 *         return proj_is_equivalent_to_with_ctx(             # <<<<<<<<<<<<<<
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
 * 
*/
  __Pyx_XDECREF(__pyx_r);

  /* "pyproj/_crs.pyx":487
 *     def _is_exact_same(self, Base other):
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1             # <<<<<<<<<<<<<<
 * 
 *     def _is_equivalent(self, Base other):
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong((proj_is_equivalent_to_with_ctx(__pyx_v_self->context, __pyx_v_self->projobj, __pyx_v_other->projobj, PJ_COMP_STRICT) == 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":485
 *         return self.to_wkt(pretty=True)
 * 
 *     def _is_exact_same(self, Base other):             # <<<<<<<<<<<<<<
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Base._is_exact_same", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":489
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
 * 
 *     def _is_equivalent(self, Base other):             # <<<<<<<<<<<<<<
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_17_is_equivalent(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_16_is_equivalent, "Base._is_equivalent(self, Base other)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_17_is_equivalent = {"_is_equivalent", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_17_is_equivalent, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_16_is_equivalent};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_17_is_equivalent(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_is_equivalent (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 489, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 489, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_is_equivalent", 0) < (0)) __PYX_ERR(0, 489, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_is_equivalent", 1, 1, 1, i); __PYX_ERR(0, 489, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 489, __pyx_L3_error)
    }
    __pyx_v_other = ((struct __pyx_obj_6pyproj_4_crs_Base *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_is_equivalent", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 489, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Base._is_equivalent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, 1, "other", 0))) __PYX_ERR(0, 489, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_16_is_equivalent(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_16_is_equivalent(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_equivalent", 0);

  /* "pyproj/_crs.pyx":490
 * 
 *     def _is_equivalent(self, Base other):
 *         return proj_is_equivalent_to_with_ctx(             # <<<<<<<<<<<<<<
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1
 * 
*/
  __Pyx_XDECREF(__pyx_r);

  /* "pyproj/_crs.pyx":491
 *     def _is_equivalent(self, Base other):
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
*/
  __pyx_t_1 = __Pyx_PyBool_FromLong((proj_is_equivalent_to_with_ctx(__pyx_v_self->context, __pyx_v_self->projobj, __pyx_v_other->projobj, PJ_COMP_EQUIVALENT) == 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":489
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
 * 
 *     def _is_equivalent(self, Base other):             # <<<<<<<<<<<<<<
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Base._is_equivalent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":493
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, Base):
 *             return False
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_19__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_19__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_18__eq__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_18__eq__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);

  /* "pyproj/_crs.pyx":494
 * 
 *     def __eq__(self, other):
 *         if not isinstance(other, Base):             # <<<<<<<<<<<<<<
 *             return False
 *         return self._is_equivalent(other)
*/
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":495
 *     def __eq__(self, other):
 *         if not isinstance(other, Base):
 *             return False             # <<<<<<<<<<<<<<
 *         return self._is_equivalent(other)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":494
 * 
 *     def __eq__(self, other):
 *         if not isinstance(other, Base):             # <<<<<<<<<<<<<<
 *             return False
 *         return self._is_equivalent(other)
*/
  }

  /* "pyproj/_crs.pyx":496
 *         if not isinstance(other, Base):
 *             return False
 *         return self._is_equivalent(other)             # <<<<<<<<<<<<<<
 * 
 *     def is_exact_same(self, other):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_equivalent, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":493
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(other, Base):
 *             return False
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs.Base.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":498
 *         return self._is_equivalent(other)
 * 
 *     def is_exact_same(self, other):             # <<<<<<<<<<<<<<
 *         """Compares projection objects to see if they are exactly the same."""
 *         if not isinstance(other, Base):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_21is_exact_same(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_20is_exact_same, "Base.is_exact_same(self, other)\n\nCompares projection objects to see if they are exactly the same.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_21is_exact_same = {"is_exact_same", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_21is_exact_same, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_20is_exact_same};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_21is_exact_same(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_exact_same (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_other,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 498, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 498, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "is_exact_same", 0) < (0)) __PYX_ERR(0, 498, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("is_exact_same", 1, 1, 1, i); __PYX_ERR(0, 498, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 498, __pyx_L3_error)
    }
    __pyx_v_other = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_exact_same", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 498, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Base.is_exact_same", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_20is_exact_same(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_20is_exact_same(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_exact_same", 0);

  /* "pyproj/_crs.pyx":500
 *     def is_exact_same(self, other):
 *         """Compares projection objects to see if they are exactly the same."""
 *         if not isinstance(other, Base):             # <<<<<<<<<<<<<<
 *             return False
 *         return self._is_exact_same(other)
*/
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":501
 *         """Compares projection objects to see if they are exactly the same."""
 *         if not isinstance(other, Base):
 *             return False             # <<<<<<<<<<<<<<
 *         return self._is_exact_same(other)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":500
 *     def is_exact_same(self, other):
 *         """Compares projection objects to see if they are exactly the same."""
 *         if not isinstance(other, Base):             # <<<<<<<<<<<<<<
 *             return False
 *         return self._is_exact_same(other)
*/
  }

  /* "pyproj/_crs.pyx":502
 *         if not isinstance(other, Base):
 *             return False
 *         return self._is_exact_same(other)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_other};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_exact_same, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":498
 *         return self._is_equivalent(other)
 * 
 *     def is_exact_same(self, other):             # <<<<<<<<<<<<<<
 *         """Compares projection objects to see if they are exactly the same."""
 *         if not isinstance(other, Base):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs.Base.is_exact_same", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":50
 *     cdef PJ *projobj
 *     cdef PJ_CONTEXT* context
 *     cdef readonly object _context_manager             # <<<<<<<<<<<<<<
 *     cdef readonly str name
 *     cdef readonly str _remarks
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_16_context_manager_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_16_context_manager_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_16_context_manager___get__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_16_context_manager___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_context_manager);
  __pyx_r = __pyx_v_self->_context_manager;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":51
 *     cdef PJ_CONTEXT* context
 *     cdef readonly object _context_manager
 *     cdef readonly str name             # <<<<<<<<<<<<<<
 *     cdef readonly str _remarks
 *     cdef readonly str _scope
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_4name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_4name___get__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_4name___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":52
 *     cdef readonly object _context_manager
 *     cdef readonly str name
 *     cdef readonly str _remarks             # <<<<<<<<<<<<<<
 *     cdef readonly str _scope
 *     cdef _set_base_info(self)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_8_remarks_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_8_remarks_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_8_remarks___get__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_8_remarks___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_remarks);
  __pyx_r = __pyx_v_self->_remarks;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":53
 *     cdef readonly str name
 *     cdef readonly str _remarks
 *     cdef readonly str _scope             # <<<<<<<<<<<<<<
 *     cdef _set_base_info(self)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_6_scope_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_6_scope_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_6_scope___get__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_6_scope___get__(struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_scope);
  __pyx_r = __pyx_v_self->_scope;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_23__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_22__reduce_cython__, "Base.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_23__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_23__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_22__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_23__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_22__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Base.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_25__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Base_24__setstate_cython__, "Base.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Base_25__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_25__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_24__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4Base_25__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Base.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Base_24__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Base_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Base *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Base.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":506
 * 
 * cdef class _CRSParts(Base):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_user_input(cls, user_input):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_1from_user_input(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9_CRSParts_from_user_input, "_CRSParts.from_user_input(cls, user_input)\n\n.. versionadded:: 2.5.0\n\nCreate cls from user input:\n  - PROJ JSON string\n  - PROJ JSON dict\n  - WKT string\n  - An authority string\n  - An EPSG integer code\n  - An iterable of (\"auth_name\", \"auth_code\")\n  - An object with a `to_json` method.\n\nParameters\n----------\nuser_input: str, dict, int, Iterable[str, str]\n    Input to create cls.\n\nReturns\n-------\ncls");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9_CRSParts_1from_user_input = {"from_user_input", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9_CRSParts_1from_user_input, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9_CRSParts_from_user_input};
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_1from_user_input(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_user_input = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_user_input (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_user_input,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 506, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 506, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_user_input", 0) < (0)) __PYX_ERR(0, 506, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_user_input", 1, 1, 1, i); __PYX_ERR(0, 506, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 506, __pyx_L3_error)
    }
    __pyx_v_user_input = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_user_input", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 506, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRSParts.from_user_input", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_9_CRSParts_from_user_input(((PyTypeObject*)__pyx_v_cls), __pyx_v_user_input);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_from_user_input(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_user_input) {
  PyObject *__pyx_v_prepared = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11[4];
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_user_input", 0);

  /* "pyproj/_crs.pyx":529
 *         cls
 *         """
 *         if isinstance(user_input, str):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_string(user_input)
 *         elif isinstance(user_input, dict):
*/
  __pyx_t_1 = PyUnicode_Check(__pyx_v_user_input); 
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":530
 *         """
 *         if isinstance(user_input, str):
 *             prepared = cls.from_string(user_input)             # <<<<<<<<<<<<<<
 *         elif isinstance(user_input, dict):
 *             prepared = cls.from_json_dict(user_input)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_cls);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_user_input};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_prepared = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":529
 *         cls
 *         """
 *         if isinstance(user_input, str):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_string(user_input)
 *         elif isinstance(user_input, dict):
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":531
 *         if isinstance(user_input, str):
 *             prepared = cls.from_string(user_input)
 *         elif isinstance(user_input, dict):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_json_dict(user_input)
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):
*/
  __pyx_t_1 = PyDict_Check(__pyx_v_user_input); 
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":532
 *             prepared = cls.from_string(user_input)
 *         elif isinstance(user_input, dict):
 *             prepared = cls.from_json_dict(user_input)             # <<<<<<<<<<<<<<
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):
 *             prepared = cls.from_epsg(user_input)
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_cls);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_user_input};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_prepared = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":531
 *         if isinstance(user_input, str):
 *             prepared = cls.from_string(user_input)
 *         elif isinstance(user_input, dict):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_json_dict(user_input)
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":533
 *         elif isinstance(user_input, dict):
 *             prepared = cls.from_json_dict(user_input)
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_epsg(user_input)
 *         elif (
*/
  __pyx_t_5 = PyLong_Check(__pyx_v_user_input); 
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v_cls), __pyx_mstate_global->__pyx_n_u_from_epsg); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 533, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":534
 *             prepared = cls.from_json_dict(user_input)
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):
 *             prepared = cls.from_epsg(user_input)             # <<<<<<<<<<<<<<
 *         elif (
 *             isinstance(user_input, (list, tuple))
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_cls);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_user_input};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_prepared = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":533
 *         elif isinstance(user_input, dict):
 *             prepared = cls.from_json_dict(user_input)
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_epsg(user_input)
 *         elif (
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":536
 *             prepared = cls.from_epsg(user_input)
 *         elif (
 *             isinstance(user_input, (list, tuple))             # <<<<<<<<<<<<<<
 *             and len(user_input) == 2
 *             and hasattr(cls, "from_authority")
*/
  __pyx_t_6 = PyList_Check(__pyx_v_user_input); 
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_6 = PyTuple_Check(__pyx_v_user_input); 
  __pyx_t_5 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L6_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":537
 *         elif (
 *             isinstance(user_input, (list, tuple))
 *             and len(user_input) == 2             # <<<<<<<<<<<<<<
 *             and hasattr(cls, "from_authority")
 *         ):
*/
  __pyx_t_7 = PyObject_Length(__pyx_v_user_input); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 537, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_7 == 2);
  if (__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L6_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":538
 *             isinstance(user_input, (list, tuple))
 *             and len(user_input) == 2
 *             and hasattr(cls, "from_authority")             # <<<<<<<<<<<<<<
 *         ):
 *             prepared = cls.from_authority(*user_input)
*/
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v_cls), __pyx_mstate_global->__pyx_n_u_from_authority); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 538, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_5;
  __pyx_L6_bool_binop_done:;

  /* "pyproj/_crs.pyx":535
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):
 *             prepared = cls.from_epsg(user_input)
 *         elif (             # <<<<<<<<<<<<<<
 *             isinstance(user_input, (list, tuple))
 *             and len(user_input) == 2
*/
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":540
 *             and hasattr(cls, "from_authority")
 *         ):
 *             prepared = cls.from_authority(*user_input)             # <<<<<<<<<<<<<<
 *         elif hasattr(user_input, "to_json"):
 *             prepared = cls.from_json(user_input.to_json())
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_mstate_global->__pyx_n_u_from_authority); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_v_user_input); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_prepared = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "pyproj/_crs.pyx":535
 *         elif isinstance(user_input, int) and hasattr(cls, "from_epsg"):
 *             prepared = cls.from_epsg(user_input)
 *         elif (             # <<<<<<<<<<<<<<
 *             isinstance(user_input, (list, tuple))
 *             and len(user_input) == 2
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":541
 *         ):
 *             prepared = cls.from_authority(*user_input)
 *         elif hasattr(user_input, "to_json"):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_json(user_input.to_json())
 *         else:
*/
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_user_input, __pyx_mstate_global->__pyx_n_u_to_json); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 541, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "pyproj/_crs.pyx":542
 *             prepared = cls.from_authority(*user_input)
 *         elif hasattr(user_input, "to_json"):
 *             prepared = cls.from_json(user_input.to_json())             # <<<<<<<<<<<<<<
 *         else:
 *             raise CRSError(f"Invalid {cls.__name__} input: {user_input!r}")
*/
    __pyx_t_3 = ((PyObject *)__pyx_v_cls);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_9 = __pyx_v_user_input;
    __Pyx_INCREF(__pyx_t_9);
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_to_json, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_4 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __pyx_v_prepared = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "pyproj/_crs.pyx":541
 *         ):
 *             prepared = cls.from_authority(*user_input)
 *         elif hasattr(user_input, "to_json"):             # <<<<<<<<<<<<<<
 *             prepared = cls.from_json(user_input.to_json())
 *         else:
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":544
 *             prepared = cls.from_json(user_input.to_json())
 *         else:
 *             raise CRSError(f"Invalid {cls.__name__} input: {user_input!r}")             # <<<<<<<<<<<<<<
 *         return prepared
 * 
*/
  /*else*/ {
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_FormatSimple(__pyx_t_9, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_user_input), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11[0] = __pyx_mstate_global->__pyx_kp_u_Invalid;
    __pyx_t_11[1] = __pyx_t_10;
    __pyx_t_11[2] = __pyx_mstate_global->__pyx_kp_u_input;
    __pyx_t_11[3] = __pyx_t_9;
    __pyx_t_12 = __Pyx_PyUnicode_Join(__pyx_t_11, 4, 8 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_10) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_10) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9));
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_12};
      __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 544, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_Raise(__pyx_t_8, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(0, 544, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pyproj/_crs.pyx":545
 *         else:
 *             raise CRSError(f"Invalid {cls.__name__} input: {user_input!r}")
 *         return prepared             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_prepared);
  __pyx_r = __pyx_v_prepared;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":506
 * 
 * cdef class _CRSParts(Base):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_user_input(cls, user_input):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("pyproj._crs._CRSParts.from_user_input", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_prepared);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":547
 *         return prepared
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         try:
 *             other = self.from_user_input(other)
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_9_CRSParts_2__eq__(((struct __pyx_obj_6pyproj_4_crs__CRSParts *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_2__eq__(struct __pyx_obj_6pyproj_4_crs__CRSParts *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "pyproj/_crs.pyx":548
 * 
 *     def __eq__(self, other):
 *         try:             # <<<<<<<<<<<<<<
 *             other = self.from_user_input(other)
 *         except CRSError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":549
 *     def __eq__(self, other):
 *         try:
 *             other = self.from_user_input(other)             # <<<<<<<<<<<<<<
 *         except CRSError:
 *             return False
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_other};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_user_input, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 549, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pyproj/_crs.pyx":548
 * 
 *     def __eq__(self, other):
 *         try:             # <<<<<<<<<<<<<<
 *             other = self.from_user_input(other)
 *         except CRSError:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":550
 *         try:
 *             other = self.from_user_input(other)
 *         except CRSError:             # <<<<<<<<<<<<<<
 *             return False
 *         return self._is_equivalent(other)
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 550, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_7);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_ErrRestore(0,0,0);

      /* "pyproj/_crs.pyx":551
 *             other = self.from_user_input(other)
 *         except CRSError:
 *             return False             # <<<<<<<<<<<<<<
 *         return self._is_equivalent(other)
 * 
*/
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":548
 * 
 *     def __eq__(self, other):
 *         try:             # <<<<<<<<<<<<<<
 *             other = self.from_user_input(other)
 *         except CRSError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "pyproj/_crs.pyx":552
 *         except CRSError:
 *             return False
 *         return self._is_equivalent(other)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_other};
    __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_equivalent, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  }
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":547
 *         return prepared
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         try:
 *             other = self.from_user_input(other)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs._CRSParts.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9_CRSParts_4__reduce_cython__, "_CRSParts.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9_CRSParts_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9_CRSParts_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9_CRSParts_4__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_9_CRSParts_4__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs__CRSParts *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRSParts *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs._CRSParts.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9_CRSParts_6__setstate_cython__, "_CRSParts.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9_CRSParts_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9_CRSParts_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9_CRSParts_6__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_9_CRSParts_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRSParts.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_9_CRSParts_6__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs__CRSParts *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9_CRSParts_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRSParts *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs._CRSParts.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":580
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._axis_list = None
 * 
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_16CoordinateSystem_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_16CoordinateSystem_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem___cinit__(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_16CoordinateSystem___cinit__(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":581
 *     """
 *     def __cinit__(self):
 *         self._axis_list = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_axis_list);
  __Pyx_DECREF(__pyx_v_self->_axis_list);
  __pyx_v_self->_axis_list = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":580
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._axis_list = None
 * 
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":583
 *         self._axis_list = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("CoordinateSystem is not initializable.")
 * 
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_16CoordinateSystem_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_16CoordinateSystem_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_2__init__(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_16CoordinateSystem_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyproj/_crs.pyx":584
 * 
 *     def __init__(self):
 *         raise RuntimeError("CoordinateSystem is not initializable.")             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_CoordinateSystem_is_not_initiali};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 584, __pyx_L1_error)

  /* "pyproj/_crs.pyx":583
 *         self._axis_list = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError("CoordinateSystem is not initializable.")
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":586
 *         raise RuntimeError("CoordinateSystem is not initializable.")
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef CoordinateSystem create(PJ_CONTEXT* context, PJ* coord_system_pj):
 *         cdef CoordinateSystem coord_system = CoordinateSystem.__new__(CoordinateSystem)
*/

static struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_f_6pyproj_4_crs_16CoordinateSystem_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_coord_system_pj) {
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_coord_system = 0;
  PJ_COORDINATE_SYSTEM_TYPE __pyx_v_cs_type;
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":588
 *     @staticmethod
 *     cdef CoordinateSystem create(PJ_CONTEXT* context, PJ* coord_system_pj):
 *         cdef CoordinateSystem coord_system = CoordinateSystem.__new__(CoordinateSystem)             # <<<<<<<<<<<<<<
 *         coord_system.context = context
 *         coord_system._context_manager = get_context_manager()
*/
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6pyproj_4_crs_CoordinateSystem(((PyTypeObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem), __pyx_mstate_global->__pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_1);
  __pyx_v_coord_system = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":589
 *     cdef CoordinateSystem create(PJ_CONTEXT* context, PJ* coord_system_pj):
 *         cdef CoordinateSystem coord_system = CoordinateSystem.__new__(CoordinateSystem)
 *         coord_system.context = context             # <<<<<<<<<<<<<<
 *         coord_system._context_manager = get_context_manager()
 *         coord_system.projobj = coord_system_pj
*/
  __pyx_v_coord_system->__pyx_base.__pyx_base.context = __pyx_v_context;

  /* "pyproj/_crs.pyx":590
 *         cdef CoordinateSystem coord_system = CoordinateSystem.__new__(CoordinateSystem)
 *         coord_system.context = context
 *         coord_system._context_manager = get_context_manager()             # <<<<<<<<<<<<<<
 *         coord_system.projobj = coord_system_pj
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_get_context_manager); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_coord_system->__pyx_base.__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_coord_system->__pyx_base.__pyx_base._context_manager);
  __pyx_v_coord_system->__pyx_base.__pyx_base._context_manager = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":591
 *         coord_system.context = context
 *         coord_system._context_manager = get_context_manager()
 *         coord_system.projobj = coord_system_pj             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ_COORDINATE_SYSTEM_TYPE cs_type = proj_cs_get_type(
*/
  __pyx_v_coord_system->__pyx_base.__pyx_base.projobj = __pyx_v_coord_system_pj;

  /* "pyproj/_crs.pyx":593
 *         coord_system.projobj = coord_system_pj
 * 
 *         cdef PJ_COORDINATE_SYSTEM_TYPE cs_type = proj_cs_get_type(             # <<<<<<<<<<<<<<
 *             coord_system.context,
 *             coord_system.projobj,
*/
  __pyx_v_cs_type = proj_cs_get_type(__pyx_v_coord_system->__pyx_base.__pyx_base.context, __pyx_v_coord_system->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":597
 *             coord_system.projobj,
 *         )
 *         coord_system.name = _COORD_SYSTEM_TYPE_MAP[cs_type]             # <<<<<<<<<<<<<<
 *         return coord_system
 * 
*/
  if (unlikely(__pyx_v_6pyproj_4_crs__COORD_SYSTEM_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 597, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(__pyx_v_cs_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_6pyproj_4_crs__COORD_SYSTEM_TYPE_MAP, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_coord_system->__pyx_base.__pyx_base.name);
  __Pyx_DECREF(__pyx_v_coord_system->__pyx_base.__pyx_base.name);
  __pyx_v_coord_system->__pyx_base.__pyx_base.name = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyproj/_crs.pyx":598
 *         )
 *         coord_system.name = _COORD_SYSTEM_TYPE_MAP[cs_type]
 *         return coord_system             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_coord_system);
  __pyx_r = __pyx_v_coord_system;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":586
 *         raise RuntimeError("CoordinateSystem is not initializable.")
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef CoordinateSystem create(PJ_CONTEXT* context, PJ* coord_system_pj):
 *         cdef CoordinateSystem coord_system = CoordinateSystem.__new__(CoordinateSystem)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_coord_system);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":600
 *         return coord_system
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def axis_list(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_9axis_list_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_9axis_list_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_9axis_list___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_9axis_list___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self) {
  int __pyx_v_num_axes;
  long __pyx_v_axis_idx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":608
 *             The Axis list for the coordinate system.
 *         """
 *         if self._axis_list is not None:             # <<<<<<<<<<<<<<
 *             return self._axis_list
 *         self._axis_list = []
*/
  __pyx_t_1 = (__pyx_v_self->_axis_list != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":609
 *         """
 *         if self._axis_list is not None:
 *             return self._axis_list             # <<<<<<<<<<<<<<
 *         self._axis_list = []
 *         cdef int num_axes = 0
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_axis_list);
    __pyx_r = __pyx_v_self->_axis_list;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":608
 *             The Axis list for the coordinate system.
 *         """
 *         if self._axis_list is not None:             # <<<<<<<<<<<<<<
 *             return self._axis_list
 *         self._axis_list = []
*/
  }

  /* "pyproj/_crs.pyx":610
 *         if self._axis_list is not None:
 *             return self._axis_list
 *         self._axis_list = []             # <<<<<<<<<<<<<<
 *         cdef int num_axes = 0
 *         num_axes = proj_cs_get_axis_count(
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_axis_list);
  __Pyx_DECREF(__pyx_v_self->_axis_list);
  __pyx_v_self->_axis_list = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":611
 *             return self._axis_list
 *         self._axis_list = []
 *         cdef int num_axes = 0             # <<<<<<<<<<<<<<
 *         num_axes = proj_cs_get_axis_count(
 *             self.context,
*/
  __pyx_v_num_axes = 0;

  /* "pyproj/_crs.pyx":612
 *         self._axis_list = []
 *         cdef int num_axes = 0
 *         num_axes = proj_cs_get_axis_count(             # <<<<<<<<<<<<<<
 *             self.context,
 *             self.projobj
*/
  __pyx_v_num_axes = proj_cs_get_axis_count(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":616
 *             self.projobj
 *         )
 *         for axis_idx from 0 <= axis_idx < num_axes:             # <<<<<<<<<<<<<<
 *             self._axis_list.append(
 *                 Axis.create(
*/
  __pyx_t_3 = __pyx_v_num_axes;
  for (__pyx_v_axis_idx = 0; __pyx_v_axis_idx < __pyx_t_3; __pyx_v_axis_idx++) {

    /* "pyproj/_crs.pyx":617
 *         )
 *         for axis_idx from 0 <= axis_idx < num_axes:
 *             self._axis_list.append(             # <<<<<<<<<<<<<<
 *                 Axis.create(
 *                     self.context,
*/
    if (unlikely(__pyx_v_self->_axis_list == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 617, __pyx_L1_error)
    }

    /* "pyproj/_crs.pyx":618
 *         for axis_idx from 0 <= axis_idx < num_axes:
 *             self._axis_list.append(
 *                 Axis.create(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     self.projobj,
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_4Axis_create(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj, __pyx_v_axis_idx)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pyproj/_crs.pyx":617
 *         )
 *         for axis_idx from 0 <= axis_idx < num_axes:
 *             self._axis_list.append(             # <<<<<<<<<<<<<<
 *                 Axis.create(
 *                     self.context,
*/
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->_axis_list, __pyx_t_2); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 617, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":624
 *                 )
 *             )
 *         return self._axis_list             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_axis_list);
  __pyx_r = __pyx_v_self->_axis_list;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":600
 *         return coord_system
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def axis_list(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.axis_list.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":626
 *         return self._axis_list
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str coordinate_system_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_16CoordinateSystem_4from_string, "CoordinateSystem.from_string(str coordinate_system_string)\n\n.. versionadded:: 2.5.0\n\n.. note:: Only works with PROJ JSON.\n\nCreate a Coordinate System from a string.\n\nParameters\n----------\ncoordinate_system_string: str\n    Coordinate System string.\n\nReturns\n-------\nCoordinateSystem");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_5from_string = {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_4from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_system_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_system_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 626, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 626, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_string", 0) < (0)) __PYX_ERR(0, 626, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, i); __PYX_ERR(0, 626, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 626, __pyx_L3_error)
    }
    __pyx_v_coordinate_system_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 626, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_system_string), (&PyUnicode_Type), 0, "coordinate_system_string", 1))) __PYX_ERR(0, 627, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_4from_string(__pyx_v_coordinate_system_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_4from_string(PyObject *__pyx_v_coordinate_system_string) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_coordinate_system_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_string", 0);

  /* "pyproj/_crs.pyx":644
 *         CoordinateSystem
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* coordinate_system_pj = proj_create(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 644, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":647
 *         cdef PJ* coordinate_system_pj = proj_create(
 *             context,
 *             cstrencode(coordinate_system_string)             # <<<<<<<<<<<<<<
 *         )
 *         if coordinate_system_pj == NULL or proj_cs_get_type(
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_coordinate_system_string, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 647, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 647, __pyx_L1_error)

  /* "pyproj/_crs.pyx":645
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coordinate_system_pj = proj_create(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(coordinate_system_string)
*/
  __pyx_v_coordinate_system_pj = proj_create(__pyx_v_context, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":649
 *             cstrencode(coordinate_system_string)
 *         )
 *         if coordinate_system_pj == NULL or proj_cs_get_type(             # <<<<<<<<<<<<<<
 *             context,
 *             coordinate_system_pj,
*/
  __pyx_t_5 = (__pyx_v_coordinate_system_pj == NULL);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":652
 *             context,
 *             coordinate_system_pj,
 *         ) == PJ_CS_TYPE_UNKNOWN:             # <<<<<<<<<<<<<<
 *             proj_destroy(coordinate_system_pj)
 *             raise CRSError(
*/
  __pyx_t_5 = (proj_cs_get_type(__pyx_v_context, __pyx_v_coordinate_system_pj) == PJ_CS_TYPE_UNKNOWN);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "pyproj/_crs.pyx":649
 *             cstrencode(coordinate_system_string)
 *         )
 *         if coordinate_system_pj == NULL or proj_cs_get_type(             # <<<<<<<<<<<<<<
 *             context,
 *             coordinate_system_pj,
*/
  if (unlikely(__pyx_t_4)) {

    /* "pyproj/_crs.pyx":653
 *             coordinate_system_pj,
 *         ) == PJ_CS_TYPE_UNKNOWN:
 *             proj_destroy(coordinate_system_pj)             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 "Invalid coordinate system string: "
*/
    proj_destroy(__pyx_v_coordinate_system_pj);

    /* "pyproj/_crs.pyx":654
 *         ) == PJ_CS_TYPE_UNKNOWN:
 *             proj_destroy(coordinate_system_pj)
 *             raise CRSError(             # <<<<<<<<<<<<<<
 *                 "Invalid coordinate system string: "
 *                 f"{coordinate_system_string}"
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "pyproj/_crs.pyx":655
 *             proj_destroy(coordinate_system_pj)
 *             raise CRSError(
 *                 "Invalid coordinate system string: "             # <<<<<<<<<<<<<<
 *                 f"{coordinate_system_string}"
 *             )
*/
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_coordinate_system_string, __pyx_v_coordinate_system_string); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 654, __pyx_L1_error)

    /* "pyproj/_crs.pyx":649
 *             cstrencode(coordinate_system_string)
 *         )
 *         if coordinate_system_pj == NULL or proj_cs_get_type(             # <<<<<<<<<<<<<<
 *             context,
 *             coordinate_system_pj,
*/
  }

  /* "pyproj/_crs.pyx":658
 *                 f"{coordinate_system_string}"
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return CoordinateSystem.create(context, coordinate_system_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":659
 *             )
 *         _clear_proj_error()
 *         return CoordinateSystem.create(context, coordinate_system_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_16CoordinateSystem_create(__pyx_v_context, __pyx_v_coordinate_system_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":626
 *         return self._axis_list
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str coordinate_system_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":661
 *         return CoordinateSystem.create(context, coordinate_system_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict coordinate_system_dict not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_7from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_16CoordinateSystem_6from_json_dict, "CoordinateSystem.from_json_dict(dict coordinate_system_dict)\n\n.. versionadded:: 2.5.0\n\nCreate Coordinate System from a JSON dictionary.\n\nParameters\n----------\ncoordinate_system_dict: str\n    Coordinate System dictionary.\n\nReturns\n-------\nCoordinateSystem");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_7from_json_dict = {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_7from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_6from_json_dict};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_7from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_system_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_system_dict,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 661, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 661, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json_dict", 0) < (0)) __PYX_ERR(0, 661, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, i); __PYX_ERR(0, 661, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 661, __pyx_L3_error)
    }
    __pyx_v_coordinate_system_dict = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 661, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_system_dict), (&PyDict_Type), 0, "coordinate_system_dict", 1))) __PYX_ERR(0, 662, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_6from_json_dict(__pyx_v_coordinate_system_dict);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_6from_json_dict(PyObject *__pyx_v_coordinate_system_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json_dict", 0);

  /* "pyproj/_crs.pyx":677
 *         CoordinateSystem
 *         """
 *         return CoordinateSystem.from_string(             # <<<<<<<<<<<<<<
 *             json.dumps(coordinate_system_dict, cls=NumpyEncoder)
 *         )
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":678
 *         """
 *         return CoordinateSystem.from_string(
 *             json.dumps(coordinate_system_dict, cls=NumpyEncoder)             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NumpyEncoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_coordinate_system_dict};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cls, __pyx_t_5, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 678, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":661
 *         return CoordinateSystem.create(context, coordinate_system_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict coordinate_system_dict not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":681
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str coordinate_system_json_str not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_9from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_16CoordinateSystem_8from_json, "CoordinateSystem.from_json(str coordinate_system_json_str)\n\n.. versionadded:: 2.5.0\n\nCreate Coordinate System from a JSON string.\n\nParameters\n----------\ncoordinate_system_json_str: str\n    Coordinate System JSON string.\n\nReturns\n-------\nCoordinateSystem");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_9from_json = {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_9from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_8from_json};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_9from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_system_json_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_system_json_str,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 681, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 681, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json", 0) < (0)) __PYX_ERR(0, 681, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, i); __PYX_ERR(0, 681, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 681, __pyx_L3_error)
    }
    __pyx_v_coordinate_system_json_str = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 681, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_system_json_str), (&PyUnicode_Type), 0, "coordinate_system_json_str", 1))) __PYX_ERR(0, 682, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_8from_json(__pyx_v_coordinate_system_json_str);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_8from_json(PyObject *__pyx_v_coordinate_system_json_str) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json", 0);

  /* "pyproj/_crs.pyx":697
 *         CoordinateSystem
 *         """
 *         return CoordinateSystem.from_json_dict(             # <<<<<<<<<<<<<<
 *             _load_proj_json(coordinate_system_json_str)
 *         )
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":698
 *         """
 *         return CoordinateSystem.from_json_dict(
 *             _load_proj_json(coordinate_system_json_str)             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_load_proj_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_coordinate_system_json_str};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":681
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str coordinate_system_json_str not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":701
 *         )
 * 
 *     def to_cf(self, bint rotated_pole=False):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.0.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_11to_cf(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_16CoordinateSystem_10to_cf, "CoordinateSystem.to_cf(self, bool rotated_pole=False)\n\n.. versionadded:: 3.0.0\n\nThis converts a :obj:`pyproj.crs.CoordinateSystem` axis\nto a list of Climate and Forecast (CF) Version 1.8 dicts.\n\nParameters\n----------\nrotated_pole: bool, default=False\n    If True, the geographic coordinates are on a rotated pole grid.\n    This corresponds to the rotated_latitude_longitude grid_mapping_name.\n\nReturns\n-------\nlist[dict]:\n    CF-1.8 version of the CoordinateSystem.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_11to_cf = {"to_cf", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_11to_cf, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_10to_cf};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_11to_cf(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_rotated_pole;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_cf (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_rotated_pole,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 701, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 701, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_cf", 0) < (0)) __PYX_ERR(0, 701, __pyx_L3_error)
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 701, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_rotated_pole = __Pyx_PyObject_IsTrue(values[0]); if (unlikely((__pyx_v_rotated_pole == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 701, __pyx_L3_error)
    } else {
      __pyx_v_rotated_pole = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_cf", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 701, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.to_cf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_10to_cf(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self), __pyx_v_rotated_pole);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":721
 *         axis_list = self.to_json_dict()["axis"]
 *         cf_params = []
 *         def get_linear_unit(axis):             # <<<<<<<<<<<<<<
 *             try:
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5to_cf_1get_linear_unit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_5to_cf_1get_linear_unit = {"get_linear_unit", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5to_cf_1get_linear_unit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5to_cf_1get_linear_unit(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_axis = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_linear_unit (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_axis,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 721, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 721, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_linear_unit", 0) < (0)) __PYX_ERR(0, 721, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_linear_unit", 1, 1, 1, i); __PYX_ERR(0, 721, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 721, __pyx_L3_error)
    }
    __pyx_v_axis = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_linear_unit", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 721, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.to_cf.get_linear_unit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_5to_cf_get_linear_unit(__pyx_self, __pyx_v_axis);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_5to_cf_get_linear_unit(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_axis) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_linear_unit", 0);

  /* "pyproj/_crs.pyx":722
 *         cf_params = []
 *         def get_linear_unit(axis):
 *             try:             # <<<<<<<<<<<<<<
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
 *             except TypeError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":723
 *         def get_linear_unit(axis):
 *             try:
 *                 return f'{axis["unit"]["conversion_factor"]} metre'             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 return axis["unit"]
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_unit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 723, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_conversion_factor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 723, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 723, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_metre); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 723, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":722
 *         cf_params = []
 *         def get_linear_unit(axis):
 *             try:             # <<<<<<<<<<<<<<
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
 *             except TypeError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":724
 *             try:
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 return axis["unit"]
 * 
*/
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_TypeError))));
    if (__pyx_t_6) {
      __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.to_cf.get_linear_unit", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 724, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "pyproj/_crs.pyx":725
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
 *             except TypeError:
 *                 return axis["unit"]             # <<<<<<<<<<<<<<
 * 
 *         if self.name == "cartesian":
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_unit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 725, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":722
 *         cf_params = []
 *         def get_linear_unit(axis):
 *             try:             # <<<<<<<<<<<<<<
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
 *             except TypeError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":721
 *         axis_list = self.to_json_dict()["axis"]
 *         cf_params = []
 *         def get_linear_unit(axis):             # <<<<<<<<<<<<<<
 *             try:
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.to_cf.get_linear_unit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":701
 *         )
 * 
 *     def to_cf(self, bint rotated_pole=False):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.0.0
*/

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_10to_cf(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self, int __pyx_v_rotated_pole) {
  PyObject *__pyx_v_axis_list = NULL;
  PyObject *__pyx_v_cf_params = NULL;
  PyObject *__pyx_v_get_linear_unit = 0;
  PyObject *__pyx_v_axis = NULL;
  PyObject *__pyx_v_cf_axis = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[3];
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_cf", 0);

  /* "pyproj/_crs.pyx":719
 *             CF-1.8 version of the CoordinateSystem.
 *         """
 *         axis_list = self.to_json_dict()["axis"]             # <<<<<<<<<<<<<<
 *         cf_params = []
 *         def get_linear_unit(axis):
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_to_json_dict, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_axis_list = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":720
 *         """
 *         axis_list = self.to_json_dict()["axis"]
 *         cf_params = []             # <<<<<<<<<<<<<<
 *         def get_linear_unit(axis):
 *             try:
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_cf_params = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":721
 *         axis_list = self.to_json_dict()["axis"]
 *         cf_params = []
 *         def get_linear_unit(axis):             # <<<<<<<<<<<<<<
 *             try:
 *                 return f'{axis["unit"]["conversion_factor"]} metre'
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_5to_cf_1get_linear_unit, 0, __pyx_mstate_global->__pyx_n_u_to_cf_locals_get_linear_unit, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_get_linear_unit = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":727
 *                 return axis["unit"]
 * 
 *         if self.name == "cartesian":             # <<<<<<<<<<<<<<
 *             for axis in axis_list:
 *                 if axis["name"].lower() == "easting":
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_self->__pyx_base.__pyx_base.name, __pyx_mstate_global->__pyx_n_u_cartesian, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 727, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "pyproj/_crs.pyx":728
 * 
 *         if self.name == "cartesian":
 *             for axis in axis_list:             # <<<<<<<<<<<<<<
 *                 if axis["name"].lower() == "easting":
 *                     cf_axis = "X"
*/
    if (likely(PyList_CheckExact(__pyx_v_axis_list)) || PyTuple_CheckExact(__pyx_v_axis_list)) {
      __pyx_t_2 = __pyx_v_axis_list; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_axis_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 728, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 728, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 728, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_5;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 728, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5);
          #endif
          ++__pyx_t_5;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 728, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_6(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 728, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_axis, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":729
 *         if self.name == "cartesian":
 *             for axis in axis_list:
 *                 if axis["name"].lower() == "easting":             # <<<<<<<<<<<<<<
 *                     cf_axis = "X"
 *                 else:
*/
      __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 729, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __pyx_t_8;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 729, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_easting, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 729, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_4) {

        /* "pyproj/_crs.pyx":730
 *             for axis in axis_list:
 *                 if axis["name"].lower() == "easting":
 *                     cf_axis = "X"             # <<<<<<<<<<<<<<
 *                 else:
 *                     cf_axis = "Y"
*/
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_X);
        __Pyx_XDECREF_SET(__pyx_v_cf_axis, __pyx_mstate_global->__pyx_n_u_X);

        /* "pyproj/_crs.pyx":729
 *         if self.name == "cartesian":
 *             for axis in axis_list:
 *                 if axis["name"].lower() == "easting":             # <<<<<<<<<<<<<<
 *                     cf_axis = "X"
 *                 else:
*/
        goto __pyx_L6;
      }

      /* "pyproj/_crs.pyx":732
 *                     cf_axis = "X"
 *                 else:
 *                     cf_axis = "Y"             # <<<<<<<<<<<<<<
 *                 cf_params.append(dict(
 *                     axis=cf_axis,
*/
      /*else*/ {
        __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_Y);
        __Pyx_XDECREF_SET(__pyx_v_cf_axis, __pyx_mstate_global->__pyx_n_u_Y);
      }
      __pyx_L6:;

      /* "pyproj/_crs.pyx":734
 *                     cf_axis = "Y"
 *                 cf_params.append(dict(
 *                     axis=cf_axis,             # <<<<<<<<<<<<<<
 *                     long_name=axis["name"],
 *                     standard_name=f"projection_{cf_axis.lower()}_coordinate",
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 734, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis, __pyx_v_cf_axis) < (0)) __PYX_ERR(0, 734, __pyx_L1_error)

      /* "pyproj/_crs.pyx":735
 *                 cf_params.append(dict(
 *                     axis=cf_axis,
 *                     long_name=axis["name"],             # <<<<<<<<<<<<<<
 *                     standard_name=f"projection_{cf_axis.lower()}_coordinate",
 *                     units=get_linear_unit(axis),
*/
      __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 735, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_long_name, __pyx_t_8) < (0)) __PYX_ERR(0, 734, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "pyproj/_crs.pyx":736
 *                     axis=cf_axis,
 *                     long_name=axis["name"],
 *                     standard_name=f"projection_{cf_axis.lower()}_coordinate",             # <<<<<<<<<<<<<<
 *                     units=get_linear_unit(axis),
 *                 ))
*/
      __pyx_t_8 = __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyUnicode_Type__lower, __pyx_v_cf_axis); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9[0] = __pyx_mstate_global->__pyx_n_u_projection;
      __pyx_t_9[1] = __pyx_t_8;
      __pyx_t_9[2] = __pyx_mstate_global->__pyx_n_u_coordinate;
      __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_9, 3, 11 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_standard_name, __pyx_t_7) < (0)) __PYX_ERR(0, 734, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pyproj/_crs.pyx":737
 *                     long_name=axis["name"],
 *                     standard_name=f"projection_{cf_axis.lower()}_coordinate",
 *                     units=get_linear_unit(axis),             # <<<<<<<<<<<<<<
 *                 ))
 *         elif self.name == "ellipsoidal":
*/
      __pyx_t_7 = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_5to_cf_get_linear_unit(__pyx_v_get_linear_unit, __pyx_v_axis); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 737, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_units, __pyx_t_7) < (0)) __PYX_ERR(0, 734, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pyproj/_crs.pyx":733
 *                 else:
 *                     cf_axis = "Y"
 *                 cf_params.append(dict(             # <<<<<<<<<<<<<<
 *                     axis=cf_axis,
 *                     long_name=axis["name"],
*/
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_cf_params, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 733, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":728
 * 
 *         if self.name == "cartesian":
 *             for axis in axis_list:             # <<<<<<<<<<<<<<
 *                 if axis["name"].lower() == "easting":
 *                     cf_axis = "X"
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":727
 *                 return axis["unit"]
 * 
 *         if self.name == "cartesian":             # <<<<<<<<<<<<<<
 *             for axis in axis_list:
 *                 if axis["name"].lower() == "easting":
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":739
 *                     units=get_linear_unit(axis),
 *                 ))
 *         elif self.name == "ellipsoidal":             # <<<<<<<<<<<<<<
 *             for axis in axis_list:
 *                 if axis["abbreviation"].upper() in ("D", "H"):
*/
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_self->__pyx_base.__pyx_base.name, __pyx_mstate_global->__pyx_n_u_ellipsoidal, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 739, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "pyproj/_crs.pyx":740
 *                 ))
 *         elif self.name == "ellipsoidal":
 *             for axis in axis_list:             # <<<<<<<<<<<<<<
 *                 if axis["abbreviation"].upper() in ("D", "H"):
 *                     cf_params.append(dict(
*/
    if (likely(PyList_CheckExact(__pyx_v_axis_list)) || PyTuple_CheckExact(__pyx_v_axis_list)) {
      __pyx_t_2 = __pyx_v_axis_list; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_axis_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 740, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 740, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 740, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_5;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 740, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5);
          #endif
          ++__pyx_t_5;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 740, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_6(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 740, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_axis, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":741
 *         elif self.name == "ellipsoidal":
 *             for axis in axis_list:
 *                 if axis["abbreviation"].upper() in ("D", "H"):             # <<<<<<<<<<<<<<
 *                     cf_params.append(dict(
 *                         standard_name="height_above_reference_ellipsoid",
*/
      __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_abbreviation); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 741, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __pyx_t_8;
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_3 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_upper, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 741, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_D, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 741, __pyx_L1_error)
      if (!__pyx_t_11) {
      } else {
        __pyx_t_4 = __pyx_t_11;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_H, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 741, __pyx_L1_error)
      __pyx_t_4 = __pyx_t_11;
      __pyx_L11_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = __pyx_t_4;
      if (__pyx_t_11) {

        /* "pyproj/_crs.pyx":743
 *                 if axis["abbreviation"].upper() in ("D", "H"):
 *                     cf_params.append(dict(
 *                         standard_name="height_above_reference_ellipsoid",             # <<<<<<<<<<<<<<
 *                         long_name=axis["name"],
 *                         units=axis["unit"],
*/
        __pyx_t_1 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 743, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_standard_name, __pyx_mstate_global->__pyx_n_u_height_above_reference_ellipsoid) < (0)) __PYX_ERR(0, 743, __pyx_L1_error)

        /* "pyproj/_crs.pyx":744
 *                     cf_params.append(dict(
 *                         standard_name="height_above_reference_ellipsoid",
 *                         long_name=axis["name"],             # <<<<<<<<<<<<<<
 *                         units=axis["unit"],
 *                         positive=axis["direction"],
*/
        __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 744, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_long_name, __pyx_t_8) < (0)) __PYX_ERR(0, 743, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "pyproj/_crs.pyx":745
 *                         standard_name="height_above_reference_ellipsoid",
 *                         long_name=axis["name"],
 *                         units=axis["unit"],             # <<<<<<<<<<<<<<
 *                         positive=axis["direction"],
 *                         axis="Z",
*/
        __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_unit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 745, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_units, __pyx_t_8) < (0)) __PYX_ERR(0, 743, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "pyproj/_crs.pyx":746
 *                         long_name=axis["name"],
 *                         units=axis["unit"],
 *                         positive=axis["direction"],             # <<<<<<<<<<<<<<
 *                         axis="Z",
 *                     ))
*/
        __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_direction_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 746, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_positive, __pyx_t_8) < (0)) __PYX_ERR(0, 743, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis, __pyx_mstate_global->__pyx_n_u_Z) < (0)) __PYX_ERR(0, 743, __pyx_L1_error)

        /* "pyproj/_crs.pyx":742
 *             for axis in axis_list:
 *                 if axis["abbreviation"].upper() in ("D", "H"):
 *                     cf_params.append(dict(             # <<<<<<<<<<<<<<
 *                         standard_name="height_above_reference_ellipsoid",
 *                         long_name=axis["name"],
*/
        __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_cf_params, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 742, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pyproj/_crs.pyx":741
 *         elif self.name == "ellipsoidal":
 *             for axis in axis_list:
 *                 if axis["abbreviation"].upper() in ("D", "H"):             # <<<<<<<<<<<<<<
 *                     cf_params.append(dict(
 *                         standard_name="height_above_reference_ellipsoid",
*/
        goto __pyx_L10;
      }

      /* "pyproj/_crs.pyx":750
 *                     ))
 *                 else:
 *                     if "longitude" in axis["name"].lower():             # <<<<<<<<<<<<<<
 *                         cf_axis = "X"
 *                         name = "longitude"
*/
      /*else*/ {
        __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __pyx_t_7;
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_3 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_lower, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 750, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_longitude, __pyx_t_1, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 750, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_11) {

          /* "pyproj/_crs.pyx":751
 *                 else:
 *                     if "longitude" in axis["name"].lower():
 *                         cf_axis = "X"             # <<<<<<<<<<<<<<
 *                         name = "longitude"
 *                     else:
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_X);
          __Pyx_XDECREF_SET(__pyx_v_cf_axis, __pyx_mstate_global->__pyx_n_u_X);

          /* "pyproj/_crs.pyx":752
 *                     if "longitude" in axis["name"].lower():
 *                         cf_axis = "X"
 *                         name = "longitude"             # <<<<<<<<<<<<<<
 *                     else:
 *                         cf_axis = "Y"
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_longitude);
          __Pyx_XDECREF_SET(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_longitude);

          /* "pyproj/_crs.pyx":750
 *                     ))
 *                 else:
 *                     if "longitude" in axis["name"].lower():             # <<<<<<<<<<<<<<
 *                         cf_axis = "X"
 *                         name = "longitude"
*/
          goto __pyx_L13;
        }

        /* "pyproj/_crs.pyx":754
 *                         name = "longitude"
 *                     else:
 *                         cf_axis = "Y"             # <<<<<<<<<<<<<<
 *                         name = "latitude"
 *                     if rotated_pole:
*/
        /*else*/ {
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_Y);
          __Pyx_XDECREF_SET(__pyx_v_cf_axis, __pyx_mstate_global->__pyx_n_u_Y);

          /* "pyproj/_crs.pyx":755
 *                     else:
 *                         cf_axis = "Y"
 *                         name = "latitude"             # <<<<<<<<<<<<<<
 *                     if rotated_pole:
 *                         cf_params.append(dict(
*/
          __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_latitude);
          __Pyx_XDECREF_SET(__pyx_v_name, __pyx_mstate_global->__pyx_n_u_latitude);
        }
        __pyx_L13:;

        /* "pyproj/_crs.pyx":756
 *                         cf_axis = "Y"
 *                         name = "latitude"
 *                     if rotated_pole:             # <<<<<<<<<<<<<<
 *                         cf_params.append(dict(
 *                             standard_name=f"grid_{name}",
*/
        if (__pyx_v_rotated_pole) {

          /* "pyproj/_crs.pyx":758
 *                     if rotated_pole:
 *                         cf_params.append(dict(
 *                             standard_name=f"grid_{name}",             # <<<<<<<<<<<<<<
 *                             long_name=f"{name} in rotated pole grid",
 *                             units="degrees",
*/
          __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 758, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_n_u_grid, __pyx_v_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 758, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_standard_name, __pyx_t_7) < (0)) __PYX_ERR(0, 758, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "pyproj/_crs.pyx":759
 *                         cf_params.append(dict(
 *                             standard_name=f"grid_{name}",
 *                             long_name=f"{name} in rotated pole grid",             # <<<<<<<<<<<<<<
 *                             units="degrees",
 *                             axis=cf_axis,
*/
          __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_v_name, __pyx_mstate_global->__pyx_kp_u_in_rotated_pole_grid); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 759, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_long_name, __pyx_t_7) < (0)) __PYX_ERR(0, 758, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_units, __pyx_mstate_global->__pyx_n_u_degrees) < (0)) __PYX_ERR(0, 758, __pyx_L1_error)

          /* "pyproj/_crs.pyx":761
 *                             long_name=f"{name} in rotated pole grid",
 *                             units="degrees",
 *                             axis=cf_axis,             # <<<<<<<<<<<<<<
 *                         ))
 *                     else:
*/
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis, __pyx_v_cf_axis) < (0)) __PYX_ERR(0, 758, __pyx_L1_error)

          /* "pyproj/_crs.pyx":757
 *                         name = "latitude"
 *                     if rotated_pole:
 *                         cf_params.append(dict(             # <<<<<<<<<<<<<<
 *                             standard_name=f"grid_{name}",
 *                             long_name=f"{name} in rotated pole grid",
*/
          __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_cf_params, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 757, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "pyproj/_crs.pyx":756
 *                         cf_axis = "Y"
 *                         name = "latitude"
 *                     if rotated_pole:             # <<<<<<<<<<<<<<
 *                         cf_params.append(dict(
 *                             standard_name=f"grid_{name}",
*/
          goto __pyx_L14;
        }

        /* "pyproj/_crs.pyx":764
 *                         ))
 *                     else:
 *                         cf_params.append(dict(             # <<<<<<<<<<<<<<
 *                             standard_name=name,
 *                             long_name=f"{name} coordinate",
*/
        /*else*/ {

          /* "pyproj/_crs.pyx":765
 *                     else:
 *                         cf_params.append(dict(
 *                             standard_name=name,             # <<<<<<<<<<<<<<
 *                             long_name=f"{name} coordinate",
 *                             units=f'degrees_{axis["direction"]}',
*/
          __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_standard_name, __pyx_v_name) < (0)) __PYX_ERR(0, 765, __pyx_L1_error)

          /* "pyproj/_crs.pyx":766
 *                         cf_params.append(dict(
 *                             standard_name=name,
 *                             long_name=f"{name} coordinate",             # <<<<<<<<<<<<<<
 *                             units=f'degrees_{axis["direction"]}',
 *                             axis=cf_axis,
*/
          __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_v_name, __pyx_mstate_global->__pyx_kp_u_coordinate_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 766, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_long_name, __pyx_t_7) < (0)) __PYX_ERR(0, 765, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "pyproj/_crs.pyx":767
 *                             standard_name=name,
 *                             long_name=f"{name} coordinate",
 *                             units=f'degrees_{axis["direction"]}',             # <<<<<<<<<<<<<<
 *                             axis=cf_axis,
 *                         ))
*/
          __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_direction_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 767, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 767, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_n_u_degrees_2, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 767, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_units, __pyx_t_7) < (0)) __PYX_ERR(0, 765, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "pyproj/_crs.pyx":768
 *                             long_name=f"{name} coordinate",
 *                             units=f'degrees_{axis["direction"]}',
 *                             axis=cf_axis,             # <<<<<<<<<<<<<<
 *                         ))
 *         elif self.name == "vertical":
*/
          if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis, __pyx_v_cf_axis) < (0)) __PYX_ERR(0, 765, __pyx_L1_error)

          /* "pyproj/_crs.pyx":764
 *                         ))
 *                     else:
 *                         cf_params.append(dict(             # <<<<<<<<<<<<<<
 *                             standard_name=name,
 *                             long_name=f"{name} coordinate",
*/
          __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_cf_params, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 764, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L14:;
      }
      __pyx_L10:;

      /* "pyproj/_crs.pyx":740
 *                 ))
 *         elif self.name == "ellipsoidal":
 *             for axis in axis_list:             # <<<<<<<<<<<<<<
 *                 if axis["abbreviation"].upper() in ("D", "H"):
 *                     cf_params.append(dict(
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":739
 *                     units=get_linear_unit(axis),
 *                 ))
 *         elif self.name == "ellipsoidal":             # <<<<<<<<<<<<<<
 *             for axis in axis_list:
 *                 if axis["abbreviation"].upper() in ("D", "H"):
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":770
 *                             axis=cf_axis,
 *                         ))
 *         elif self.name == "vertical":             # <<<<<<<<<<<<<<
 *             for axis in axis_list:
 *                 cf_params.append(dict(
*/
  __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_v_self->__pyx_base.__pyx_base.name, __pyx_mstate_global->__pyx_n_u_vertical, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 770, __pyx_L1_error)
  if (__pyx_t_11) {

    /* "pyproj/_crs.pyx":771
 *                         ))
 *         elif self.name == "vertical":
 *             for axis in axis_list:             # <<<<<<<<<<<<<<
 *                 cf_params.append(dict(
 *                     standard_name="height_above_reference_ellipsoid",
*/
    if (likely(PyList_CheckExact(__pyx_v_axis_list)) || PyTuple_CheckExact(__pyx_v_axis_list)) {
      __pyx_t_2 = __pyx_v_axis_list; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_axis_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 771, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_6)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 771, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_2, __pyx_t_5, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_5;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 771, __pyx_L1_error)
            #endif
            if (__pyx_t_5 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_5));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_5);
          #endif
          ++__pyx_t_5;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 771, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_6(__pyx_t_2);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 771, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_axis, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":773
 *             for axis in axis_list:
 *                 cf_params.append(dict(
 *                     standard_name="height_above_reference_ellipsoid",             # <<<<<<<<<<<<<<
 *                     long_name=axis["name"],
 *                     units=get_linear_unit(axis),
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 773, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_standard_name, __pyx_mstate_global->__pyx_n_u_height_above_reference_ellipsoid) < (0)) __PYX_ERR(0, 773, __pyx_L1_error)

      /* "pyproj/_crs.pyx":774
 *                 cf_params.append(dict(
 *                     standard_name="height_above_reference_ellipsoid",
 *                     long_name=axis["name"],             # <<<<<<<<<<<<<<
 *                     units=get_linear_unit(axis),
 *                     positive=axis["direction"],
*/
      __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 774, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_long_name, __pyx_t_7) < (0)) __PYX_ERR(0, 773, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pyproj/_crs.pyx":775
 *                     standard_name="height_above_reference_ellipsoid",
 *                     long_name=axis["name"],
 *                     units=get_linear_unit(axis),             # <<<<<<<<<<<<<<
 *                     positive=axis["direction"],
 *                     axis="Z",
*/
      __pyx_t_7 = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_5to_cf_get_linear_unit(__pyx_v_get_linear_unit, __pyx_v_axis); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 775, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_units, __pyx_t_7) < (0)) __PYX_ERR(0, 773, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pyproj/_crs.pyx":776
 *                     long_name=axis["name"],
 *                     units=get_linear_unit(axis),
 *                     positive=axis["direction"],             # <<<<<<<<<<<<<<
 *                     axis="Z",
 *                 ))
*/
      __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_axis, __pyx_mstate_global->__pyx_n_u_direction_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 776, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_positive, __pyx_t_7) < (0)) __PYX_ERR(0, 773, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis, __pyx_mstate_global->__pyx_n_u_Z) < (0)) __PYX_ERR(0, 773, __pyx_L1_error)

      /* "pyproj/_crs.pyx":772
 *         elif self.name == "vertical":
 *             for axis in axis_list:
 *                 cf_params.append(dict(             # <<<<<<<<<<<<<<
 *                     standard_name="height_above_reference_ellipsoid",
 *                     long_name=axis["name"],
*/
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_cf_params, __pyx_t_1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 772, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":771
 *                         ))
 *         elif self.name == "vertical":
 *             for axis in axis_list:             # <<<<<<<<<<<<<<
 *                 cf_params.append(dict(
 *                     standard_name="height_above_reference_ellipsoid",
*/
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":770
 *                             axis=cf_axis,
 *                         ))
 *         elif self.name == "vertical":             # <<<<<<<<<<<<<<
 *             for axis in axis_list:
 *                 cf_params.append(dict(
*/
  }
  __pyx_L3:;

  /* "pyproj/_crs.pyx":780
 *                 ))
 * 
 *         return cf_params             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cf_params);
  __pyx_r = __pyx_v_cf_params;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":701
 *         )
 * 
 *     def to_cf(self, bint rotated_pole=False):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.0.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.to_cf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_axis_list);
  __Pyx_XDECREF(__pyx_v_cf_params);
  __Pyx_XDECREF(__pyx_v_get_linear_unit);
  __Pyx_XDECREF(__pyx_v_axis);
  __Pyx_XDECREF(__pyx_v_cf_axis);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":89
 * 
 * cdef class CoordinateSystem(_CRSParts):
 *     cdef readonly list _axis_list             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_10_axis_list_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_10_axis_list_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_10_axis_list___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_10_axis_list___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_axis_list);
  __pyx_r = __pyx_v_self->_axis_list;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_13__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_16CoordinateSystem_12__reduce_cython__, "CoordinateSystem.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_13__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_13__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_12__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_13__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_12__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_12__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_15__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_16CoordinateSystem_14__setstate_cython__, "CoordinateSystem.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_16CoordinateSystem_15__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_15__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_14__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_16CoordinateSystem_15__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_16CoordinateSystem_14__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_16CoordinateSystem_14__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.CoordinateSystem.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":803
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         # load in ellipsoid information if applicable
 *         self.semi_major_metre = float("NaN")
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_9Ellipsoid_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_9Ellipsoid_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid___cinit__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_9Ellipsoid___cinit__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  int __pyx_r;
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pyproj/_crs.pyx":805
 *     def __cinit__(self):
 *         # load in ellipsoid information if applicable
 *         self.semi_major_metre = float("NaN")             # <<<<<<<<<<<<<<
 *         self.semi_minor_metre = float("NaN")
 *         self.is_semi_minor_computed = False
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_NaN); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 805, __pyx_L1_error)
  __pyx_v_self->semi_major_metre = __pyx_t_1;

  /* "pyproj/_crs.pyx":806
 *         # load in ellipsoid information if applicable
 *         self.semi_major_metre = float("NaN")
 *         self.semi_minor_metre = float("NaN")             # <<<<<<<<<<<<<<
 *         self.is_semi_minor_computed = False
 *         self.inverse_flattening = float("NaN")
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_NaN); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 806, __pyx_L1_error)
  __pyx_v_self->semi_minor_metre = __pyx_t_1;

  /* "pyproj/_crs.pyx":807
 *         self.semi_major_metre = float("NaN")
 *         self.semi_minor_metre = float("NaN")
 *         self.is_semi_minor_computed = False             # <<<<<<<<<<<<<<
 *         self.inverse_flattening = float("NaN")
 * 
*/
  __pyx_v_self->is_semi_minor_computed = 0;

  /* "pyproj/_crs.pyx":808
 *         self.semi_minor_metre = float("NaN")
 *         self.is_semi_minor_computed = False
 *         self.inverse_flattening = float("NaN")             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_NaN); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 808, __pyx_L1_error)
  __pyx_v_self->inverse_flattening = __pyx_t_1;

  /* "pyproj/_crs.pyx":803
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         # load in ellipsoid information if applicable
 *         self.semi_major_metre = float("NaN")
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pyproj/_crs.pyx":810
 *         self.inverse_flattening = float("NaN")
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "Ellipsoid can only be initialized like 'Ellipsoid.from_*()'."
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_9Ellipsoid_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_9Ellipsoid_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_2__init__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_9Ellipsoid_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyproj/_crs.pyx":811
 * 
 *     def __init__(self):
 *         raise RuntimeError(             # <<<<<<<<<<<<<<
 *             "Ellipsoid can only be initialized like 'Ellipsoid.from_*()'."
 *         )
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Ellipsoid_can_only_be_initialize};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 811, __pyx_L1_error)

  /* "pyproj/_crs.pyx":810
 *         self.inverse_flattening = float("NaN")
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "Ellipsoid can only be initialized like 'Ellipsoid.from_*()'."
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":815
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Ellipsoid create(PJ_CONTEXT* context, PJ* ellipsoid_pj):
 *         cdef Ellipsoid ellips = Ellipsoid.__new__(Ellipsoid)
*/

static struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_f_6pyproj_4_crs_9Ellipsoid_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_ellipsoid_pj) {
  struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_ellips = 0;
  int __pyx_v_is_semi_minor_computed;
  struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":817
 *     @staticmethod
 *     cdef Ellipsoid create(PJ_CONTEXT* context, PJ* ellipsoid_pj):
 *         cdef Ellipsoid ellips = Ellipsoid.__new__(Ellipsoid)             # <<<<<<<<<<<<<<
 *         ellips.context = context
 *         ellips._context_manager = get_context_manager()
*/
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6pyproj_4_crs_Ellipsoid(((PyTypeObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid), __pyx_mstate_global->__pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 817, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_1);
  __pyx_v_ellips = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":818
 *     cdef Ellipsoid create(PJ_CONTEXT* context, PJ* ellipsoid_pj):
 *         cdef Ellipsoid ellips = Ellipsoid.__new__(Ellipsoid)
 *         ellips.context = context             # <<<<<<<<<<<<<<
 *         ellips._context_manager = get_context_manager()
 *         ellips.projobj = ellipsoid_pj
*/
  __pyx_v_ellips->__pyx_base.__pyx_base.context = __pyx_v_context;

  /* "pyproj/_crs.pyx":819
 *         cdef Ellipsoid ellips = Ellipsoid.__new__(Ellipsoid)
 *         ellips.context = context
 *         ellips._context_manager = get_context_manager()             # <<<<<<<<<<<<<<
 *         ellips.projobj = ellipsoid_pj
 *         cdef int is_semi_minor_computed = 0
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_get_context_manager); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_ellips->__pyx_base.__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_ellips->__pyx_base.__pyx_base._context_manager);
  __pyx_v_ellips->__pyx_base.__pyx_base._context_manager = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":820
 *         ellips.context = context
 *         ellips._context_manager = get_context_manager()
 *         ellips.projobj = ellipsoid_pj             # <<<<<<<<<<<<<<
 *         cdef int is_semi_minor_computed = 0
 *         proj_ellipsoid_get_parameters(
*/
  __pyx_v_ellips->__pyx_base.__pyx_base.projobj = __pyx_v_ellipsoid_pj;

  /* "pyproj/_crs.pyx":821
 *         ellips._context_manager = get_context_manager()
 *         ellips.projobj = ellipsoid_pj
 *         cdef int is_semi_minor_computed = 0             # <<<<<<<<<<<<<<
 *         proj_ellipsoid_get_parameters(
 *             context,
*/
  __pyx_v_is_semi_minor_computed = 0;

  /* "pyproj/_crs.pyx":822
 *         ellips.projobj = ellipsoid_pj
 *         cdef int is_semi_minor_computed = 0
 *         proj_ellipsoid_get_parameters(             # <<<<<<<<<<<<<<
 *             context,
 *             ellipsoid_pj,
*/
  (void)(proj_ellipsoid_get_parameters(__pyx_v_context, __pyx_v_ellipsoid_pj, (&__pyx_v_ellips->semi_major_metre), (&__pyx_v_ellips->semi_minor_metre), (&__pyx_v_is_semi_minor_computed), (&__pyx_v_ellips->inverse_flattening)));

  /* "pyproj/_crs.pyx":830
 *             &ellips.inverse_flattening,
 *         )
 *         ellips.is_semi_minor_computed = is_semi_minor_computed == 1             # <<<<<<<<<<<<<<
 *         ellips._set_base_info()
 *         _clear_proj_error()
*/
  __pyx_v_ellips->is_semi_minor_computed = (__pyx_v_is_semi_minor_computed == 1);

  /* "pyproj/_crs.pyx":831
 *         )
 *         ellips.is_semi_minor_computed = is_semi_minor_computed == 1
 *         ellips._set_base_info()             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return ellips
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pyproj_4_crs_Ellipsoid *)__pyx_v_ellips->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._set_base_info(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_ellips)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":832
 *         ellips.is_semi_minor_computed = is_semi_minor_computed == 1
 *         ellips._set_base_info()
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return ellips
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":833
 *         ellips._set_base_info()
 *         _clear_proj_error()
 *         return ellips             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_ellips);
  __pyx_r = __pyx_v_ellips;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":815
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Ellipsoid create(PJ_CONTEXT* context, PJ* ellipsoid_pj):
 *         cdef Ellipsoid ellips = Ellipsoid.__new__(Ellipsoid)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ellips);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":835
 *         return ellips
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_5from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_4from_authority, "Ellipsoid.from_authority(str auth_name, code)\n\n.. versionadded:: 2.2.0\n\nCreate an Ellipsoid from an authority code.\n\nParameters\n----------\nauth_name: str\n    Name of the authority.\ncode: str or int\n    The code used by the authority.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_5from_authority = {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_5from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_4from_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_5from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 835, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 835, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 835, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_authority", 0) < (0)) __PYX_ERR(0, 835, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_authority", 1, 2, 2, i); __PYX_ERR(0, 835, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 835, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 835, __pyx_L3_error)
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    __pyx_v_code = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_authority", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 835, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 0, "auth_name", 1))) __PYX_ERR(0, 836, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 836, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_4from_authority(__pyx_v_auth_name, __pyx_v_code);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_4from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_ellipsoid_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  char const *__pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_authority", 0);

  /* "pyproj/_crs.pyx":853
 *         Ellipsoid
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* ellipsoid_pj = proj_create_from_database(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 853, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":856
 *         cdef PJ* ellipsoid_pj = proj_create_from_database(
 *             context,
 *             cstrencode(auth_name),             # <<<<<<<<<<<<<<
 *             cstrencode(str(code)),
 *             PJ_CATEGORY_ELLIPSOID,
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_auth_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 856, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 856, __pyx_L1_error)

  /* "pyproj/_crs.pyx":857
 *             context,
 *             cstrencode(auth_name),
 *             cstrencode(str(code)),             # <<<<<<<<<<<<<<
 *             PJ_CATEGORY_ELLIPSOID,
 *             False,
*/
  __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __pyx_f_6pyproj_7_compat_cstrencode(((PyObject*)__pyx_t_4), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 857, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsString(__pyx_t_5); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 857, __pyx_L1_error)

  /* "pyproj/_crs.pyx":854
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = proj_create_from_database(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(auth_name),
*/
  __pyx_v_ellipsoid_pj = proj_create_from_database(__pyx_v_context, __pyx_t_3, __pyx_t_6, PJ_CATEGORY_ELLIPSOID, 0, NULL);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pyproj/_crs.pyx":863
 *         )
 * 
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  __pyx_t_7 = (__pyx_v_ellipsoid_pj == NULL);
  if (unlikely(__pyx_t_7)) {

    /* "pyproj/_crs.pyx":864
 * 
 *         if ellipsoid_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return Ellipsoid.create(context, ellipsoid_pj)
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_code, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Invalid_authority_or_code;
    __pyx_t_9[1] = __pyx_v_auth_name;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__8;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__5;
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 27 + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_auth_name) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_auth_name) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 864, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 864, __pyx_L1_error)

    /* "pyproj/_crs.pyx":863
 *         )
 * 
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  }

  /* "pyproj/_crs.pyx":865
 *         if ellipsoid_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":866
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
 *         return Ellipsoid.create(context, ellipsoid_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = ((PyObject *)__pyx_f_6pyproj_4_crs_9Ellipsoid_create(__pyx_v_context, __pyx_v_ellipsoid_pj)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":835
 *         return ellips
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":868
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_7from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_6from_epsg, "Ellipsoid.from_epsg(code)\n\n.. versionadded:: 2.2.0\n\nCreate an Ellipsoid from an EPSG code.\n\nParameters\n----------\ncode: str or int\n    The code used by the EPSG.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_7from_epsg = {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_7from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_6from_epsg};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_7from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_epsg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 868, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 868, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_epsg", 0) < (0)) __PYX_ERR(0, 868, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_epsg", 1, 1, 1, i); __PYX_ERR(0, 868, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 868, __pyx_L3_error)
    }
    __pyx_v_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_epsg", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 868, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 869, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_6from_epsg(__pyx_v_code);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_6from_epsg(PyObject *__pyx_v_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_epsg", 0);

  /* "pyproj/_crs.pyx":884
 *         Ellipsoid
 *         """
 *         return Ellipsoid.from_authority("EPSG", code)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_EPSG, __pyx_v_code};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_authority, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":868
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":886
 *         return Ellipsoid.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str ellipsoid_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_9_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_8_from_string, "Ellipsoid._from_string(str ellipsoid_string)\n\nCreate an Ellipsoid from a string.\n\nExamples:\n  - urn:ogc:def:ellipsoid:EPSG::7001\n  - ELLIPSOID[\"Airy 1830\",6377563.396,299.3249646,\n    LENGTHUNIT[\"metre\",1],\n    ID[\"EPSG\",7001]]\n\nParameters\n----------\nellipsoid_string: str\n    Ellipsoid string.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_9_from_string = {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_9_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_8_from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_9_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ellipsoid_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ellipsoid_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 886, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 886, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_string", 0) < (0)) __PYX_ERR(0, 886, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, i); __PYX_ERR(0, 886, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 886, __pyx_L3_error)
    }
    __pyx_v_ellipsoid_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 886, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ellipsoid_string), (&PyUnicode_Type), 0, "ellipsoid_string", 1))) __PYX_ERR(0, 887, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_8_from_string(__pyx_v_ellipsoid_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_8_from_string(PyObject *__pyx_v_ellipsoid_string) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_ellipsoid_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_string", 0);

  /* "pyproj/_crs.pyx":906
 *         Ellipsoid
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* ellipsoid_pj = proj_create(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 906, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":909
 *         cdef PJ* ellipsoid_pj = proj_create(
 *             context,
 *             cstrencode(ellipsoid_string)             # <<<<<<<<<<<<<<
 *         )
 *         if ellipsoid_pj == NULL or proj_get_type(ellipsoid_pj) != PJ_TYPE_ELLIPSOID:
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_ellipsoid_string, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 909, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 909, __pyx_L1_error)

  /* "pyproj/_crs.pyx":907
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = proj_create(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(ellipsoid_string)
*/
  __pyx_v_ellipsoid_pj = proj_create(__pyx_v_context, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":911
 *             cstrencode(ellipsoid_string)
 *         )
 *         if ellipsoid_pj == NULL or proj_get_type(ellipsoid_pj) != PJ_TYPE_ELLIPSOID:             # <<<<<<<<<<<<<<
 *             proj_destroy(ellipsoid_pj)
 *             raise CRSError(
*/
  __pyx_t_5 = (__pyx_v_ellipsoid_pj == NULL);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (proj_get_type(__pyx_v_ellipsoid_pj) != PJ_TYPE_ELLIPSOID);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_4)) {

    /* "pyproj/_crs.pyx":912
 *         )
 *         if ellipsoid_pj == NULL or proj_get_type(ellipsoid_pj) != PJ_TYPE_ELLIPSOID:
 *             proj_destroy(ellipsoid_pj)             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 f"Invalid ellipsoid string: {ellipsoid_string}"
*/
    proj_destroy(__pyx_v_ellipsoid_pj);

    /* "pyproj/_crs.pyx":913
 *         if ellipsoid_pj == NULL or proj_get_type(ellipsoid_pj) != PJ_TYPE_ELLIPSOID:
 *             proj_destroy(ellipsoid_pj)
 *             raise CRSError(             # <<<<<<<<<<<<<<
 *                 f"Invalid ellipsoid string: {ellipsoid_string}"
 *             )
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "pyproj/_crs.pyx":914
 *             proj_destroy(ellipsoid_pj)
 *             raise CRSError(
 *                 f"Invalid ellipsoid string: {ellipsoid_string}"             # <<<<<<<<<<<<<<
 *             )
 *         _clear_proj_error()
*/
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_ellipsoid_string, __pyx_v_ellipsoid_string); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 913, __pyx_L1_error)

    /* "pyproj/_crs.pyx":911
 *             cstrencode(ellipsoid_string)
 *         )
 *         if ellipsoid_pj == NULL or proj_get_type(ellipsoid_pj) != PJ_TYPE_ELLIPSOID:             # <<<<<<<<<<<<<<
 *             proj_destroy(ellipsoid_pj)
 *             raise CRSError(
*/
  }

  /* "pyproj/_crs.pyx":916
 *                 f"Invalid ellipsoid string: {ellipsoid_string}"
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":917
 *             )
 *         _clear_proj_error()
 *         return Ellipsoid.create(context, ellipsoid_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_9Ellipsoid_create(__pyx_v_context, __pyx_v_ellipsoid_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 917, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":886
 *         return Ellipsoid.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str ellipsoid_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":919
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str ellipsoid_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_11from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_10from_string, "Ellipsoid.from_string(str ellipsoid_string)\n\n.. versionadded:: 2.2.0\n\nCreate an Ellipsoid from a string.\n\nExamples:\n  - urn:ogc:def:ellipsoid:EPSG::7001\n  - ELLIPSOID[\"Airy 1830\",6377563.396,299.3249646,\n    LENGTHUNIT[\"metre\",1],\n    ID[\"EPSG\",7001]]\n  - WGS 84\n\nParameters\n----------\nellipsoid_string: str\n    Ellipsoid string.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_11from_string = {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_11from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_10from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_11from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ellipsoid_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ellipsoid_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 919, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 919, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_string", 0) < (0)) __PYX_ERR(0, 919, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, i); __PYX_ERR(0, 919, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 919, __pyx_L3_error)
    }
    __pyx_v_ellipsoid_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 919, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ellipsoid_string), (&PyUnicode_Type), 0, "ellipsoid_string", 1))) __PYX_ERR(0, 920, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_10from_string(__pyx_v_ellipsoid_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_10from_string(PyObject *__pyx_v_ellipsoid_string) {
  PyObject *__pyx_v_crs_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_string", 0);

  /* "pyproj/_crs.pyx":942
 *         Ellipsoid
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":943
 *         """
 *         try:
 *             return Ellipsoid._from_string(ellipsoid_string)             # <<<<<<<<<<<<<<
 *         except CRSError as crs_err:
 *             try:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_ellipsoid_string};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 943, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":942
 *         Ellipsoid
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":944
 *         try:
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return Ellipsoid.from_name(ellipsoid_string)
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 944, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_7);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 944, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_crs_err = __pyx_t_5;
      /*try:*/ {

        /* "pyproj/_crs.pyx":945
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return Ellipsoid.from_name(ellipsoid_string)
 *             except CRSError:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {

            /* "pyproj/_crs.pyx":946
 *         except CRSError as crs_err:
 *             try:
 *                 return Ellipsoid.from_name(ellipsoid_string)             # <<<<<<<<<<<<<<
 *             except CRSError:
 *                 raise crs_err
*/
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_13 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_ellipsoid_string};
              __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 946, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_8);
            }
            __pyx_r = __pyx_t_8;
            __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            goto __pyx_L20_try_return;

            /* "pyproj/_crs.pyx":945
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return Ellipsoid.from_name(ellipsoid_string)
 *             except CRSError:
*/
          }
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "pyproj/_crs.pyx":947
 *             try:
 *                 return Ellipsoid.from_name(ellipsoid_string)
 *             except CRSError:             # <<<<<<<<<<<<<<
 *                 raise crs_err
 * 
*/
          __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_13, &__pyx_t_14);
          __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 947, __pyx_L18_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_8, __pyx_t_15);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_ErrRestore(__pyx_t_8, __pyx_t_13, __pyx_t_14);
          __pyx_t_8 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
          if (__pyx_t_9) {
            __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_13, &__pyx_t_8) < 0) __PYX_ERR(0, 947, __pyx_L18_except_error)
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_8);

            /* "pyproj/_crs.pyx":948
 *                 return Ellipsoid.from_name(ellipsoid_string)
 *             except CRSError:
 *                 raise crs_err             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
            __Pyx_Raise(__pyx_v_crs_err, 0, 0, 0);
            __PYX_ERR(0, 948, __pyx_L18_except_error)
          }
          goto __pyx_L18_except_error;

          /* "pyproj/_crs.pyx":945
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return Ellipsoid.from_name(ellipsoid_string)
 *             except CRSError:
*/
          __pyx_L18_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L14_error;
          __pyx_L20_try_return:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L13_return;
        }
      }

      /* "pyproj/_crs.pyx":944
 *         try:
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return Ellipsoid.from_name(ellipsoid_string)
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_9 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_20 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          __pyx_r = __pyx_t_20;
          __pyx_t_20 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":942
 *         Ellipsoid
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Ellipsoid._from_string(ellipsoid_string)
 *         except CRSError as crs_err:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":919
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str ellipsoid_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_crs_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":950
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict ellipsoid_dict not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_13from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_12from_json_dict, "Ellipsoid.from_json_dict(dict ellipsoid_dict)\n\n.. versionadded:: 2.4.0\n\nCreate Ellipsoid from a JSON dictionary.\n\nParameters\n----------\nellipsoid_dict: str\n    Ellipsoid dictionary.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_13from_json_dict = {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_13from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_12from_json_dict};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_13from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ellipsoid_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ellipsoid_dict,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 950, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 950, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json_dict", 0) < (0)) __PYX_ERR(0, 950, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, i); __PYX_ERR(0, 950, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 950, __pyx_L3_error)
    }
    __pyx_v_ellipsoid_dict = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 950, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ellipsoid_dict), (&PyDict_Type), 0, "ellipsoid_dict", 1))) __PYX_ERR(0, 951, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_12from_json_dict(__pyx_v_ellipsoid_dict);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_12from_json_dict(PyObject *__pyx_v_ellipsoid_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json_dict", 0);

  /* "pyproj/_crs.pyx":966
 *         Ellipsoid
 *         """
 *         return Ellipsoid._from_string(json.dumps(ellipsoid_dict, cls=NumpyEncoder))             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NumpyEncoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_ellipsoid_dict};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cls, __pyx_t_5, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 966, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":950
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict ellipsoid_dict not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":968
 *         return Ellipsoid._from_string(json.dumps(ellipsoid_dict, cls=NumpyEncoder))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str ellipsoid_json_str not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_15from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_14from_json, "Ellipsoid.from_json(str ellipsoid_json_str)\n\n.. versionadded:: 2.4.0\n\nCreate Ellipsoid from a JSON string.\n\nParameters\n----------\nellipsoid_json_str: str\n    Ellipsoid JSON string.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_15from_json = {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_15from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_14from_json};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_15from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ellipsoid_json_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ellipsoid_json_str,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 968, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 968, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json", 0) < (0)) __PYX_ERR(0, 968, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, i); __PYX_ERR(0, 968, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 968, __pyx_L3_error)
    }
    __pyx_v_ellipsoid_json_str = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 968, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ellipsoid_json_str), (&PyUnicode_Type), 0, "ellipsoid_json_str", 1))) __PYX_ERR(0, 969, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_14from_json(__pyx_v_ellipsoid_json_str);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_14from_json(PyObject *__pyx_v_ellipsoid_json_str) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json", 0);

  /* "pyproj/_crs.pyx":984
 *         Ellipsoid
 *         """
 *         return Ellipsoid.from_json_dict(_load_proj_json(ellipsoid_json_str))             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_load_proj_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_ellipsoid_json_str};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":968
 *         return Ellipsoid._from_string(json.dumps(ellipsoid_dict, cls=NumpyEncoder))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str ellipsoid_json_str not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":986
 *         return Ellipsoid.from_json_dict(_load_proj_json(ellipsoid_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_name(
 *         str ellipsoid_name,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_17_from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_16_from_name, "Ellipsoid._from_name(str ellipsoid_name, str auth_name)\n\n.. versionadded:: 2.5.0\n\nCreate a Ellipsoid from a name.\n\nParameters\n----------\nellipsoid_name: str\n    Ellipsoid name.\nauth_name: str\n    The authority name to refine search (e.g. 'EPSG').\n    If None, will search all authorities.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_17_from_name = {"_from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_17_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_16_from_name};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_17_from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ellipsoid_name = 0;
  PyObject *__pyx_v_auth_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ellipsoid_name,&__pyx_mstate_global->__pyx_n_u_auth_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 986, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 986, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 986, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_name", 0) < (0)) __PYX_ERR(0, 986, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_name", 1, 2, 2, i); __PYX_ERR(0, 986, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 986, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 986, __pyx_L3_error)
    }
    __pyx_v_ellipsoid_name = ((PyObject*)values[0]);
    __pyx_v_auth_name = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 986, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ellipsoid_name), (&PyUnicode_Type), 1, "ellipsoid_name", 1))) __PYX_ERR(0, 988, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 989, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_16_from_name(__pyx_v_ellipsoid_name, __pyx_v_auth_name);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_16_from_name(PyObject *__pyx_v_ellipsoid_name, PyObject *__pyx_v_auth_name) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_ellipsoid_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PJ *__pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 0);

  /* "pyproj/_crs.pyx":1008
 *         Ellipsoid
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* ellipsoid_pj = _from_name(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1008, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1009
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = _from_name(             # <<<<<<<<<<<<<<
 *             context,
 *             ellipsoid_name,
*/
  __pyx_t_2 = __pyx_f_6pyproj_4_crs__from_name(__pyx_v_context, __pyx_v_ellipsoid_name, __pyx_v_auth_name, PJ_TYPE_ELLIPSOID); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 1009, __pyx_L1_error)
  __pyx_v_ellipsoid_pj = __pyx_t_2;

  /* "pyproj/_crs.pyx":1015
 *             PJ_TYPE_ELLIPSOID,
 *         )
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         _clear_proj_error()
*/
  __pyx_t_3 = (__pyx_v_ellipsoid_pj == NULL);
  if (unlikely(__pyx_t_3)) {

    /* "pyproj/_crs.pyx":1016
 *         )
 *         if ellipsoid_pj == NULL:
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return Ellipsoid.create(context, ellipsoid_pj)
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyUnicode_Unicode(__pyx_v_ellipsoid_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_ellipsoid_name, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1016, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1015
 *             PJ_TYPE_ELLIPSOID,
 *         )
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         _clear_proj_error()
*/
  }

  /* "pyproj/_crs.pyx":1017
 *         if ellipsoid_pj == NULL:
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1018
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         _clear_proj_error()
 *         return Ellipsoid.create(context, ellipsoid_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_f_6pyproj_4_crs_9Ellipsoid_create(__pyx_v_context, __pyx_v_ellipsoid_pj)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":986
 *         return Ellipsoid.from_json_dict(_load_proj_json(ellipsoid_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_name(
 *         str ellipsoid_name,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1020
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str ellipsoid_name not None,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_19from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_18from_name, "Ellipsoid.from_name(str ellipsoid_name, str auth_name=None)\n\n.. versionadded:: 2.5.0\n\nCreate a Ellipsoid from a name.\n\nExamples:\n  - WGS 84\n\nParameters\n----------\nellipsoid_name: str\n    Ellipsoid name.\nauth_name: str, optional\n    The authority name to refine search (e.g. 'EPSG').\n    If None, will search all authorities.\n\nReturns\n-------\nEllipsoid");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_19from_name = {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_19from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_18from_name};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_19from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_ellipsoid_name = 0;
  PyObject *__pyx_v_auth_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_ellipsoid_name,&__pyx_mstate_global->__pyx_n_u_auth_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1020, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1020, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1020, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_name", 0) < (0)) __PYX_ERR(0, 1020, __pyx_L3_error)

      /* "pyproj/_crs.pyx":1023
 *     def from_name(
 *         str ellipsoid_name not None,
 *         str auth_name=None,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 2, i); __PYX_ERR(0, 1020, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1020, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1020, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_ellipsoid_name = ((PyObject*)values[0]);
    __pyx_v_auth_name = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1020, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ellipsoid_name), (&PyUnicode_Type), 0, "ellipsoid_name", 1))) __PYX_ERR(0, 1022, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 1023, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_18from_name(__pyx_v_ellipsoid_name, __pyx_v_auth_name);

  /* "pyproj/_crs.pyx":1020
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str ellipsoid_name not None,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_18from_name(PyObject *__pyx_v_ellipsoid_name, PyObject *__pyx_v_auth_name) {
  PyObject *__pyx_v_ellipsoid_params = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_name", 0);

  /* "pyproj/_crs.pyx":1045
 *         Ellipsoid
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Ellipsoid._from_name(
 *                 ellipsoid_name=ellipsoid_name,
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":1046
 *         """
 *         try:
 *             return Ellipsoid._from_name(             # <<<<<<<<<<<<<<
 *                 ellipsoid_name=ellipsoid_name,
 *                 auth_name=auth_name,
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
      __Pyx_INCREF(__pyx_t_5);

      /* "pyproj/_crs.pyx":1048
 *             return Ellipsoid._from_name(
 *                 ellipsoid_name=ellipsoid_name,
 *                 auth_name=auth_name,             # <<<<<<<<<<<<<<
 *             )
 *         except CRSError:
*/
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, NULL};
        __pyx_t_7 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1046, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ellipsoid_name, __pyx_v_ellipsoid_name, __pyx_t_7, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1046, __pyx_L3_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_auth_name, __pyx_v_auth_name, __pyx_t_7, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1046, __pyx_L3_error)
        __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name_2, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_7);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1046, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":1045
 *         Ellipsoid
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Ellipsoid._from_name(
 *                 ellipsoid_name=ellipsoid_name,
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "pyproj/_crs.pyx":1050
 *                 auth_name=auth_name,
 *             )
 *         except CRSError:             # <<<<<<<<<<<<<<
 *             if auth_name not in ("PROJ", None):
 *                 raise
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1050, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_7, __pyx_t_5);
    __pyx_t_4 = 0; __pyx_t_7 = 0; __pyx_t_5 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_4) < 0) __PYX_ERR(0, 1050, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "pyproj/_crs.pyx":1051
 *             )
 *         except CRSError:
 *             if auth_name not in ("PROJ", None):             # <<<<<<<<<<<<<<
 *                 raise
 *             pass
*/
      __Pyx_INCREF(__pyx_v_auth_name);
      __pyx_t_10 = __pyx_v_auth_name;
      __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PROJ, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1051, __pyx_L5_except_error)
      if (__pyx_t_12) {
      } else {
        __pyx_t_11 = __pyx_t_12;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_t_10, Py_None, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1051, __pyx_L5_except_error)
      __pyx_t_11 = __pyx_t_12;
      __pyx_L12_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_12 = __pyx_t_11;
      if (unlikely(__pyx_t_12)) {

        /* "pyproj/_crs.pyx":1052
 *         except CRSError:
 *             if auth_name not in ("PROJ", None):
 *                 raise             # <<<<<<<<<<<<<<
 *             pass
 * 
*/
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_7, __pyx_t_4);
        __pyx_t_5 = 0;  __pyx_t_7 = 0;  __pyx_t_4 = 0; 
        __PYX_ERR(0, 1052, __pyx_L5_except_error)

        /* "pyproj/_crs.pyx":1051
 *             )
 *         except CRSError:
 *             if auth_name not in ("PROJ", None):             # <<<<<<<<<<<<<<
 *                 raise
 *             pass
*/
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":1045
 *         Ellipsoid
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Ellipsoid._from_name(
 *                 ellipsoid_name=ellipsoid_name,
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "pyproj/_crs.pyx":1056
 * 
 *         # add support for past names for PROJ ellipsoids
 *         try:             # <<<<<<<<<<<<<<
 *             ellipsoid_params = pj_ellps[
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "pyproj/_crs.pyx":1057
 *         # add support for past names for PROJ ellipsoids
 *         try:
 *             ellipsoid_params = pj_ellps[             # <<<<<<<<<<<<<<
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)
 *             ]
*/
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pj_ellps); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1057, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "pyproj/_crs.pyx":1058
 *         try:
 *             ellipsoid_params = pj_ellps[
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)             # <<<<<<<<<<<<<<
 *             ]
 *         except KeyError:
*/
      if (unlikely(__pyx_v_6pyproj_4_crs__PJ_ELLPS_NAME_MAP == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
        __PYX_ERR(0, 1058, __pyx_L14_error)
      }
      __pyx_t_7 = __Pyx_PyDict_GetItemDefault(__pyx_v_6pyproj_4_crs__PJ_ELLPS_NAME_MAP, __pyx_v_ellipsoid_name, __pyx_v_ellipsoid_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1058, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "pyproj/_crs.pyx":1057
 *         # add support for past names for PROJ ellipsoids
 *         try:
 *             ellipsoid_params = pj_ellps[             # <<<<<<<<<<<<<<
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)
 *             ]
*/
      __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1057, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_ellipsoid_params = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "pyproj/_crs.pyx":1056
 * 
 *         # add support for past names for PROJ ellipsoids
 *         try:             # <<<<<<<<<<<<<<
 *             ellipsoid_params = pj_ellps[
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)
*/
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L19_try_end;
    __pyx_L14_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pyproj/_crs.pyx":1060
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)
 *             ]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         return CustomEllipsoid(
*/
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_4) < 0) __PYX_ERR(0, 1060, __pyx_L16_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "pyproj/_crs.pyx":1061
 *             ]
 *         except KeyError:
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")             # <<<<<<<<<<<<<<
 *         return CustomEllipsoid(
 *             name=ellipsoid_params["description"],
*/
      __pyx_t_13 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1061, __pyx_L16_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_15 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_ellipsoid_name, __pyx_v_ellipsoid_name); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1061, __pyx_L16_except_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
        assert(__pyx_t_13);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_15};
        __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1061, __pyx_L16_except_error)
        __Pyx_GOTREF(__pyx_t_8);
      }
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 1061, __pyx_L16_except_error)
    }
    goto __pyx_L16_except_error;

    /* "pyproj/_crs.pyx":1056
 * 
 *         # add support for past names for PROJ ellipsoids
 *         try:             # <<<<<<<<<<<<<<
 *             ellipsoid_params = pj_ellps[
 *                 _PJ_ELLPS_NAME_MAP.get(ellipsoid_name, ellipsoid_name)
*/
    __pyx_L16_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L19_try_end:;
  }

  /* "pyproj/_crs.pyx":1062
 *         except KeyError:
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         return CustomEllipsoid(             # <<<<<<<<<<<<<<
 *             name=ellipsoid_params["description"],
 *             semi_major_axis=ellipsoid_params["a"],
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_CustomEllipsoid); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pyproj/_crs.pyx":1063
 *             raise CRSError(f"Invalid ellipsoid name: {ellipsoid_name}")
 *         return CustomEllipsoid(
 *             name=ellipsoid_params["description"],             # <<<<<<<<<<<<<<
 *             semi_major_axis=ellipsoid_params["a"],
 *             semi_minor_axis=ellipsoid_params.get("b"),
*/
  __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ellipsoid_params, __pyx_mstate_global->__pyx_n_u_description); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "pyproj/_crs.pyx":1064
 *         return CustomEllipsoid(
 *             name=ellipsoid_params["description"],
 *             semi_major_axis=ellipsoid_params["a"],             # <<<<<<<<<<<<<<
 *             semi_minor_axis=ellipsoid_params.get("b"),
 *             inverse_flattening=ellipsoid_params.get("rf"),
*/
  __pyx_t_14 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ellipsoid_params, __pyx_mstate_global->__pyx_n_u_a); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);

  /* "pyproj/_crs.pyx":1065
 *             name=ellipsoid_params["description"],
 *             semi_major_axis=ellipsoid_params["a"],
 *             semi_minor_axis=ellipsoid_params.get("b"),             # <<<<<<<<<<<<<<
 *             inverse_flattening=ellipsoid_params.get("rf"),
 *         )
*/
  __pyx_t_13 = __pyx_v_ellipsoid_params;
  __Pyx_INCREF(__pyx_t_13);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_mstate_global->__pyx_n_u_b};
    __pyx_t_15 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
  }

  /* "pyproj/_crs.pyx":1066
 *             semi_major_axis=ellipsoid_params["a"],
 *             semi_minor_axis=ellipsoid_params.get("b"),
 *             inverse_flattening=ellipsoid_params.get("rf"),             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_16 = __pyx_v_ellipsoid_params;
  __Pyx_INCREF(__pyx_t_16);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_mstate_global->__pyx_n_u_rf};
    __pyx_t_13 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1066, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
  }
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_7);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_7);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 4 : 0)] = {__pyx_t_7, NULL};
    __pyx_t_16 = __Pyx_MakeVectorcallBuilderKwds(4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_name, __pyx_t_8, __pyx_t_16, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1062, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_semi_major_axis, __pyx_t_14, __pyx_t_16, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1062, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_semi_minor_axis, __pyx_t_15, __pyx_t_16, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1062, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_inverse_flattening, __pyx_t_13, __pyx_t_16, __pyx_callargs+1, 3) < (0)) __PYX_ERR(0, 1062, __pyx_L1_error)
    __pyx_t_4 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_16);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1062, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1020
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str ellipsoid_name not None,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ellipsoid_params);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":61
 * 
 * cdef class Ellipsoid(_CRSParts):
 *     cdef readonly double semi_major_metre             # <<<<<<<<<<<<<<
 *     cdef readonly double semi_minor_metre
 *     cdef readonly bint is_semi_minor_computed
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_16semi_major_metre_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_16semi_major_metre_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_16semi_major_metre___get__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_16semi_major_metre___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->semi_major_metre); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.semi_major_metre.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":62
 * cdef class Ellipsoid(_CRSParts):
 *     cdef readonly double semi_major_metre
 *     cdef readonly double semi_minor_metre             # <<<<<<<<<<<<<<
 *     cdef readonly bint is_semi_minor_computed
 *     cdef readonly double inverse_flattening
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_16semi_minor_metre_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_16semi_minor_metre_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_16semi_minor_metre___get__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_16semi_minor_metre___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->semi_minor_metre); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.semi_minor_metre.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":63
 *     cdef readonly double semi_major_metre
 *     cdef readonly double semi_minor_metre
 *     cdef readonly bint is_semi_minor_computed             # <<<<<<<<<<<<<<
 *     cdef readonly double inverse_flattening
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_22is_semi_minor_computed_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_22is_semi_minor_computed_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_22is_semi_minor_computed___get__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_22is_semi_minor_computed___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_semi_minor_computed); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.is_semi_minor_computed.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":64
 *     cdef readonly double semi_minor_metre
 *     cdef readonly bint is_semi_minor_computed
 *     cdef readonly double inverse_flattening             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_18inverse_flattening_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_18inverse_flattening_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_18inverse_flattening___get__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_18inverse_flattening___get__(struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->inverse_flattening); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.inverse_flattening.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_21__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_20__reduce_cython__, "Ellipsoid.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_21__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_21__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_20__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_21__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_20__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_20__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_23__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_9Ellipsoid_22__setstate_cython__, "Ellipsoid.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_9Ellipsoid_23__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_23__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_22__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_9Ellipsoid_23__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_9Ellipsoid_22__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_9Ellipsoid_22__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Ellipsoid *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Ellipsoid.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1084
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.unit_name = None
 * 
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_13PrimeMeridian_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_13PrimeMeridian_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian___cinit__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_13PrimeMeridian___cinit__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":1085
 *     """
 *     def __cinit__(self):
 *         self.unit_name = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->unit_name);
  __Pyx_DECREF(__pyx_v_self->unit_name);
  __pyx_v_self->unit_name = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":1084
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.unit_name = None
 * 
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1087
 *         self.unit_name = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "PrimeMeridian can only be initialized like 'PrimeMeridian.from_*()'."
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_13PrimeMeridian_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_13PrimeMeridian_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_2__init__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_13PrimeMeridian_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyproj/_crs.pyx":1088
 * 
 *     def __init__(self):
 *         raise RuntimeError(             # <<<<<<<<<<<<<<
 *             "PrimeMeridian can only be initialized like 'PrimeMeridian.from_*()'."
 *         )
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_PrimeMeridian_can_only_be_initia};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 1088, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1087
 *         self.unit_name = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "PrimeMeridian can only be initialized like 'PrimeMeridian.from_*()'."
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1092
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef PrimeMeridian create(PJ_CONTEXT* context, PJ* prime_meridian_pj):
 *         cdef PrimeMeridian prime_meridian = PrimeMeridian.__new__(PrimeMeridian)
*/

static struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_prime_meridian_pj) {
  struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_prime_meridian = 0;
  char const *__pyx_v_unit_name;
  struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":1094
 *     @staticmethod
 *     cdef PrimeMeridian create(PJ_CONTEXT* context, PJ* prime_meridian_pj):
 *         cdef PrimeMeridian prime_meridian = PrimeMeridian.__new__(PrimeMeridian)             # <<<<<<<<<<<<<<
 *         prime_meridian.context = context
 *         prime_meridian._context_manager = get_context_manager()
*/
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6pyproj_4_crs_PrimeMeridian(((PyTypeObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian), __pyx_mstate_global->__pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_1);
  __pyx_v_prime_meridian = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1095
 *     cdef PrimeMeridian create(PJ_CONTEXT* context, PJ* prime_meridian_pj):
 *         cdef PrimeMeridian prime_meridian = PrimeMeridian.__new__(PrimeMeridian)
 *         prime_meridian.context = context             # <<<<<<<<<<<<<<
 *         prime_meridian._context_manager = get_context_manager()
 *         prime_meridian.projobj = prime_meridian_pj
*/
  __pyx_v_prime_meridian->__pyx_base.__pyx_base.context = __pyx_v_context;

  /* "pyproj/_crs.pyx":1096
 *         cdef PrimeMeridian prime_meridian = PrimeMeridian.__new__(PrimeMeridian)
 *         prime_meridian.context = context
 *         prime_meridian._context_manager = get_context_manager()             # <<<<<<<<<<<<<<
 *         prime_meridian.projobj = prime_meridian_pj
 *         cdef const char * unit_name
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_get_context_manager); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_prime_meridian->__pyx_base.__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_prime_meridian->__pyx_base.__pyx_base._context_manager);
  __pyx_v_prime_meridian->__pyx_base.__pyx_base._context_manager = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1097
 *         prime_meridian.context = context
 *         prime_meridian._context_manager = get_context_manager()
 *         prime_meridian.projobj = prime_meridian_pj             # <<<<<<<<<<<<<<
 *         cdef const char * unit_name
 *         proj_prime_meridian_get_parameters(
*/
  __pyx_v_prime_meridian->__pyx_base.__pyx_base.projobj = __pyx_v_prime_meridian_pj;

  /* "pyproj/_crs.pyx":1099
 *         prime_meridian.projobj = prime_meridian_pj
 *         cdef const char * unit_name
 *         proj_prime_meridian_get_parameters(             # <<<<<<<<<<<<<<
 *             prime_meridian.context,
 *             prime_meridian.projobj,
*/
  (void)(proj_prime_meridian_get_parameters(__pyx_v_prime_meridian->__pyx_base.__pyx_base.context, __pyx_v_prime_meridian->__pyx_base.__pyx_base.projobj, (&__pyx_v_prime_meridian->longitude), (&__pyx_v_prime_meridian->unit_conversion_factor), (&__pyx_v_unit_name)));

  /* "pyproj/_crs.pyx":1106
 *             &unit_name,
 *         )
 *         prime_meridian.unit_name = decode_or_undefined(unit_name)             # <<<<<<<<<<<<<<
 *         prime_meridian._set_base_info()
 *         _clear_proj_error()
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_unit_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_prime_meridian->unit_name);
  __Pyx_DECREF(__pyx_v_prime_meridian->unit_name);
  __pyx_v_prime_meridian->unit_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1107
 *         )
 *         prime_meridian.unit_name = decode_or_undefined(unit_name)
 *         prime_meridian._set_base_info()             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return prime_meridian
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pyproj_4_crs_PrimeMeridian *)__pyx_v_prime_meridian->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._set_base_info(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_prime_meridian)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1108
 *         prime_meridian.unit_name = decode_or_undefined(unit_name)
 *         prime_meridian._set_base_info()
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return prime_meridian
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1109
 *         prime_meridian._set_base_info()
 *         _clear_proj_error()
 *         return prime_meridian             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_prime_meridian);
  __pyx_r = __pyx_v_prime_meridian;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1092
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef PrimeMeridian create(PJ_CONTEXT* context, PJ* prime_meridian_pj):
 *         cdef PrimeMeridian prime_meridian = PrimeMeridian.__new__(PrimeMeridian)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_prime_meridian);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1111
 *         return prime_meridian
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_5from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_4from_authority, "PrimeMeridian.from_authority(str auth_name, code)\n\n.. versionadded:: 2.2.0\n\nCreate a PrimeMeridian from an authority code.\n\nParameters\n----------\nauth_name: str\n    Name of the authority.\ncode: str or int\n    The code used by the authority.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_5from_authority = {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_5from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_4from_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_5from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1111, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1111, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1111, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_authority", 0) < (0)) __PYX_ERR(0, 1111, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_authority", 1, 2, 2, i); __PYX_ERR(0, 1111, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1111, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1111, __pyx_L3_error)
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    __pyx_v_code = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_authority", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1111, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 0, "auth_name", 1))) __PYX_ERR(0, 1112, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1112, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_4from_authority(__pyx_v_auth_name, __pyx_v_code);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_4from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_prime_meridian_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  char const *__pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_authority", 0);

  /* "pyproj/_crs.pyx":1129
 *         PrimeMeridian
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* prime_meridian_pj = proj_create_from_database(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1129, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1132
 *         cdef PJ* prime_meridian_pj = proj_create_from_database(
 *             context,
 *             cstrencode(auth_name),             # <<<<<<<<<<<<<<
 *             cstrencode(str(code)),
 *             PJ_CATEGORY_PRIME_MERIDIAN,
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_auth_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1132, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1132, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1133
 *             context,
 *             cstrencode(auth_name),
 *             cstrencode(str(code)),             # <<<<<<<<<<<<<<
 *             PJ_CATEGORY_PRIME_MERIDIAN,
 *             False,
*/
  __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __pyx_f_6pyproj_7_compat_cstrencode(((PyObject*)__pyx_t_4), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1133, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsString(__pyx_t_5); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1133, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1130
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = proj_create_from_database(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(auth_name),
*/
  __pyx_v_prime_meridian_pj = proj_create_from_database(__pyx_v_context, __pyx_t_3, __pyx_t_6, PJ_CATEGORY_PRIME_MERIDIAN, 0, NULL);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pyproj/_crs.pyx":1139
 *         )
 * 
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  __pyx_t_7 = (__pyx_v_prime_meridian_pj == NULL);
  if (unlikely(__pyx_t_7)) {

    /* "pyproj/_crs.pyx":1140
 * 
 *         if prime_meridian_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return PrimeMeridian.create(context, prime_meridian_pj)
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_code, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Invalid_authority_or_code;
    __pyx_t_9[1] = __pyx_v_auth_name;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__8;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__5;
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 27 + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_auth_name) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_auth_name) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1140, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1139
 *         )
 * 
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  }

  /* "pyproj/_crs.pyx":1141
 *         if prime_meridian_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1142
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
 *         return PrimeMeridian.create(context, prime_meridian_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = ((PyObject *)__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(__pyx_v_context, __pyx_v_prime_meridian_pj)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1111
 *         return prime_meridian
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1144
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_7from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_6from_epsg, "PrimeMeridian.from_epsg(code)\n\n.. versionadded:: 2.2.0\n\nCreate a PrimeMeridian from an EPSG code.\n\nParameters\n----------\ncode: str or int\n    The code used by EPSG.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_7from_epsg = {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_7from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_6from_epsg};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_7from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_epsg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1144, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1144, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_epsg", 0) < (0)) __PYX_ERR(0, 1144, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_epsg", 1, 1, 1, i); __PYX_ERR(0, 1144, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1144, __pyx_L3_error)
    }
    __pyx_v_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_epsg", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1144, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1145, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_6from_epsg(__pyx_v_code);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_6from_epsg(PyObject *__pyx_v_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_epsg", 0);

  /* "pyproj/_crs.pyx":1160
 *         PrimeMeridian
 *         """
 *         return PrimeMeridian.from_authority("EPSG", code)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_EPSG, __pyx_v_code};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_authority, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1144
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1162
 *         return PrimeMeridian.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str prime_meridian_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_8_from_string, "PrimeMeridian._from_string(str prime_meridian_string)\n\nCreate an PrimeMeridian from a string.\n\nExamples:\n  - urn:ogc:def:meridian:EPSG::8901\n  - PRIMEM[\"Greenwich\",0,\n    ANGLEUNIT[\"degree\",0.0174532925199433],\n    ID[\"EPSG\",8901]]\n\nParameters\n----------\nprime_meridian_string: str\n    prime meridian string.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_9_from_string = {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_8_from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_prime_meridian_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_prime_meridian_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1162, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1162, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_string", 0) < (0)) __PYX_ERR(0, 1162, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, i); __PYX_ERR(0, 1162, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1162, __pyx_L3_error)
    }
    __pyx_v_prime_meridian_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1162, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_prime_meridian_string), (&PyUnicode_Type), 0, "prime_meridian_string", 1))) __PYX_ERR(0, 1163, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_8_from_string(__pyx_v_prime_meridian_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_8_from_string(PyObject *__pyx_v_prime_meridian_string) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_prime_meridian_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_string", 0);

  /* "pyproj/_crs.pyx":1182
 *         PrimeMeridian
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* prime_meridian_pj = proj_create(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1182, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1185
 *         cdef PJ* prime_meridian_pj = proj_create(
 *             context,
 *             cstrencode(prime_meridian_string)             # <<<<<<<<<<<<<<
 *         )
 *         if (
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_prime_meridian_string, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1185, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1185, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1183
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = proj_create(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(prime_meridian_string)
*/
  __pyx_v_prime_meridian_pj = proj_create(__pyx_v_context, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1188
 *         )
 *         if (
 *             prime_meridian_pj == NULL or             # <<<<<<<<<<<<<<
 *             proj_get_type(prime_meridian_pj) != PJ_TYPE_PRIME_MERIDIAN
 *         ):
*/
  __pyx_t_5 = (__pyx_v_prime_meridian_pj == NULL);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":1189
 *         if (
 *             prime_meridian_pj == NULL or
 *             proj_get_type(prime_meridian_pj) != PJ_TYPE_PRIME_MERIDIAN             # <<<<<<<<<<<<<<
 *         ):
 *             proj_destroy(prime_meridian_pj)
*/
  __pyx_t_5 = (proj_get_type(__pyx_v_prime_meridian_pj) != PJ_TYPE_PRIME_MERIDIAN);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "pyproj/_crs.pyx":1187
 *             cstrencode(prime_meridian_string)
 *         )
 *         if (             # <<<<<<<<<<<<<<
 *             prime_meridian_pj == NULL or
 *             proj_get_type(prime_meridian_pj) != PJ_TYPE_PRIME_MERIDIAN
*/
  if (unlikely(__pyx_t_4)) {

    /* "pyproj/_crs.pyx":1191
 *             proj_get_type(prime_meridian_pj) != PJ_TYPE_PRIME_MERIDIAN
 *         ):
 *             proj_destroy(prime_meridian_pj)             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 f"Invalid prime meridian string: {prime_meridian_string}"
*/
    proj_destroy(__pyx_v_prime_meridian_pj);

    /* "pyproj/_crs.pyx":1192
 *         ):
 *             proj_destroy(prime_meridian_pj)
 *             raise CRSError(             # <<<<<<<<<<<<<<
 *                 f"Invalid prime meridian string: {prime_meridian_string}"
 *             )
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "pyproj/_crs.pyx":1193
 *             proj_destroy(prime_meridian_pj)
 *             raise CRSError(
 *                 f"Invalid prime meridian string: {prime_meridian_string}"             # <<<<<<<<<<<<<<
 *             )
 *         _clear_proj_error()
*/
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_prime_meridian_string, __pyx_v_prime_meridian_string); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1192, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1187
 *             cstrencode(prime_meridian_string)
 *         )
 *         if (             # <<<<<<<<<<<<<<
 *             prime_meridian_pj == NULL or
 *             proj_get_type(prime_meridian_pj) != PJ_TYPE_PRIME_MERIDIAN
*/
  }

  /* "pyproj/_crs.pyx":1195
 *                 f"Invalid prime meridian string: {prime_meridian_string}"
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1196
 *             )
 *         _clear_proj_error()
 *         return PrimeMeridian.create(context, prime_meridian_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(__pyx_v_context, __pyx_v_prime_meridian_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1162
 *         return PrimeMeridian.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str prime_meridian_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1198
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str prime_meridian_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_11from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_10from_string, "PrimeMeridian.from_string(str prime_meridian_string)\n\n.. versionadded:: 2.2.0\n\nCreate an PrimeMeridian from a string.\n\nExamples:\n  - urn:ogc:def:meridian:EPSG::8901\n  - PRIMEM[\"Greenwich\",0,\n    ANGLEUNIT[\"degree\",0.0174532925199433],\n    ID[\"EPSG\",8901]]\n  - Greenwich\n\nParameters\n----------\nprime_meridian_string: str\n    prime meridian string.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_11from_string = {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_11from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_10from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_11from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_prime_meridian_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_prime_meridian_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1198, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1198, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_string", 0) < (0)) __PYX_ERR(0, 1198, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, i); __PYX_ERR(0, 1198, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1198, __pyx_L3_error)
    }
    __pyx_v_prime_meridian_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1198, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_prime_meridian_string), (&PyUnicode_Type), 0, "prime_meridian_string", 1))) __PYX_ERR(0, 1199, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_10from_string(__pyx_v_prime_meridian_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_10from_string(PyObject *__pyx_v_prime_meridian_string) {
  PyObject *__pyx_v_crs_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_string", 0);

  /* "pyproj/_crs.pyx":1221
 *         PrimeMeridian
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":1222
 *         """
 *         try:
 *             return PrimeMeridian._from_string(prime_meridian_string)             # <<<<<<<<<<<<<<
 *         except CRSError as crs_err:
 *             try:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_prime_meridian_string};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1222, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":1221
 *         PrimeMeridian
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":1223
 *         try:
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return PrimeMeridian.from_name(prime_meridian_string)
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1223, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_7);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 1223, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_crs_err = __pyx_t_5;
      /*try:*/ {

        /* "pyproj/_crs.pyx":1224
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return PrimeMeridian.from_name(prime_meridian_string)
 *             except CRSError:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {

            /* "pyproj/_crs.pyx":1225
 *         except CRSError as crs_err:
 *             try:
 *                 return PrimeMeridian.from_name(prime_meridian_string)             # <<<<<<<<<<<<<<
 *             except CRSError:
 *                 raise crs_err
*/
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_13 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_prime_meridian_string};
              __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1225, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_8);
            }
            __pyx_r = __pyx_t_8;
            __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            goto __pyx_L20_try_return;

            /* "pyproj/_crs.pyx":1224
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return PrimeMeridian.from_name(prime_meridian_string)
 *             except CRSError:
*/
          }
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "pyproj/_crs.pyx":1226
 *             try:
 *                 return PrimeMeridian.from_name(prime_meridian_string)
 *             except CRSError:             # <<<<<<<<<<<<<<
 *                 raise crs_err
 * 
*/
          __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_13, &__pyx_t_14);
          __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1226, __pyx_L18_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_8, __pyx_t_15);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_ErrRestore(__pyx_t_8, __pyx_t_13, __pyx_t_14);
          __pyx_t_8 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
          if (__pyx_t_9) {
            __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_13, &__pyx_t_8) < 0) __PYX_ERR(0, 1226, __pyx_L18_except_error)
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_8);

            /* "pyproj/_crs.pyx":1227
 *                 return PrimeMeridian.from_name(prime_meridian_string)
 *             except CRSError:
 *                 raise crs_err             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
            __Pyx_Raise(__pyx_v_crs_err, 0, 0, 0);
            __PYX_ERR(0, 1227, __pyx_L18_except_error)
          }
          goto __pyx_L18_except_error;

          /* "pyproj/_crs.pyx":1224
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return PrimeMeridian.from_name(prime_meridian_string)
 *             except CRSError:
*/
          __pyx_L18_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L14_error;
          __pyx_L20_try_return:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L13_return;
        }
      }

      /* "pyproj/_crs.pyx":1223
 *         try:
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return PrimeMeridian.from_name(prime_meridian_string)
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_9 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_20 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          __pyx_r = __pyx_t_20;
          __pyx_t_20 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":1221
 *         PrimeMeridian
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return PrimeMeridian._from_string(prime_meridian_string)
 *         except CRSError as crs_err:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":1198
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str prime_meridian_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_crs_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1229
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict prime_meridian_dict not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_13from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_12from_json_dict, "PrimeMeridian.from_json_dict(dict prime_meridian_dict)\n\n.. versionadded:: 2.4.0\n\nCreate PrimeMeridian from a JSON dictionary.\n\nParameters\n----------\nprime_meridian_dict: str\n    PrimeMeridian dictionary.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_13from_json_dict = {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_13from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_12from_json_dict};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_13from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_prime_meridian_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_prime_meridian_dict,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1229, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1229, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json_dict", 0) < (0)) __PYX_ERR(0, 1229, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, i); __PYX_ERR(0, 1229, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1229, __pyx_L3_error)
    }
    __pyx_v_prime_meridian_dict = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1229, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_prime_meridian_dict), (&PyDict_Type), 0, "prime_meridian_dict", 1))) __PYX_ERR(0, 1230, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_12from_json_dict(__pyx_v_prime_meridian_dict);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_12from_json_dict(PyObject *__pyx_v_prime_meridian_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json_dict", 0);

  /* "pyproj/_crs.pyx":1245
 *         PrimeMeridian
 *         """
 *         return PrimeMeridian._from_string(             # <<<<<<<<<<<<<<
 *             json.dumps(prime_meridian_dict, cls=NumpyEncoder)
 *         )
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":1246
 *         """
 *         return PrimeMeridian._from_string(
 *             json.dumps(prime_meridian_dict, cls=NumpyEncoder)             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NumpyEncoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_prime_meridian_dict};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cls, __pyx_t_5, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1246, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1229
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict prime_meridian_dict not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1249
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str prime_meridian_json_str not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_15from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_14from_json, "PrimeMeridian.from_json(str prime_meridian_json_str)\n\n.. versionadded:: 2.4.0\n\nCreate PrimeMeridian from a JSON string.\n\nParameters\n----------\nprime_meridian_json_str: str\n    PrimeMeridian JSON string.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_15from_json = {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_15from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_14from_json};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_15from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_prime_meridian_json_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_prime_meridian_json_str,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1249, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1249, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json", 0) < (0)) __PYX_ERR(0, 1249, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, i); __PYX_ERR(0, 1249, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1249, __pyx_L3_error)
    }
    __pyx_v_prime_meridian_json_str = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1249, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_prime_meridian_json_str), (&PyUnicode_Type), 0, "prime_meridian_json_str", 1))) __PYX_ERR(0, 1250, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_14from_json(__pyx_v_prime_meridian_json_str);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_14from_json(PyObject *__pyx_v_prime_meridian_json_str) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json", 0);

  /* "pyproj/_crs.pyx":1265
 *         PrimeMeridian
 *         """
 *         return PrimeMeridian.from_json_dict(_load_proj_json(prime_meridian_json_str))             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_load_proj_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_prime_meridian_json_str};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1249
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str prime_meridian_json_str not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1267
 *         return PrimeMeridian.from_json_dict(_load_proj_json(prime_meridian_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str prime_meridian_name not None,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_17from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_16from_name, "PrimeMeridian.from_name(str prime_meridian_name, str auth_name=None)\n\n.. versionadded:: 2.5.0\n\nCreate a Prime Meridian from a name.\n\nExamples:\n  - Greenwich\n\nParameters\n----------\nprime_meridian_name: str\n    Prime Meridian name.\nauth_name: str, optional\n    The authority name to refine search (e.g. 'EPSG').\n    If None, will search all authorities.\n\nReturns\n-------\nPrimeMeridian");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_17from_name = {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_17from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_16from_name};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_17from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_prime_meridian_name = 0;
  PyObject *__pyx_v_auth_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_prime_meridian_name,&__pyx_mstate_global->__pyx_n_u_auth_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1267, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1267, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1267, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_name", 0) < (0)) __PYX_ERR(0, 1267, __pyx_L3_error)

      /* "pyproj/_crs.pyx":1270
 *     def from_name(
 *         str prime_meridian_name not None,
 *         str auth_name=None,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 2, i); __PYX_ERR(0, 1267, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1267, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1267, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_prime_meridian_name = ((PyObject*)values[0]);
    __pyx_v_auth_name = ((PyObject*)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1267, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_prime_meridian_name), (&PyUnicode_Type), 0, "prime_meridian_name", 1))) __PYX_ERR(0, 1269, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 1270, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_16from_name(__pyx_v_prime_meridian_name, __pyx_v_auth_name);

  /* "pyproj/_crs.pyx":1267
 *         return PrimeMeridian.from_json_dict(_load_proj_json(prime_meridian_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str prime_meridian_name not None,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_16from_name(PyObject *__pyx_v_prime_meridian_name, PyObject *__pyx_v_auth_name) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_prime_meridian_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PJ *__pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_name", 0);

  /* "pyproj/_crs.pyx":1292
 *         PrimeMeridian
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* prime_meridian_pj = _from_name(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1292, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1293
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = _from_name(             # <<<<<<<<<<<<<<
 *             context,
 *             prime_meridian_name,
*/
  __pyx_t_2 = __pyx_f_6pyproj_4_crs__from_name(__pyx_v_context, __pyx_v_prime_meridian_name, __pyx_v_auth_name, PJ_TYPE_PRIME_MERIDIAN); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 1293, __pyx_L1_error)
  __pyx_v_prime_meridian_pj = __pyx_t_2;

  /* "pyproj/_crs.pyx":1299
 *             PJ_TYPE_PRIME_MERIDIAN,
 *         )
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 f"Invalid prime meridian name: {prime_meridian_name}"
*/
  __pyx_t_3 = (__pyx_v_prime_meridian_pj == NULL);
  if (unlikely(__pyx_t_3)) {

    /* "pyproj/_crs.pyx":1300
 *         )
 *         if prime_meridian_pj == NULL:
 *             raise CRSError(             # <<<<<<<<<<<<<<
 *                 f"Invalid prime meridian name: {prime_meridian_name}"
 *             )
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "pyproj/_crs.pyx":1301
 *         if prime_meridian_pj == NULL:
 *             raise CRSError(
 *                 f"Invalid prime meridian name: {prime_meridian_name}"             # <<<<<<<<<<<<<<
 *             )
 *         _clear_proj_error()
*/
    __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_prime_meridian_name, __pyx_v_prime_meridian_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1300, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1299
 *             PJ_TYPE_PRIME_MERIDIAN,
 *         )
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 f"Invalid prime meridian name: {prime_meridian_name}"
*/
  }

  /* "pyproj/_crs.pyx":1303
 *                 f"Invalid prime meridian name: {prime_meridian_name}"
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1304
 *             )
 *         _clear_proj_error()
 *         return PrimeMeridian.create(context, prime_meridian_pj)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(__pyx_v_context, __pyx_v_prime_meridian_pj)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1267
 *         return PrimeMeridian.from_json_dict(_load_proj_json(prime_meridian_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str prime_meridian_name not None,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":71
 * 
 * cdef class PrimeMeridian(_CRSParts):
 *     cdef readonly double longitude             # <<<<<<<<<<<<<<
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9longitude_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9longitude_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_9longitude___get__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_9longitude___get__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->longitude); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.longitude.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":72
 * cdef class PrimeMeridian(_CRSParts):
 *     cdef readonly double longitude
 *     cdef readonly double unit_conversion_factor             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_22unit_conversion_factor_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_22unit_conversion_factor_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_22unit_conversion_factor___get__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_22unit_conversion_factor___get__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->unit_conversion_factor); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.unit_conversion_factor.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":73
 *     cdef readonly double longitude
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9unit_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9unit_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_9unit_name___get__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_9unit_name___get__(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_name);
  __pyx_r = __pyx_v_self->unit_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_19__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_18__reduce_cython__, "PrimeMeridian.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_19__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_19__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_18__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_19__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_18__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_18__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_21__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_13PrimeMeridian_20__setstate_cython__, "PrimeMeridian.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_13PrimeMeridian_21__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_21__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_20__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_13PrimeMeridian_21__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_13PrimeMeridian_20__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_13PrimeMeridian_20__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.PrimeMeridian.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1341
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._ellipsoid = None
 *         self._prime_meridian = None
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_5Datum_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_5Datum_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum___cinit__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_5Datum___cinit__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":1342
 *     """
 *     def __cinit__(self):
 *         self._ellipsoid = None             # <<<<<<<<<<<<<<
 *         self._prime_meridian = None
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_ellipsoid);
  __Pyx_DECREF(__pyx_v_self->_ellipsoid);
  __pyx_v_self->_ellipsoid = Py_None;

  /* "pyproj/_crs.pyx":1343
 *     def __cinit__(self):
 *         self._ellipsoid = None
 *         self._prime_meridian = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_prime_meridian);
  __Pyx_DECREF(__pyx_v_self->_prime_meridian);
  __pyx_v_self->_prime_meridian = Py_None;

  /* "pyproj/_crs.pyx":1341
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._ellipsoid = None
 *         self._prime_meridian = None
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1345
 *         self._prime_meridian = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "Datum can only be initialized like 'Datum.from_*()'."
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_5Datum_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_5Datum_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_2__init__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_5Datum_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyproj/_crs.pyx":1346
 * 
 *     def __init__(self):
 *         raise RuntimeError(             # <<<<<<<<<<<<<<
 *             "Datum can only be initialized like 'Datum.from_*()'."
 *         )
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Datum_can_only_be_initialized_li};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 1346, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1345
 *         self._prime_meridian = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "Datum can only be initialized like 'Datum.from_*()'."
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Datum.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1350
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Datum create(PJ_CONTEXT* context, PJ* datum_pj):
 *         cdef Datum datum = Datum.__new__(Datum)
*/

static struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_f_6pyproj_4_crs_5Datum_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_datum_pj) {
  struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_datum = 0;
  struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":1352
 *     @staticmethod
 *     cdef Datum create(PJ_CONTEXT* context, PJ* datum_pj):
 *         cdef Datum datum = Datum.__new__(Datum)             # <<<<<<<<<<<<<<
 *         datum.context = context
 *         datum._context_manager = get_context_manager()
*/
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6pyproj_4_crs_Datum(((PyTypeObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum), __pyx_mstate_global->__pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1352, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_1);
  __pyx_v_datum = ((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1353
 *     cdef Datum create(PJ_CONTEXT* context, PJ* datum_pj):
 *         cdef Datum datum = Datum.__new__(Datum)
 *         datum.context = context             # <<<<<<<<<<<<<<
 *         datum._context_manager = get_context_manager()
 *         datum.projobj = datum_pj
*/
  __pyx_v_datum->__pyx_base.__pyx_base.context = __pyx_v_context;

  /* "pyproj/_crs.pyx":1354
 *         cdef Datum datum = Datum.__new__(Datum)
 *         datum.context = context
 *         datum._context_manager = get_context_manager()             # <<<<<<<<<<<<<<
 *         datum.projobj = datum_pj
 *         datum._set_base_info()
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_get_context_manager); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_datum->__pyx_base.__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_datum->__pyx_base.__pyx_base._context_manager);
  __pyx_v_datum->__pyx_base.__pyx_base._context_manager = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1355
 *         datum.context = context
 *         datum._context_manager = get_context_manager()
 *         datum.projobj = datum_pj             # <<<<<<<<<<<<<<
 *         datum._set_base_info()
 *         datum.type_name = _DATUM_TYPE_MAP[proj_get_type(datum.projobj)]
*/
  __pyx_v_datum->__pyx_base.__pyx_base.projobj = __pyx_v_datum_pj;

  /* "pyproj/_crs.pyx":1356
 *         datum._context_manager = get_context_manager()
 *         datum.projobj = datum_pj
 *         datum._set_base_info()             # <<<<<<<<<<<<<<
 *         datum.type_name = _DATUM_TYPE_MAP[proj_get_type(datum.projobj)]
 *         return datum
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pyproj_4_crs_Datum *)__pyx_v_datum->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._set_base_info(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_datum)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1357
 *         datum.projobj = datum_pj
 *         datum._set_base_info()
 *         datum.type_name = _DATUM_TYPE_MAP[proj_get_type(datum.projobj)]             # <<<<<<<<<<<<<<
 *         return datum
 * 
*/
  if (unlikely(__pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1357, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyLong_From_PJ_TYPE(proj_get_type(__pyx_v_datum->__pyx_base.__pyx_base.projobj)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(0, 1357, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_datum->type_name);
  __Pyx_DECREF(__pyx_v_datum->type_name);
  __pyx_v_datum->type_name = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyproj/_crs.pyx":1358
 *         datum._set_base_info()
 *         datum.type_name = _DATUM_TYPE_MAP[proj_get_type(datum.projobj)]
 *         return datum             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_datum);
  __pyx_r = __pyx_v_datum;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1350
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Datum create(PJ_CONTEXT* context, PJ* datum_pj):
 *         cdef Datum datum = Datum.__new__(Datum)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.Datum.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_datum);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1360
 *         return datum
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_authority(str auth_name not None, code not None, PJ_CATEGORY category):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_5_from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_4_from_authority, "Datum._from_authority(str auth_name, code, PJ_CATEGORY category)\n\nCreate a Datum from an authority code.\n\nParameters\n----------\nauth_name: str\n    Name of the authority.\ncode: str or int\n    The code used by the authority.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_5_from_authority = {"_from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_5_from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_4_from_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_5_from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_code = 0;
  PJ_CATEGORY __pyx_v_category;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_code,&__pyx_mstate_global->__pyx_n_u_category,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1360, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1360, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1360, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1360, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_authority", 0) < (0)) __PYX_ERR(0, 1360, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_authority", 1, 3, 3, i); __PYX_ERR(0, 1360, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1360, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1360, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1360, __pyx_L3_error)
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    __pyx_v_code = values[1];
    __pyx_v_category = ((PJ_CATEGORY)__Pyx_PyLong_As_PJ_CATEGORY(values[2])); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1361, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_authority", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1360, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum._from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 0, "auth_name", 1))) __PYX_ERR(0, 1361, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1361, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_4_from_authority(__pyx_v_auth_name, __pyx_v_code, __pyx_v_category);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_4_from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code, PJ_CATEGORY __pyx_v_category) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_datum_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  char const *__pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_authority", 0);

  /* "pyproj/_crs.pyx":1376
 *         Datum
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ* datum_pj = proj_create_from_database(
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1376, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1380
 *         cdef PJ* datum_pj = proj_create_from_database(
 *             context,
 *             cstrencode(auth_name),             # <<<<<<<<<<<<<<
 *             cstrencode(str(code)),
 *             category,
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_auth_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1380, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1380, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1381
 *             context,
 *             cstrencode(auth_name),
 *             cstrencode(str(code)),             # <<<<<<<<<<<<<<
 *             category,
 *             False,
*/
  __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __pyx_f_6pyproj_7_compat_cstrencode(((PyObject*)__pyx_t_4), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1381, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsString(__pyx_t_5); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1381, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1378
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 * 
 *         cdef PJ* datum_pj = proj_create_from_database(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(auth_name),
*/
  __pyx_v_datum_pj = proj_create_from_database(__pyx_v_context, __pyx_t_3, __pyx_t_6, __pyx_v_category, 0, NULL);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pyproj/_crs.pyx":1387
 *         )
 * 
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  __pyx_t_7 = (__pyx_v_datum_pj == NULL);
  if (unlikely(__pyx_t_7)) {

    /* "pyproj/_crs.pyx":1388
 * 
 *         if datum_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return Datum.create(context, datum_pj)
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_code, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Invalid_authority_or_code;
    __pyx_t_9[1] = __pyx_v_auth_name;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__8;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__5;
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 27 + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_auth_name) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_auth_name) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1388, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1388, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1387
 *         )
 * 
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  }

  /* "pyproj/_crs.pyx":1389
 *         if datum_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return Datum.create(context, datum_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1390
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
 *         return Datum.create(context, datum_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = ((PyObject *)__pyx_f_6pyproj_4_crs_5Datum_create(__pyx_v_context, __pyx_v_datum_pj)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1360
 *         return datum
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_authority(str auth_name not None, code not None, PJ_CATEGORY category):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyproj._crs.Datum._from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1392
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_7from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_6from_authority, "Datum.from_authority(str auth_name, code)\n\nCreate a Datum from an authority code.\n\nParameters\n----------\nauth_name: str\n    Name of the authority.\ncode: str or int\n    The code used by the authority.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_7from_authority = {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_7from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_6from_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_7from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1392, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1392, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1392, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_authority", 0) < (0)) __PYX_ERR(0, 1392, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_authority", 1, 2, 2, i); __PYX_ERR(0, 1392, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1392, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1392, __pyx_L3_error)
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    __pyx_v_code = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_authority", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1392, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 0, "auth_name", 1))) __PYX_ERR(0, 1393, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1393, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_6from_authority(__pyx_v_auth_name, __pyx_v_code);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_6from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_authority", 0);

  /* "pyproj/_crs.pyx":1408
 *         Datum
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM_ENSEMBLE)
 *         except CRSError:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":1409
 *         """
 *         try:
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM_ENSEMBLE)             # <<<<<<<<<<<<<<
 *         except CRSError:
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM)
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyLong_From_PJ_CATEGORY(PJ_CATEGORY_DATUM_ENSEMBLE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1409, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_5, __pyx_v_auth_name, __pyx_v_code, __pyx_t_6};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_authority_2, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1409, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":1408
 *         Datum
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM_ENSEMBLE)
 *         except CRSError:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "pyproj/_crs.pyx":1410
 *         try:
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM_ENSEMBLE)
 *         except CRSError:             # <<<<<<<<<<<<<<
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM)
 * 
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1410, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_6, __pyx_t_5);
    __pyx_t_4 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.Datum.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 1410, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "pyproj/_crs.pyx":1411
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM_ENSEMBLE)
 *         except CRSError:
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_10 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyLong_From_PJ_CATEGORY(PJ_CATEGORY_DATUM); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1411, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_10, __pyx_v_auth_name, __pyx_v_code, __pyx_t_11};
        __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_authority_2, __pyx_callargs+__pyx_t_7, (4-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1411, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
      }
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":1408
 *         Datum
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM_ENSEMBLE)
 *         except CRSError:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":1392
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pyproj._crs.Datum.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1413
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_9from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_8from_epsg, "Datum.from_epsg(code)\n\nCreate a Datum from an EPSG code.\n\nParameters\n----------\ncode: str or int\n    The code used by EPSG.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_9from_epsg = {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_9from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_8from_epsg};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_9from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_epsg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_code,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1413, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1413, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_epsg", 0) < (0)) __PYX_ERR(0, 1413, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_epsg", 1, 1, 1, i); __PYX_ERR(0, 1413, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1413, __pyx_L3_error)
    }
    __pyx_v_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_epsg", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1413, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1414, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_8from_epsg(__pyx_v_code);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_8from_epsg(PyObject *__pyx_v_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_epsg", 0);

  /* "pyproj/_crs.pyx":1427
 *         Datum
 *         """
 *         return Datum.from_authority("EPSG", code)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_EPSG, __pyx_v_code};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_authority, __pyx_callargs+__pyx_t_3, (3-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1413
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Datum.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1429
 *         return Datum.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str datum_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_11_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_10_from_string, "Datum._from_string(str datum_string)\n\nCreate a Datum from a string.\n\nExamples:\n  - urn:ogc:def:datum:EPSG::6326\n  - DATUM[\"World Geodetic System 1984\",\n    ELLIPSOID[\"WGS 84\",6378137,298.257223563,\n    LENGTHUNIT[\"metre\",1]],\n    ID[\"EPSG\",6326]]\n\nParameters\n----------\ndatum_string: str\n    Datum string.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_11_from_string = {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_11_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_10_from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_11_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_datum_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_datum_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1429, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1429, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_string", 0) < (0)) __PYX_ERR(0, 1429, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, i); __PYX_ERR(0, 1429, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1429, __pyx_L3_error)
    }
    __pyx_v_datum_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1429, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_datum_string), (&PyUnicode_Type), 0, "datum_string", 1))) __PYX_ERR(0, 1430, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_10_from_string(__pyx_v_datum_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_10_from_string(PyObject *__pyx_v_datum_string) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_datum_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_string", 0);

  /* "pyproj/_crs.pyx":1450
 *         Datum
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* datum_pj = proj_create(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1450, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1453
 *         cdef PJ* datum_pj = proj_create(
 *             context,
 *             cstrencode(datum_string)             # <<<<<<<<<<<<<<
 *         )
 *         if (
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_datum_string, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1453, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1453, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1451
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* datum_pj = proj_create(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(datum_string)
*/
  __pyx_v_datum_pj = proj_create(__pyx_v_context, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1456
 *         )
 *         if (
 *             datum_pj == NULL or             # <<<<<<<<<<<<<<
 *              proj_get_type(datum_pj) not in _DATUM_TYPE_MAP
 *         ):
*/
  __pyx_t_5 = (__pyx_v_datum_pj == NULL);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":1457
 *         if (
 *             datum_pj == NULL or
 *              proj_get_type(datum_pj) not in _DATUM_TYPE_MAP             # <<<<<<<<<<<<<<
 *         ):
 *             proj_destroy(datum_pj)
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(proj_get_type(__pyx_v_datum_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(0, 1457, __pyx_L1_error)
  }
  __pyx_t_5 = (__Pyx_PyDict_ContainsTF(__pyx_t_2, __pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;

  /* "pyproj/_crs.pyx":1455
 *             cstrencode(datum_string)
 *         )
 *         if (             # <<<<<<<<<<<<<<
 *             datum_pj == NULL or
 *              proj_get_type(datum_pj) not in _DATUM_TYPE_MAP
*/
  if (unlikely(__pyx_t_4)) {

    /* "pyproj/_crs.pyx":1459
 *              proj_get_type(datum_pj) not in _DATUM_TYPE_MAP
 *         ):
 *             proj_destroy(datum_pj)             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid datum string: {datum_string}")
 *         _clear_proj_error()
*/
    proj_destroy(__pyx_v_datum_pj);

    /* "pyproj/_crs.pyx":1460
 *         ):
 *             proj_destroy(datum_pj)
 *             raise CRSError(f"Invalid datum string: {datum_string}")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return Datum.create(context, datum_pj)
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_datum_string, __pyx_v_datum_string); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1460, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1455
 *             cstrencode(datum_string)
 *         )
 *         if (             # <<<<<<<<<<<<<<
 *             datum_pj == NULL or
 *              proj_get_type(datum_pj) not in _DATUM_TYPE_MAP
*/
  }

  /* "pyproj/_crs.pyx":1461
 *             proj_destroy(datum_pj)
 *             raise CRSError(f"Invalid datum string: {datum_string}")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return Datum.create(context, datum_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1462
 *             raise CRSError(f"Invalid datum string: {datum_string}")
 *         _clear_proj_error()
 *         return Datum.create(context, datum_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_5Datum_create(__pyx_v_context, __pyx_v_datum_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1429
 *         return Datum.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str datum_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.Datum._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1464
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str datum_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_13from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_12from_string, "Datum.from_string(str datum_string)\n\nCreate a Datum from a string.\n\nExamples:\n  - urn:ogc:def:datum:EPSG::6326\n  - DATUM[\"World Geodetic System 1984\",\n    ELLIPSOID[\"WGS 84\",6378137,298.257223563,\n    LENGTHUNIT[\"metre\",1]],\n    ID[\"EPSG\",6326]]\n  - World Geodetic System 1984\n\nParameters\n----------\ndatum_string: str\n    Datum string.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_13from_string = {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_13from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_12from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_13from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_datum_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_datum_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1464, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1464, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_string", 0) < (0)) __PYX_ERR(0, 1464, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, i); __PYX_ERR(0, 1464, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1464, __pyx_L3_error)
    }
    __pyx_v_datum_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1464, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_datum_string), (&PyUnicode_Type), 0, "datum_string", 1))) __PYX_ERR(0, 1465, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_12from_string(__pyx_v_datum_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_12from_string(PyObject *__pyx_v_datum_string) {
  PyObject *__pyx_v_crs_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_string", 0);

  /* "pyproj/_crs.pyx":1486
 *         Datum
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":1487
 *         """
 *         try:
 *             return Datum._from_string(datum_string)             # <<<<<<<<<<<<<<
 *         except CRSError as crs_err:
 *             try:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_datum_string};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1487, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":1486
 *         Datum
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":1488
 *         try:
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return Datum.from_name(datum_string)
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1488, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_7);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.Datum.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 1488, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_crs_err = __pyx_t_5;
      /*try:*/ {

        /* "pyproj/_crs.pyx":1489
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return Datum.from_name(datum_string)
 *             except CRSError:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {

            /* "pyproj/_crs.pyx":1490
 *         except CRSError as crs_err:
 *             try:
 *                 return Datum.from_name(datum_string)             # <<<<<<<<<<<<<<
 *             except CRSError:
 *                 raise crs_err
*/
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_13 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_datum_string};
              __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1490, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_8);
            }
            __pyx_r = __pyx_t_8;
            __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            goto __pyx_L20_try_return;

            /* "pyproj/_crs.pyx":1489
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return Datum.from_name(datum_string)
 *             except CRSError:
*/
          }
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "pyproj/_crs.pyx":1491
 *             try:
 *                 return Datum.from_name(datum_string)
 *             except CRSError:             # <<<<<<<<<<<<<<
 *                 raise crs_err
 * 
*/
          __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_13, &__pyx_t_14);
          __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1491, __pyx_L18_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_8, __pyx_t_15);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_ErrRestore(__pyx_t_8, __pyx_t_13, __pyx_t_14);
          __pyx_t_8 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
          if (__pyx_t_9) {
            __Pyx_AddTraceback("pyproj._crs.Datum.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_13, &__pyx_t_8) < 0) __PYX_ERR(0, 1491, __pyx_L18_except_error)
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_8);

            /* "pyproj/_crs.pyx":1492
 *                 return Datum.from_name(datum_string)
 *             except CRSError:
 *                 raise crs_err             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
            __Pyx_Raise(__pyx_v_crs_err, 0, 0, 0);
            __PYX_ERR(0, 1492, __pyx_L18_except_error)
          }
          goto __pyx_L18_except_error;

          /* "pyproj/_crs.pyx":1489
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return Datum.from_name(datum_string)
 *             except CRSError:
*/
          __pyx_L18_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L14_error;
          __pyx_L20_try_return:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L13_return;
        }
      }

      /* "pyproj/_crs.pyx":1488
 *         try:
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return Datum.from_name(datum_string)
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_9 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_20 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          __pyx_r = __pyx_t_20;
          __pyx_t_20 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":1486
 *         Datum
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return Datum._from_string(datum_string)
 *         except CRSError as crs_err:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":1464
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str datum_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("pyproj._crs.Datum.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_crs_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1494
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_name(
 *         str datum_name,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_15_from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_14_from_name, "Datum._from_name(str datum_name, str auth_name, datum_type)\n\n.. versionadded:: 2.5.0\n\nCreate a Datum from a name.\n\nParameters\n----------\ndatum_name: str\n    Datum name.\nauth_name: str\n    The authority name to refine search (e.g. 'EPSG').\n    If None, will search all authorities.\ndatum_type: DatumType\n    The datum type to create.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_15_from_name = {"_from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_15_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_14_from_name};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_15_from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_datum_name = 0;
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_datum_type = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_datum_name,&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_datum_type,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1494, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1494, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1494, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1494, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_name", 0) < (0)) __PYX_ERR(0, 1494, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_name", 1, 3, 3, i); __PYX_ERR(0, 1494, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1494, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1494, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1494, __pyx_L3_error)
    }
    __pyx_v_datum_name = ((PyObject*)values[0]);
    __pyx_v_auth_name = ((PyObject*)values[1]);
    __pyx_v_datum_type = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1494, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_datum_name), (&PyUnicode_Type), 1, "datum_name", 1))) __PYX_ERR(0, 1496, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 1497, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_14_from_name(__pyx_v_datum_name, __pyx_v_auth_name, __pyx_v_datum_type);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_14_from_name(PyObject *__pyx_v_datum_name, PyObject *__pyx_v_auth_name, PyObject *__pyx_v_datum_type) {
  PyObject *__pyx_v_pj_datum_type = NULL;
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_datum_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PJ_CONTEXT *__pyx_t_2;
  PJ_TYPE __pyx_t_3;
  PJ *__pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 0);

  /* "pyproj/_crs.pyx":1519
 *         Datum
 *         """
 *         pj_datum_type = _PJ_DATUM_TYPE_MAP[datum_type]             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* datum_pj = _from_name(
*/
  if (unlikely(__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1519, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP, __pyx_v_datum_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_pj_datum_type = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1520
 *         """
 *         pj_datum_type = _PJ_DATUM_TYPE_MAP[datum_type]
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* datum_pj = _from_name(
 *             context,
*/
  __pyx_t_2 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1520, __pyx_L1_error)
  __pyx_v_context = __pyx_t_2;

  /* "pyproj/_crs.pyx":1525
 *             datum_name,
 *             auth_name,
 *             <PJ_TYPE>pj_datum_type,             # <<<<<<<<<<<<<<
 *         )
 *         if datum_pj == NULL:
*/
  __pyx_t_3 = ((PJ_TYPE)__Pyx_PyLong_As_PJ_TYPE(__pyx_v_pj_datum_type)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1525, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1521
 *         pj_datum_type = _PJ_DATUM_TYPE_MAP[datum_type]
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* datum_pj = _from_name(             # <<<<<<<<<<<<<<
 *             context,
 *             datum_name,
*/
  __pyx_t_4 = __pyx_f_6pyproj_4_crs__from_name(__pyx_v_context, __pyx_v_datum_name, __pyx_v_auth_name, ((PJ_TYPE)__pyx_t_3)); if (unlikely(__pyx_t_4 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 1521, __pyx_L1_error)
  __pyx_v_datum_pj = __pyx_t_4;

  /* "pyproj/_crs.pyx":1527
 *             <PJ_TYPE>pj_datum_type,
 *         )
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid datum name: {datum_name}")
 *         _clear_proj_error()
*/
  __pyx_t_5 = (__pyx_v_datum_pj == NULL);
  if (unlikely(__pyx_t_5)) {

    /* "pyproj/_crs.pyx":1528
 *         )
 *         if datum_pj == NULL:
 *             raise CRSError(f"Invalid datum name: {datum_name}")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return Datum.create(context, datum_pj)
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_v_datum_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_datum_name, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_10 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_10 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1528, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1527
 *             <PJ_TYPE>pj_datum_type,
 *         )
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid datum name: {datum_name}")
 *         _clear_proj_error()
*/
  }

  /* "pyproj/_crs.pyx":1529
 *         if datum_pj == NULL:
 *             raise CRSError(f"Invalid datum name: {datum_name}")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return Datum.create(context, datum_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1530
 *             raise CRSError(f"Invalid datum name: {datum_name}")
 *         _clear_proj_error()
 *         return Datum.create(context, datum_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pyproj_4_crs_5Datum_create(__pyx_v_context, __pyx_v_datum_pj)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1494
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_name(
 *         str datum_name,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyproj._crs.Datum._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pj_datum_type);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1532
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str datum_name not None,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_17from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_16from_name, "Datum.from_name(str datum_name, str auth_name=None, datum_type=None)\n\n.. versionadded:: 2.5.0\n\nCreate a Datum from a name.\n\nExamples:\n  - WGS 84\n  - World Geodetic System 1984\n\nParameters\n----------\ndatum_name: str\n    Datum name.\nauth_name: str, optional\n    The authority name to refine search (e.g. 'EPSG').\n    If None, will search all authorities.\ndatum_type: DatumType, optional\n    The datum type to create. If it is None, it uses any datum type.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_17from_name = {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_17from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_16from_name};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_17from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_datum_name = 0;
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_datum_type = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_datum_name,&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_datum_type,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1532, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1532, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1532, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1532, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_name", 0) < (0)) __PYX_ERR(0, 1532, __pyx_L3_error)

      /* "pyproj/_crs.pyx":1535
 *     def from_name(
 *         str datum_name not None,
 *         str auth_name=None,             # <<<<<<<<<<<<<<
 *         datum_type=None,
 *     ):
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));

      /* "pyproj/_crs.pyx":1536
 *         str datum_name not None,
 *         str auth_name=None,
 *         datum_type=None,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 3, i); __PYX_ERR(0, 1532, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1532, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1532, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1532, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "pyproj/_crs.pyx":1535
 *     def from_name(
 *         str datum_name not None,
 *         str auth_name=None,             # <<<<<<<<<<<<<<
 *         datum_type=None,
 *     ):
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));

      /* "pyproj/_crs.pyx":1536
 *         str datum_name not None,
 *         str auth_name=None,
 *         datum_type=None,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_datum_name = ((PyObject*)values[0]);
    __pyx_v_auth_name = ((PyObject*)values[1]);
    __pyx_v_datum_type = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 1532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_datum_name), (&PyUnicode_Type), 0, "datum_name", 1))) __PYX_ERR(0, 1534, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 1535, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_16from_name(__pyx_v_datum_name, __pyx_v_auth_name, __pyx_v_datum_type);

  /* "pyproj/_crs.pyx":1532
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str datum_name not None,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_16from_name(PyObject *__pyx_v_datum_name, PyObject *__pyx_v_auth_name, PyObject *__pyx_v_datum_type) {
  PyObject *__pyx_v_first_error = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_name", 0);
  __Pyx_INCREF(__pyx_v_datum_type);

  /* "pyproj/_crs.pyx":1561
 *         Datum
 *         """
 *         if datum_type is None:             # <<<<<<<<<<<<<<
 *             # try creating name from all datum types
 *             first_error = None
*/
  __pyx_t_1 = (__pyx_v_datum_type == Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":1563
 *         if datum_type is None:
 *             # try creating name from all datum types
 *             first_error = None             # <<<<<<<<<<<<<<
 *             for datum_type in _PJ_DATUM_TYPE_MAP:
 *                 try:
*/
    __Pyx_INCREF(Py_None);
    __pyx_v_first_error = ((PyObject*)Py_None);

    /* "pyproj/_crs.pyx":1564
 *             # try creating name from all datum types
 *             first_error = None
 *             for datum_type in _PJ_DATUM_TYPE_MAP:             # <<<<<<<<<<<<<<
 *                 try:
 *                     return Datum.from_name(
*/
    __pyx_t_3 = 0;
    if (unlikely(__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 1564, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_dict_iterator(__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP, 1, ((PyObject *)NULL), (&__pyx_t_4), (&__pyx_t_5)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_6;
    __pyx_t_6 = 0;
    while (1) {
      __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_4, &__pyx_t_3, &__pyx_t_6, NULL, NULL, __pyx_t_5);
      if (unlikely(__pyx_t_7 == 0)) break;
      if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(0, 1564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF_SET(__pyx_v_datum_type, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "pyproj/_crs.pyx":1565
 *             first_error = None
 *             for datum_type in _PJ_DATUM_TYPE_MAP:
 *                 try:             # <<<<<<<<<<<<<<
 *                     return Datum.from_name(
 *                         datum_name=datum_name,
*/
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {

          /* "pyproj/_crs.pyx":1566
 *             for datum_type in _PJ_DATUM_TYPE_MAP:
 *                 try:
 *                     return Datum.from_name(             # <<<<<<<<<<<<<<
 *                         datum_name=datum_name,
 *                         auth_name=auth_name,
*/
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_11 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
          __Pyx_INCREF(__pyx_t_11);

          /* "pyproj/_crs.pyx":1569
 *                         datum_name=datum_name,
 *                         auth_name=auth_name,
 *                         datum_type=datum_type,             # <<<<<<<<<<<<<<
 *                     )
 *                 except CRSError as err:
*/
          __pyx_t_12 = 0;
          {
            PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_11, NULL};
            __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1566, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_13);
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_datum_name, __pyx_v_datum_name, __pyx_t_13, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1566, __pyx_L6_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_auth_name, __pyx_v_auth_name, __pyx_t_13, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1566, __pyx_L6_error)
            if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_datum_type, __pyx_v_datum_type, __pyx_t_13, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1566, __pyx_L6_error)
            __pyx_t_6 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name, __pyx_callargs+__pyx_t_12, (1-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1566, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_6);
          }
          __pyx_r = __pyx_t_6;
          __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L10_try_return;

          /* "pyproj/_crs.pyx":1565
 *             first_error = None
 *             for datum_type in _PJ_DATUM_TYPE_MAP:
 *                 try:             # <<<<<<<<<<<<<<
 *                     return Datum.from_name(
 *                         datum_name=datum_name,
*/
        }
        __pyx_L6_error:;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "pyproj/_crs.pyx":1571
 *                         datum_type=datum_type,
 *                     )
 *                 except CRSError as err:             # <<<<<<<<<<<<<<
 *                     if first_error is None:
 *                         first_error = err
*/
        __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_13, &__pyx_t_11);
        __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1571, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_7 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_14);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_ErrRestore(__pyx_t_6, __pyx_t_13, __pyx_t_11);
        __pyx_t_6 = 0; __pyx_t_13 = 0; __pyx_t_11 = 0;
        if (__pyx_t_7) {
          __Pyx_AddTraceback("pyproj._crs.Datum.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_13, &__pyx_t_6) < 0) __PYX_ERR(0, 1571, __pyx_L8_except_error)
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_13);
          __pyx_v_err = __pyx_t_13;
          /*try:*/ {

            /* "pyproj/_crs.pyx":1572
 *                     )
 *                 except CRSError as err:
 *                     if first_error is None:             # <<<<<<<<<<<<<<
 *                         first_error = err
 *             raise first_error
*/
            __pyx_t_1 = (__pyx_v_first_error == ((PyObject*)Py_None));
            if (__pyx_t_1) {

              /* "pyproj/_crs.pyx":1573
 *                 except CRSError as err:
 *                     if first_error is None:
 *                         first_error = err             # <<<<<<<<<<<<<<
 *             raise first_error
 * 
*/
              __Pyx_INCREF(__pyx_v_err);
              __Pyx_DECREF_SET(__pyx_v_first_error, __pyx_v_err);

              /* "pyproj/_crs.pyx":1572
 *                     )
 *                 except CRSError as err:
 *                     if first_error is None:             # <<<<<<<<<<<<<<
 *                         first_error = err
 *             raise first_error
*/
            }
          }

          /* "pyproj/_crs.pyx":1571
 *                         datum_type=datum_type,
 *                     )
 *                 except CRSError as err:             # <<<<<<<<<<<<<<
 *                     if first_error is None:
 *                         first_error = err
*/
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
              goto __pyx_L20;
            }
            __pyx_L20:;
          }
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L7_exception_handled;
        }
        goto __pyx_L8_except_error;

        /* "pyproj/_crs.pyx":1565
 *             first_error = None
 *             for datum_type in _PJ_DATUM_TYPE_MAP:
 *                 try:             # <<<<<<<<<<<<<<
 *                     return Datum.from_name(
 *                         datum_name=datum_name,
*/
        __pyx_L8_except_error:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L10_try_return:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L0;
        __pyx_L7_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":1574
 *                     if first_error is None:
 *                         first_error = err
 *             raise first_error             # <<<<<<<<<<<<<<
 * 
 *         datum_type = DatumType.create(datum_type)
*/
    __Pyx_Raise(__pyx_v_first_error, 0, 0, 0);
    __PYX_ERR(0, 1574, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1561
 *         Datum
 *         """
 *         if datum_type is None:             # <<<<<<<<<<<<<<
 *             # try creating name from all datum types
 *             first_error = None
*/
  }

  /* "pyproj/_crs.pyx":1576
 *             raise first_error
 * 
 *         datum_type = DatumType.create(datum_type)             # <<<<<<<<<<<<<<
 *         return Datum._from_name(
 *             datum_name=datum_name,
*/
  __pyx_t_6 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_DatumType); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_create); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_12 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
    assert(__pyx_t_6);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
    __pyx_t_12 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_datum_type};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_DECREF_SET(__pyx_v_datum_type, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1577
 * 
 *         datum_type = DatumType.create(datum_type)
 *         return Datum._from_name(             # <<<<<<<<<<<<<<
 *             datum_name=datum_name,
 *             auth_name=auth_name,
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_11 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
  __Pyx_INCREF(__pyx_t_11);

  /* "pyproj/_crs.pyx":1580
 *             datum_name=datum_name,
 *             auth_name=auth_name,
 *             datum_type=datum_type,             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_12 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 3 : 0)] = {__pyx_t_11, NULL};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_datum_name, __pyx_v_datum_name, __pyx_t_6, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 1577, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_auth_name, __pyx_v_auth_name, __pyx_t_6, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 1577, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_datum_type, __pyx_v_datum_type, __pyx_t_6, __pyx_callargs+1, 2) < (0)) __PYX_ERR(0, 1577, __pyx_L1_error)
    __pyx_t_2 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name_2, __pyx_callargs+__pyx_t_12, (1-__pyx_t_12) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1532
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str datum_name not None,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("pyproj._crs.Datum.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_first_error);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_datum_type);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1583
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict datum_dict not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_19from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_18from_json_dict, "Datum.from_json_dict(dict datum_dict)\n\n.. versionadded:: 2.4.0\n\nCreate Datum from a JSON dictionary.\n\nParameters\n----------\ndatum_dict: str\n    Datum dictionary.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_19from_json_dict = {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_19from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_18from_json_dict};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_19from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_datum_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_datum_dict,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1583, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1583, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json_dict", 0) < (0)) __PYX_ERR(0, 1583, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, i); __PYX_ERR(0, 1583, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1583, __pyx_L3_error)
    }
    __pyx_v_datum_dict = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1583, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_datum_dict), (&PyDict_Type), 0, "datum_dict", 1))) __PYX_ERR(0, 1584, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_18from_json_dict(__pyx_v_datum_dict);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_18from_json_dict(PyObject *__pyx_v_datum_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json_dict", 0);

  /* "pyproj/_crs.pyx":1599
 *         Datum
 *         """
 *         return Datum._from_string(json.dumps(datum_dict, cls=NumpyEncoder))             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NumpyEncoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_datum_dict};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cls, __pyx_t_5, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1583
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict datum_dict not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.Datum.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1601
 *         return Datum._from_string(json.dumps(datum_dict, cls=NumpyEncoder))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str datum_json_str not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_21from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_20from_json, "Datum.from_json(str datum_json_str)\n\n.. versionadded:: 2.4.0\n\nCreate Datum from a JSON string.\n\nParameters\n----------\ndatum_json_str: str\n    Datum JSON string.\n\nReturns\n-------\nDatum");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_21from_json = {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_21from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_20from_json};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_21from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_datum_json_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_datum_json_str,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1601, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1601, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json", 0) < (0)) __PYX_ERR(0, 1601, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, i); __PYX_ERR(0, 1601, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1601, __pyx_L3_error)
    }
    __pyx_v_datum_json_str = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1601, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_datum_json_str), (&PyUnicode_Type), 0, "datum_json_str", 1))) __PYX_ERR(0, 1602, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_20from_json(__pyx_v_datum_json_str);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_20from_json(PyObject *__pyx_v_datum_json_str) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json", 0);

  /* "pyproj/_crs.pyx":1617
 *         Datum
 *         """
 *         return Datum.from_json_dict(_load_proj_json(datum_json_str))             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_load_proj_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_datum_json_str};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1601
 *         return Datum._from_string(json.dumps(datum_dict, cls=NumpyEncoder))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str datum_json_str not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.Datum.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1619
 *         return Datum.from_json_dict(_load_proj_json(datum_json_str))
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ellipsoid(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_9ellipsoid_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_9ellipsoid_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_9ellipsoid___get__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_9ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_ellipsoid_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PJ_CONTEXT *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":1627
 *             The ellipsoid object with associated attributes.
 *         """
 *         if self._ellipsoid is not None:             # <<<<<<<<<<<<<<
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_1 = (__pyx_v_self->_ellipsoid != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":1628
 *         """
 *         if self._ellipsoid is not None:
 *             return None if self._ellipsoid is False else self._ellipsoid             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = proj_get_ellipsoid(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (__pyx_v_self->_ellipsoid == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF(__pyx_v_self->_ellipsoid);
      __pyx_t_2 = __pyx_v_self->_ellipsoid;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":1627
 *             The ellipsoid object with associated attributes.
 *         """
 *         if self._ellipsoid is not None:             # <<<<<<<<<<<<<<
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  }

  /* "pyproj/_crs.pyx":1629
 *         if self._ellipsoid is not None:
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* ellipsoid_pj = proj_get_ellipsoid(
 *             context,
*/
  __pyx_t_3 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1629, __pyx_L1_error)
  __pyx_v_context = __pyx_t_3;

  /* "pyproj/_crs.pyx":1630
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = proj_get_ellipsoid(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj,
*/
  __pyx_v_ellipsoid_pj = proj_get_ellipsoid(__pyx_v_context, __pyx_v_self->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":1634
 *             self.projobj,
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if ellipsoid_pj == NULL:
 *             self._ellipsoid = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1635
 *         )
 *         _clear_proj_error()
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._ellipsoid = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_ellipsoid_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":1636
 *         _clear_proj_error()
 *         if ellipsoid_pj == NULL:
 *             self._ellipsoid = False             # <<<<<<<<<<<<<<
 *             return None
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF(__pyx_v_self->_ellipsoid);
    __Pyx_DECREF(__pyx_v_self->_ellipsoid);
    __pyx_v_self->_ellipsoid = Py_False;

    /* "pyproj/_crs.pyx":1637
 *         if ellipsoid_pj == NULL:
 *             self._ellipsoid = False
 *             return None             # <<<<<<<<<<<<<<
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)
 *         return self._ellipsoid
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":1635
 *         )
 *         _clear_proj_error()
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._ellipsoid = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":1638
 *             self._ellipsoid = False
 *             return None
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)             # <<<<<<<<<<<<<<
 *         return self._ellipsoid
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_9Ellipsoid_create(__pyx_v_context, __pyx_v_ellipsoid_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_ellipsoid);
  __Pyx_DECREF(__pyx_v_self->_ellipsoid);
  __pyx_v_self->_ellipsoid = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1639
 *             return None
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)
 *         return self._ellipsoid             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_ellipsoid);
  __pyx_r = __pyx_v_self->_ellipsoid;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1619
 *         return Datum.from_json_dict(_load_proj_json(datum_json_str))
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ellipsoid(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Datum.ellipsoid.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1641
 *         return self._ellipsoid
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def prime_meridian(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_14prime_meridian_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_14prime_meridian_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_14prime_meridian___get__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_14prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_prime_meridian_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PJ_CONTEXT *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":1649
 *             The CRS prime meridian object with associated attributes.
 *         """
 *         if self._prime_meridian is not None:             # <<<<<<<<<<<<<<
 *             return None if self._prime_meridian is False else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_1 = (__pyx_v_self->_prime_meridian != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":1650
 *         """
 *         if self._prime_meridian is not None:
 *             return None if self._prime_meridian is False else self._prime_meridian             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = proj_get_prime_meridian(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (__pyx_v_self->_prime_meridian == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF(__pyx_v_self->_prime_meridian);
      __pyx_t_2 = __pyx_v_self->_prime_meridian;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":1649
 *             The CRS prime meridian object with associated attributes.
 *         """
 *         if self._prime_meridian is not None:             # <<<<<<<<<<<<<<
 *             return None if self._prime_meridian is False else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  }

  /* "pyproj/_crs.pyx":1651
 *         if self._prime_meridian is not None:
 *             return None if self._prime_meridian is False else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* prime_meridian_pj = proj_get_prime_meridian(
 *             context,
*/
  __pyx_t_3 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1651, __pyx_L1_error)
  __pyx_v_context = __pyx_t_3;

  /* "pyproj/_crs.pyx":1652
 *             return None if self._prime_meridian is False else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = proj_get_prime_meridian(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj,
*/
  __pyx_v_prime_meridian_pj = proj_get_prime_meridian(__pyx_v_context, __pyx_v_self->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":1656
 *             self.projobj,
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if prime_meridian_pj == NULL:
 *             self._prime_meridian = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1657
 *         )
 *         _clear_proj_error()
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._prime_meridian = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_prime_meridian_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":1658
 *         _clear_proj_error()
 *         if prime_meridian_pj == NULL:
 *             self._prime_meridian = False             # <<<<<<<<<<<<<<
 *             return None
 *         self._prime_meridian = PrimeMeridian.create(
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF(__pyx_v_self->_prime_meridian);
    __Pyx_DECREF(__pyx_v_self->_prime_meridian);
    __pyx_v_self->_prime_meridian = Py_False;

    /* "pyproj/_crs.pyx":1659
 *         if prime_meridian_pj == NULL:
 *             self._prime_meridian = False
 *             return None             # <<<<<<<<<<<<<<
 *         self._prime_meridian = PrimeMeridian.create(
 *             context,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":1657
 *         )
 *         _clear_proj_error()
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._prime_meridian = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":1660
 *             self._prime_meridian = False
 *             return None
 *         self._prime_meridian = PrimeMeridian.create(             # <<<<<<<<<<<<<<
 *             context,
 *             prime_meridian_pj,
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(__pyx_v_context, __pyx_v_prime_meridian_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_prime_meridian);
  __Pyx_DECREF(__pyx_v_self->_prime_meridian);
  __pyx_v_self->_prime_meridian = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1664
 *             prime_meridian_pj,
 *         )
 *         return self._prime_meridian             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_prime_meridian);
  __pyx_r = __pyx_v_self->_prime_meridian;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1641
 *         return self._ellipsoid
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def prime_meridian(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Datum.prime_meridian.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":80
 * 
 * cdef class Datum(_CRSParts):
 *     cdef readonly str type_name             # <<<<<<<<<<<<<<
 *     cdef readonly object _ellipsoid
 *     cdef readonly object _prime_meridian
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_9type_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_9type_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_9type_name___get__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_9type_name___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->type_name);
  __pyx_r = __pyx_v_self->type_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":81
 * cdef class Datum(_CRSParts):
 *     cdef readonly str type_name
 *     cdef readonly object _ellipsoid             # <<<<<<<<<<<<<<
 *     cdef readonly object _prime_meridian
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_10_ellipsoid_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_10_ellipsoid_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_10_ellipsoid___get__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_10_ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_ellipsoid);
  __pyx_r = __pyx_v_self->_ellipsoid;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":82
 *     cdef readonly str type_name
 *     cdef readonly object _ellipsoid
 *     cdef readonly object _prime_meridian             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_15_prime_meridian_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_15_prime_meridian_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_15_prime_meridian___get__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_15_prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_prime_meridian);
  __pyx_r = __pyx_v_self->_prime_meridian;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_23__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_22__reduce_cython__, "Datum.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_23__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_23__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_22__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_23__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_22__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Datum.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_25__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Datum_24__setstate_cython__, "Datum.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Datum_25__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_25__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_24__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_5Datum_25__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Datum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Datum_24__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Datum_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Datum *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Datum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1696
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.name = "undefined"
 *         self.auth_name = "undefined"
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_5Param_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_5Param_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param___cinit__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_5Param___cinit__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":1697
 *     """
 *     def __cinit__(self):
 *         self.name = "undefined"             # <<<<<<<<<<<<<<
 *         self.auth_name = "undefined"
 *         self.code = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1698
 *     def __cinit__(self):
 *         self.name = "undefined"
 *         self.auth_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.code = "undefined"
 *         self.value = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->auth_name);
  __Pyx_DECREF(__pyx_v_self->auth_name);
  __pyx_v_self->auth_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1699
 *         self.name = "undefined"
 *         self.auth_name = "undefined"
 *         self.code = "undefined"             # <<<<<<<<<<<<<<
 *         self.value = "undefined"
 *         self.unit_conversion_factor = float("nan")
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->code);
  __Pyx_DECREF(__pyx_v_self->code);
  __pyx_v_self->code = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1700
 *         self.auth_name = "undefined"
 *         self.code = "undefined"
 *         self.value = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_conversion_factor = float("nan")
 *         self.unit_name = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->value);
  __Pyx_DECREF(__pyx_v_self->value);
  __pyx_v_self->value = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1701
 *         self.code = "undefined"
 *         self.value = "undefined"
 *         self.unit_conversion_factor = float("nan")             # <<<<<<<<<<<<<<
 *         self.unit_name = "undefined"
 *         self.unit_auth_name = "undefined"
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_nan); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 1701, __pyx_L1_error)
  __pyx_v_self->unit_conversion_factor = __pyx_t_1;

  /* "pyproj/_crs.pyx":1702
 *         self.value = "undefined"
 *         self.unit_conversion_factor = float("nan")
 *         self.unit_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_auth_name = "undefined"
 *         self.unit_code = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_name);
  __Pyx_DECREF(__pyx_v_self->unit_name);
  __pyx_v_self->unit_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1703
 *         self.unit_conversion_factor = float("nan")
 *         self.unit_name = "undefined"
 *         self.unit_auth_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_code = "undefined"
 *         self.unit_category = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_auth_name);
  __Pyx_DECREF(__pyx_v_self->unit_auth_name);
  __pyx_v_self->unit_auth_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1704
 *         self.unit_name = "undefined"
 *         self.unit_auth_name = "undefined"
 *         self.unit_code = "undefined"             # <<<<<<<<<<<<<<
 *         self.unit_category = "undefined"
 * 
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_code);
  __Pyx_DECREF(__pyx_v_self->unit_code);
  __pyx_v_self->unit_code = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1705
 *         self.unit_auth_name = "undefined"
 *         self.unit_code = "undefined"
 *         self.unit_category = "undefined"             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->unit_category);
  __Pyx_DECREF(__pyx_v_self->unit_category);
  __pyx_v_self->unit_category = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1696
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.name = "undefined"
 *         self.auth_name = "undefined"
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Param.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1707
 *         self.unit_category = "undefined"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Param create(PJ_CONTEXT* context, PJ* projobj, int param_idx):
 *         cdef:
*/

static struct __pyx_obj_6pyproj_4_crs_Param *__pyx_f_6pyproj_4_crs_5Param_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, int __pyx_v_param_idx) {
  struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_param = 0;
  char const *__pyx_v_out_name;
  char const *__pyx_v_out_auth_name;
  char const *__pyx_v_out_code;
  char const *__pyx_v_out_value_string;
  char const *__pyx_v_out_unit_name;
  char const *__pyx_v_out_unit_auth_name;
  char const *__pyx_v_out_unit_code;
  char const *__pyx_v_out_unit_category;
  double __pyx_v_value_double;
  PyObject *__pyx_v_value_string = NULL;
  struct __pyx_obj_6pyproj_4_crs_Param *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":1710
 *     cdef Param create(PJ_CONTEXT* context, PJ* projobj, int param_idx):
 *         cdef:
 *             Param param = Param()             # <<<<<<<<<<<<<<
 *             const char *out_name
 *             const char *out_auth_name
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Param, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1710, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_param = ((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1722
 *             double value_double
 * 
 *         proj_coordoperation_get_param(             # <<<<<<<<<<<<<<
 *             context,
 *             projobj,
*/
  (void)(proj_coordoperation_get_param(__pyx_v_context, __pyx_v_projobj, __pyx_v_param_idx, (&__pyx_v_out_name), (&__pyx_v_out_auth_name), (&__pyx_v_out_code), (&__pyx_v_value_double), (&__pyx_v_out_value_string), (&__pyx_v_param->unit_conversion_factor), (&__pyx_v_out_unit_name), (&__pyx_v_out_unit_auth_name), (&__pyx_v_out_unit_code), (&__pyx_v_out_unit_category)));

  /* "pyproj/_crs.pyx":1737
 *             &out_unit_category
 *         )
 *         param.name = decode_or_undefined(out_name)             # <<<<<<<<<<<<<<
 *         param.auth_name = decode_or_undefined(out_auth_name)
 *         param.code = decode_or_undefined(out_code)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->name);
  __Pyx_DECREF(__pyx_v_param->name);
  __pyx_v_param->name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1738
 *         )
 *         param.name = decode_or_undefined(out_name)
 *         param.auth_name = decode_or_undefined(out_auth_name)             # <<<<<<<<<<<<<<
 *         param.code = decode_or_undefined(out_code)
 *         param.unit_name = decode_or_undefined(out_unit_name)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_auth_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->auth_name);
  __Pyx_DECREF(__pyx_v_param->auth_name);
  __pyx_v_param->auth_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1739
 *         param.name = decode_or_undefined(out_name)
 *         param.auth_name = decode_or_undefined(out_auth_name)
 *         param.code = decode_or_undefined(out_code)             # <<<<<<<<<<<<<<
 *         param.unit_name = decode_or_undefined(out_unit_name)
 *         param.unit_auth_name = decode_or_undefined(out_unit_auth_name)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->code);
  __Pyx_DECREF(__pyx_v_param->code);
  __pyx_v_param->code = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1740
 *         param.auth_name = decode_or_undefined(out_auth_name)
 *         param.code = decode_or_undefined(out_code)
 *         param.unit_name = decode_or_undefined(out_unit_name)             # <<<<<<<<<<<<<<
 *         param.unit_auth_name = decode_or_undefined(out_unit_auth_name)
 *         param.unit_code = decode_or_undefined(out_unit_code)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_unit_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->unit_name);
  __Pyx_DECREF(__pyx_v_param->unit_name);
  __pyx_v_param->unit_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1741
 *         param.code = decode_or_undefined(out_code)
 *         param.unit_name = decode_or_undefined(out_unit_name)
 *         param.unit_auth_name = decode_or_undefined(out_unit_auth_name)             # <<<<<<<<<<<<<<
 *         param.unit_code = decode_or_undefined(out_unit_code)
 *         param.unit_category = decode_or_undefined(out_unit_category)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_unit_auth_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->unit_auth_name);
  __Pyx_DECREF(__pyx_v_param->unit_auth_name);
  __pyx_v_param->unit_auth_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1742
 *         param.unit_name = decode_or_undefined(out_unit_name)
 *         param.unit_auth_name = decode_or_undefined(out_unit_auth_name)
 *         param.unit_code = decode_or_undefined(out_unit_code)             # <<<<<<<<<<<<<<
 *         param.unit_category = decode_or_undefined(out_unit_category)
 *         value_string = cstrdecode(out_value_string)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_unit_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->unit_code);
  __Pyx_DECREF(__pyx_v_param->unit_code);
  __pyx_v_param->unit_code = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1743
 *         param.unit_auth_name = decode_or_undefined(out_unit_auth_name)
 *         param.unit_code = decode_or_undefined(out_unit_code)
 *         param.unit_category = decode_or_undefined(out_unit_category)             # <<<<<<<<<<<<<<
 *         value_string = cstrdecode(out_value_string)
 *         param.value = value_double if value_string is None else value_string
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_unit_category); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->unit_category);
  __Pyx_DECREF(__pyx_v_param->unit_category);
  __pyx_v_param->unit_category = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1744
 *         param.unit_code = decode_or_undefined(out_unit_code)
 *         param.unit_category = decode_or_undefined(out_unit_category)
 *         value_string = cstrdecode(out_value_string)             # <<<<<<<<<<<<<<
 *         param.value = value_double if value_string is None else value_string
 *         return param
*/
  __pyx_t_1 = __pyx_f_6pyproj_7_compat_cstrdecode(__pyx_v_out_value_string); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_value_string = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1745
 *         param.unit_category = decode_or_undefined(out_unit_category)
 *         value_string = cstrdecode(out_value_string)
 *         param.value = value_double if value_string is None else value_string             # <<<<<<<<<<<<<<
 *         return param
 * 
*/
  __pyx_t_4 = (__pyx_v_value_string == ((PyObject*)Py_None));
  if (__pyx_t_4) {
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_value_double); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_value_string);
    __pyx_t_1 = __pyx_v_value_string;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_param->value);
  __Pyx_DECREF(__pyx_v_param->value);
  __pyx_v_param->value = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1746
 *         value_string = cstrdecode(out_value_string)
 *         param.value = value_double if value_string is None else value_string
 *         return param             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_param);
  __pyx_r = __pyx_v_param;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1707
 *         self.unit_category = "undefined"
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Param create(PJ_CONTEXT* context, PJ* projobj, int param_idx):
 *         cdef:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Param.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_param);
  __Pyx_XDECREF(__pyx_v_value_string);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1748
 *         return param
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return f"{self.auth_name}:{self.auth_code}"
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_3__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_3__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_2__str__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_2__str__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4[3];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "pyproj/_crs.pyx":1749
 * 
 *     def __str__(self):
 *         return f"{self.auth_name}:{self.auth_code}"             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->auth_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_auth_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4[0] = __pyx_t_1;
  __pyx_t_4[1] = __pyx_mstate_global->__pyx_kp_u__9;
  __pyx_t_4[2] = __pyx_t_3;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_4, 3, __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 1 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3));
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1748
 *         return param
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return f"{self.auth_name}:{self.auth_code}"
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.Param.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1751
 *         return f"{self.auth_name}:{self.auth_code}"
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_5__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_4__repr__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_4__repr__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[17];
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyproj/_crs.pyx":1752
 * 
 *     def __repr__(self):
 *         return (             # <<<<<<<<<<<<<<
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "
 *             f"value={self.value}, unit_name={self.unit_name}, "
*/
  __Pyx_XDECREF(__pyx_r);

  /* "pyproj/_crs.pyx":1753
 *     def __repr__(self):
 *         return (
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "             # <<<<<<<<<<<<<<
 *             f"value={self.value}, unit_name={self.unit_name}, "
 *             f"unit_auth_name={self.unit_auth_name}, unit_code={self.unit_code}, "
*/
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_self->auth_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_self->code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pyproj/_crs.pyx":1754
 *         return (
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "
 *             f"value={self.value}, unit_name={self.unit_name}, "             # <<<<<<<<<<<<<<
 *             f"unit_auth_name={self.unit_auth_name}, unit_code={self.unit_code}, "
 *             f"unit_category={self.unit_category})"
*/
  __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_self->value, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pyproj/_crs.pyx":1755
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "
 *             f"value={self.value}, unit_name={self.unit_name}, "
 *             f"unit_auth_name={self.unit_auth_name}, unit_code={self.unit_code}, "             # <<<<<<<<<<<<<<
 *             f"unit_category={self.unit_category})"
 *         )
*/
  __pyx_t_6 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_auth_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_code); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "pyproj/_crs.pyx":1756
 *             f"value={self.value}, unit_name={self.unit_name}, "
 *             f"unit_auth_name={self.unit_auth_name}, unit_code={self.unit_code}, "
 *             f"unit_category={self.unit_category})"             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_v_self->unit_category); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1756, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Param_name;
  __pyx_t_9[1] = __pyx_t_1;
  __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_auth_name_2;
  __pyx_t_9[3] = __pyx_t_2;
  __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u_code_2;
  __pyx_t_9[5] = __pyx_t_3;
  __pyx_t_9[6] = __pyx_mstate_global->__pyx_kp_u_value;
  __pyx_t_9[7] = __pyx_t_4;
  __pyx_t_9[8] = __pyx_mstate_global->__pyx_kp_u_unit_name;
  __pyx_t_9[9] = __pyx_t_5;
  __pyx_t_9[10] = __pyx_mstate_global->__pyx_kp_u_unit_auth_name;
  __pyx_t_9[11] = __pyx_t_6;
  __pyx_t_9[12] = __pyx_mstate_global->__pyx_kp_u_unit_code;
  __pyx_t_9[13] = __pyx_t_7;
  __pyx_t_9[14] = __pyx_mstate_global->__pyx_kp_u_unit_category;
  __pyx_t_9[15] = __pyx_t_8;
  __pyx_t_9[16] = __pyx_mstate_global->__pyx_kp_u__5;

  /* "pyproj/_crs.pyx":1753
 *     def __repr__(self):
 *         return (
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "             # <<<<<<<<<<<<<<
 *             f"value={self.value}, unit_name={self.unit_name}, "
 *             f"unit_auth_name={self.unit_auth_name}, unit_code={self.unit_code}, "
*/
  __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 17, 11 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 12 * 3 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 7 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 16 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1751
 *         return f"{self.auth_name}:{self.auth_code}"
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"Param(name={self.name}, auth_name={self.auth_name}, code={self.code}, "
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyproj._crs.Param.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":96
 * 
 * cdef class Param:
 *     cdef readonly str name             # <<<<<<<<<<<<<<
 *     cdef readonly str auth_name
 *     cdef readonly str code
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_4name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_4name___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_4name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":97
 * cdef class Param:
 *     cdef readonly str name
 *     cdef readonly str auth_name             # <<<<<<<<<<<<<<
 *     cdef readonly str code
 *     cdef readonly object value
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9auth_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9auth_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_9auth_name___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_9auth_name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->auth_name);
  __pyx_r = __pyx_v_self->auth_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":98
 *     cdef readonly str name
 *     cdef readonly str auth_name
 *     cdef readonly str code             # <<<<<<<<<<<<<<
 *     cdef readonly object value
 *     cdef readonly double unit_conversion_factor
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_4code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_4code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_4code___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_4code___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->code);
  __pyx_r = __pyx_v_self->code;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":99
 *     cdef readonly str auth_name
 *     cdef readonly str code
 *     cdef readonly object value             # <<<<<<<<<<<<<<
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_5value_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_5value_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_5value___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_5value___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->value);
  __pyx_r = __pyx_v_self->value;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":100
 *     cdef readonly str code
 *     cdef readonly object value
 *     cdef readonly double unit_conversion_factor             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_name
 *     cdef readonly str unit_auth_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_22unit_conversion_factor_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_22unit_conversion_factor_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_22unit_conversion_factor___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_22unit_conversion_factor___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->unit_conversion_factor); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Param.unit_conversion_factor.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":101
 *     cdef readonly object value
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_auth_name
 *     cdef readonly str unit_code
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9unit_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9unit_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_9unit_name___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_9unit_name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_name);
  __pyx_r = __pyx_v_self->unit_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":102
 *     cdef readonly double unit_conversion_factor
 *     cdef readonly str unit_name
 *     cdef readonly str unit_auth_name             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_code
 *     cdef readonly str unit_category
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_14unit_auth_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_14unit_auth_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_14unit_auth_name___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_14unit_auth_name___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_auth_name);
  __pyx_r = __pyx_v_self->unit_auth_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":103
 *     cdef readonly str unit_name
 *     cdef readonly str unit_auth_name
 *     cdef readonly str unit_code             # <<<<<<<<<<<<<<
 *     cdef readonly str unit_category
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9unit_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9unit_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_9unit_code___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_9unit_code___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_code);
  __pyx_r = __pyx_v_self->unit_code;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":104
 *     cdef readonly str unit_auth_name
 *     cdef readonly str unit_code
 *     cdef readonly str unit_category             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_13unit_category_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_13unit_category_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_13unit_category___get__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_13unit_category___get__(struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->unit_category);
  __pyx_r = __pyx_v_self->unit_category;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Param_6__reduce_cython__, "Param.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Param_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Param_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Param_6__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_6__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Param.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_5Param_8__setstate_cython__, "Param.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_5Param_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Param_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Param_8__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_5Param_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Param.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_5Param_8__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_Param *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_5Param_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Param *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Param.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1784
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.short_name = "undefined"
 *         self.full_name = "undefined"
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_4Grid_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_4Grid_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid___cinit__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_4Grid___cinit__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":1785
 *     """
 *     def __cinit__(self):
 *         self.short_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.full_name = "undefined"
 *         self.package_name = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->short_name);
  __Pyx_DECREF(__pyx_v_self->short_name);
  __pyx_v_self->short_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1786
 *     def __cinit__(self):
 *         self.short_name = "undefined"
 *         self.full_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.package_name = "undefined"
 *         self.url = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->full_name);
  __Pyx_DECREF(__pyx_v_self->full_name);
  __pyx_v_self->full_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1787
 *         self.short_name = "undefined"
 *         self.full_name = "undefined"
 *         self.package_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.url = "undefined"
 *         self.direct_download = False
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->package_name);
  __Pyx_DECREF(__pyx_v_self->package_name);
  __pyx_v_self->package_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1788
 *         self.full_name = "undefined"
 *         self.package_name = "undefined"
 *         self.url = "undefined"             # <<<<<<<<<<<<<<
 *         self.direct_download = False
 *         self.open_license = False
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->url);
  __Pyx_DECREF(__pyx_v_self->url);
  __pyx_v_self->url = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1789
 *         self.package_name = "undefined"
 *         self.url = "undefined"
 *         self.direct_download = False             # <<<<<<<<<<<<<<
 *         self.open_license = False
 *         self.available = False
*/
  __pyx_v_self->direct_download = 0;

  /* "pyproj/_crs.pyx":1790
 *         self.url = "undefined"
 *         self.direct_download = False
 *         self.open_license = False             # <<<<<<<<<<<<<<
 *         self.available = False
 * 
*/
  __pyx_v_self->open_license = 0;

  /* "pyproj/_crs.pyx":1791
 *         self.direct_download = False
 *         self.open_license = False
 *         self.available = False             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __pyx_v_self->available = 0;

  /* "pyproj/_crs.pyx":1784
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.short_name = "undefined"
 *         self.full_name = "undefined"
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1793
 *         self.available = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Grid create(PJ_CONTEXT* context, PJ* projobj, int grid_idx):
 *         cdef:
*/

static struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_f_6pyproj_4_crs_4Grid_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_projobj, int __pyx_v_grid_idx) {
  struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_grid = 0;
  char const *__pyx_v_out_short_name;
  char const *__pyx_v_out_full_name;
  char const *__pyx_v_out_package_name;
  char const *__pyx_v_out_url;
  int __pyx_v_direct_download;
  int __pyx_v_open_license;
  int __pyx_v_available;
  struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":1796
 *     cdef Grid create(PJ_CONTEXT* context, PJ* projobj, int grid_idx):
 *         cdef:
 *             Grid grid = Grid()             # <<<<<<<<<<<<<<
 *             const char *out_short_name
 *             const char *out_full_name
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Grid, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_grid = ((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1801
 *             const char *out_package_name
 *             const char *out_url
 *             int direct_download = 0             # <<<<<<<<<<<<<<
 *             int open_license = 0
 *             int available = 0
*/
  __pyx_v_direct_download = 0;

  /* "pyproj/_crs.pyx":1802
 *             const char *out_url
 *             int direct_download = 0
 *             int open_license = 0             # <<<<<<<<<<<<<<
 *             int available = 0
 * 
*/
  __pyx_v_open_license = 0;

  /* "pyproj/_crs.pyx":1803
 *             int direct_download = 0
 *             int open_license = 0
 *             int available = 0             # <<<<<<<<<<<<<<
 * 
 *         proj_coordoperation_get_grid_used(
*/
  __pyx_v_available = 0;

  /* "pyproj/_crs.pyx":1805
 *             int available = 0
 * 
 *         proj_coordoperation_get_grid_used(             # <<<<<<<<<<<<<<
 *             context,
 *             projobj,
*/
  (void)(proj_coordoperation_get_grid_used(__pyx_v_context, __pyx_v_projobj, __pyx_v_grid_idx, (&__pyx_v_out_short_name), (&__pyx_v_out_full_name), (&__pyx_v_out_package_name), (&__pyx_v_out_url), (&__pyx_v_direct_download), (&__pyx_v_open_license), (&__pyx_v_available)));

  /* "pyproj/_crs.pyx":1817
 *             &available
 *         )
 *         grid.short_name = decode_or_undefined(out_short_name)             # <<<<<<<<<<<<<<
 *         grid.full_name = decode_or_undefined(out_full_name)
 *         grid.package_name = decode_or_undefined(out_package_name)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_short_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_grid->short_name);
  __Pyx_DECREF(__pyx_v_grid->short_name);
  __pyx_v_grid->short_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1818
 *         )
 *         grid.short_name = decode_or_undefined(out_short_name)
 *         grid.full_name = decode_or_undefined(out_full_name)             # <<<<<<<<<<<<<<
 *         grid.package_name = decode_or_undefined(out_package_name)
 *         grid.url = decode_or_undefined(out_url)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_full_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_grid->full_name);
  __Pyx_DECREF(__pyx_v_grid->full_name);
  __pyx_v_grid->full_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1819
 *         grid.short_name = decode_or_undefined(out_short_name)
 *         grid.full_name = decode_or_undefined(out_full_name)
 *         grid.package_name = decode_or_undefined(out_package_name)             # <<<<<<<<<<<<<<
 *         grid.url = decode_or_undefined(out_url)
 *         grid.direct_download = direct_download == 1
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_package_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_grid->package_name);
  __Pyx_DECREF(__pyx_v_grid->package_name);
  __pyx_v_grid->package_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1820
 *         grid.full_name = decode_or_undefined(out_full_name)
 *         grid.package_name = decode_or_undefined(out_package_name)
 *         grid.url = decode_or_undefined(out_url)             # <<<<<<<<<<<<<<
 *         grid.direct_download = direct_download == 1
 *         grid.open_license = open_license == 1
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_url); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_grid->url);
  __Pyx_DECREF(__pyx_v_grid->url);
  __pyx_v_grid->url = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1821
 *         grid.package_name = decode_or_undefined(out_package_name)
 *         grid.url = decode_or_undefined(out_url)
 *         grid.direct_download = direct_download == 1             # <<<<<<<<<<<<<<
 *         grid.open_license = open_license == 1
 *         grid.available = available == 1
*/
  __pyx_v_grid->direct_download = (__pyx_v_direct_download == 1);

  /* "pyproj/_crs.pyx":1822
 *         grid.url = decode_or_undefined(out_url)
 *         grid.direct_download = direct_download == 1
 *         grid.open_license = open_license == 1             # <<<<<<<<<<<<<<
 *         grid.available = available == 1
 *         _clear_proj_error()
*/
  __pyx_v_grid->open_license = (__pyx_v_open_license == 1);

  /* "pyproj/_crs.pyx":1823
 *         grid.direct_download = direct_download == 1
 *         grid.open_license = open_license == 1
 *         grid.available = available == 1             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return grid
*/
  __pyx_v_grid->available = (__pyx_v_available == 1);

  /* "pyproj/_crs.pyx":1824
 *         grid.open_license = open_license == 1
 *         grid.available = available == 1
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return grid
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1825
 *         grid.available = available == 1
 *         _clear_proj_error()
 *         return grid             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_grid);
  __pyx_r = __pyx_v_grid;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1793
 *         self.available = False
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef Grid create(PJ_CONTEXT* context, PJ* projobj, int grid_idx):
 *         cdef:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.Grid.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_grid);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1827
 *         return grid
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.full_name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_3__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_3__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_2__str__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_2__str__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__", 0);

  /* "pyproj/_crs.pyx":1828
 * 
 *     def __str__(self):
 *         return self.full_name             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->full_name);
  __pyx_r = __pyx_v_self->full_name;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1827
 *         return grid
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return self.full_name
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1830
 *         return self.full_name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_5__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_4__repr__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_4__repr__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8[15];
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyproj/_crs.pyx":1831
 * 
 *     def __repr__(self):
 *         return (             # <<<<<<<<<<<<<<
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "
 *             f"package_name={self.package_name}, url={self.url}, "
*/
  __Pyx_XDECREF(__pyx_r);

  /* "pyproj/_crs.pyx":1832
 *     def __repr__(self):
 *         return (
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "             # <<<<<<<<<<<<<<
 *             f"package_name={self.package_name}, url={self.url}, "
 *             f"direct_download={self.direct_download}, "
*/
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->short_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_self->full_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":1833
 *         return (
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "
 *             f"package_name={self.package_name}, url={self.url}, "             # <<<<<<<<<<<<<<
 *             f"direct_download={self.direct_download}, "
 *             f"open_license={self.open_license}, available={self.available})"
*/
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_self->package_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyUnicode_Unicode(__pyx_v_self->url); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pyproj/_crs.pyx":1834
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "
 *             f"package_name={self.package_name}, url={self.url}, "
 *             f"direct_download={self.direct_download}, "             # <<<<<<<<<<<<<<
 *             f"open_license={self.open_license}, available={self.available})"
 *         )
*/
  __pyx_t_5 = __Pyx_PyUnicode_FromBInt_bint(__pyx_v_self->direct_download); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pyproj/_crs.pyx":1835
 *             f"package_name={self.package_name}, url={self.url}, "
 *             f"direct_download={self.direct_download}, "
 *             f"open_license={self.open_license}, available={self.available})"             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_6 = __Pyx_PyUnicode_FromBInt_bint(__pyx_v_self->open_license); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyUnicode_FromBInt_bint(__pyx_v_self->available); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_Grid_short_name;
  __pyx_t_8[1] = __pyx_t_1;
  __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u_full_name;
  __pyx_t_8[3] = __pyx_t_2;
  __pyx_t_8[4] = __pyx_mstate_global->__pyx_kp_u_package_name;
  __pyx_t_8[5] = __pyx_t_3;
  __pyx_t_8[6] = __pyx_mstate_global->__pyx_kp_u_url;
  __pyx_t_8[7] = __pyx_t_4;
  __pyx_t_8[8] = __pyx_mstate_global->__pyx_kp_u_direct_download;
  __pyx_t_8[9] = __pyx_t_5;
  __pyx_t_8[10] = __pyx_mstate_global->__pyx_kp_u_open_license;
  __pyx_t_8[11] = __pyx_t_6;
  __pyx_t_8[12] = __pyx_mstate_global->__pyx_kp_u_available;
  __pyx_t_8[13] = __pyx_t_7;
  __pyx_t_8[14] = __pyx_mstate_global->__pyx_kp_u__5;

  /* "pyproj/_crs.pyx":1832
 *     def __repr__(self):
 *         return (
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "             # <<<<<<<<<<<<<<
 *             f"package_name={self.package_name}, url={self.url}, "
 *             f"direct_download={self.direct_download}, "
*/
  __pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_8, 15, 16 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 12 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 15 * 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 18 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4));
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1830
 *         return self.full_name
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"Grid(short_name={self.short_name}, full_name={self.full_name}, "
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyproj._crs.Grid.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":111
 * 
 * cdef class Grid:
 *     cdef readonly str short_name             # <<<<<<<<<<<<<<
 *     cdef readonly str full_name
 *     cdef readonly str package_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_10short_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_10short_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_10short_name___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_10short_name___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->short_name);
  __pyx_r = __pyx_v_self->short_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":112
 * cdef class Grid:
 *     cdef readonly str short_name
 *     cdef readonly str full_name             # <<<<<<<<<<<<<<
 *     cdef readonly str package_name
 *     cdef readonly str url
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_9full_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_9full_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_9full_name___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_9full_name___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->full_name);
  __pyx_r = __pyx_v_self->full_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":113
 *     cdef readonly str short_name
 *     cdef readonly str full_name
 *     cdef readonly str package_name             # <<<<<<<<<<<<<<
 *     cdef readonly str url
 *     cdef readonly bint direct_download
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_12package_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_12package_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_12package_name___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_12package_name___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->package_name);
  __pyx_r = __pyx_v_self->package_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":114
 *     cdef readonly str full_name
 *     cdef readonly str package_name
 *     cdef readonly str url             # <<<<<<<<<<<<<<
 *     cdef readonly bint direct_download
 *     cdef readonly bint open_license
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_3url_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_3url_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_3url___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_3url___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->url);
  __pyx_r = __pyx_v_self->url;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":115
 *     cdef readonly str package_name
 *     cdef readonly str url
 *     cdef readonly bint direct_download             # <<<<<<<<<<<<<<
 *     cdef readonly bint open_license
 *     cdef readonly bint available
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_15direct_download_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_15direct_download_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_15direct_download___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_15direct_download___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->direct_download); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Grid.direct_download.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":116
 *     cdef readonly str url
 *     cdef readonly bint direct_download
 *     cdef readonly bint open_license             # <<<<<<<<<<<<<<
 *     cdef readonly bint available
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_12open_license_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_12open_license_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_12open_license___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_12open_license___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->open_license); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Grid.open_license.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":117
 *     cdef readonly bint direct_download
 *     cdef readonly bint open_license
 *     cdef readonly bint available             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_9available_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_9available_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_9available___get__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_9available___get__(struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->available); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.Grid.available.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Grid_6__reduce_cython__, "Grid.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Grid_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Grid_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Grid_6__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_6__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Grid.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4Grid_8__setstate_cython__, "Grid.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4Grid_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Grid_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Grid_8__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4Grid_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.Grid.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4Grid_8__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_Grid *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4Grid_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_Grid *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.Grid.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1881
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._params = None
 *         self._grids = None
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_19CoordinateOperation_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_19CoordinateOperation_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation___cinit__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_19CoordinateOperation___cinit__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":1882
 *     """
 *     def __cinit__(self):
 *         self._params = None             # <<<<<<<<<<<<<<
 *         self._grids = None
 *         self._area_of_use = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_params);
  __Pyx_DECREF(__pyx_v_self->_params);
  __pyx_v_self->_params = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":1883
 *     def __cinit__(self):
 *         self._params = None
 *         self._grids = None             # <<<<<<<<<<<<<<
 *         self._area_of_use = None
 *         self.method_name = "undefined"
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_grids);
  __Pyx_DECREF(__pyx_v_self->_grids);
  __pyx_v_self->_grids = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":1884
 *         self._params = None
 *         self._grids = None
 *         self._area_of_use = None             # <<<<<<<<<<<<<<
 *         self.method_name = "undefined"
 *         self.method_auth_name = "undefined"
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_area_of_use);
  __Pyx_DECREF(__pyx_v_self->_area_of_use);
  __pyx_v_self->_area_of_use = Py_None;

  /* "pyproj/_crs.pyx":1885
 *         self._grids = None
 *         self._area_of_use = None
 *         self.method_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.method_auth_name = "undefined"
 *         self.method_code = "undefined"
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->method_name);
  __Pyx_DECREF(__pyx_v_self->method_name);
  __pyx_v_self->method_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1886
 *         self._area_of_use = None
 *         self.method_name = "undefined"
 *         self.method_auth_name = "undefined"             # <<<<<<<<<<<<<<
 *         self.method_code = "undefined"
 *         self.is_instantiable = False
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->method_auth_name);
  __Pyx_DECREF(__pyx_v_self->method_auth_name);
  __pyx_v_self->method_auth_name = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1887
 *         self.method_name = "undefined"
 *         self.method_auth_name = "undefined"
 *         self.method_code = "undefined"             # <<<<<<<<<<<<<<
 *         self.is_instantiable = False
 *         self.has_ballpark_transformation = False
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_n_u_undefined);
  __Pyx_GOTREF(__pyx_v_self->method_code);
  __Pyx_DECREF(__pyx_v_self->method_code);
  __pyx_v_self->method_code = __pyx_mstate_global->__pyx_n_u_undefined;

  /* "pyproj/_crs.pyx":1888
 *         self.method_auth_name = "undefined"
 *         self.method_code = "undefined"
 *         self.is_instantiable = False             # <<<<<<<<<<<<<<
 *         self.has_ballpark_transformation = False
 *         self.accuracy = float("nan")
*/
  __pyx_v_self->is_instantiable = 0;

  /* "pyproj/_crs.pyx":1889
 *         self.method_code = "undefined"
 *         self.is_instantiable = False
 *         self.has_ballpark_transformation = False             # <<<<<<<<<<<<<<
 *         self.accuracy = float("nan")
 *         self._towgs84 = None
*/
  __pyx_v_self->has_ballpark_transformation = 0;

  /* "pyproj/_crs.pyx":1890
 *         self.is_instantiable = False
 *         self.has_ballpark_transformation = False
 *         self.accuracy = float("nan")             # <<<<<<<<<<<<<<
 *         self._towgs84 = None
 *         self._operations = None
*/
  __pyx_t_1 = __Pyx_PyUnicode_AsDouble(__pyx_mstate_global->__pyx_n_u_nan); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(0, 1890, __pyx_L1_error)
  __pyx_v_self->accuracy = __pyx_t_1;

  /* "pyproj/_crs.pyx":1891
 *         self.has_ballpark_transformation = False
 *         self.accuracy = float("nan")
 *         self._towgs84 = None             # <<<<<<<<<<<<<<
 *         self._operations = None
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_towgs84);
  __Pyx_DECREF(__pyx_v_self->_towgs84);
  __pyx_v_self->_towgs84 = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":1892
 *         self.accuracy = float("nan")
 *         self._towgs84 = None
 *         self._operations = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_operations);
  __Pyx_DECREF(__pyx_v_self->_operations);
  __pyx_v_self->_operations = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":1881
 * 
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._params = None
 *         self._grids = None
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1894
 *         self._operations = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "CoordinateOperation can only be initialized like "
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_19CoordinateOperation_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_19CoordinateOperation_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__init__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_2__init__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_19CoordinateOperation_2__init__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyproj/_crs.pyx":1895
 * 
 *     def __init__(self):
 *         raise RuntimeError(             # <<<<<<<<<<<<<<
 *             "CoordinateOperation can only be initialized like "
 *             "CoordinateOperation.from_*()'."
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_CoordinateOperation_can_only_be};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_RuntimeError)), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 1895, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1894
 *         self._operations = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise RuntimeError(
 *             "CoordinateOperation can only be initialized like "
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1900
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef CoordinateOperation create(PJ_CONTEXT* context, PJ* coord_operation_pj):
 *         cdef CoordinateOperation coord_operation = CoordinateOperation.__new__(
*/

static struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(PJ_CONTEXT *__pyx_v_context, PJ *__pyx_v_coord_operation_pj) {
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_coord_operation = 0;
  char const *__pyx_v_out_method_name;
  char const *__pyx_v_out_method_auth_name;
  char const *__pyx_v_out_method_code;
  PJ_TYPE __pyx_v_operation_type;
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create", 0);

  /* "pyproj/_crs.pyx":1902
 *     @staticmethod
 *     cdef CoordinateOperation create(PJ_CONTEXT* context, PJ* coord_operation_pj):
 *         cdef CoordinateOperation coord_operation = CoordinateOperation.__new__(             # <<<<<<<<<<<<<<
 *             CoordinateOperation
 *         )
*/
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6pyproj_4_crs_CoordinateOperation(((PyTypeObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation), __pyx_mstate_global->__pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1902, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_1);
  __pyx_v_coord_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1905
 *             CoordinateOperation
 *         )
 *         coord_operation.context = context             # <<<<<<<<<<<<<<
 *         coord_operation._context_manager = get_context_manager()
 *         coord_operation.projobj = coord_operation_pj
*/
  __pyx_v_coord_operation->__pyx_base.__pyx_base.context = __pyx_v_context;

  /* "pyproj/_crs.pyx":1906
 *         )
 *         coord_operation.context = context
 *         coord_operation._context_manager = get_context_manager()             # <<<<<<<<<<<<<<
 *         coord_operation.projobj = coord_operation_pj
 *         cdef const char *out_method_name = NULL
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_get_context_manager); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1906, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_coord_operation->__pyx_base.__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_coord_operation->__pyx_base.__pyx_base._context_manager);
  __pyx_v_coord_operation->__pyx_base.__pyx_base._context_manager = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1907
 *         coord_operation.context = context
 *         coord_operation._context_manager = get_context_manager()
 *         coord_operation.projobj = coord_operation_pj             # <<<<<<<<<<<<<<
 *         cdef const char *out_method_name = NULL
 *         cdef const char *out_method_auth_name = NULL
*/
  __pyx_v_coord_operation->__pyx_base.__pyx_base.projobj = __pyx_v_coord_operation_pj;

  /* "pyproj/_crs.pyx":1908
 *         coord_operation._context_manager = get_context_manager()
 *         coord_operation.projobj = coord_operation_pj
 *         cdef const char *out_method_name = NULL             # <<<<<<<<<<<<<<
 *         cdef const char *out_method_auth_name = NULL
 *         cdef const char *out_method_code = NULL
*/
  __pyx_v_out_method_name = NULL;

  /* "pyproj/_crs.pyx":1909
 *         coord_operation.projobj = coord_operation_pj
 *         cdef const char *out_method_name = NULL
 *         cdef const char *out_method_auth_name = NULL             # <<<<<<<<<<<<<<
 *         cdef const char *out_method_code = NULL
 *         proj_coordoperation_get_method_info(
*/
  __pyx_v_out_method_auth_name = NULL;

  /* "pyproj/_crs.pyx":1910
 *         cdef const char *out_method_name = NULL
 *         cdef const char *out_method_auth_name = NULL
 *         cdef const char *out_method_code = NULL             # <<<<<<<<<<<<<<
 *         proj_coordoperation_get_method_info(
 *             coord_operation.context,
*/
  __pyx_v_out_method_code = NULL;

  /* "pyproj/_crs.pyx":1911
 *         cdef const char *out_method_auth_name = NULL
 *         cdef const char *out_method_code = NULL
 *         proj_coordoperation_get_method_info(             # <<<<<<<<<<<<<<
 *             coord_operation.context,
 *             coord_operation.projobj,
*/
  (void)(proj_coordoperation_get_method_info(__pyx_v_coord_operation->__pyx_base.__pyx_base.context, __pyx_v_coord_operation->__pyx_base.__pyx_base.projobj, (&__pyx_v_out_method_name), (&__pyx_v_out_method_auth_name), (&__pyx_v_out_method_code)));

  /* "pyproj/_crs.pyx":1918
 *             &out_method_code
 *         )
 *         coord_operation._set_base_info()             # <<<<<<<<<<<<<<
 *         coord_operation.method_name = decode_or_undefined(out_method_name)
 *         coord_operation.method_auth_name = decode_or_undefined(out_method_auth_name)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateOperation *)__pyx_v_coord_operation->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._set_base_info(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_coord_operation)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1919
 *         )
 *         coord_operation._set_base_info()
 *         coord_operation.method_name = decode_or_undefined(out_method_name)             # <<<<<<<<<<<<<<
 *         coord_operation.method_auth_name = decode_or_undefined(out_method_auth_name)
 *         coord_operation.method_code = decode_or_undefined(out_method_code)
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_method_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_coord_operation->method_name);
  __Pyx_DECREF(__pyx_v_coord_operation->method_name);
  __pyx_v_coord_operation->method_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1920
 *         coord_operation._set_base_info()
 *         coord_operation.method_name = decode_or_undefined(out_method_name)
 *         coord_operation.method_auth_name = decode_or_undefined(out_method_auth_name)             # <<<<<<<<<<<<<<
 *         coord_operation.method_code = decode_or_undefined(out_method_code)
 *         coord_operation.accuracy = proj_coordoperation_get_accuracy(
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_method_auth_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_coord_operation->method_auth_name);
  __Pyx_DECREF(__pyx_v_coord_operation->method_auth_name);
  __pyx_v_coord_operation->method_auth_name = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1921
 *         coord_operation.method_name = decode_or_undefined(out_method_name)
 *         coord_operation.method_auth_name = decode_or_undefined(out_method_auth_name)
 *         coord_operation.method_code = decode_or_undefined(out_method_code)             # <<<<<<<<<<<<<<
 *         coord_operation.accuracy = proj_coordoperation_get_accuracy(
 *             coord_operation.context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_4_crs_decode_or_undefined(__pyx_v_out_method_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_coord_operation->method_code);
  __Pyx_DECREF(__pyx_v_coord_operation->method_code);
  __pyx_v_coord_operation->method_code = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":1922
 *         coord_operation.method_auth_name = decode_or_undefined(out_method_auth_name)
 *         coord_operation.method_code = decode_or_undefined(out_method_code)
 *         coord_operation.accuracy = proj_coordoperation_get_accuracy(             # <<<<<<<<<<<<<<
 *             coord_operation.context,
 *             coord_operation.projobj
*/
  __pyx_v_coord_operation->accuracy = proj_coordoperation_get_accuracy(__pyx_v_coord_operation->__pyx_base.__pyx_base.context, __pyx_v_coord_operation->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":1926
 *             coord_operation.projobj
 *         )
 *         coord_operation.is_instantiable = proj_coordoperation_is_instantiable(             # <<<<<<<<<<<<<<
 *             coord_operation.context,
 *             coord_operation.projobj
*/
  __pyx_v_coord_operation->is_instantiable = (proj_coordoperation_is_instantiable(__pyx_v_coord_operation->__pyx_base.__pyx_base.context, __pyx_v_coord_operation->__pyx_base.__pyx_base.projobj) == 1);

  /* "pyproj/_crs.pyx":1930
 *             coord_operation.projobj
 *         ) == 1
 *         coord_operation.has_ballpark_transformation = \             # <<<<<<<<<<<<<<
 *             proj_coordoperation_has_ballpark_transformation(
 *                 coord_operation.context,
*/
  __pyx_v_coord_operation->has_ballpark_transformation = (proj_coordoperation_has_ballpark_transformation(__pyx_v_coord_operation->__pyx_base.__pyx_base.context, __pyx_v_coord_operation->__pyx_base.__pyx_base.projobj) == 1);

  /* "pyproj/_crs.pyx":1935
 *                 coord_operation.projobj
 *             ) == 1
 *         cdef PJ_TYPE operation_type = proj_get_type(coord_operation.projobj)             # <<<<<<<<<<<<<<
 *         coord_operation.type_name = _COORDINATE_OPERATION_TYPE_MAP[operation_type]
 *         _clear_proj_error()
*/
  __pyx_v_operation_type = proj_get_type(__pyx_v_coord_operation->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":1936
 *             ) == 1
 *         cdef PJ_TYPE operation_type = proj_get_type(coord_operation.projobj)
 *         coord_operation.type_name = _COORDINATE_OPERATION_TYPE_MAP[operation_type]             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return coord_operation
*/
  if (unlikely(__pyx_v_6pyproj_4_crs__COORDINATE_OPERATION_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1936, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyLong_From_PJ_TYPE(__pyx_v_operation_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_6pyproj_4_crs__COORDINATE_OPERATION_TYPE_MAP, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(0, 1936, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_coord_operation->type_name);
  __Pyx_DECREF(__pyx_v_coord_operation->type_name);
  __pyx_v_coord_operation->type_name = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyproj/_crs.pyx":1937
 *         cdef PJ_TYPE operation_type = proj_get_type(coord_operation.projobj)
 *         coord_operation.type_name = _COORDINATE_OPERATION_TYPE_MAP[operation_type]
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return coord_operation
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1938
 *         coord_operation.type_name = _COORDINATE_OPERATION_TYPE_MAP[operation_type]
 *         _clear_proj_error()
 *         return coord_operation             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_coord_operation);
  __pyx_r = __pyx_v_coord_operation;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1900
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef CoordinateOperation create(PJ_CONTEXT* context, PJ* coord_operation_pj):
 *         cdef CoordinateOperation coord_operation = CoordinateOperation.__new__(
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.create", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_coord_operation);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1940
 *         return coord_operation
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(
 *         str auth_name not None,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_5from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_4from_authority, "CoordinateOperation.from_authority(str auth_name, code, bool use_proj_alternative_grid_names=False)\n\nCreate a CoordinateOperation from an authority code.\n\nParameters\n----------\nauth_name: str\n    Name of the authority.\ncode: str or int\n    The code used by the authority.\nuse_proj_alternative_grid_names: bool, default=False\n    Use the PROJ alternative grid names.\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_5from_authority = {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_5from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_4from_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_5from_authority(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_code = 0;
  int __pyx_v_use_proj_alternative_grid_names;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_code,&__pyx_mstate_global->__pyx_n_u_use_proj_alternative_grid_names,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1940, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1940, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1940, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1940, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_authority", 0) < (0)) __PYX_ERR(0, 1940, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_authority", 0, 2, 3, i); __PYX_ERR(0, 1940, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 1940, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1940, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1940, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    __pyx_v_code = values[1];
    if (values[2]) {
      __pyx_v_use_proj_alternative_grid_names = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_use_proj_alternative_grid_names == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
    } else {

      /* "pyproj/_crs.pyx":1944
 *         str auth_name not None,
 *         code not None,
 *         bint use_proj_alternative_grid_names=False,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
      __pyx_v_use_proj_alternative_grid_names = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_authority", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 1940, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 0, "auth_name", 1))) __PYX_ERR(0, 1942, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1943, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_4from_authority(__pyx_v_auth_name, __pyx_v_code, __pyx_v_use_proj_alternative_grid_names);

  /* "pyproj/_crs.pyx":1940
 *         return coord_operation
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(
 *         str auth_name not None,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_4from_authority(PyObject *__pyx_v_auth_name, PyObject *__pyx_v_code, int __pyx_v_use_proj_alternative_grid_names) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_coord_operation_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  char const *__pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_authority", 0);

  /* "pyproj/_crs.pyx":1962
 *         CoordinateOperation
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* coord_operation_pj = proj_create_from_database(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1962, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":1965
 *         cdef PJ* coord_operation_pj = proj_create_from_database(
 *             context,
 *             cstrencode(auth_name),             # <<<<<<<<<<<<<<
 *             cstrencode(str(code)),
 *             PJ_CATEGORY_COORDINATE_OPERATION,
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_auth_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1965, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 1965, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1966
 *             context,
 *             cstrencode(auth_name),
 *             cstrencode(str(code)),             # <<<<<<<<<<<<<<
 *             PJ_CATEGORY_COORDINATE_OPERATION,
 *             use_proj_alternative_grid_names,
*/
  __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __pyx_f_6pyproj_7_compat_cstrencode(((PyObject*)__pyx_t_4), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(__pyx_t_5 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 1966, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsString(__pyx_t_5); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 1966, __pyx_L1_error)

  /* "pyproj/_crs.pyx":1963
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coord_operation_pj = proj_create_from_database(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(auth_name),
*/
  __pyx_v_coord_operation_pj = proj_create_from_database(__pyx_v_context, __pyx_t_3, __pyx_t_6, PJ_CATEGORY_COORDINATE_OPERATION, __pyx_v_use_proj_alternative_grid_names, NULL);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pyproj/_crs.pyx":1972
 *         )
 * 
 *         if coord_operation_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  __pyx_t_7 = (__pyx_v_coord_operation_pj == NULL);
  if (unlikely(__pyx_t_7)) {

    /* "pyproj/_crs.pyx":1973
 * 
 *         if coord_operation_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         return CoordinateOperation.create(context, coord_operation_pj)
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_code, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_Invalid_authority_or_code;
    __pyx_t_9[1] = __pyx_v_auth_name;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u__8;
    __pyx_t_9[3] = __pyx_t_8;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u__5;
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 27 + __Pyx_PyUnicode_GET_LENGTH(__pyx_v_auth_name) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8) + 1, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_auth_name) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8));
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1973, __pyx_L1_error)

    /* "pyproj/_crs.pyx":1972
 *         )
 * 
 *         if coord_operation_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
*/
  }

  /* "pyproj/_crs.pyx":1974
 *         if coord_operation_pj == NULL:
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":1975
 *             raise CRSError(f"Invalid authority or code ({auth_name}, {code})")
 *         _clear_proj_error()
 *         return CoordinateOperation.create(context, coord_operation_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = ((PyObject *)__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(__pyx_v_context, __pyx_v_coord_operation_pj)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1940
 *         return coord_operation
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(
 *         str auth_name not None,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1977
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None, bint use_proj_alternative_grid_names= False):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_6from_epsg, "CoordinateOperation.from_epsg(code, bool use_proj_alternative_grid_names=False)\n\nCreate a CoordinateOperation from an EPSG code.\n\nParameters\n----------\ncode: str or int\n    The code used by EPSG.\nuse_proj_alternative_grid_names: bool, default=False\n    Use the PROJ alternative grid names.\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_7from_epsg = {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_6from_epsg};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7from_epsg(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  int __pyx_v_use_proj_alternative_grid_names;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_epsg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_code,&__pyx_mstate_global->__pyx_n_u_use_proj_alternative_grid_names,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1977, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1977, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1977, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_epsg", 0) < (0)) __PYX_ERR(0, 1977, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_epsg", 0, 1, 2, i); __PYX_ERR(0, 1977, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 1977, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1977, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_code = values[0];
    if (values[1]) {
      __pyx_v_use_proj_alternative_grid_names = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_use_proj_alternative_grid_names == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1978, __pyx_L3_error)
    } else {

      /* "pyproj/_crs.pyx":1978
 * 
 *     @staticmethod
 *     def from_epsg(code not None, bint use_proj_alternative_grid_names= False):             # <<<<<<<<<<<<<<
 *         """
 *         Create a CoordinateOperation from an EPSG code.
*/
      __pyx_v_use_proj_alternative_grid_names = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_epsg", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1977, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(((PyObject *)__pyx_v_code) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "code"); __PYX_ERR(0, 1978, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_6from_epsg(__pyx_v_code, __pyx_v_use_proj_alternative_grid_names);

  /* "pyproj/_crs.pyx":1977
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None, bint use_proj_alternative_grid_names= False):
 *         """
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_6from_epsg(PyObject *__pyx_v_code, int __pyx_v_use_proj_alternative_grid_names) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_epsg", 0);

  /* "pyproj/_crs.pyx":1993
 *         CoordinateOperation
 *         """
 *         return CoordinateOperation.from_authority(             # <<<<<<<<<<<<<<
 *             "EPSG", code, use_proj_alternative_grid_names
 *         )
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":1994
 *         """
 *         return CoordinateOperation.from_authority(
 *             "EPSG", code, use_proj_alternative_grid_names             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_use_proj_alternative_grid_names); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_EPSG, __pyx_v_code, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_authority, __pyx_callargs+__pyx_t_4, (4-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1977
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None, bint use_proj_alternative_grid_names= False):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":1997
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str coordinate_operation_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_9_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_8_from_string, "CoordinateOperation._from_string(str coordinate_operation_string)\n\nCreate a CoordinateOperation from a string.\n\nExample:\n  - urn:ogc:def:coordinateOperation:EPSG::1671\n\nParameters\n----------\ncoordinate_operation_string: str\n    Coordinate operation string.\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_9_from_string = {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_9_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_8_from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_9_from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_operation_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_operation_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 1997, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1997, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_from_string", 0) < (0)) __PYX_ERR(0, 1997, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, i); __PYX_ERR(0, 1997, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 1997, __pyx_L3_error)
    }
    __pyx_v_coordinate_operation_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1997, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_operation_string), (&PyUnicode_Type), 0, "coordinate_operation_string", 1))) __PYX_ERR(0, 1998, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_8_from_string(__pyx_v_coordinate_operation_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_8_from_string(PyObject *__pyx_v_coordinate_operation_string) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_coord_operation_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char const *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PJ_TYPE __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  size_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_string", 0);

  /* "pyproj/_crs.pyx":2014
 *         CoordinateOperation
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* coord_operation_pj = proj_create(
 *             context,
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2014, __pyx_L1_error)
  __pyx_v_context = __pyx_t_1;

  /* "pyproj/_crs.pyx":2017
 *         cdef PJ* coord_operation_pj = proj_create(
 *             context,
 *             cstrencode(coordinate_operation_string)             # <<<<<<<<<<<<<<
 *         )
 *         if (
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_coordinate_operation_string, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 2017, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 2017, __pyx_L1_error)

  /* "pyproj/_crs.pyx":2015
 *         """
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coord_operation_pj = proj_create(             # <<<<<<<<<<<<<<
 *             context,
 *             cstrencode(coordinate_operation_string)
*/
  __pyx_v_coord_operation_pj = proj_create(__pyx_v_context, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2020
 *         )
 *         if (
 *             coord_operation_pj == NULL or             # <<<<<<<<<<<<<<
 *             proj_get_type(coord_operation_pj) not in (
 *                 PJ_TYPE_CONVERSION,
*/
  __pyx_t_5 = (__pyx_v_coord_operation_pj == NULL);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":2021
 *         if (
 *             coord_operation_pj == NULL or
 *             proj_get_type(coord_operation_pj) not in (             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_CONVERSION,
 *                 PJ_TYPE_TRANSFORMATION,
*/
  __pyx_t_6 = proj_get_type(__pyx_v_coord_operation_pj);

  /* "pyproj/_crs.pyx":2022
 *             coord_operation_pj == NULL or
 *             proj_get_type(coord_operation_pj) not in (
 *                 PJ_TYPE_CONVERSION,             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_TRANSFORMATION,
 *                 PJ_TYPE_CONCATENATED_OPERATION,
*/
  __pyx_t_7 = (__pyx_t_6 != PJ_TYPE_CONVERSION);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L6_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":2021
 *         if (
 *             coord_operation_pj == NULL or
 *             proj_get_type(coord_operation_pj) not in (             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_CONVERSION,
 *                 PJ_TYPE_TRANSFORMATION,
*/
  __pyx_t_7 = (__pyx_t_6 != PJ_TYPE_TRANSFORMATION);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L6_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":2024
 *                 PJ_TYPE_CONVERSION,
 *                 PJ_TYPE_TRANSFORMATION,
 *                 PJ_TYPE_CONCATENATED_OPERATION,             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_OTHER_COORDINATE_OPERATION,
 *             )
*/
  __pyx_t_7 = (__pyx_t_6 != PJ_TYPE_CONCATENATED_OPERATION);
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L6_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":2021
 *         if (
 *             coord_operation_pj == NULL or
 *             proj_get_type(coord_operation_pj) not in (             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_CONVERSION,
 *                 PJ_TYPE_TRANSFORMATION,
*/
  __pyx_t_7 = (__pyx_t_6 != PJ_TYPE_OTHER_COORDINATE_OPERATION);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L6_bool_binop_done:;
  __pyx_t_7 = __pyx_t_5;
  __pyx_t_4 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;

  /* "pyproj/_crs.pyx":2019
 *             cstrencode(coordinate_operation_string)
 *         )
 *         if (             # <<<<<<<<<<<<<<
 *             coord_operation_pj == NULL or
 *             proj_get_type(coord_operation_pj) not in (
*/
  if (unlikely(__pyx_t_4)) {

    /* "pyproj/_crs.pyx":2028
 *             )
 *         ):
 *             proj_destroy(coord_operation_pj)             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 "Invalid coordinate operation string: "
*/
    proj_destroy(__pyx_v_coord_operation_pj);

    /* "pyproj/_crs.pyx":2029
 *         ):
 *             proj_destroy(coord_operation_pj)
 *             raise CRSError(             # <<<<<<<<<<<<<<
 *                 "Invalid coordinate operation string: "
 *                 f"{coordinate_operation_string}"
*/
    __pyx_t_8 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);

    /* "pyproj/_crs.pyx":2030
 *             proj_destroy(coord_operation_pj)
 *             raise CRSError(
 *                 "Invalid coordinate operation string: "             # <<<<<<<<<<<<<<
 *                 f"{coordinate_operation_string}"
 *             )
*/
    __pyx_t_10 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_coordinate_operation_str, __pyx_v_coordinate_operation_string); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2030, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      assert(__pyx_t_8);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
      __pyx_t_11 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_10};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_11, (2-__pyx_t_11) | (__pyx_t_11*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2029, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2029, __pyx_L1_error)

    /* "pyproj/_crs.pyx":2019
 *             cstrencode(coordinate_operation_string)
 *         )
 *         if (             # <<<<<<<<<<<<<<
 *             coord_operation_pj == NULL or
 *             proj_get_type(coord_operation_pj) not in (
*/
  }

  /* "pyproj/_crs.pyx":2033
 *                 f"{coordinate_operation_string}"
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2034
 *             )
 *         _clear_proj_error()
 *         return CoordinateOperation.create(context, coord_operation_pj)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(__pyx_v_context, __pyx_v_coord_operation_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":1997
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str coordinate_operation_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation._from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2036
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str coordinate_operation_string not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_10from_string, "CoordinateOperation.from_string(str coordinate_operation_string)\n\nCreate a CoordinateOperation from a string.\n\nExample:\n  - urn:ogc:def:coordinateOperation:EPSG::1671\n  - UTM zone 14N\n  - +proj=utm +zone=14\n\nParameters\n----------\ncoordinate_operation_string: str\n    Coordinate operation string.\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_11from_string = {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_10from_string};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11from_string(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_operation_string = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_string (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_operation_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2036, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2036, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_string", 0) < (0)) __PYX_ERR(0, 2036, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, i); __PYX_ERR(0, 2036, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2036, __pyx_L3_error)
    }
    __pyx_v_coordinate_operation_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_string", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2036, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_operation_string), (&PyUnicode_Type), 0, "coordinate_operation_string", 1))) __PYX_ERR(0, 2037, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_10from_string(__pyx_v_coordinate_operation_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_10from_string(PyObject *__pyx_v_coordinate_operation_string) {
  PyObject *__pyx_v_crs_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_string", 0);

  /* "pyproj/_crs.pyx":2055
 *         CoordinateOperation
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":2056
 *         """
 *         try:
 *             return CoordinateOperation._from_string(coordinate_operation_string)             # <<<<<<<<<<<<<<
 *         except CRSError as crs_err:
 *             try:
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_coordinate_operation_string};
        __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2056, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":2055
 *         CoordinateOperation
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":2057
 *         try:
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
*/
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2057, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_7);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 2057, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_crs_err = __pyx_t_5;
      /*try:*/ {

        /* "pyproj/_crs.pyx":2058
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
 *             except CRSError:
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {

            /* "pyproj/_crs.pyx":2059
 *         except CRSError as crs_err:
 *             try:
 *                 return CoordinateOperation.from_name(coordinate_operation_string)             # <<<<<<<<<<<<<<
 *             except CRSError:
 *                 raise crs_err
*/
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_13 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
            __Pyx_INCREF(__pyx_t_13);
            __pyx_t_6 = 0;
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_coordinate_operation_string};
              __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_name, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2059, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_8);
            }
            __pyx_r = __pyx_t_8;
            __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            goto __pyx_L20_try_return;

            /* "pyproj/_crs.pyx":2058
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
 *             except CRSError:
*/
          }
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "pyproj/_crs.pyx":2060
 *             try:
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
 *             except CRSError:             # <<<<<<<<<<<<<<
 *                 raise crs_err
 * 
*/
          __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_13, &__pyx_t_14);
          __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 2060, __pyx_L18_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_8, __pyx_t_15);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_ErrRestore(__pyx_t_8, __pyx_t_13, __pyx_t_14);
          __pyx_t_8 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
          if (__pyx_t_9) {
            __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_13, &__pyx_t_8) < 0) __PYX_ERR(0, 2060, __pyx_L18_except_error)
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_8);

            /* "pyproj/_crs.pyx":2061
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
 *             except CRSError:
 *                 raise crs_err             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
            __Pyx_Raise(__pyx_v_crs_err, 0, 0, 0);
            __PYX_ERR(0, 2061, __pyx_L18_except_error)
          }
          goto __pyx_L18_except_error;

          /* "pyproj/_crs.pyx":2058
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:
 *             try:             # <<<<<<<<<<<<<<
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
 *             except CRSError:
*/
          __pyx_L18_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L14_error;
          __pyx_L20_try_return:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L13_return;
        }
      }

      /* "pyproj/_crs.pyx":2057
 *         try:
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:             # <<<<<<<<<<<<<<
 *             try:
 *                 return CoordinateOperation.from_name(coordinate_operation_string)
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_9 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L5_except_error;
        }
        __pyx_L13_return: {
          __pyx_t_20 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_crs_err); __pyx_v_crs_err = 0;
          __pyx_r = __pyx_t_20;
          __pyx_t_20 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":2055
 *         CoordinateOperation
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             return CoordinateOperation._from_string(coordinate_operation_string)
 *         except CRSError as crs_err:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":2036
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str coordinate_operation_string not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_crs_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2063
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict coordinate_operation_dict not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_13from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_12from_json_dict, "CoordinateOperation.from_json_dict(dict coordinate_operation_dict)\n\nCreate CoordinateOperation from a JSON dictionary.\n\n.. versionadded:: 2.4.0\n\nParameters\n----------\ncoordinate_operation_dict: str\n    CoordinateOperation dictionary.\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_13from_json_dict = {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_13from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_12from_json_dict};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_13from_json_dict(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_operation_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json_dict (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_operation_dict,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2063, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2063, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json_dict", 0) < (0)) __PYX_ERR(0, 2063, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, i); __PYX_ERR(0, 2063, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2063, __pyx_L3_error)
    }
    __pyx_v_coordinate_operation_dict = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json_dict", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2063, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_operation_dict), (&PyDict_Type), 0, "coordinate_operation_dict", 1))) __PYX_ERR(0, 2064, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_12from_json_dict(__pyx_v_coordinate_operation_dict);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_12from_json_dict(PyObject *__pyx_v_coordinate_operation_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json_dict", 0);

  /* "pyproj/_crs.pyx":2079
 *         CoordinateOperation
 *         """
 *         return CoordinateOperation._from_string(             # <<<<<<<<<<<<<<
 *             json.dumps(coordinate_operation_dict, cls=NumpyEncoder)
 *         )
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":2080
 *         """
 *         return CoordinateOperation._from_string(
 *             json.dumps(coordinate_operation_dict, cls=NumpyEncoder)             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_dumps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_NumpyEncoder); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_coordinate_operation_dict};
    __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_cls, __pyx_t_5, __pyx_t_8, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 2080, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2063
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict coordinate_operation_dict not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_json_dict", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2083
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str coordinate_operation_json_str not None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_15from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_14from_json, "CoordinateOperation.from_json(str coordinate_operation_json_str)\n\nCreate CoordinateOperation from a JSON string.\n\n.. versionadded:: 2.4.0\n\nParameters\n----------\ncoordinate_operation_json_str: str\n    CoordinateOperation JSON string.\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_15from_json = {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_15from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_14from_json};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_15from_json(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_operation_json_str = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_json (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_operation_json_str,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2083, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2083, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_json", 0) < (0)) __PYX_ERR(0, 2083, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, i); __PYX_ERR(0, 2083, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2083, __pyx_L3_error)
    }
    __pyx_v_coordinate_operation_json_str = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_json", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2083, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_operation_json_str), (&PyUnicode_Type), 0, "coordinate_operation_json_str", 1))) __PYX_ERR(0, 2084, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_14from_json(__pyx_v_coordinate_operation_json_str);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_14from_json(PyObject *__pyx_v_coordinate_operation_json_str) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_json", 0);

  /* "pyproj/_crs.pyx":2099
 *         CoordinateOperation
 *         """
 *         return CoordinateOperation.from_json_dict(             # <<<<<<<<<<<<<<
 *             _load_proj_json(coordinate_operation_json_str
 *         ))
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":2100
 *         """
 *         return CoordinateOperation.from_json_dict(
 *             _load_proj_json(coordinate_operation_json_str             # <<<<<<<<<<<<<<
 *         ))
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_load_proj_json); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_coordinate_operation_json_str};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2083
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str coordinate_operation_json_str not None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_json", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2103
 *         ))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str coordinate_operation_name not None,
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_17from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_16from_name, "CoordinateOperation.from_name(str coordinate_operation_name, str auth_name=None, coordinate_operation_type=CoordinateOperationType.CONVERSION)\n\n.. versionadded:: 2.5.0\n\nCreate a Coordinate Operation from a name.\n\nExamples:\n  - UTM zone 14N\n\nParameters\n----------\ncoordinate_operation_name: str\n    Coordinate Operation name.\nauth_name: str, optional\n    The authority name to refine search (e.g. 'EPSG').\n    If None, will search all authorities.\ncoordinate_operation_type: CoordinateOperationType, optional\n    The coordinate operation type to create. Default is\n    ``pyproj.crs.enums.CoordinateOperationType.CONVERSION``\n\nReturns\n-------\nCoordinateOperation");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_17from_name = {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_17from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_16from_name};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_17from_name(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_coordinate_operation_name = 0;
  PyObject *__pyx_v_auth_name = 0;
  PyObject *__pyx_v_coordinate_operation_type = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_coordinate_operation_name,&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_coordinate_operation_type,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2103, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 2103, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2103, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2103, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "from_name", 0) < (0)) __PYX_ERR(0, 2103, __pyx_L3_error)

      /* "pyproj/_crs.pyx":2106
 *     def from_name(
 *         str coordinate_operation_name not None,
 *         str auth_name=None,             # <<<<<<<<<<<<<<
 *         coordinate_operation_type not None=CoordinateOperationType.CONVERSION,
 *     ):
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__10);
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 3, i); __PYX_ERR(0, 2103, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 2103, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2103, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2103, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject*)Py_None));
      if (!values[2]) values[2] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__10);
    }
    __pyx_v_coordinate_operation_name = ((PyObject*)values[0]);
    __pyx_v_auth_name = ((PyObject*)values[1]);
    __pyx_v_coordinate_operation_type = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("from_name", 0, 1, 3, __pyx_nargs); __PYX_ERR(0, 2103, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_coordinate_operation_name), (&PyUnicode_Type), 0, "coordinate_operation_name", 1))) __PYX_ERR(0, 2105, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 2106, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_coordinate_operation_type) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "coordinate_operation_type"); __PYX_ERR(0, 2107, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_16from_name(__pyx_v_coordinate_operation_name, __pyx_v_auth_name, __pyx_v_coordinate_operation_type);

  /* "pyproj/_crs.pyx":2103
 *         ))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str coordinate_operation_name not None,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_16from_name(PyObject *__pyx_v_coordinate_operation_name, PyObject *__pyx_v_auth_name, PyObject *__pyx_v_coordinate_operation_type) {
  PyObject *__pyx_v_pj_coordinate_operation_type = NULL;
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_coordinate_operation_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PJ_CONTEXT *__pyx_t_6;
  PJ_TYPE __pyx_t_7;
  PJ *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_name", 0);

  /* "pyproj/_crs.pyx":2132
 *         CoordinateOperation
 *         """
 *         pj_coordinate_operation_type = _PJ_COORDINATE_OPERATION_TYPE_MAP[             # <<<<<<<<<<<<<<
 *             CoordinateOperationType.create(coordinate_operation_type)
 *         ]
*/
  if (unlikely(__pyx_v_6pyproj_4_crs__PJ_COORDINATE_OPERATION_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 2132, __pyx_L1_error)
  }

  /* "pyproj/_crs.pyx":2133
 *         """
 *         pj_coordinate_operation_type = _PJ_COORDINATE_OPERATION_TYPE_MAP[
 *             CoordinateOperationType.create(coordinate_operation_type)             # <<<<<<<<<<<<<<
 *         ]
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_create); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_coordinate_operation_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }

  /* "pyproj/_crs.pyx":2132
 *         CoordinateOperation
 *         """
 *         pj_coordinate_operation_type = _PJ_COORDINATE_OPERATION_TYPE_MAP[             # <<<<<<<<<<<<<<
 *             CoordinateOperationType.create(coordinate_operation_type)
 *         ]
*/
  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_6pyproj_4_crs__PJ_COORDINATE_OPERATION_TYPE_MAP, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_pj_coordinate_operation_type = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2135
 *             CoordinateOperationType.create(coordinate_operation_type)
 *         ]
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* coordinate_operation_pj = _from_name(
 *             context,
*/
  __pyx_t_6 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2135, __pyx_L1_error)
  __pyx_v_context = __pyx_t_6;

  /* "pyproj/_crs.pyx":2140
 *             coordinate_operation_name,
 *             auth_name,
 *             <PJ_TYPE>pj_coordinate_operation_type,             # <<<<<<<<<<<<<<
 *         )
 *         if coordinate_operation_pj == NULL:
*/
  __pyx_t_7 = ((PJ_TYPE)__Pyx_PyLong_As_PJ_TYPE(__pyx_v_pj_coordinate_operation_type)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2140, __pyx_L1_error)

  /* "pyproj/_crs.pyx":2136
 *         ]
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coordinate_operation_pj = _from_name(             # <<<<<<<<<<<<<<
 *             context,
 *             coordinate_operation_name,
*/
  __pyx_t_8 = __pyx_f_6pyproj_4_crs__from_name(__pyx_v_context, __pyx_v_coordinate_operation_name, __pyx_v_auth_name, ((PJ_TYPE)__pyx_t_7)); if (unlikely(__pyx_t_8 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 2136, __pyx_L1_error)
  __pyx_v_coordinate_operation_pj = __pyx_t_8;

  /* "pyproj/_crs.pyx":2142
 *             <PJ_TYPE>pj_coordinate_operation_type,
 *         )
 *         if coordinate_operation_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 "Invalid coordinate operation name: "
*/
  __pyx_t_9 = (__pyx_v_coordinate_operation_pj == NULL);
  if (unlikely(__pyx_t_9)) {

    /* "pyproj/_crs.pyx":2143
 *         )
 *         if coordinate_operation_pj == NULL:
 *             raise CRSError(             # <<<<<<<<<<<<<<
 *                 "Invalid coordinate operation name: "
 *                 f"{coordinate_operation_name}"
*/
    __pyx_t_1 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pyproj/_crs.pyx":2144
 *         if coordinate_operation_pj == NULL:
 *             raise CRSError(
 *                 "Invalid coordinate operation name: "             # <<<<<<<<<<<<<<
 *                 f"{coordinate_operation_name}"
 *             )
*/
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_coordinate_operation_nam, __pyx_v_coordinate_operation_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2143, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 2143, __pyx_L1_error)

    /* "pyproj/_crs.pyx":2142
 *             <PJ_TYPE>pj_coordinate_operation_type,
 *         )
 *         if coordinate_operation_pj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(
 *                 "Invalid coordinate operation name: "
*/
  }

  /* "pyproj/_crs.pyx":2147
 *                 f"{coordinate_operation_name}"
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return CoordinateOperation.create(context, coordinate_operation_pj)
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2148
 *             )
 *         _clear_proj_error()
 *         return CoordinateOperation.create(context, coordinate_operation_pj)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(__pyx_v_context, __pyx_v_coordinate_operation_pj)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2103
 *         ))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str coordinate_operation_name not None,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pj_coordinate_operation_type);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2150
 *         return CoordinateOperation.create(context, coordinate_operation_pj)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def params(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_6params_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_6params_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_6params___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_6params___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  int __pyx_v_num_params;
  long __pyx_v_param_idx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2158
 *             The coordinate operation parameters.
 *         """
 *         if self._params is not None:             # <<<<<<<<<<<<<<
 *             return self._params
 *         self._params = []
*/
  __pyx_t_1 = (__pyx_v_self->_params != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2159
 *         """
 *         if self._params is not None:
 *             return self._params             # <<<<<<<<<<<<<<
 *         self._params = []
 *         cdef int num_params = 0
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_params);
    __pyx_r = __pyx_v_self->_params;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2158
 *             The coordinate operation parameters.
 *         """
 *         if self._params is not None:             # <<<<<<<<<<<<<<
 *             return self._params
 *         self._params = []
*/
  }

  /* "pyproj/_crs.pyx":2160
 *         if self._params is not None:
 *             return self._params
 *         self._params = []             # <<<<<<<<<<<<<<
 *         cdef int num_params = 0
 *         num_params = proj_coordoperation_get_param_count(
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_params);
  __Pyx_DECREF(__pyx_v_self->_params);
  __pyx_v_self->_params = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2161
 *             return self._params
 *         self._params = []
 *         cdef int num_params = 0             # <<<<<<<<<<<<<<
 *         num_params = proj_coordoperation_get_param_count(
 *             self.context,
*/
  __pyx_v_num_params = 0;

  /* "pyproj/_crs.pyx":2162
 *         self._params = []
 *         cdef int num_params = 0
 *         num_params = proj_coordoperation_get_param_count(             # <<<<<<<<<<<<<<
 *             self.context,
 *             self.projobj
*/
  __pyx_v_num_params = proj_coordoperation_get_param_count(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2166
 *             self.projobj
 *         )
 *         for param_idx from 0 <= param_idx < num_params:             # <<<<<<<<<<<<<<
 *             self._params.append(
 *                 Param.create(
*/
  __pyx_t_3 = __pyx_v_num_params;
  for (__pyx_v_param_idx = 0; __pyx_v_param_idx < __pyx_t_3; __pyx_v_param_idx++) {

    /* "pyproj/_crs.pyx":2167
 *         )
 *         for param_idx from 0 <= param_idx < num_params:
 *             self._params.append(             # <<<<<<<<<<<<<<
 *                 Param.create(
 *                     self.context,
*/
    if (unlikely(__pyx_v_self->_params == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 2167, __pyx_L1_error)
    }

    /* "pyproj/_crs.pyx":2168
 *         for param_idx from 0 <= param_idx < num_params:
 *             self._params.append(
 *                 Param.create(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     self.projobj,
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_5Param_create(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj, __pyx_v_param_idx)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pyproj/_crs.pyx":2167
 *         )
 *         for param_idx from 0 <= param_idx < num_params:
 *             self._params.append(             # <<<<<<<<<<<<<<
 *                 Param.create(
 *                     self.context,
*/
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->_params, __pyx_t_2); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2167, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2174
 *                 )
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return self._params
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2175
 *             )
 *         _clear_proj_error()
 *         return self._params             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_params);
  __pyx_r = __pyx_v_self->_params;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2150
 *         return CoordinateOperation.create(context, coordinate_operation_pj)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def params(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.params.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2177
 *         return self._params
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def grids(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_5grids_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_5grids_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_5grids___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_5grids___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  int __pyx_v_num_grids;
  long __pyx_v_grid_idx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2185
 *             The coordinate operation grids.
 *         """
 *         if self._grids is not None:             # <<<<<<<<<<<<<<
 *             return self._grids
 *         self._grids = []
*/
  __pyx_t_1 = (__pyx_v_self->_grids != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2186
 *         """
 *         if self._grids is not None:
 *             return self._grids             # <<<<<<<<<<<<<<
 *         self._grids = []
 *         cdef int num_grids = 0
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_grids);
    __pyx_r = __pyx_v_self->_grids;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2185
 *             The coordinate operation grids.
 *         """
 *         if self._grids is not None:             # <<<<<<<<<<<<<<
 *             return self._grids
 *         self._grids = []
*/
  }

  /* "pyproj/_crs.pyx":2187
 *         if self._grids is not None:
 *             return self._grids
 *         self._grids = []             # <<<<<<<<<<<<<<
 *         cdef int num_grids = 0
 *         num_grids = proj_coordoperation_get_grid_used_count(
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_grids);
  __Pyx_DECREF(__pyx_v_self->_grids);
  __pyx_v_self->_grids = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2188
 *             return self._grids
 *         self._grids = []
 *         cdef int num_grids = 0             # <<<<<<<<<<<<<<
 *         num_grids = proj_coordoperation_get_grid_used_count(
 *             self.context,
*/
  __pyx_v_num_grids = 0;

  /* "pyproj/_crs.pyx":2189
 *         self._grids = []
 *         cdef int num_grids = 0
 *         num_grids = proj_coordoperation_get_grid_used_count(             # <<<<<<<<<<<<<<
 *             self.context,
 *             self.projobj
*/
  __pyx_v_num_grids = proj_coordoperation_get_grid_used_count(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2193
 *             self.projobj
 *         )
 *         for grid_idx from 0 <= grid_idx < num_grids:             # <<<<<<<<<<<<<<
 *             self._grids.append(
 *                 Grid.create(
*/
  __pyx_t_3 = __pyx_v_num_grids;
  for (__pyx_v_grid_idx = 0; __pyx_v_grid_idx < __pyx_t_3; __pyx_v_grid_idx++) {

    /* "pyproj/_crs.pyx":2194
 *         )
 *         for grid_idx from 0 <= grid_idx < num_grids:
 *             self._grids.append(             # <<<<<<<<<<<<<<
 *                 Grid.create(
 *                     self.context,
*/
    if (unlikely(__pyx_v_self->_grids == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(0, 2194, __pyx_L1_error)
    }

    /* "pyproj/_crs.pyx":2195
 *         for grid_idx from 0 <= grid_idx < num_grids:
 *             self._grids.append(
 *                 Grid.create(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     self.projobj,
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_4Grid_create(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj, __pyx_v_grid_idx)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pyproj/_crs.pyx":2194
 *         )
 *         for grid_idx from 0 <= grid_idx < num_grids:
 *             self._grids.append(             # <<<<<<<<<<<<<<
 *                 Grid.create(
 *                     self.context,
*/
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_self->_grids, __pyx_t_2); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2194, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2201
 *                 )
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return self._grids
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2202
 *             )
 *         _clear_proj_error()
 *         return self._grids             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_grids);
  __pyx_r = __pyx_v_self->_grids;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2177
 *         return self._params
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def grids(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.grids.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2204
 *         return self._grids
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def area_of_use(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11area_of_use_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11area_of_use_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_11area_of_use___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11area_of_use___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2212
 *             The area of use object with associated attributes.
 *         """
 *         if self._area_of_use is not None:             # <<<<<<<<<<<<<<
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
*/
  __pyx_t_1 = (__pyx_v_self->_area_of_use != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2213
 *         """
 *         if self._area_of_use is not None:
 *             return self._area_of_use             # <<<<<<<<<<<<<<
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
 *         return self._area_of_use
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_area_of_use);
    __pyx_r = __pyx_v_self->_area_of_use;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2212
 *             The area of use object with associated attributes.
 *         """
 *         if self._area_of_use is not None:             # <<<<<<<<<<<<<<
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":2214
 *         if self._area_of_use is not None:
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)             # <<<<<<<<<<<<<<
 *         return self._area_of_use
 * 
*/
  __pyx_t_2 = __pyx_f_6pyproj_4_crs_create_area_of_use(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_area_of_use);
  __Pyx_DECREF(__pyx_v_self->_area_of_use);
  __pyx_v_self->_area_of_use = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2215
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
 *         return self._area_of_use             # <<<<<<<<<<<<<<
 * 
 *     def to_proj4(self, version not None=ProjVersion.PROJ_5, bint pretty=False):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_area_of_use);
  __pyx_r = __pyx_v_self->_area_of_use;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2204
 *         return self._grids
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def area_of_use(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.area_of_use.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2217
 *         return self._area_of_use
 * 
 *     def to_proj4(self, version not None=ProjVersion.PROJ_5, bint pretty=False):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a PROJ string.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_19to_proj4(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_18to_proj4, "CoordinateOperation.to_proj4(self, version=ProjVersion.PROJ_5, bool pretty=False)\n\nConvert the projection to a PROJ string.\n\n.. versionadded:: 3.1.0 pretty\n\nParameters\n----------\nversion: pyproj.enums.ProjVersion, default=pyproj.enums.ProjVersion.PROJ_5\n    The version of the PROJ string output.\npretty: bool, default=False\n    If True, it will set the output to be a multiline string.\n\nReturns\n-------\nstr:\n    The PROJ string.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_19to_proj4 = {"to_proj4", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_19to_proj4, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_18to_proj4};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_19to_proj4(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_version = 0;
  int __pyx_v_pretty;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_proj4 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_version,&__pyx_mstate_global->__pyx_n_u_pretty,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2217, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2217, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2217, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_proj4", 0) < (0)) __PYX_ERR(0, 2217, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__11);
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2217, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2217, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__11);
    }
    __pyx_v_version = values[0];
    if (values[1]) {
      __pyx_v_pretty = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_pretty == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2217, __pyx_L3_error)
    } else {
      __pyx_v_pretty = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_proj4", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 2217, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.to_proj4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(((PyObject *)__pyx_v_version) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "version"); __PYX_ERR(0, 2217, __pyx_L1_error)
  }
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_18to_proj4(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self), __pyx_v_version, __pyx_v_pretty);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_18to_proj4(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self, PyObject *__pyx_v_version, int __pyx_v_pretty) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_proj4", 0);

  /* "pyproj/_crs.pyx":2236
 * 
 *         """
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=pretty)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pyproj_4_crs__to_proj4(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj, __pyx_v_version, __pyx_v_pretty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2217
 *         return self._area_of_use
 * 
 *     def to_proj4(self, version not None=ProjVersion.PROJ_5, bint pretty=False):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a PROJ string.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.to_proj4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2238
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=pretty)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def towgs84(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7towgs84_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7towgs84_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_7towgs84___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_7towgs84___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_v_towgs84_dict = NULL;
  PyObject *__pyx_v_param = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2247
 * 
 *         """
 *         if self._towgs84 is not None:             # <<<<<<<<<<<<<<
 *             return self._towgs84
 *         towgs84_dict = OrderedDict(
*/
  __pyx_t_1 = (__pyx_v_self->_towgs84 != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2248
 *         """
 *         if self._towgs84 is not None:
 *             return self._towgs84             # <<<<<<<<<<<<<<
 *         towgs84_dict = OrderedDict(
 *             (
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_towgs84);
    __pyx_r = __pyx_v_self->_towgs84;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2247
 * 
 *         """
 *         if self._towgs84 is not None:             # <<<<<<<<<<<<<<
 *             return self._towgs84
 *         towgs84_dict = OrderedDict(
*/
  }

  /* "pyproj/_crs.pyx":2249
 *         if self._towgs84 is not None:
 *             return self._towgs84
 *         towgs84_dict = OrderedDict(             # <<<<<<<<<<<<<<
 *             (
 *                 ('X-axis translation', None),
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_OrderedDict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pyproj/_crs.pyx":2251
 *         towgs84_dict = OrderedDict(
 *             (
 *                 ('X-axis translation', None),             # <<<<<<<<<<<<<<
 *                 ('Y-axis translation', None),
 *                 ('Z-axis translation', None),
*/
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_tuple[7]};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_v_towgs84_dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2260
 *             )
 *         )
 *         for param in self.params:             # <<<<<<<<<<<<<<
 *             if param.name in towgs84_dict:
 *                 towgs84_dict[param.name] = param.value
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_params); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_4 = __pyx_t_2; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2260, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2260, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        __pyx_t_2 = __Pyx_PyList_GetItemRefFast(__pyx_t_4, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
        ++__pyx_t_6;
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_SIZE
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2260, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6));
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6);
        #endif
        ++__pyx_t_6;
      }
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2260, __pyx_L1_error)
    } else {
      __pyx_t_2 = __pyx_t_7(__pyx_t_4);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 2260, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_param, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":2261
 *         )
 *         for param in self.params:
 *             if param.name in towgs84_dict:             # <<<<<<<<<<<<<<
 *                 towgs84_dict[param.name] = param.value
 *         self._towgs84 = [val for val in towgs84_dict.values() if val is not None]
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_param, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_v_towgs84_dict, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2261, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "pyproj/_crs.pyx":2262
 *         for param in self.params:
 *             if param.name in towgs84_dict:
 *                 towgs84_dict[param.name] = param.value             # <<<<<<<<<<<<<<
 *         self._towgs84 = [val for val in towgs84_dict.values() if val is not None]
 *         return self._towgs84
*/
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_param, __pyx_mstate_global->__pyx_n_u_value_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_param, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely((PyObject_SetItem(__pyx_v_towgs84_dict, __pyx_t_3, __pyx_t_2) < 0))) __PYX_ERR(0, 2262, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "pyproj/_crs.pyx":2261
 *         )
 *         for param in self.params:
 *             if param.name in towgs84_dict:             # <<<<<<<<<<<<<<
 *                 towgs84_dict[param.name] = param.value
 *         self._towgs84 = [val for val in towgs84_dict.values() if val is not None]
*/
    }

    /* "pyproj/_crs.pyx":2260
 *             )
 *         )
 *         for param in self.params:             # <<<<<<<<<<<<<<
 *             if param.name in towgs84_dict:
 *                 towgs84_dict[param.name] = param.value
*/
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2263
 *             if param.name in towgs84_dict:
 *                 towgs84_dict[param.name] = param.value
 *         self._towgs84 = [val for val in towgs84_dict.values() if val is not None]             # <<<<<<<<<<<<<<
 *         return self._towgs84
 * 
*/
  { /* enter inner scope */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2263, __pyx_L10_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = 0;
    if (unlikely(__pyx_v_towgs84_dict == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(0, 2263, __pyx_L10_error)
    }
    __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_towgs84_dict, 0, __pyx_mstate_global->__pyx_n_u_values, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2263, __pyx_L10_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_8, &__pyx_t_6, NULL, &__pyx_t_3, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 2263, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_val, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = (__pyx_8genexpr1__pyx_v_val != Py_None);
      if (__pyx_t_1) {
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_8genexpr1__pyx_v_val))) __PYX_ERR(0, 2263, __pyx_L10_error)
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_val); __pyx_8genexpr1__pyx_v_val = 0;
    goto __pyx_L14_exit_scope;
    __pyx_L10_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_val); __pyx_8genexpr1__pyx_v_val = 0;
    goto __pyx_L1_error;
    __pyx_L14_exit_scope:;
  } /* exit inner scope */
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_towgs84);
  __Pyx_DECREF(__pyx_v_self->_towgs84);
  __pyx_v_self->_towgs84 = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2264
 *                 towgs84_dict[param.name] = param.value
 *         self._towgs84 = [val for val in towgs84_dict.values() if val is not None]
 *         return self._towgs84             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_towgs84);
  __pyx_r = __pyx_v_self->_towgs84;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2238
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=pretty)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def towgs84(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.towgs84.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_towgs84_dict);
  __Pyx_XDECREF(__pyx_v_param);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2266
 *         return self._towgs84
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def operations(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_10operations_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_10operations_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_10operations___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_10operations___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2277
 * 
 *         """
 *         if self._operations is not None:             # <<<<<<<<<<<<<<
 *             return self._operations
 *         self._operations = _get_concatenated_operations(self.context, self.projobj)
*/
  __pyx_t_1 = (__pyx_v_self->_operations != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2278
 *         """
 *         if self._operations is not None:
 *             return self._operations             # <<<<<<<<<<<<<<
 *         self._operations = _get_concatenated_operations(self.context, self.projobj)
 *         return self._operations
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_operations);
    __pyx_r = __pyx_v_self->_operations;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2277
 * 
 *         """
 *         if self._operations is not None:             # <<<<<<<<<<<<<<
 *             return self._operations
 *         self._operations = _get_concatenated_operations(self.context, self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":2279
 *         if self._operations is not None:
 *             return self._operations
 *         self._operations = _get_concatenated_operations(self.context, self.projobj)             # <<<<<<<<<<<<<<
 *         return self._operations
 * 
*/
  __pyx_t_2 = __pyx_f_6pyproj_4_crs__get_concatenated_operations(__pyx_v_self->__pyx_base.__pyx_base.context, __pyx_v_self->__pyx_base.__pyx_base.projobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_operations);
  __Pyx_DECREF(__pyx_v_self->_operations);
  __pyx_v_self->_operations = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2280
 *             return self._operations
 *         self._operations = _get_concatenated_operations(self.context, self.projobj)
 *         return self._operations             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_operations);
  __pyx_r = __pyx_v_self->_operations;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2266
 *         return self._towgs84
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def operations(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.operations.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2282
 *         return self._operations
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"<Coordinate Operation: {self.type_name}>\n"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_21__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_21__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_20__repr__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_20__repr__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7[8];
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "pyproj/_crs.pyx":2283
 * 
 *     def __repr__(self):
 *         return (             # <<<<<<<<<<<<<<
 *             f"<Coordinate Operation: {self.type_name}>\n"
 *             f"Name: {self.name}\n"
*/
  __Pyx_XDECREF(__pyx_r);

  /* "pyproj/_crs.pyx":2284
 *     def __repr__(self):
 *         return (
 *             f"<Coordinate Operation: {self.type_name}>\n"             # <<<<<<<<<<<<<<
 *             f"Name: {self.name}\n"
 *             f"Method: {self.method_name}\n"
*/
  __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->type_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pyproj/_crs.pyx":2285
 *         return (
 *             f"<Coordinate Operation: {self.type_name}>\n"
 *             f"Name: {self.name}\n"             # <<<<<<<<<<<<<<
 *             f"Method: {self.method_name}\n"
 *             f"Area of Use:\n{self.area_of_use or '- undefined'}"
*/
  __pyx_t_2 = __Pyx_PyUnicode_Unicode(__pyx_v_self->__pyx_base.__pyx_base.name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":2286
 *             f"<Coordinate Operation: {self.type_name}>\n"
 *             f"Name: {self.name}\n"
 *             f"Method: {self.method_name}\n"             # <<<<<<<<<<<<<<
 *             f"Area of Use:\n{self.area_of_use or '- undefined'}"
 *         )
*/
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_self->method_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pyproj/_crs.pyx":2287
 *             f"Name: {self.name}\n"
 *             f"Method: {self.method_name}\n"
 *             f"Area of Use:\n{self.area_of_use or '- undefined'}"             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_area_of_use); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2287, __pyx_L1_error)
  if (!__pyx_t_6) {
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_4 = __pyx_t_5;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_undefined_2);
  __pyx_t_4 = __pyx_mstate_global->__pyx_kp_u_undefined_2;
  __pyx_L3_bool_binop_done:;
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_Coordinate_Operation;
  __pyx_t_7[1] = __pyx_t_1;
  __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u_Name;
  __pyx_t_7[3] = __pyx_t_2;
  __pyx_t_7[4] = __pyx_mstate_global->__pyx_kp_u_Method;
  __pyx_t_7[5] = __pyx_t_3;
  __pyx_t_7[6] = __pyx_mstate_global->__pyx_kp_u_Area_of_Use;
  __pyx_t_7[7] = __pyx_t_5;

  /* "pyproj/_crs.pyx":2284
 *     def __repr__(self):
 *         return (
 *             f"<Coordinate Operation: {self.type_name}>\n"             # <<<<<<<<<<<<<<
 *             f"Name: {self.name}\n"
 *             f"Method: {self.method_name}\n"
*/
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_7, 8, 23 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3) + 14 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2282
 *         return self._operations
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return (
 *             f"<Coordinate Operation: {self.type_name}>\n"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":124
 * 
 * cdef class CoordinateOperation(_CRSParts):
 *     cdef readonly list _params             # <<<<<<<<<<<<<<
 *     cdef readonly list _grids
 *     cdef readonly object _area_of_use
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7_params_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7_params_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_7_params___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_7_params___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_params);
  __pyx_r = __pyx_v_self->_params;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":125
 * cdef class CoordinateOperation(_CRSParts):
 *     cdef readonly list _params
 *     cdef readonly list _grids             # <<<<<<<<<<<<<<
 *     cdef readonly object _area_of_use
 *     cdef readonly str method_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_6_grids_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_6_grids_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_6_grids___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_6_grids___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_grids);
  __pyx_r = __pyx_v_self->_grids;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":126
 *     cdef readonly list _params
 *     cdef readonly list _grids
 *     cdef readonly object _area_of_use             # <<<<<<<<<<<<<<
 *     cdef readonly str method_name
 *     cdef readonly str method_auth_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_12_area_of_use_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_12_area_of_use_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_12_area_of_use___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_12_area_of_use___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_area_of_use);
  __pyx_r = __pyx_v_self->_area_of_use;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":127
 *     cdef readonly list _grids
 *     cdef readonly object _area_of_use
 *     cdef readonly str method_name             # <<<<<<<<<<<<<<
 *     cdef readonly str method_auth_name
 *     cdef readonly str method_code
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11method_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11method_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_11method_name___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11method_name___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->method_name);
  __pyx_r = __pyx_v_self->method_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":128
 *     cdef readonly object _area_of_use
 *     cdef readonly str method_name
 *     cdef readonly str method_auth_name             # <<<<<<<<<<<<<<
 *     cdef readonly str method_code
 *     cdef readonly double accuracy
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_16method_auth_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_16method_auth_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_16method_auth_name___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_16method_auth_name___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->method_auth_name);
  __pyx_r = __pyx_v_self->method_auth_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":129
 *     cdef readonly str method_name
 *     cdef readonly str method_auth_name
 *     cdef readonly str method_code             # <<<<<<<<<<<<<<
 *     cdef readonly double accuracy
 *     cdef readonly bint is_instantiable
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11method_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11method_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_11method_code___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11method_code___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->method_code);
  __pyx_r = __pyx_v_self->method_code;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":130
 *     cdef readonly str method_auth_name
 *     cdef readonly str method_code
 *     cdef readonly double accuracy             # <<<<<<<<<<<<<<
 *     cdef readonly bint is_instantiable
 *     cdef readonly bint has_ballpark_transformation
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_8accuracy_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_8accuracy_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_8accuracy___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_8accuracy___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->accuracy); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.accuracy.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":131
 *     cdef readonly str method_code
 *     cdef readonly double accuracy
 *     cdef readonly bint is_instantiable             # <<<<<<<<<<<<<<
 *     cdef readonly bint has_ballpark_transformation
 *     cdef readonly list _towgs84
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_15is_instantiable_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_15is_instantiable_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_15is_instantiable___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_15is_instantiable___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->is_instantiable); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.is_instantiable.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":132
 *     cdef readonly double accuracy
 *     cdef readonly bint is_instantiable
 *     cdef readonly bint has_ballpark_transformation             # <<<<<<<<<<<<<<
 *     cdef readonly list _towgs84
 *     cdef readonly tuple _operations
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_27has_ballpark_transformation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_27has_ballpark_transformation_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_27has_ballpark_transformation___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_27has_ballpark_transformation___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->has_ballpark_transformation); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.has_ballpark_transformation.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":133
 *     cdef readonly bint is_instantiable
 *     cdef readonly bint has_ballpark_transformation
 *     cdef readonly list _towgs84             # <<<<<<<<<<<<<<
 *     cdef readonly tuple _operations
 *     cdef readonly str type_name
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_8_towgs84_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_8_towgs84_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_8_towgs84___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_8_towgs84___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_towgs84);
  __pyx_r = __pyx_v_self->_towgs84;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":134
 *     cdef readonly bint has_ballpark_transformation
 *     cdef readonly list _towgs84
 *     cdef readonly tuple _operations             # <<<<<<<<<<<<<<
 *     cdef readonly str type_name
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11_operations_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11_operations_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_11_operations___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_11_operations___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_operations);
  __pyx_r = __pyx_v_self->_operations;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":135
 *     cdef readonly list _towgs84
 *     cdef readonly tuple _operations
 *     cdef readonly str type_name             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_9type_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_9type_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_9type_name___get__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_9type_name___get__(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->type_name);
  __pyx_r = __pyx_v_self->type_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_23__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_22__reduce_cython__, "CoordinateOperation.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_23__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_23__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_22__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_23__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_22__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_25__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_19CoordinateOperation_24__setstate_cython__, "CoordinateOperation.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_19CoordinateOperation_25__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_25__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_24__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_19CoordinateOperation_25__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_19CoordinateOperation_24__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_19CoordinateOperation_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs.CoordinateOperation.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2341
 *     python CRS class.
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._context_manager = None
 *         self._ellipsoid = None
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_4_CRS_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_4_CRS_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return -1;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS___cinit__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_4_CRS___cinit__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyproj/_crs.pyx":2342
 *     """
 *     def __cinit__(self):
 *         self._context_manager = None             # <<<<<<<<<<<<<<
 *         self._ellipsoid = None
 *         self._area_of_use = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_self->__pyx_base._context_manager);
  __pyx_v_self->__pyx_base._context_manager = Py_None;

  /* "pyproj/_crs.pyx":2343
 *     def __cinit__(self):
 *         self._context_manager = None
 *         self._ellipsoid = None             # <<<<<<<<<<<<<<
 *         self._area_of_use = None
 *         self._prime_meridian = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_ellipsoid);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_ellipsoid);
  __pyx_v_self->_ellipsoid = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)Py_None);

  /* "pyproj/_crs.pyx":2344
 *         self._context_manager = None
 *         self._ellipsoid = None
 *         self._area_of_use = None             # <<<<<<<<<<<<<<
 *         self._prime_meridian = None
 *         self._datum = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_area_of_use);
  __Pyx_DECREF(__pyx_v_self->_area_of_use);
  __pyx_v_self->_area_of_use = Py_None;

  /* "pyproj/_crs.pyx":2345
 *         self._ellipsoid = None
 *         self._area_of_use = None
 *         self._prime_meridian = None             # <<<<<<<<<<<<<<
 *         self._datum = None
 *         self._sub_crs_list = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_prime_meridian);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_prime_meridian);
  __pyx_v_self->_prime_meridian = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)Py_None);

  /* "pyproj/_crs.pyx":2346
 *         self._area_of_use = None
 *         self._prime_meridian = None
 *         self._datum = None             # <<<<<<<<<<<<<<
 *         self._sub_crs_list = None
 *         self._source_crs = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_datum);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_datum);
  __pyx_v_self->_datum = ((struct __pyx_obj_6pyproj_4_crs_Datum *)Py_None);

  /* "pyproj/_crs.pyx":2347
 *         self._prime_meridian = None
 *         self._datum = None
 *         self._sub_crs_list = None             # <<<<<<<<<<<<<<
 *         self._source_crs = None
 *         self._target_crs = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_sub_crs_list);
  __Pyx_DECREF(__pyx_v_self->_sub_crs_list);
  __pyx_v_self->_sub_crs_list = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":2348
 *         self._datum = None
 *         self._sub_crs_list = None
 *         self._source_crs = None             # <<<<<<<<<<<<<<
 *         self._target_crs = None
 *         self._geodetic_crs = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_source_crs);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_source_crs);
  __pyx_v_self->_source_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None);

  /* "pyproj/_crs.pyx":2349
 *         self._sub_crs_list = None
 *         self._source_crs = None
 *         self._target_crs = None             # <<<<<<<<<<<<<<
 *         self._geodetic_crs = None
 *         self._coordinate_system = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_target_crs);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_target_crs);
  __pyx_v_self->_target_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None);

  /* "pyproj/_crs.pyx":2350
 *         self._source_crs = None
 *         self._target_crs = None
 *         self._geodetic_crs = None             # <<<<<<<<<<<<<<
 *         self._coordinate_system = None
 *         self._coordinate_operation = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_geodetic_crs);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_geodetic_crs);
  __pyx_v_self->_geodetic_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None);

  /* "pyproj/_crs.pyx":2351
 *         self._target_crs = None
 *         self._geodetic_crs = None
 *         self._coordinate_system = None             # <<<<<<<<<<<<<<
 *         self._coordinate_operation = None
 *         self._type_name = None
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_system);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_system);
  __pyx_v_self->_coordinate_system = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)Py_None);

  /* "pyproj/_crs.pyx":2352
 *         self._geodetic_crs = None
 *         self._coordinate_system = None
 *         self._coordinate_operation = None             # <<<<<<<<<<<<<<
 *         self._type_name = None
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_operation);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_operation);
  __pyx_v_self->_coordinate_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)Py_None);

  /* "pyproj/_crs.pyx":2353
 *         self._coordinate_system = None
 *         self._coordinate_operation = None
 *         self._type_name = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, str proj_string):
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_type_name);
  __Pyx_DECREF(__pyx_v_self->_type_name);
  __pyx_v_self->_type_name = ((PyObject*)Py_None);

  /* "pyproj/_crs.pyx":2341
 *     python CRS class.
 *     """
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._context_manager = None
 *         self._ellipsoid = None
*/

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2355
 *         self._type_name = None
 * 
 *     def __init__(self, str proj_string):             # <<<<<<<<<<<<<<
 *         self.context = pyproj_context_create()
 *         self._context_manager = get_context_manager()
*/

/* Python wrapper */
static int __pyx_pw_6pyproj_4_crs_4_CRS_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pyproj_4_crs_4_CRS_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_proj_string = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_proj_string,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2355, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2355, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__init__", 0) < (0)) __PYX_ERR(0, 2355, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, i); __PYX_ERR(0, 2355, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2355, __pyx_L3_error)
    }
    __pyx_v_proj_string = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2355, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_proj_string), (&PyUnicode_Type), 1, "proj_string", 1))) __PYX_ERR(0, 2355, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_2__init__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_proj_string);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pyproj_4_crs_4_CRS_2__init__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_proj_string) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PJ_CONTEXT *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  char const *__pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyproj/_crs.pyx":2356
 * 
 *     def __init__(self, str proj_string):
 *         self.context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         self._context_manager = get_context_manager()
 *         # initialize projection
*/
  __pyx_t_1 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2356, __pyx_L1_error)
  __pyx_v_self->__pyx_base.context = __pyx_t_1;

  /* "pyproj/_crs.pyx":2357
 *     def __init__(self, str proj_string):
 *         self.context = pyproj_context_create()
 *         self._context_manager = get_context_manager()             # <<<<<<<<<<<<<<
 *         # initialize projection
 *         self.projobj = proj_create(
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_get_context_manager); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (1-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base._context_manager);
  __Pyx_DECREF(__pyx_v_self->__pyx_base._context_manager);
  __pyx_v_self->__pyx_base._context_manager = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2361
 *         self.projobj = proj_create(
 *             self.context,
 *             cstrencode(proj_string),             # <<<<<<<<<<<<<<
 *         )
 *         if self.projobj == NULL:
*/
  __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_proj_string, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(0, 2361, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_PyBytes_AsString(__pyx_t_2); if (unlikely((!__pyx_t_6) && PyErr_Occurred())) __PYX_ERR(0, 2361, __pyx_L1_error)

  /* "pyproj/_crs.pyx":2359
 *         self._context_manager = get_context_manager()
 *         # initialize projection
 *         self.projobj = proj_create(             # <<<<<<<<<<<<<<
 *             self.context,
 *             cstrencode(proj_string),
*/
  __pyx_v_self->__pyx_base.projobj = proj_create(__pyx_v_self->__pyx_base.context, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2363
 *             cstrencode(proj_string),
 *         )
 *         if self.projobj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid projection: {proj_string}")
 *         # make sure the input is a CRS
*/
  __pyx_t_7 = (__pyx_v_self->__pyx_base.projobj == NULL);
  if (unlikely(__pyx_t_7)) {

    /* "pyproj/_crs.pyx":2364
 *         )
 *         if self.projobj == NULL:
 *             raise CRSError(f"Invalid projection: {proj_string}")             # <<<<<<<<<<<<<<
 *         # make sure the input is a CRS
 *         if not proj_is_crs(self.projobj):
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyUnicode_Unicode(__pyx_v_proj_string); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Invalid_projection, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_9};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2364, __pyx_L1_error)

    /* "pyproj/_crs.pyx":2363
 *             cstrencode(proj_string),
 *         )
 *         if self.projobj == NULL:             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Invalid projection: {proj_string}")
 *         # make sure the input is a CRS
*/
  }

  /* "pyproj/_crs.pyx":2366
 *             raise CRSError(f"Invalid projection: {proj_string}")
 *         # make sure the input is a CRS
 *         if not proj_is_crs(self.projobj):             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Input is not a CRS: {proj_string}")
 *         # set proj information
*/
  __pyx_t_7 = (!(proj_is_crs(__pyx_v_self->__pyx_base.projobj) != 0));
  if (unlikely(__pyx_t_7)) {

    /* "pyproj/_crs.pyx":2367
 *         # make sure the input is a CRS
 *         if not proj_is_crs(self.projobj):
 *             raise CRSError(f"Input is not a CRS: {proj_string}")             # <<<<<<<<<<<<<<
 *         # set proj information
 *         self.srs = proj_string
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_CRSError); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_4 = __Pyx_PyUnicode_Unicode(__pyx_v_proj_string); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Input_is_not_a_CRS, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2367, __pyx_L1_error)

    /* "pyproj/_crs.pyx":2366
 *             raise CRSError(f"Invalid projection: {proj_string}")
 *         # make sure the input is a CRS
 *         if not proj_is_crs(self.projobj):             # <<<<<<<<<<<<<<
 *             raise CRSError(f"Input is not a CRS: {proj_string}")
 *         # set proj information
*/
  }

  /* "pyproj/_crs.pyx":2369
 *             raise CRSError(f"Input is not a CRS: {proj_string}")
 *         # set proj information
 *         self.srs = proj_string             # <<<<<<<<<<<<<<
 *         self._type = proj_get_type(self.projobj)
 *         self._set_base_info()
*/
  __Pyx_INCREF(__pyx_v_proj_string);
  __Pyx_GIVEREF(__pyx_v_proj_string);
  __Pyx_GOTREF(__pyx_v_self->srs);
  __Pyx_DECREF(__pyx_v_self->srs);
  __pyx_v_self->srs = __pyx_v_proj_string;

  /* "pyproj/_crs.pyx":2370
 *         # set proj information
 *         self.srs = proj_string
 *         self._type = proj_get_type(self.projobj)             # <<<<<<<<<<<<<<
 *         self._set_base_info()
 *         _clear_proj_error()
*/
  __pyx_v_self->_type = proj_get_type(__pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2371
 *         self.srs = proj_string
 *         self._type = proj_get_type(self.projobj)
 *         self._set_base_info()             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 * 
*/
  __pyx_t_2 = ((struct __pyx_vtabstruct_6pyproj_4_crs__CRS *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._set_base_info(((struct __pyx_obj_6pyproj_4_crs_Base *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2372
 *         self._type = proj_get_type(self.projobj)
 *         self._set_base_info()
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2355
 *         self._type_name = None
 * 
 *     def __init__(self, str proj_string):             # <<<<<<<<<<<<<<
 *         self.context = pyproj_context_create()
 *         self._context_manager = get_context_manager()
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pyproj._crs._CRS.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2374
 *         _clear_proj_error()
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def type_name(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9type_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9type_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_9type_name___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_9type_name___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2382
 *             The name of the type of the CRS object.
 *         """
 *         if self._type_name is not None:             # <<<<<<<<<<<<<<
 *             return self._type_name
 *         self._type_name = _CRS_TYPE_MAP[self._type]
*/
  __pyx_t_1 = (__pyx_v_self->_type_name != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2383
 *         """
 *         if self._type_name is not None:
 *             return self._type_name             # <<<<<<<<<<<<<<
 *         self._type_name = _CRS_TYPE_MAP[self._type]
 *         if not self.is_derived or self._type in (
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_type_name);
    __pyx_r = __pyx_v_self->_type_name;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2382
 *             The name of the type of the CRS object.
 *         """
 *         if self._type_name is not None:             # <<<<<<<<<<<<<<
 *             return self._type_name
 *         self._type_name = _CRS_TYPE_MAP[self._type]
*/
  }

  /* "pyproj/_crs.pyx":2384
 *         if self._type_name is not None:
 *             return self._type_name
 *         self._type_name = _CRS_TYPE_MAP[self._type]             # <<<<<<<<<<<<<<
 *         if not self.is_derived or self._type in (
 *             PJ_TYPE_PROJECTED_CRS,
*/
  if (unlikely(__pyx_v_6pyproj_4_crs__CRS_TYPE_MAP == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 2384, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(__pyx_v_self->_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_6pyproj_4_crs__CRS_TYPE_MAP, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->_type_name);
  __Pyx_DECREF(__pyx_v_self->_type_name);
  __pyx_v_self->_type_name = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyproj/_crs.pyx":2385
 *             return self._type_name
 *         self._type_name = _CRS_TYPE_MAP[self._type]
 *         if not self.is_derived or self._type in (             # <<<<<<<<<<<<<<
 *             PJ_TYPE_PROJECTED_CRS,
 *             PJ_TYPE_DERIVED_PROJECTED_CRS,
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_derived); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2385, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (!__pyx_t_4);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_1 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }

  /* "pyproj/_crs.pyx":2387
 *         if not self.is_derived or self._type in (
 *             PJ_TYPE_PROJECTED_CRS,
 *             PJ_TYPE_DERIVED_PROJECTED_CRS,             # <<<<<<<<<<<<<<
 *         ):
 *             # Projected CRS are derived by definition
*/
  switch (__pyx_v_self->_type) {
    case PJ_TYPE_PROJECTED_CRS:

    /* "pyproj/_crs.pyx":2386
 *         self._type_name = _CRS_TYPE_MAP[self._type]
 *         if not self.is_derived or self._type in (
 *             PJ_TYPE_PROJECTED_CRS,             # <<<<<<<<<<<<<<
 *             PJ_TYPE_DERIVED_PROJECTED_CRS,
 *         ):
*/
    case PJ_TYPE_DERIVED_PROJECTED_CRS:

    /* "pyproj/_crs.pyx":2385
 *             return self._type_name
 *         self._type_name = _CRS_TYPE_MAP[self._type]
 *         if not self.is_derived or self._type in (             # <<<<<<<<<<<<<<
 *             PJ_TYPE_PROJECTED_CRS,
 *             PJ_TYPE_DERIVED_PROJECTED_CRS,
*/
    __pyx_t_5 = 1;
    break;
    default:
    __pyx_t_5 = 0;
    break;
  }
  __pyx_t_4 = __pyx_t_5;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2391
 *             # Projected CRS are derived by definition
 *             # https://github.com/OSGeo/PROJ/issues/3525#issuecomment-1365790999
 *             return self._type_name             # <<<<<<<<<<<<<<
 * 
 *         self._type_name = f"Derived {self._type_name}"
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_type_name);
    __pyx_r = __pyx_v_self->_type_name;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2385
 *             return self._type_name
 *         self._type_name = _CRS_TYPE_MAP[self._type]
 *         if not self.is_derived or self._type in (             # <<<<<<<<<<<<<<
 *             PJ_TYPE_PROJECTED_CRS,
 *             PJ_TYPE_DERIVED_PROJECTED_CRS,
*/
  }

  /* "pyproj/_crs.pyx":2393
 *             return self._type_name
 * 
 *         self._type_name = f"Derived {self._type_name}"             # <<<<<<<<<<<<<<
 *         return self._type_name
 * 
*/
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_self->_type_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_Derived, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_type_name);
  __Pyx_DECREF(__pyx_v_self->_type_name);
  __pyx_v_self->_type_name = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2394
 * 
 *         self._type_name = f"Derived {self._type_name}"
 *         return self._type_name             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_type_name);
  __pyx_r = __pyx_v_self->_type_name;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2374
 *         _clear_proj_error()
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def type_name(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs._CRS.type_name.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2396
 *         return self._type_name
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def axis_info(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9axis_info_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9axis_info_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_9axis_info___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_9axis_info___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_v_axis_info_list = NULL;
  PyObject *__pyx_v_sub_crs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2408
 *             The list of axis information.
 *         """
 *         axis_info_list = []             # <<<<<<<<<<<<<<
 *         if self.coordinate_system:
 *             axis_info_list.extend(self.coordinate_system.axis_list)
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_axis_info_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":2409
 *         """
 *         axis_info_list = []
 *         if self.coordinate_system:             # <<<<<<<<<<<<<<
 *             axis_info_list.extend(self.coordinate_system.axis_list)
 *         elif self.is_bound and self.source_crs:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_coordinate_system); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":2410
 *         axis_info_list = []
 *         if self.coordinate_system:
 *             axis_info_list.extend(self.coordinate_system.axis_list)             # <<<<<<<<<<<<<<
 *         elif self.is_bound and self.source_crs:
 *             axis_info_list.extend(self.source_crs.axis_info)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_coordinate_system); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_axis_list); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyList_Extend(__pyx_v_axis_info_list, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2410, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pyproj/_crs.pyx":2409
 *         """
 *         axis_info_list = []
 *         if self.coordinate_system:             # <<<<<<<<<<<<<<
 *             axis_info_list.extend(self.coordinate_system.axis_list)
 *         elif self.is_bound and self.source_crs:
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":2411
 *         if self.coordinate_system:
 *             axis_info_list.extend(self.coordinate_system.axis_list)
 *         elif self.is_bound and self.source_crs:             # <<<<<<<<<<<<<<
 *             axis_info_list.extend(self.source_crs.axis_info)
 *         else:
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_bound); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2411, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_source_crs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2411, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":2412
 *             axis_info_list.extend(self.coordinate_system.axis_list)
 *         elif self.is_bound and self.source_crs:
 *             axis_info_list.extend(self.source_crs.axis_info)             # <<<<<<<<<<<<<<
 *         else:
 *             for sub_crs in self.sub_crs_list:
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_source_crs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_axis_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyList_Extend(__pyx_v_axis_info_list, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2412, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pyproj/_crs.pyx":2411
 *         if self.coordinate_system:
 *             axis_info_list.extend(self.coordinate_system.axis_list)
 *         elif self.is_bound and self.source_crs:             # <<<<<<<<<<<<<<
 *             axis_info_list.extend(self.source_crs.axis_info)
 *         else:
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":2414
 *             axis_info_list.extend(self.source_crs.axis_info)
 *         else:
 *             for sub_crs in self.sub_crs_list:             # <<<<<<<<<<<<<<
 *                 axis_info_list.extend(sub_crs.axis_info)
 *         return axis_info_list
*/
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_sub_crs_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2414, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2414, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          __pyx_t_1 = __Pyx_PyList_GetItemRefFast(__pyx_t_3, __pyx_t_6, __Pyx_ReferenceSharing_OwnStrongReference);
          ++__pyx_t_6;
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2414, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = __Pyx_NewRef(PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6));
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6);
          #endif
          ++__pyx_t_6;
        }
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2414, __pyx_L1_error)
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_3);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(0, 2414, __pyx_L1_error)
            PyErr_Clear();
          }
          break;
        }
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sub_crs, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":2415
 *         else:
 *             for sub_crs in self.sub_crs_list:
 *                 axis_info_list.extend(sub_crs.axis_info)             # <<<<<<<<<<<<<<
 *         return axis_info_list
 * 
*/
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sub_crs, __pyx_mstate_global->__pyx_n_u_axis_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyList_Extend(__pyx_v_axis_info_list, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 2415, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":2414
 *             axis_info_list.extend(self.source_crs.axis_info)
 *         else:
 *             for sub_crs in self.sub_crs_list:             # <<<<<<<<<<<<<<
 *                 axis_info_list.extend(sub_crs.axis_info)
 *         return axis_info_list
*/
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "pyproj/_crs.pyx":2416
 *             for sub_crs in self.sub_crs_list:
 *                 axis_info_list.extend(sub_crs.axis_info)
 *         return axis_info_list             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_axis_info_list);
  __pyx_r = __pyx_v_axis_info_list;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2396
 *         return self._type_name
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def axis_info(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs._CRS.axis_info.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_axis_info_list);
  __Pyx_XDECREF(__pyx_v_sub_crs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2418
 *         return axis_info_list
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def area_of_use(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11area_of_use_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11area_of_use_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_11area_of_use___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11area_of_use___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2426
 *             The area of use object with associated attributes.
 *         """
 *         if self._area_of_use is not None:             # <<<<<<<<<<<<<<
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
*/
  __pyx_t_1 = (__pyx_v_self->_area_of_use != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2427
 *         """
 *         if self._area_of_use is not None:
 *             return self._area_of_use             # <<<<<<<<<<<<<<
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
 *         return self._area_of_use
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_area_of_use);
    __pyx_r = __pyx_v_self->_area_of_use;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2426
 *             The area of use object with associated attributes.
 *         """
 *         if self._area_of_use is not None:             # <<<<<<<<<<<<<<
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":2428
 *         if self._area_of_use is not None:
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)             # <<<<<<<<<<<<<<
 *         return self._area_of_use
 * 
*/
  __pyx_t_2 = __pyx_f_6pyproj_4_crs_create_area_of_use(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2428, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_area_of_use);
  __Pyx_DECREF(__pyx_v_self->_area_of_use);
  __pyx_v_self->_area_of_use = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2429
 *             return self._area_of_use
 *         self._area_of_use = create_area_of_use(self.context, self.projobj)
 *         return self._area_of_use             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_area_of_use);
  __pyx_r = __pyx_v_self->_area_of_use;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2418
 *         return axis_info_list
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def area_of_use(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS.area_of_use.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2431
 *         return self._area_of_use
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ellipsoid(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9ellipsoid_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9ellipsoid_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_9ellipsoid___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_9ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_ellipsoid_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PJ_CONTEXT *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2441
 *             The ellipsoid object with associated attributes.
 *         """
 *         if self._ellipsoid is not None:             # <<<<<<<<<<<<<<
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_ellipsoid) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2442
 *         """
 *         if self._ellipsoid is not None:
 *             return None if self._ellipsoid is False else self._ellipsoid             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = proj_get_ellipsoid(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_ellipsoid) == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_ellipsoid);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_ellipsoid);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2441
 *             The ellipsoid object with associated attributes.
 *         """
 *         if self._ellipsoid is not None:             # <<<<<<<<<<<<<<
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  }

  /* "pyproj/_crs.pyx":2443
 *         if self._ellipsoid is not None:
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* ellipsoid_pj = proj_get_ellipsoid(
 *             context,
*/
  __pyx_t_3 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2443, __pyx_L1_error)
  __pyx_v_context = __pyx_t_3;

  /* "pyproj/_crs.pyx":2444
 *             return None if self._ellipsoid is False else self._ellipsoid
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* ellipsoid_pj = proj_get_ellipsoid(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj
*/
  __pyx_v_ellipsoid_pj = proj_get_ellipsoid(__pyx_v_context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2448
 *             self.projobj
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if ellipsoid_pj == NULL:
 *             self._ellipsoid = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2449
 *         )
 *         _clear_proj_error()
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._ellipsoid = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_ellipsoid_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2450
 *         _clear_proj_error()
 *         if ellipsoid_pj == NULL:
 *             self._ellipsoid = False             # <<<<<<<<<<<<<<
 *             return None
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_ellipsoid);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_ellipsoid);
    __pyx_v_self->_ellipsoid = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)Py_False);

    /* "pyproj/_crs.pyx":2451
 *         if ellipsoid_pj == NULL:
 *             self._ellipsoid = False
 *             return None             # <<<<<<<<<<<<<<
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)
 *         return self._ellipsoid
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2449
 *         )
 *         _clear_proj_error()
 *         if ellipsoid_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._ellipsoid = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2452
 *             self._ellipsoid = False
 *             return None
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)             # <<<<<<<<<<<<<<
 *         return self._ellipsoid
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_9Ellipsoid_create(__pyx_v_context, __pyx_v_ellipsoid_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_ellipsoid);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_ellipsoid);
  __pyx_v_self->_ellipsoid = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2453
 *             return None
 *         self._ellipsoid = Ellipsoid.create(context, ellipsoid_pj)
 *         return self._ellipsoid             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_ellipsoid);
  __pyx_r = ((PyObject *)__pyx_v_self->_ellipsoid);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2431
 *         return self._area_of_use
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ellipsoid(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS.ellipsoid.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2455
 *         return self._ellipsoid
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def prime_meridian(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_14prime_meridian_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_14prime_meridian_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_14prime_meridian___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_14prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_prime_meridian_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PJ_CONTEXT *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2465
 *             The prime meridian object with associated attributes.
 *         """
 *         if self._prime_meridian is not None:             # <<<<<<<<<<<<<<
 *             return None if self._prime_meridian is True else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_prime_meridian) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2466
 *         """
 *         if self._prime_meridian is not None:
 *             return None if self._prime_meridian is True else self._prime_meridian             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = proj_get_prime_meridian(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_prime_meridian) == Py_True);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_prime_meridian);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_prime_meridian);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2465
 *             The prime meridian object with associated attributes.
 *         """
 *         if self._prime_meridian is not None:             # <<<<<<<<<<<<<<
 *             return None if self._prime_meridian is True else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  }

  /* "pyproj/_crs.pyx":2467
 *         if self._prime_meridian is not None:
 *             return None if self._prime_meridian is True else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* prime_meridian_pj = proj_get_prime_meridian(
 *             context,
*/
  __pyx_t_3 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2467, __pyx_L1_error)
  __pyx_v_context = __pyx_t_3;

  /* "pyproj/_crs.pyx":2468
 *             return None if self._prime_meridian is True else self._prime_meridian
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* prime_meridian_pj = proj_get_prime_meridian(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj,
*/
  __pyx_v_prime_meridian_pj = proj_get_prime_meridian(__pyx_v_context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2472
 *             self.projobj,
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if prime_meridian_pj == NULL:
 *             self._prime_meridian = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2473
 *         )
 *         _clear_proj_error()
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._prime_meridian = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_prime_meridian_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2474
 *         _clear_proj_error()
 *         if prime_meridian_pj == NULL:
 *             self._prime_meridian = False             # <<<<<<<<<<<<<<
 *             return None
 *         self._prime_meridian = PrimeMeridian.create(context, prime_meridian_pj)
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_prime_meridian);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_prime_meridian);
    __pyx_v_self->_prime_meridian = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)Py_False);

    /* "pyproj/_crs.pyx":2475
 *         if prime_meridian_pj == NULL:
 *             self._prime_meridian = False
 *             return None             # <<<<<<<<<<<<<<
 *         self._prime_meridian = PrimeMeridian.create(context, prime_meridian_pj)
 *         return self._prime_meridian
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2473
 *         )
 *         _clear_proj_error()
 *         if prime_meridian_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._prime_meridian = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2476
 *             self._prime_meridian = False
 *             return None
 *         self._prime_meridian = PrimeMeridian.create(context, prime_meridian_pj)             # <<<<<<<<<<<<<<
 *         return self._prime_meridian
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_13PrimeMeridian_create(__pyx_v_context, __pyx_v_prime_meridian_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_prime_meridian);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_prime_meridian);
  __pyx_v_self->_prime_meridian = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2477
 *             return None
 *         self._prime_meridian = PrimeMeridian.create(context, prime_meridian_pj)
 *         return self._prime_meridian             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_prime_meridian);
  __pyx_r = ((PyObject *)__pyx_v_self->_prime_meridian);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2455
 *         return self._ellipsoid
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def prime_meridian(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS.prime_meridian.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2479
 *         return self._prime_meridian
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def datum(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_5datum_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_5datum_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_5datum___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_5datum___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_datum_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PJ_CONTEXT *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2488
 *         Datum
 *         """
 *         if self._datum is not None:             # <<<<<<<<<<<<<<
 *             return None if self._datum is False else self._datum
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_datum) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2489
 *         """
 *         if self._datum is not None:
 *             return None if self._datum is False else self._datum             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* datum_pj = proj_crs_get_datum(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_datum) == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_datum);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_datum);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2488
 *         Datum
 *         """
 *         if self._datum is not None:             # <<<<<<<<<<<<<<
 *             return None if self._datum is False else self._datum
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  }

  /* "pyproj/_crs.pyx":2490
 *         if self._datum is not None:
 *             return None if self._datum is False else self._datum
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* datum_pj = proj_crs_get_datum(
 *             context,
*/
  __pyx_t_3 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2490, __pyx_L1_error)
  __pyx_v_context = __pyx_t_3;

  /* "pyproj/_crs.pyx":2491
 *             return None if self._datum is False else self._datum
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* datum_pj = proj_crs_get_datum(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj,
*/
  __pyx_v_datum_pj = proj_crs_get_datum(__pyx_v_context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2495
 *             self.projobj,
 *         )
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             datum_pj = proj_crs_get_horizontal_datum(
 *                 context,
*/
  __pyx_t_1 = (__pyx_v_datum_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2496
 *         )
 *         if datum_pj == NULL:
 *             datum_pj = proj_crs_get_horizontal_datum(             # <<<<<<<<<<<<<<
 *                 context,
 *                 self.projobj,
*/
    __pyx_v_datum_pj = proj_crs_get_horizontal_datum(__pyx_v_context, __pyx_v_self->__pyx_base.projobj);

    /* "pyproj/_crs.pyx":2495
 *             self.projobj,
 *         )
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             datum_pj = proj_crs_get_horizontal_datum(
 *                 context,
*/
  }

  /* "pyproj/_crs.pyx":2500
 *                 self.projobj,
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if datum_pj == NULL:
 *             self._datum = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2501
 *             )
 *         _clear_proj_error()
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._datum = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_datum_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2502
 *         _clear_proj_error()
 *         if datum_pj == NULL:
 *             self._datum = False             # <<<<<<<<<<<<<<
 *             return None
 *         self._datum = Datum.create(context, datum_pj)
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_datum);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_datum);
    __pyx_v_self->_datum = ((struct __pyx_obj_6pyproj_4_crs_Datum *)Py_False);

    /* "pyproj/_crs.pyx":2503
 *         if datum_pj == NULL:
 *             self._datum = False
 *             return None             # <<<<<<<<<<<<<<
 *         self._datum = Datum.create(context, datum_pj)
 *         return self._datum
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2501
 *             )
 *         _clear_proj_error()
 *         if datum_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._datum = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2504
 *             self._datum = False
 *             return None
 *         self._datum = Datum.create(context, datum_pj)             # <<<<<<<<<<<<<<
 *         return self._datum
 * 
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_5Datum_create(__pyx_v_context, __pyx_v_datum_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_datum);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_datum);
  __pyx_v_self->_datum = ((struct __pyx_obj_6pyproj_4_crs_Datum *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2505
 *             return None
 *         self._datum = Datum.create(context, datum_pj)
 *         return self._datum             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_datum);
  __pyx_r = ((PyObject *)__pyx_v_self->_datum);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2479
 *         return self._prime_meridian
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def datum(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS.datum.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2507
 *         return self._datum
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def coordinate_system(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_17coordinate_system_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_17coordinate_system_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_17coordinate_system___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_17coordinate_system___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_coord_system_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PJ_CONTEXT *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2516
 *         CoordinateSystem
 *         """
 *         if self._coordinate_system is not None:             # <<<<<<<<<<<<<<
 *             return None if self._coordinate_system is False else self._coordinate_system
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_coordinate_system) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2517
 *         """
 *         if self._coordinate_system is not None:
 *             return None if self._coordinate_system is False else self._coordinate_system             # <<<<<<<<<<<<<<
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coord_system_pj = proj_crs_get_coordinate_system(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_coordinate_system) == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_coordinate_system);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_coordinate_system);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2516
 *         CoordinateSystem
 *         """
 *         if self._coordinate_system is not None:             # <<<<<<<<<<<<<<
 *             return None if self._coordinate_system is False else self._coordinate_system
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
  }

  /* "pyproj/_crs.pyx":2518
 *         if self._coordinate_system is not None:
 *             return None if self._coordinate_system is False else self._coordinate_system
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* coord_system_pj = proj_crs_get_coordinate_system(
 *             context,
*/
  __pyx_t_3 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2518, __pyx_L1_error)
  __pyx_v_context = __pyx_t_3;

  /* "pyproj/_crs.pyx":2519
 *             return None if self._coordinate_system is False else self._coordinate_system
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coord_system_pj = proj_crs_get_coordinate_system(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj
*/
  __pyx_v_coord_system_pj = proj_crs_get_coordinate_system(__pyx_v_context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2523
 *             self.projobj
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if coord_system_pj == NULL:
 *             self._coordinate_system = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2524
 *         )
 *         _clear_proj_error()
 *         if coord_system_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._coordinate_system = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_coord_system_pj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2525
 *         _clear_proj_error()
 *         if coord_system_pj == NULL:
 *             self._coordinate_system = False             # <<<<<<<<<<<<<<
 *             return None
 * 
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_system);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_system);
    __pyx_v_self->_coordinate_system = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)Py_False);

    /* "pyproj/_crs.pyx":2526
 *         if coord_system_pj == NULL:
 *             self._coordinate_system = False
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         self._coordinate_system = CoordinateSystem.create(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2524
 *         )
 *         _clear_proj_error()
 *         if coord_system_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._coordinate_system = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2528
 *             return None
 * 
 *         self._coordinate_system = CoordinateSystem.create(             # <<<<<<<<<<<<<<
 *             context,
 *             coord_system_pj,
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_16CoordinateSystem_create(__pyx_v_context, __pyx_v_coord_system_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_system);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_system);
  __pyx_v_self->_coordinate_system = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2532
 *             coord_system_pj,
 *         )
 *         return self._coordinate_system             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_coordinate_system);
  __pyx_r = ((PyObject *)__pyx_v_self->_coordinate_system);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2507
 *         return self._datum
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def coordinate_system(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS.coordinate_system.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2534
 *         return self._coordinate_system
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def coordinate_operation(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_20coordinate_operation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_20coordinate_operation_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_20coordinate_operation___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_20coordinate_operation___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ_CONTEXT *__pyx_v_context;
  PJ *__pyx_v_coord_pj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PJ_CONTEXT *__pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2543
 *         CoordinateOperation
 *         """
 *         if self._coordinate_operation is not None:             # <<<<<<<<<<<<<<
 *             return (
 *                 None
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_coordinate_operation) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2544
 *         """
 *         if self._coordinate_operation is not None:
 *             return (             # <<<<<<<<<<<<<<
 *                 None
 *                 if self._coordinate_operation is False
*/
    __Pyx_XDECREF(__pyx_r);

    /* "pyproj/_crs.pyx":2546
 *             return (
 *                 None
 *                 if self._coordinate_operation is False             # <<<<<<<<<<<<<<
 *                 else self._coordinate_operation
 *             )
*/
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_coordinate_operation) == Py_False);
    if (__pyx_t_1) {

      /* "pyproj/_crs.pyx":2545
 *         if self._coordinate_operation is not None:
 *             return (
 *                 None             # <<<<<<<<<<<<<<
 *                 if self._coordinate_operation is False
 *                 else self._coordinate_operation
*/
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {

      /* "pyproj/_crs.pyx":2547
 *                 None
 *                 if self._coordinate_operation is False
 *                 else self._coordinate_operation             # <<<<<<<<<<<<<<
 *             )
 * 
*/
      __Pyx_INCREF((PyObject *)__pyx_v_self->_coordinate_operation);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_coordinate_operation);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2543
 *         CoordinateOperation
 *         """
 *         if self._coordinate_operation is not None:             # <<<<<<<<<<<<<<
 *             return (
 *                 None
*/
  }

  /* "pyproj/_crs.pyx":2551
 * 
 *         if not (
 *             self.is_bound or self.is_derived             # <<<<<<<<<<<<<<
 *         ):
 *             self._coordinate_operation = False
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_derived); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;

  /* "pyproj/_crs.pyx":2550
 *             )
 * 
 *         if not (             # <<<<<<<<<<<<<<
 *             self.is_bound or self.is_derived
 *         ):
*/
  __pyx_t_3 = (!__pyx_t_1);
  if (__pyx_t_3) {

    /* "pyproj/_crs.pyx":2553
 *             self.is_bound or self.is_derived
 *         ):
 *             self._coordinate_operation = False             # <<<<<<<<<<<<<<
 *             return None
 * 
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_operation);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_operation);
    __pyx_v_self->_coordinate_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)Py_False);

    /* "pyproj/_crs.pyx":2554
 *         ):
 *             self._coordinate_operation = False
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2550
 *             )
 * 
 *         if not (             # <<<<<<<<<<<<<<
 *             self.is_bound or self.is_derived
 *         ):
*/
  }

  /* "pyproj/_crs.pyx":2556
 *             return None
 * 
 *         cdef PJ_CONTEXT* context = pyproj_context_create()             # <<<<<<<<<<<<<<
 *         cdef PJ* coord_pj = proj_crs_get_coordoperation(
 *             context,
*/
  __pyx_t_4 = __pyx_f_6pyproj_8_context_pyproj_context_create(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2556, __pyx_L1_error)
  __pyx_v_context = __pyx_t_4;

  /* "pyproj/_crs.pyx":2557
 * 
 *         cdef PJ_CONTEXT* context = pyproj_context_create()
 *         cdef PJ* coord_pj = proj_crs_get_coordoperation(             # <<<<<<<<<<<<<<
 *             context,
 *             self.projobj
*/
  __pyx_v_coord_pj = proj_crs_get_coordoperation(__pyx_v_context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2561
 *             self.projobj
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if coord_pj == NULL:
 *             self._coordinate_operation = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2562
 *         )
 *         _clear_proj_error()
 *         if coord_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._coordinate_operation = False
 *             return None
*/
  __pyx_t_3 = (__pyx_v_coord_pj == NULL);
  if (__pyx_t_3) {

    /* "pyproj/_crs.pyx":2563
 *         _clear_proj_error()
 *         if coord_pj == NULL:
 *             self._coordinate_operation = False             # <<<<<<<<<<<<<<
 *             return None
 *         self._coordinate_operation = CoordinateOperation.create(
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_operation);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_operation);
    __pyx_v_self->_coordinate_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)Py_False);

    /* "pyproj/_crs.pyx":2564
 *         if coord_pj == NULL:
 *             self._coordinate_operation = False
 *             return None             # <<<<<<<<<<<<<<
 *         self._coordinate_operation = CoordinateOperation.create(
 *             context,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2562
 *         )
 *         _clear_proj_error()
 *         if coord_pj == NULL:             # <<<<<<<<<<<<<<
 *             self._coordinate_operation = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2565
 *             self._coordinate_operation = False
 *             return None
 *         self._coordinate_operation = CoordinateOperation.create(             # <<<<<<<<<<<<<<
 *             context,
 *             coord_pj,
*/
  __pyx_t_2 = ((PyObject *)__pyx_f_6pyproj_4_crs_19CoordinateOperation_create(__pyx_v_context, __pyx_v_coord_pj)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_coordinate_operation);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_coordinate_operation);
  __pyx_v_self->_coordinate_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2569
 *             coord_pj,
 *         )
 *         return self._coordinate_operation             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_coordinate_operation);
  __pyx_r = ((PyObject *)__pyx_v_self->_coordinate_operation);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2534
 *         return self._coordinate_system
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def coordinate_operation(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS.coordinate_operation.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2571
 *         return self._coordinate_operation
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def source_crs(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10source_crs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10source_crs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_10source_crs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10source_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ *__pyx_v_projobj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2579
 *             The base CRS of a BoundCRS or a DerivedCRS/ProjectedCRS.
 *         """
 *         if self._source_crs is not None:             # <<<<<<<<<<<<<<
 *             return None if self._source_crs is False else self._source_crs
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_source_crs) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2580
 *         """
 *         if self._source_crs is not None:
 *             return None if self._source_crs is False else self._source_crs             # <<<<<<<<<<<<<<
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)
 *         _clear_proj_error()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_source_crs) == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_source_crs);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_source_crs);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2579
 *             The base CRS of a BoundCRS or a DerivedCRS/ProjectedCRS.
 *         """
 *         if self._source_crs is not None:             # <<<<<<<<<<<<<<
 *             return None if self._source_crs is False else self._source_crs
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":2581
 *         if self._source_crs is not None:
 *             return None if self._source_crs is False else self._source_crs
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         if projobj == NULL:
*/
  __pyx_v_projobj = proj_get_source_crs(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2582
 *             return None if self._source_crs is False else self._source_crs
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if projobj == NULL:
 *             self._source_crs = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2583
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             self._source_crs = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_projobj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2584
 *         _clear_proj_error()
 *         if projobj == NULL:
 *             self._source_crs = False             # <<<<<<<<<<<<<<
 *             return None
 *         try:
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_source_crs);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_source_crs);
    __pyx_v_self->_source_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_False);

    /* "pyproj/_crs.pyx":2585
 *         if projobj == NULL:
 *             self._source_crs = False
 *             return None             # <<<<<<<<<<<<<<
 *         try:
 *             self._source_crs = _CRS(_to_wkt(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2583
 *         cdef PJ * projobj = proj_get_source_crs(self.context, self.projobj)
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             self._source_crs = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2586
 *             self._source_crs = False
 *             return None
 *         try:             # <<<<<<<<<<<<<<
 *             self._source_crs = _CRS(_to_wkt(
 *                 self.context,
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2587
 *             return None
 *         try:
 *             self._source_crs = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_3 = NULL;

    /* "pyproj/_crs.pyx":2590
 *                 self.context,
 *                 projobj,
 *                 version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                 pretty=False,
 *             ))
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2590, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2590, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyproj/_crs.pyx":2587
 *             return None
 *         try:
 *             self._source_crs = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_4 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_projobj, __pyx_t_5, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2587, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2587, __pyx_L6_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_2);
    }
    __Pyx_GIVEREF((PyObject *)__pyx_t_2);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_source_crs);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_source_crs);
    __pyx_v_self->_source_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2594
 *             ))
 *         finally:
 *             proj_destroy(projobj)             # <<<<<<<<<<<<<<
 *         return self._source_crs
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_projobj);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ( unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_7 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
      {
        proj_destroy(__pyx_v_projobj);
      }
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "pyproj/_crs.pyx":2595
 *         finally:
 *             proj_destroy(projobj)
 *         return self._source_crs             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_source_crs);
  __pyx_r = ((PyObject *)__pyx_v_self->_source_crs);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2571
 *         return self._coordinate_operation
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def source_crs(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs._CRS.source_crs.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2597
 *         return self._source_crs
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def target_crs(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10target_crs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10target_crs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_10target_crs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10target_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ *__pyx_v_projobj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2607
 *             The hub CRS of a BoundCRS.
 *         """
 *         if self._target_crs is not None:             # <<<<<<<<<<<<<<
 *             return None if self._target_crs is False else self._target_crs
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_target_crs) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2608
 *         """
 *         if self._target_crs is not None:
 *             return None if self._target_crs is False else self._target_crs             # <<<<<<<<<<<<<<
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)
 *         _clear_proj_error()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_target_crs) == Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    } else {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_target_crs);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_target_crs);
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2607
 *             The hub CRS of a BoundCRS.
 *         """
 *         if self._target_crs is not None:             # <<<<<<<<<<<<<<
 *             return None if self._target_crs is False else self._target_crs
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":2609
 *         if self._target_crs is not None:
 *             return None if self._target_crs is False else self._target_crs
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         if projobj == NULL:
*/
  __pyx_v_projobj = proj_get_target_crs(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2610
 *             return None if self._target_crs is False else self._target_crs
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if projobj == NULL:
 *             self._target_crs = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2611
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             self._target_crs = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_projobj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2612
 *         _clear_proj_error()
 *         if projobj == NULL:
 *             self._target_crs = False             # <<<<<<<<<<<<<<
 *             return None
 *         try:
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_target_crs);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_target_crs);
    __pyx_v_self->_target_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_False);

    /* "pyproj/_crs.pyx":2613
 *         if projobj == NULL:
 *             self._target_crs = False
 *             return None             # <<<<<<<<<<<<<<
 *         try:
 *             self._target_crs = _CRS(_to_wkt(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2611
 *         cdef PJ * projobj = proj_get_target_crs(self.context, self.projobj)
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             self._target_crs = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2614
 *             self._target_crs = False
 *             return None
 *         try:             # <<<<<<<<<<<<<<
 *             self._target_crs = _CRS(_to_wkt(
 *                 self.context,
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2615
 *             return None
 *         try:
 *             self._target_crs = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_3 = NULL;

    /* "pyproj/_crs.pyx":2618
 *                 self.context,
 *                 projobj,
 *                 version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                 pretty=False,
 *             ))
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2618, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2618, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyproj/_crs.pyx":2615
 *             return None
 *         try:
 *             self._target_crs = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_4 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_projobj, __pyx_t_5, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2615, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2615, __pyx_L6_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_2);
    }
    __Pyx_GIVEREF((PyObject *)__pyx_t_2);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_target_crs);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_target_crs);
    __pyx_v_self->_target_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2622
 *             ))
 *         finally:
 *             proj_destroy(projobj)             # <<<<<<<<<<<<<<
 *         return self._target_crs
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_projobj);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ( unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_7 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
      {
        proj_destroy(__pyx_v_projobj);
      }
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "pyproj/_crs.pyx":2623
 *         finally:
 *             proj_destroy(projobj)
 *         return self._target_crs             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_target_crs);
  __pyx_r = ((PyObject *)__pyx_v_self->_target_crs);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2597
 *         return self._source_crs
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def target_crs(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs._CRS.target_crs.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2625
 *         return self._target_crs
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def sub_crs_list(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12sub_crs_list_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12sub_crs_list_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_12sub_crs_list___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12sub_crs_list___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  int __pyx_v_iii;
  PJ *__pyx_v_projobj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2634
 *         list[_CRS]
 *         """
 *         if self._sub_crs_list is not None:             # <<<<<<<<<<<<<<
 *             return self._sub_crs_list
 *         if not self.is_compound:
*/
  __pyx_t_1 = (__pyx_v_self->_sub_crs_list != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2635
 *         """
 *         if self._sub_crs_list is not None:
 *             return self._sub_crs_list             # <<<<<<<<<<<<<<
 *         if not self.is_compound:
 *             self._sub_crs_list = []
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_sub_crs_list);
    __pyx_r = __pyx_v_self->_sub_crs_list;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2634
 *         list[_CRS]
 *         """
 *         if self._sub_crs_list is not None:             # <<<<<<<<<<<<<<
 *             return self._sub_crs_list
 *         if not self.is_compound:
*/
  }

  /* "pyproj/_crs.pyx":2636
 *         if self._sub_crs_list is not None:
 *             return self._sub_crs_list
 *         if not self.is_compound:             # <<<<<<<<<<<<<<
 *             self._sub_crs_list = []
 *             return self._sub_crs_list
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_compound); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2636, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = (!__pyx_t_1);
  if (__pyx_t_3) {

    /* "pyproj/_crs.pyx":2637
 *             return self._sub_crs_list
 *         if not self.is_compound:
 *             self._sub_crs_list = []             # <<<<<<<<<<<<<<
 *             return self._sub_crs_list
 * 
*/
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_sub_crs_list);
    __Pyx_DECREF(__pyx_v_self->_sub_crs_list);
    __pyx_v_self->_sub_crs_list = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":2638
 *         if not self.is_compound:
 *             self._sub_crs_list = []
 *             return self._sub_crs_list             # <<<<<<<<<<<<<<
 * 
 *         cdef int iii = 0
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_sub_crs_list);
    __pyx_r = __pyx_v_self->_sub_crs_list;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2636
 *         if self._sub_crs_list is not None:
 *             return self._sub_crs_list
 *         if not self.is_compound:             # <<<<<<<<<<<<<<
 *             self._sub_crs_list = []
 *             return self._sub_crs_list
*/
  }

  /* "pyproj/_crs.pyx":2640
 *             return self._sub_crs_list
 * 
 *         cdef int iii = 0             # <<<<<<<<<<<<<<
 *         cdef PJ * projobj = proj_crs_get_sub_crs(
 *             self.context,
*/
  __pyx_v_iii = 0;

  /* "pyproj/_crs.pyx":2641
 * 
 *         cdef int iii = 0
 *         cdef PJ * projobj = proj_crs_get_sub_crs(             # <<<<<<<<<<<<<<
 *             self.context,
 *             self.projobj,
*/
  __pyx_v_projobj = proj_crs_get_sub_crs(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj, __pyx_v_iii);

  /* "pyproj/_crs.pyx":2646
 *             iii,
 *         )
 *         self._sub_crs_list = []             # <<<<<<<<<<<<<<
 *         while projobj != NULL:
 *             try:
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->_sub_crs_list);
  __Pyx_DECREF(__pyx_v_self->_sub_crs_list);
  __pyx_v_self->_sub_crs_list = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2647
 *         )
 *         self._sub_crs_list = []
 *         while projobj != NULL:             # <<<<<<<<<<<<<<
 *             try:
 *                 self._sub_crs_list.append(_CRS(_to_wkt(
*/
  while (1) {
    __pyx_t_3 = (__pyx_v_projobj != NULL);
    if (!__pyx_t_3) break;

    /* "pyproj/_crs.pyx":2648
 *         self._sub_crs_list = []
 *         while projobj != NULL:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._sub_crs_list.append(_CRS(_to_wkt(
 *                     self.context,
*/
    /*try:*/ {

      /* "pyproj/_crs.pyx":2649
 *         while projobj != NULL:
 *             try:
 *                 self._sub_crs_list.append(_CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     projobj,
*/
      if (unlikely(__pyx_v_self->_sub_crs_list == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(0, 2649, __pyx_L10_error)
      }
      __pyx_t_4 = NULL;

      /* "pyproj/_crs.pyx":2652
 *                     self.context,
 *                     projobj,
 *                     version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                     pretty=False,
 *                 )))
*/
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2652, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2652, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "pyproj/_crs.pyx":2649
 *         while projobj != NULL:
 *             try:
 *                 self._sub_crs_list.append(_CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     projobj,
*/
      __pyx_t_5 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_projobj, __pyx_t_6, 0, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2649, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2649, __pyx_L10_error)
        __Pyx_GOTREF((PyObject *)__pyx_t_2);
      }
      __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_self->_sub_crs_list, ((PyObject *)__pyx_t_2)); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 2649, __pyx_L10_error)
      __Pyx_DECREF((PyObject *)__pyx_t_2); __pyx_t_2 = 0;
    }

    /* "pyproj/_crs.pyx":2656
 *                 )))
 *             finally:
 *                 proj_destroy(projobj)  # deallocate temp proj             # <<<<<<<<<<<<<<
 *             iii += 1
 *             projobj = proj_crs_get_sub_crs(
*/
    /*finally:*/ {
      /*normal exit:*/{
        proj_destroy(__pyx_v_projobj);
        goto __pyx_L11;
      }
      __pyx_L10_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __pyx_t_9 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
        {
          proj_destroy(__pyx_v_projobj);
        }
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
        __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
        goto __pyx_L1_error;
      }
      __pyx_L11:;
    }

    /* "pyproj/_crs.pyx":2657
 *             finally:
 *                 proj_destroy(projobj)  # deallocate temp proj
 *             iii += 1             # <<<<<<<<<<<<<<
 *             projobj = proj_crs_get_sub_crs(
 *                 self.context,
*/
    __pyx_v_iii = (__pyx_v_iii + 1);

    /* "pyproj/_crs.pyx":2658
 *                 proj_destroy(projobj)  # deallocate temp proj
 *             iii += 1
 *             projobj = proj_crs_get_sub_crs(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 self.projobj,
*/
    __pyx_v_projobj = proj_crs_get_sub_crs(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj, __pyx_v_iii);
  }

  /* "pyproj/_crs.pyx":2663
 *                 iii,
 *             )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return self._sub_crs_list
 * 
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2664
 *             )
 *         _clear_proj_error()
 *         return self._sub_crs_list             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_sub_crs_list);
  __pyx_r = __pyx_v_self->_sub_crs_list;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2625
 *         return self._target_crs
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def sub_crs_list(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyproj._crs._CRS.sub_crs_list.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2666
 *         return self._sub_crs_list
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def geodetic_crs(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12geodetic_crs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12geodetic_crs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_12geodetic_crs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12geodetic_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PJ *__pyx_v_projobj;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":2677
 *         _CRS
 *         """
 *         if self._geodetic_crs is not None:             # <<<<<<<<<<<<<<
 *             return self._geodetic_crs if self. _geodetic_crs is not False else None
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_geodetic_crs) != Py_None);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2678
 *         """
 *         if self._geodetic_crs is not None:
 *             return self._geodetic_crs if self. _geodetic_crs is not False else None             # <<<<<<<<<<<<<<
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)
 *         _clear_proj_error()
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_geodetic_crs) != Py_False);
    if (__pyx_t_1) {
      __Pyx_INCREF((PyObject *)__pyx_v_self->_geodetic_crs);
      __pyx_t_2 = ((PyObject *)__pyx_v_self->_geodetic_crs);
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_2 = Py_None;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2677
 *         _CRS
 *         """
 *         if self._geodetic_crs is not None:             # <<<<<<<<<<<<<<
 *             return self._geodetic_crs if self. _geodetic_crs is not False else None
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)
*/
  }

  /* "pyproj/_crs.pyx":2679
 *         if self._geodetic_crs is not None:
 *             return self._geodetic_crs if self. _geodetic_crs is not False else None
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)             # <<<<<<<<<<<<<<
 *         _clear_proj_error()
 *         if projobj == NULL:
*/
  __pyx_v_projobj = proj_crs_get_geodetic_crs(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2680
 *             return self._geodetic_crs if self. _geodetic_crs is not False else None
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if projobj == NULL:
 *             self._geodetic_crs = False
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2681
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             self._geodetic_crs = False
 *             return None
*/
  __pyx_t_1 = (__pyx_v_projobj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2682
 *         _clear_proj_error()
 *         if projobj == NULL:
 *             self._geodetic_crs = False             # <<<<<<<<<<<<<<
 *             return None
 *         try:
*/
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_geodetic_crs);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_geodetic_crs);
    __pyx_v_self->_geodetic_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_False);

    /* "pyproj/_crs.pyx":2683
 *         if projobj == NULL:
 *             self._geodetic_crs = False
 *             return None             # <<<<<<<<<<<<<<
 *         try:
 *             self._geodetic_crs = _CRS(_to_wkt(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2681
 *         cdef PJ * projobj = proj_crs_get_geodetic_crs(self.context, self.projobj)
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             self._geodetic_crs = False
 *             return None
*/
  }

  /* "pyproj/_crs.pyx":2684
 *             self._geodetic_crs = False
 *             return None
 *         try:             # <<<<<<<<<<<<<<
 *             self._geodetic_crs = _CRS(_to_wkt(
 *                 self.context,
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2685
 *             return None
 *         try:
 *             self._geodetic_crs = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_3 = NULL;

    /* "pyproj/_crs.pyx":2688
 *                 self.context,
 *                 projobj,
 *                 version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                 pretty=False,
 *             ))
*/
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2688, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2688, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyproj/_crs.pyx":2685
 *             return None
 *         try:
 *             self._geodetic_crs = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_4 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_projobj, __pyx_t_5, 0, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2685, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2685, __pyx_L6_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_2);
    }
    __Pyx_GIVEREF((PyObject *)__pyx_t_2);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_geodetic_crs);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_geodetic_crs);
    __pyx_v_self->_geodetic_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2692
 *             ))
 *         finally:
 *             proj_destroy(projobj)  # deallocate temp proj             # <<<<<<<<<<<<<<
 *         return self._geodetic_crs
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_projobj);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ( unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_7 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
      {
        proj_destroy(__pyx_v_projobj);
      }
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "pyproj/_crs.pyx":2693
 *         finally:
 *             proj_destroy(projobj)  # deallocate temp proj
 *         return self._geodetic_crs             # <<<<<<<<<<<<<<
 * 
 *     def to_proj4(self, version=ProjVersion.PROJ_4):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_geodetic_crs);
  __pyx_r = ((PyObject *)__pyx_v_self->_geodetic_crs);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2666
 *         return self._sub_crs_list
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def geodetic_crs(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs._CRS.geodetic_crs.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2695
 *         return self._geodetic_crs
 * 
 *     def to_proj4(self, version=ProjVersion.PROJ_4):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a PROJ string.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_5to_proj4(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_4to_proj4, "_CRS.to_proj4(self, version=ProjVersion.PROJ_4)\n\nConvert the projection to a PROJ string.\n\n.. warning:: You will likely lose important projection\n  information when converting to a PROJ string from\n  another format. See:\n  https://proj.org/faq.html#what-is-the-best-format-for-describing-coordinate-reference-systems\n\nParameters\n----------\nversion: pyproj.enums.ProjVersion, default=pyproj.enums.ProjVersion.PROJ_4\n    The version of the PROJ string output.\n\nReturns\n-------\nstr");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_5to_proj4 = {"to_proj4", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_5to_proj4, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_4to_proj4};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_5to_proj4(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_version = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_proj4 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_version,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2695, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2695, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_proj4", 0) < (0)) __PYX_ERR(0, 2695, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__12);
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2695, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(__pyx_mstate_global->__pyx_k__12);
    }
    __pyx_v_version = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_proj4", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2695, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.to_proj4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_4to_proj4(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_version);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_4to_proj4(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_version) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_proj4", 0);

  /* "pyproj/_crs.pyx":2713
 *         str
 *         """  # noqa: E501
 *         warnings.warn(             # <<<<<<<<<<<<<<
 *             "You will likely lose important projection information when "
 *             "converting to a PROJ string from another format. See: "
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_warnings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_warn); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
    __pyx_t_5 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_You_will_likely_lose_important_p};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":2719
 *             "coordinate-reference-systems"
 *         )
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=False)             # <<<<<<<<<<<<<<
 * 
 *     def to_epsg(self, int min_confidence=70):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pyproj_4_crs__to_proj4(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj, __pyx_v_version, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2695
 *         return self._geodetic_crs
 * 
 *     def to_proj4(self, version=ProjVersion.PROJ_4):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a PROJ string.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs._CRS.to_proj4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2721
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=False)
 * 
 *     def to_epsg(self, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         Return the EPSG code best matching the CRS
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_7to_epsg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_6to_epsg, "_CRS.to_epsg(self, int min_confidence=70)\n\nReturn the EPSG code best matching the CRS\nor None if it a match is not found.\n\nExample:\n\n>>> from pyproj import CRS\n>>> ccs = CRS(\"EPSG:4328\")\n>>> ccs.to_epsg()\n4328\n\nIf the CRS is bound, you can attempt to get an epsg code from\nthe source CRS:\n\n>>> from pyproj import CRS\n>>> ccs = CRS(\"+proj=geocent +datum=WGS84 +towgs84=0,0,0\")\n>>> ccs.to_epsg()\n>>> ccs.source_crs.to_epsg()\n4978\n>>> ccs == CRS.from_epsg(4978)\nFalse\n\nParameters\n----------\nmin_confidence: int, default=70\n    A value between 0-100 where 100 is the most confident.\n    :ref:`min_confidence`\n\n\nReturns\n-------\nint | None:\n    The best matching EPSG code matching the confidence level.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_7to_epsg = {"to_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_7to_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_6to_epsg};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_7to_epsg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_min_confidence;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_epsg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_min_confidence,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2721, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2721, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_epsg", 0) < (0)) __PYX_ERR(0, 2721, __pyx_L3_error)
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2721, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_min_confidence = __Pyx_PyLong_As_int(values[0]); if (unlikely((__pyx_v_min_confidence == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2721, __pyx_L3_error)
    } else {
      __pyx_v_min_confidence = ((int)70);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_epsg", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2721, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.to_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_6to_epsg(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_min_confidence);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_6to_epsg(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, int __pyx_v_min_confidence) {
  PyObject *__pyx_v_auth_info = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_epsg", 0);

  /* "pyproj/_crs.pyx":2756
 *             The best matching EPSG code matching the confidence level.
 *         """
 *         auth_info = self.to_authority(             # <<<<<<<<<<<<<<
 *             auth_name="EPSG",
 *             min_confidence=min_confidence
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":2758
 *         auth_info = self.to_authority(
 *             auth_name="EPSG",
 *             min_confidence=min_confidence             # <<<<<<<<<<<<<<
 *         )
 *         if auth_info is not None and auth_info[0].upper() == "EPSG":
*/
  __pyx_t_3 = __Pyx_PyLong_From_int(__pyx_v_min_confidence); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2758, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_auth_name, __pyx_mstate_global->__pyx_n_u_EPSG, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 2756, __pyx_L1_error)
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_min_confidence, __pyx_t_3, __pyx_t_5, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 2756, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_to_authority, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2756, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_auth_info = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":2760
 *             min_confidence=min_confidence
 *         )
 *         if auth_info is not None and auth_info[0].upper() == "EPSG":             # <<<<<<<<<<<<<<
 *             return int(auth_info[1])
 *         return None
*/
  __pyx_t_7 = (__pyx_v_auth_info != Py_None);
  if (__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_auth_info, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_upper, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_EPSG, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_6) {

    /* "pyproj/_crs.pyx":2761
 *         )
 *         if auth_info is not None and auth_info[0].upper() == "EPSG":
 *             return int(auth_info[1])             # <<<<<<<<<<<<<<
 *         return None
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_auth_info, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2760
 *             min_confidence=min_confidence
 *         )
 *         if auth_info is not None and auth_info[0].upper() == "EPSG":             # <<<<<<<<<<<<<<
 *             return int(auth_info[1])
 *         return None
*/
  }

  /* "pyproj/_crs.pyx":2762
 *         if auth_info is not None and auth_info[0].upper() == "EPSG":
 *             return int(auth_info[1])
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def to_authority(self, str auth_name=None, int min_confidence=70):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2721
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=False)
 * 
 *     def to_epsg(self, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         Return the EPSG code best matching the CRS
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyproj._crs._CRS.to_epsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_auth_info);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2764
 *         return None
 * 
 *     def to_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.2.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9to_authority(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_8to_authority, "_CRS.to_authority(self, str auth_name=None, int min_confidence=70)\n\n.. versionadded:: 2.2.0\n\nReturn the authority name and code best matching the CRS\nor None if it a match is not found.\n\nExample:\n\n>>> from pyproj import CRS\n>>> ccs = CRS(\"EPSG:4328\")\n>>> ccs.to_authority()\n('EPSG', '4328')\n\nIf the CRS is bound, you can get an authority from\nthe source CRS:\n\n>>> from pyproj import CRS\n>>> ccs = CRS(\"+proj=geocent +datum=WGS84 +towgs84=0,0,0\")\n>>> ccs.to_authority()\n>>> ccs.source_crs.to_authority()\n('EPSG', '4978')\n>>> ccs == CRS.from_authorty('EPSG', '4978')\nFalse\n\nParameters\n----------\nauth_name: str, optional\n    The name of the authority to filter by.\nmin_confidence: int, default=70\n    A value between 0-100 where 100 is the most confident.\n    :ref:`min_confidence`\n\nReturns\n-------\ntuple(str, str) or None:\n    The best matching (<auth_name>, <code>) for the confidence level.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_9to_authority = {"to_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_9to_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_8to_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_9to_authority(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  int __pyx_v_min_confidence;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_min_confidence,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2764, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2764, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2764, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_authority", 0) < (0)) __PYX_ERR(0, 2764, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2764, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2764, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_min_confidence = __Pyx_PyLong_As_int(values[1]); if (unlikely((__pyx_v_min_confidence == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2764, __pyx_L3_error)
    } else {
      __pyx_v_min_confidence = ((int)70);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_authority", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 2764, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.to_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 2764, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_8to_authority(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_auth_name, __pyx_v_min_confidence);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_8to_authority(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_auth_name, int __pyx_v_min_confidence) {
  PyObject *__pyx_v_authority = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_authority", 0);

  /* "pyproj/_crs.pyx":2802
 *             The best matching (<auth_name>, <code>) for the confidence level.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             authority = self.list_authority(
 *                 auth_name=auth_name, min_confidence=min_confidence,
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pyproj/_crs.pyx":2803
 *         """
 *         try:
 *             authority = self.list_authority(             # <<<<<<<<<<<<<<
 *                 auth_name=auth_name, min_confidence=min_confidence,
 *             )[0]
*/
      __pyx_t_5 = ((PyObject *)__pyx_v_self);
      __Pyx_INCREF(__pyx_t_5);

      /* "pyproj/_crs.pyx":2804
 *         try:
 *             authority = self.list_authority(
 *                 auth_name=auth_name, min_confidence=min_confidence,             # <<<<<<<<<<<<<<
 *             )[0]
 *             return authority.auth_name, authority.code
*/
      __pyx_t_6 = __Pyx_PyLong_From_int(__pyx_v_min_confidence); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2804, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = 0;
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 2 : 0)] = {__pyx_t_5, NULL};
        __pyx_t_8 = __Pyx_MakeVectorcallBuilderKwds(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2803, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_auth_name, __pyx_v_auth_name, __pyx_t_8, __pyx_callargs+1, 0) < (0)) __PYX_ERR(0, 2803, __pyx_L3_error)
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_min_confidence, __pyx_t_6, __pyx_t_8, __pyx_callargs+1, 1) < (0)) __PYX_ERR(0, 2803, __pyx_L3_error)
        __pyx_t_4 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_list_authority, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_8);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2803, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      }

      /* "pyproj/_crs.pyx":2805
 *             authority = self.list_authority(
 *                 auth_name=auth_name, min_confidence=min_confidence,
 *             )[0]             # <<<<<<<<<<<<<<
 *             return authority.auth_name, authority.code
 *         except IndexError:
*/
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2805, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_authority = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "pyproj/_crs.pyx":2806
 *                 auth_name=auth_name, min_confidence=min_confidence,
 *             )[0]
 *             return authority.auth_name, authority.code             # <<<<<<<<<<<<<<
 *         except IndexError:
 *             return None
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_authority, __pyx_mstate_global->__pyx_n_u_auth_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2806, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_authority, __pyx_mstate_global->__pyx_n_u_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2806, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2806, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_8);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_8) != (0)) __PYX_ERR(0, 2806, __pyx_L3_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 2806, __pyx_L3_error);
      __pyx_t_8 = 0;
      __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "pyproj/_crs.pyx":2802
 *             The best matching (<auth_name>, <code>) for the confidence level.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             authority = self.list_authority(
 *                 auth_name=auth_name, min_confidence=min_confidence,
*/
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pyproj/_crs.pyx":2807
 *             )[0]
 *             return authority.auth_name, authority.code
 *         except IndexError:             # <<<<<<<<<<<<<<
 *             return None
 * 
*/
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_IndexError))));
    if (__pyx_t_9) {
      __Pyx_ErrRestore(0,0,0);

      /* "pyproj/_crs.pyx":2808
 *             return authority.auth_name, authority.code
 *         except IndexError:
 *             return None             # <<<<<<<<<<<<<<
 * 
 *     def list_authority(self, str auth_name=None, int min_confidence=70):
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "pyproj/_crs.pyx":2802
 *             The best matching (<auth_name>, <code>) for the confidence level.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             authority = self.list_authority(
 *                 auth_name=auth_name, min_confidence=min_confidence,
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "pyproj/_crs.pyx":2764
 *         return None
 * 
 *     def to_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.2.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs._CRS.to_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_authority);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2810
 *             return None
 * 
 *     def list_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.2.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11list_authority(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_10list_authority, "_CRS.list_authority(self, str auth_name=None, int min_confidence=70)\n\n.. versionadded:: 3.2.0\n\nReturn the authority names and codes best matching the CRS.\n\nExample:\n\n>>> from pyproj import CRS\n>>> ccs = CRS(\"EPSG:4328\")\n>>> ccs.list_authority()\n[AuthorityMatchInfo(auth_name='EPSG', code='4326', confidence=100)]\n\nIf the CRS is bound, you can get an authority from\nthe source CRS:\n\n>>> from pyproj import CRS\n>>> ccs = CRS(\"+proj=geocent +datum=WGS84 +towgs84=0,0,0\")\n>>> ccs.list_authority()\n[]\n>>> ccs.source_crs.list_authority()\n[AuthorityMatchInfo(auth_name='EPSG', code='4978', confidence=70)]\n>>> ccs == CRS.from_authorty('EPSG', '4978')\nFalse\n\nParameters\n----------\nauth_name: str, optional\n    The name of the authority to filter by.\nmin_confidence: int, default=70\n    A value between 0-100 where 100 is the most confident.\n    :ref:`min_confidence`\n\nReturns\n-------\nlist[AuthorityMatchInfo]:\n    List of authority matches for the CRS.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_11list_authority = {"list_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_11list_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_10list_authority};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11list_authority(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_auth_name = 0;
  int __pyx_v_min_confidence;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("list_authority (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_auth_name,&__pyx_mstate_global->__pyx_n_u_min_confidence,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2810, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2810, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2810, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "list_authority", 0) < (0)) __PYX_ERR(0, 2810, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2810, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2810, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_auth_name = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_min_confidence = __Pyx_PyLong_As_int(values[1]); if (unlikely((__pyx_v_min_confidence == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2810, __pyx_L3_error)
    } else {
      __pyx_v_min_confidence = ((int)70);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("list_authority", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 2810, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.list_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_auth_name), (&PyUnicode_Type), 1, "auth_name", 1))) __PYX_ERR(0, 2810, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_10list_authority(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_auth_name, __pyx_v_min_confidence);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10list_authority(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_auth_name, int __pyx_v_min_confidence) {
  PJ_OBJ_LIST *__pyx_v_proj_list;
  int *__pyx_v_c_out_confidence_list;
  int __pyx_v_num_proj_objects;
  PyObject *__pyx_v_b_auth_name = 0;
  char *__pyx_v_user_auth_name;
  int __pyx_v_iii;
  PyObject *__pyx_v_out_confidence_list = NULL;
  PJ *__pyx_v_proj;
  char const *__pyx_v_code;
  char const *__pyx_v_out_auth_name;
  PyObject *__pyx_v_authority_list = NULL;
  int __pyx_8genexpr2__pyx_v_iii;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  size_t __pyx_t_20;
  int __pyx_t_21;
  char const *__pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_authority", 0);

  /* "pyproj/_crs.pyx":2849
 *         """
 *         # get list of possible matching projections
 *         cdef PJ_OBJ_LIST *proj_list = NULL             # <<<<<<<<<<<<<<
 *         cdef int *c_out_confidence_list = NULL
 *         cdef int num_proj_objects = -9999
*/
  __pyx_v_proj_list = NULL;

  /* "pyproj/_crs.pyx":2850
 *         # get list of possible matching projections
 *         cdef PJ_OBJ_LIST *proj_list = NULL
 *         cdef int *c_out_confidence_list = NULL             # <<<<<<<<<<<<<<
 *         cdef int num_proj_objects = -9999
 *         cdef bytes b_auth_name
*/
  __pyx_v_c_out_confidence_list = NULL;

  /* "pyproj/_crs.pyx":2851
 *         cdef PJ_OBJ_LIST *proj_list = NULL
 *         cdef int *c_out_confidence_list = NULL
 *         cdef int num_proj_objects = -9999             # <<<<<<<<<<<<<<
 *         cdef bytes b_auth_name
 *         cdef char *user_auth_name = NULL
*/
  __pyx_v_num_proj_objects = -9999;

  /* "pyproj/_crs.pyx":2853
 *         cdef int num_proj_objects = -9999
 *         cdef bytes b_auth_name
 *         cdef char *user_auth_name = NULL             # <<<<<<<<<<<<<<
 *         cdef int iii = 0
 * 
*/
  __pyx_v_user_auth_name = NULL;

  /* "pyproj/_crs.pyx":2854
 *         cdef bytes b_auth_name
 *         cdef char *user_auth_name = NULL
 *         cdef int iii = 0             # <<<<<<<<<<<<<<
 * 
 *         if auth_name is not None:
*/
  __pyx_v_iii = 0;

  /* "pyproj/_crs.pyx":2856
 *         cdef int iii = 0
 * 
 *         if auth_name is not None:             # <<<<<<<<<<<<<<
 *             b_auth_name = cstrencode(auth_name)
 *             user_auth_name = b_auth_name
*/
  __pyx_t_1 = (__pyx_v_auth_name != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2857
 * 
 *         if auth_name is not None:
 *             b_auth_name = cstrencode(auth_name)             # <<<<<<<<<<<<<<
 *             user_auth_name = b_auth_name
 * 
*/
    __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_auth_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_b_auth_name = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":2858
 *         if auth_name is not None:
 *             b_auth_name = cstrencode(auth_name)
 *             user_auth_name = b_auth_name             # <<<<<<<<<<<<<<
 * 
 *         out_confidence_list = []
*/
    if (unlikely(__pyx_v_b_auth_name == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 2858, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyBytes_AsWritableString(__pyx_v_b_auth_name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 2858, __pyx_L1_error)
    __pyx_v_user_auth_name = __pyx_t_3;

    /* "pyproj/_crs.pyx":2856
 *         cdef int iii = 0
 * 
 *         if auth_name is not None:             # <<<<<<<<<<<<<<
 *             b_auth_name = cstrencode(auth_name)
 *             user_auth_name = b_auth_name
*/
  }

  /* "pyproj/_crs.pyx":2860
 *             user_auth_name = b_auth_name
 * 
 *         out_confidence_list = []             # <<<<<<<<<<<<<<
 *         try:
 *             proj_list = proj_identify(
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_out_confidence_list = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2861
 * 
 *         out_confidence_list = []
 *         try:             # <<<<<<<<<<<<<<
 *             proj_list = proj_identify(
 *                 self.context,
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2862
 *         out_confidence_list = []
 *         try:
 *             proj_list = proj_identify(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 self.projobj,
*/
    __pyx_v_proj_list = proj_identify(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj, __pyx_v_user_auth_name, NULL, (&__pyx_v_c_out_confidence_list));

    /* "pyproj/_crs.pyx":2869
 *                 &c_out_confidence_list
 *             )
 *             if proj_list != NULL:             # <<<<<<<<<<<<<<
 *                 num_proj_objects = proj_list_get_count(proj_list)
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:
*/
    __pyx_t_1 = (__pyx_v_proj_list != NULL);
    if (__pyx_t_1) {

      /* "pyproj/_crs.pyx":2870
 *             )
 *             if proj_list != NULL:
 *                 num_proj_objects = proj_list_get_count(proj_list)             # <<<<<<<<<<<<<<
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:
 *                 out_confidence_list = [
*/
      __pyx_v_num_proj_objects = proj_list_get_count(__pyx_v_proj_list);

      /* "pyproj/_crs.pyx":2869
 *                 &c_out_confidence_list
 *             )
 *             if proj_list != NULL:             # <<<<<<<<<<<<<<
 *                 num_proj_objects = proj_list_get_count(proj_list)
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:
*/
    }

    /* "pyproj/_crs.pyx":2871
 *             if proj_list != NULL:
 *                 num_proj_objects = proj_list_get_count(proj_list)
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:             # <<<<<<<<<<<<<<
 *                 out_confidence_list = [
 *                     c_out_confidence_list[iii] for iii in range(num_proj_objects)
*/
    __pyx_t_4 = (__pyx_v_c_out_confidence_list != NULL);
    if (__pyx_t_4) {
    } else {
      __pyx_t_1 = __pyx_t_4;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_4 = (__pyx_v_num_proj_objects > 0);
    __pyx_t_1 = __pyx_t_4;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_1) {

      /* "pyproj/_crs.pyx":2872
 *                 num_proj_objects = proj_list_get_count(proj_list)
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:
 *                 out_confidence_list = [             # <<<<<<<<<<<<<<
 *                     c_out_confidence_list[iii] for iii in range(num_proj_objects)
 *                 ]
*/
      { /* enter inner scope */
        __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2872, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "pyproj/_crs.pyx":2873
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:
 *                 out_confidence_list = [
 *                     c_out_confidence_list[iii] for iii in range(num_proj_objects)             # <<<<<<<<<<<<<<
 *                 ]
 *         finally:
*/
        __pyx_t_5 = __pyx_v_num_proj_objects;
        __pyx_t_6 = __pyx_t_5;
        for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
          __pyx_8genexpr2__pyx_v_iii = __pyx_t_7;
          __pyx_t_8 = __Pyx_PyLong_From_int((__pyx_v_c_out_confidence_list[__pyx_8genexpr2__pyx_v_iii])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2873, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 2872, __pyx_L5_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      } /* exit inner scope */
      __Pyx_DECREF_SET(__pyx_v_out_confidence_list, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "pyproj/_crs.pyx":2871
 *             if proj_list != NULL:
 *                 num_proj_objects = proj_list_get_count(proj_list)
 *             if c_out_confidence_list != NULL and num_proj_objects > 0:             # <<<<<<<<<<<<<<
 *                 out_confidence_list = [
 *                     c_out_confidence_list[iii] for iii in range(num_proj_objects)
*/
    }
  }

  /* "pyproj/_crs.pyx":2876
 *                 ]
 *         finally:
 *             if c_out_confidence_list != NULL:             # <<<<<<<<<<<<<<
 *                 proj_int_list_destroy(c_out_confidence_list)
 *             _clear_proj_error()
*/
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_1 = (__pyx_v_c_out_confidence_list != NULL);
      if (__pyx_t_1) {

        /* "pyproj/_crs.pyx":2877
 *         finally:
 *             if c_out_confidence_list != NULL:
 *                 proj_int_list_destroy(c_out_confidence_list)             # <<<<<<<<<<<<<<
 *             _clear_proj_error()
 * 
*/
        proj_int_list_destroy(__pyx_v_c_out_confidence_list);

        /* "pyproj/_crs.pyx":2876
 *                 ]
 *         finally:
 *             if c_out_confidence_list != NULL:             # <<<<<<<<<<<<<<
 *                 proj_int_list_destroy(c_out_confidence_list)
 *             _clear_proj_error()
*/
      }

      /* "pyproj/_crs.pyx":2878
 *             if c_out_confidence_list != NULL:
 *                 proj_int_list_destroy(c_out_confidence_list)
 *             _clear_proj_error()             # <<<<<<<<<<<<<<
 * 
 *         # retrieve the best matching projection
*/
      __pyx_f_6pyproj_8_context__clear_proj_error(0);
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ( unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_5 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
      {

        /* "pyproj/_crs.pyx":2876
 *                 ]
 *         finally:
 *             if c_out_confidence_list != NULL:             # <<<<<<<<<<<<<<
 *                 proj_int_list_destroy(c_out_confidence_list)
 *             _clear_proj_error()
*/
        __pyx_t_1 = (__pyx_v_c_out_confidence_list != NULL);
        if (__pyx_t_1) {

          /* "pyproj/_crs.pyx":2877
 *         finally:
 *             if c_out_confidence_list != NULL:
 *                 proj_int_list_destroy(c_out_confidence_list)             # <<<<<<<<<<<<<<
 *             _clear_proj_error()
 * 
*/
          proj_int_list_destroy(__pyx_v_c_out_confidence_list);

          /* "pyproj/_crs.pyx":2876
 *                 ]
 *         finally:
 *             if c_out_confidence_list != NULL:             # <<<<<<<<<<<<<<
 *                 proj_int_list_destroy(c_out_confidence_list)
 *             _clear_proj_error()
*/
        }

        /* "pyproj/_crs.pyx":2878
 *             if c_out_confidence_list != NULL:
 *                 proj_int_list_destroy(c_out_confidence_list)
 *             _clear_proj_error()             # <<<<<<<<<<<<<<
 * 
 *         # retrieve the best matching projection
*/
        __pyx_f_6pyproj_8_context__clear_proj_error(0);
      }
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_9;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "pyproj/_crs.pyx":2881
 * 
 *         # retrieve the best matching projection
 *         cdef PJ* proj = NULL             # <<<<<<<<<<<<<<
 *         cdef const char* code
 *         cdef const char* out_auth_name
*/
  __pyx_v_proj = NULL;

  /* "pyproj/_crs.pyx":2884
 *         cdef const char* code
 *         cdef const char* out_auth_name
 *         authority_list = []             # <<<<<<<<<<<<<<
 *         try:
 *             for iii in range(num_proj_objects):
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_authority_list = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2885
 *         cdef const char* out_auth_name
 *         authority_list = []
 *         try:             # <<<<<<<<<<<<<<
 *             for iii in range(num_proj_objects):
 *                 if out_confidence_list[iii] < min_confidence:
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2886
 *         authority_list = []
 *         try:
 *             for iii in range(num_proj_objects):             # <<<<<<<<<<<<<<
 *                 if out_confidence_list[iii] < min_confidence:
 *                     continue
*/
    __pyx_t_6 = __pyx_v_num_proj_objects;
    __pyx_t_5 = __pyx_t_6;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_5; __pyx_t_7+=1) {
      __pyx_v_iii = __pyx_t_7;

      /* "pyproj/_crs.pyx":2887
 *         try:
 *             for iii in range(num_proj_objects):
 *                 if out_confidence_list[iii] < min_confidence:             # <<<<<<<<<<<<<<
 *                     continue
 *                 proj = proj_list_get(self.context, proj_list, iii)
*/
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_out_confidence_list, __pyx_v_iii, int, 1, __Pyx_PyLong_From_int, 1, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2887, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyLong_From_int(__pyx_v_min_confidence); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2887, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_16 = PyObject_RichCompare(__pyx_t_2, __pyx_t_8, Py_LT); __Pyx_XGOTREF(__pyx_t_16); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2887, __pyx_L18_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2887, __pyx_L18_error)
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      if (__pyx_t_1) {

        /* "pyproj/_crs.pyx":2888
 *             for iii in range(num_proj_objects):
 *                 if out_confidence_list[iii] < min_confidence:
 *                     continue             # <<<<<<<<<<<<<<
 *                 proj = proj_list_get(self.context, proj_list, iii)
 *                 code = proj_get_id_code(proj, 0)
*/
        goto __pyx_L20_continue;

        /* "pyproj/_crs.pyx":2887
 *         try:
 *             for iii in range(num_proj_objects):
 *                 if out_confidence_list[iii] < min_confidence:             # <<<<<<<<<<<<<<
 *                     continue
 *                 proj = proj_list_get(self.context, proj_list, iii)
*/
      }

      /* "pyproj/_crs.pyx":2889
 *                 if out_confidence_list[iii] < min_confidence:
 *                     continue
 *                 proj = proj_list_get(self.context, proj_list, iii)             # <<<<<<<<<<<<<<
 *                 code = proj_get_id_code(proj, 0)
 *                 out_auth_name = proj_get_id_auth_name(proj, 0)
*/
      __pyx_v_proj = proj_list_get(__pyx_v_self->__pyx_base.context, __pyx_v_proj_list, __pyx_v_iii);

      /* "pyproj/_crs.pyx":2890
 *                     continue
 *                 proj = proj_list_get(self.context, proj_list, iii)
 *                 code = proj_get_id_code(proj, 0)             # <<<<<<<<<<<<<<
 *                 out_auth_name = proj_get_id_auth_name(proj, 0)
 *                 if out_auth_name != NULL and code != NULL:
*/
      __pyx_v_code = proj_get_id_code(__pyx_v_proj, 0);

      /* "pyproj/_crs.pyx":2891
 *                 proj = proj_list_get(self.context, proj_list, iii)
 *                 code = proj_get_id_code(proj, 0)
 *                 out_auth_name = proj_get_id_auth_name(proj, 0)             # <<<<<<<<<<<<<<
 *                 if out_auth_name != NULL and code != NULL:
 *                     authority_list.append(
*/
      __pyx_v_out_auth_name = proj_get_id_auth_name(__pyx_v_proj, 0);

      /* "pyproj/_crs.pyx":2892
 *                 code = proj_get_id_code(proj, 0)
 *                 out_auth_name = proj_get_id_auth_name(proj, 0)
 *                 if out_auth_name != NULL and code != NULL:             # <<<<<<<<<<<<<<
 *                     authority_list.append(
 *                         AuthorityMatchInfo(
*/
      __pyx_t_4 = (__pyx_v_out_auth_name != NULL);
      if (__pyx_t_4) {
      } else {
        __pyx_t_1 = __pyx_t_4;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_4 = (__pyx_v_code != NULL);
      __pyx_t_1 = __pyx_t_4;
      __pyx_L24_bool_binop_done:;
      if (__pyx_t_1) {

        /* "pyproj/_crs.pyx":2894
 *                 if out_auth_name != NULL and code != NULL:
 *                     authority_list.append(
 *                         AuthorityMatchInfo(             # <<<<<<<<<<<<<<
 *                             out_auth_name,
 *                             code,
*/
        __pyx_t_8 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_AuthorityMatchInfo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2894, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "pyproj/_crs.pyx":2895
 *                     authority_list.append(
 *                         AuthorityMatchInfo(
 *                             out_auth_name,             # <<<<<<<<<<<<<<
 *                             code,
 *                             out_confidence_list[iii]
*/
        __pyx_t_17 = __Pyx_PyUnicode_FromString(__pyx_v_out_auth_name); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 2895, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_17);

        /* "pyproj/_crs.pyx":2896
 *                         AuthorityMatchInfo(
 *                             out_auth_name,
 *                             code,             # <<<<<<<<<<<<<<
 *                             out_confidence_list[iii]
 *                         )
*/
        __pyx_t_18 = __Pyx_PyUnicode_FromString(__pyx_v_code); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 2896, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_18);

        /* "pyproj/_crs.pyx":2897
 *                             out_auth_name,
 *                             code,
 *                             out_confidence_list[iii]             # <<<<<<<<<<<<<<
 *                         )
 *                     )
*/
        __pyx_t_19 = __Pyx_GetItemInt_List(__pyx_v_out_confidence_list, __pyx_v_iii, int, 1, __Pyx_PyLong_From_int, 1, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 2897, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_19);
        __pyx_t_20 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
          assert(__pyx_t_8);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
          __pyx_t_20 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_t_17, __pyx_t_18, __pyx_t_19};
          __pyx_t_16 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_20, (4-__pyx_t_20) | (__pyx_t_20*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 2894, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_16);
        }

        /* "pyproj/_crs.pyx":2893
 *                 out_auth_name = proj_get_id_auth_name(proj, 0)
 *                 if out_auth_name != NULL and code != NULL:
 *                     authority_list.append(             # <<<<<<<<<<<<<<
 *                         AuthorityMatchInfo(
 *                             out_auth_name,
*/
        __pyx_t_21 = __Pyx_PyList_Append(__pyx_v_authority_list, __pyx_t_16); if (unlikely(__pyx_t_21 == ((int)-1))) __PYX_ERR(0, 2893, __pyx_L18_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

        /* "pyproj/_crs.pyx":2892
 *                 code = proj_get_id_code(proj, 0)
 *                 out_auth_name = proj_get_id_auth_name(proj, 0)
 *                 if out_auth_name != NULL and code != NULL:             # <<<<<<<<<<<<<<
 *                     authority_list.append(
 *                         AuthorityMatchInfo(
*/
      }

      /* "pyproj/_crs.pyx":2901
 *                     )
 *                 # at this point, the auth name is copied and we can release the proj object
 *                 proj_destroy(proj)             # <<<<<<<<<<<<<<
 *                 proj = NULL
 *         finally:
*/
      proj_destroy(__pyx_v_proj);

      /* "pyproj/_crs.pyx":2902
 *                 # at this point, the auth name is copied and we can release the proj object
 *                 proj_destroy(proj)
 *                 proj = NULL             # <<<<<<<<<<<<<<
 *         finally:
 *             # If there was an error we have to call proj_destroy
*/
      __pyx_v_proj = NULL;
      __pyx_L20_continue:;
    }
  }

  /* "pyproj/_crs.pyx":2906
 *             # If there was an error we have to call proj_destroy
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)             # <<<<<<<<<<<<<<
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_proj);

      /* "pyproj/_crs.pyx":2907
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)             # <<<<<<<<<<<<<<
 *             _clear_proj_error()
 *         return authority_list
*/
      proj_list_destroy(__pyx_v_proj_list);

      /* "pyproj/_crs.pyx":2908
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return authority_list
 * 
*/
      __pyx_f_6pyproj_8_context__clear_proj_error(0);
      goto __pyx_L19;
    }
    __pyx_L18_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if ( unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_10);
      __pyx_t_6 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
      {

        /* "pyproj/_crs.pyx":2906
 *             # If there was an error we have to call proj_destroy
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)             # <<<<<<<<<<<<<<
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()
*/
        proj_destroy(__pyx_v_proj);

        /* "pyproj/_crs.pyx":2907
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)             # <<<<<<<<<<<<<<
 *             _clear_proj_error()
 *         return authority_list
*/
        proj_list_destroy(__pyx_v_proj_list);

        /* "pyproj/_crs.pyx":2908
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()             # <<<<<<<<<<<<<<
 *         return authority_list
 * 
*/
        __pyx_f_6pyproj_8_context__clear_proj_error(0);
      }
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
      __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_22;
      goto __pyx_L1_error;
    }
    __pyx_L19:;
  }

  /* "pyproj/_crs.pyx":2909
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()
 *         return authority_list             # <<<<<<<<<<<<<<
 * 
 *     def to_3d(self, str name=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_authority_list);
  __pyx_r = __pyx_v_authority_list;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2810
 *             return None
 * 
 *     def list_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.2.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("pyproj._crs._CRS.list_authority", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_b_auth_name);
  __Pyx_XDECREF(__pyx_v_out_confidence_list);
  __Pyx_XDECREF(__pyx_v_authority_list);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2911
 *         return authority_list
 * 
 *     def to_3d(self, str name=None):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.1.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13to_3d(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_12to_3d, "_CRS.to_3d(self, str name=None)\n\n.. versionadded:: 3.1.0\n\nConvert the current CRS to the 3D version if it makes sense.\n\nNew vertical axis attributes:\n  - ellipsoidal height\n  - oriented upwards\n  - metre units\n\nParameters\n----------\nname: str, optional\n    CRS name. If None, it will use the name of the original CRS.\n\nReturns\n-------\n_CRS");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_13to_3d = {"to_3d", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_13to_3d, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_12to_3d};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13to_3d(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_3d (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2911, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2911, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_3d", 0) < (0)) __PYX_ERR(0, 2911, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2911, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_name = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_3d", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2911, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.to_3d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_name), (&PyUnicode_Type), 1, "name", 1))) __PYX_ERR(0, 2911, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_12to_3d(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_name);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12to_3d(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_name) {
  char *__pyx_v_c_name;
  PyObject *__pyx_v_b_name = 0;
  PJ *__pyx_v_projobj;
  struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_crs_3d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_3d", 0);

  /* "pyproj/_crs.pyx":2931
 *         _CRS
 *         """
 *         cdef char* c_name = NULL             # <<<<<<<<<<<<<<
 *         cdef bytes b_name
 *         if name is not None:
*/
  __pyx_v_c_name = NULL;

  /* "pyproj/_crs.pyx":2933
 *         cdef char* c_name = NULL
 *         cdef bytes b_name
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             b_name = cstrencode(name)
 *             c_name = b_name
*/
  __pyx_t_1 = (__pyx_v_name != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2934
 *         cdef bytes b_name
 *         if name is not None:
 *             b_name = cstrencode(name)             # <<<<<<<<<<<<<<
 *             c_name = b_name
 * 
*/
    __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_b_name = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":2935
 *         if name is not None:
 *             b_name = cstrencode(name)
 *             c_name = b_name             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ * projobj = proj_crs_promote_to_3D(
*/
    if (unlikely(__pyx_v_b_name == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 2935, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyBytes_AsWritableString(__pyx_v_b_name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 2935, __pyx_L1_error)
    __pyx_v_c_name = __pyx_t_3;

    /* "pyproj/_crs.pyx":2933
 *         cdef char* c_name = NULL
 *         cdef bytes b_name
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             b_name = cstrencode(name)
 *             c_name = b_name
*/
  }

  /* "pyproj/_crs.pyx":2937
 *             c_name = b_name
 * 
 *         cdef PJ * projobj = proj_crs_promote_to_3D(             # <<<<<<<<<<<<<<
 *             self.context, c_name, self.projobj
 *         )
*/
  __pyx_v_projobj = proj_crs_promote_to_3D(__pyx_v_self->__pyx_base.context, __pyx_v_c_name, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2940
 *             self.context, c_name, self.projobj
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if projobj == NULL:
 *             return self
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2941
 *         )
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             return self
 *         try:
*/
  __pyx_t_1 = (__pyx_v_projobj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2942
 *         _clear_proj_error()
 *         if projobj == NULL:
 *             return self             # <<<<<<<<<<<<<<
 *         try:
 *             crs_3d = _CRS(_to_wkt(
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __pyx_r = ((PyObject *)__pyx_v_self);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2941
 *         )
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             return self
 *         try:
*/
  }

  /* "pyproj/_crs.pyx":2943
 *         if projobj == NULL:
 *             return self
 *         try:             # <<<<<<<<<<<<<<
 *             crs_3d = _CRS(_to_wkt(
 *                 self.context,
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2944
 *             return self
 *         try:
 *             crs_3d = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_4 = NULL;

    /* "pyproj/_crs.pyx":2947
 *                 self.context,
 *                 projobj,
 *                 version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                 pretty=False,
 *             ))
*/
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2947, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2947, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":2944
 *             return self
 *         try:
 *             crs_3d = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_5 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_projobj, __pyx_t_6, 0, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2944, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2944, __pyx_L6_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_2);
    }
    __pyx_v_crs_3d = ((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2951
 *             ))
 *         finally:
 *             proj_destroy(projobj)             # <<<<<<<<<<<<<<
 *         return crs_3d
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_projobj);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      if ( unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_8 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
      {
        proj_destroy(__pyx_v_projobj);
      }
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "pyproj/_crs.pyx":2952
 *         finally:
 *             proj_destroy(projobj)
 *         return crs_3d             # <<<<<<<<<<<<<<
 * 
 *     def to_2d(self, str name=None):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_crs_3d);
  __pyx_r = ((PyObject *)__pyx_v_crs_3d);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2911
 *         return authority_list
 * 
 *     def to_3d(self, str name=None):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.1.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyproj._crs._CRS.to_3d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_b_name);
  __Pyx_XDECREF((PyObject *)__pyx_v_crs_3d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2954
 *         return crs_3d
 * 
 *     def to_2d(self, str name=None):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.6.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_15to_2d(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_14to_2d, "_CRS.to_2d(self, str name=None)\n\n.. versionadded:: 3.6.0\n\nConvert the current CRS to the 2D version if it makes sense.\n\nParameters\n----------\nname: str, optional\n    CRS name. If None, it will use the name of the original CRS.\n\nReturns\n-------\n_CRS");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_15to_2d = {"to_2d", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_15to_2d, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_14to_2d};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_15to_2d(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_2d (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_name,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2954, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2954, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "to_2d", 0) < (0)) __PYX_ERR(0, 2954, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2954, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject*)Py_None));
    }
    __pyx_v_name = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_2d", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2954, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.to_2d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_name), (&PyUnicode_Type), 1, "name", 1))) __PYX_ERR(0, 2954, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_14to_2d(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_name);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_14to_2d(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_name) {
  char *__pyx_v_c_name;
  PyObject *__pyx_v_b_name = 0;
  PJ *__pyx_v_projobj;
  struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_crs_2d = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  char *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_2d", 0);

  /* "pyproj/_crs.pyx":2969
 *         _CRS
 *         """
 *         cdef char* c_name = NULL             # <<<<<<<<<<<<<<
 *         cdef bytes b_name
 *         if name is not None:
*/
  __pyx_v_c_name = NULL;

  /* "pyproj/_crs.pyx":2971
 *         cdef char* c_name = NULL
 *         cdef bytes b_name
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             b_name = cstrencode(name)
 *             c_name = b_name
*/
  __pyx_t_1 = (__pyx_v_name != ((PyObject*)Py_None));
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2972
 *         cdef bytes b_name
 *         if name is not None:
 *             b_name = cstrencode(name)             # <<<<<<<<<<<<<<
 *             c_name = b_name
 * 
*/
    __pyx_t_2 = __pyx_f_6pyproj_7_compat_cstrencode(__pyx_v_name, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_b_name = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyproj/_crs.pyx":2973
 *         if name is not None:
 *             b_name = cstrencode(name)
 *             c_name = b_name             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ * projobj = proj_crs_demote_to_2D(
*/
    if (unlikely(__pyx_v_b_name == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(0, 2973, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyBytes_AsWritableString(__pyx_v_b_name); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(0, 2973, __pyx_L1_error)
    __pyx_v_c_name = __pyx_t_3;

    /* "pyproj/_crs.pyx":2971
 *         cdef char* c_name = NULL
 *         cdef bytes b_name
 *         if name is not None:             # <<<<<<<<<<<<<<
 *             b_name = cstrencode(name)
 *             c_name = b_name
*/
  }

  /* "pyproj/_crs.pyx":2975
 *             c_name = b_name
 * 
 *         cdef PJ * projobj = proj_crs_demote_to_2D(             # <<<<<<<<<<<<<<
 *             self.context, c_name, self.projobj
 *         )
*/
  __pyx_v_projobj = proj_crs_demote_to_2D(__pyx_v_self->__pyx_base.context, __pyx_v_c_name, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":2978
 *             self.context, c_name, self.projobj
 *         )
 *         _clear_proj_error()             # <<<<<<<<<<<<<<
 *         if projobj == NULL:
 *             return self
*/
  __pyx_f_6pyproj_8_context__clear_proj_error(0);

  /* "pyproj/_crs.pyx":2979
 *         )
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             return self
 *         try:
*/
  __pyx_t_1 = (__pyx_v_projobj == NULL);
  if (__pyx_t_1) {

    /* "pyproj/_crs.pyx":2980
 *         _clear_proj_error()
 *         if projobj == NULL:
 *             return self             # <<<<<<<<<<<<<<
 *         try:
 *             crs_2d = _CRS(_to_wkt(
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __pyx_r = ((PyObject *)__pyx_v_self);
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":2979
 *         )
 *         _clear_proj_error()
 *         if projobj == NULL:             # <<<<<<<<<<<<<<
 *             return self
 *         try:
*/
  }

  /* "pyproj/_crs.pyx":2981
 *         if projobj == NULL:
 *             return self
 *         try:             # <<<<<<<<<<<<<<
 *             crs_2d = _CRS(_to_wkt(
 *                 self.context,
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":2982
 *             return self
 *         try:
 *             crs_2d = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_4 = NULL;

    /* "pyproj/_crs.pyx":2985
 *                 self.context,
 *                 projobj,
 *                 version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                 pretty=False,
 *             ))
*/
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2985, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2985, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyproj/_crs.pyx":2982
 *             return self
 *         try:
 *             crs_2d = _CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 projobj,
*/
    __pyx_t_5 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_projobj, __pyx_t_6, 0, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2982, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2982, __pyx_L6_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_2);
    }
    __pyx_v_crs_2d = ((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_t_2);
    __pyx_t_2 = 0;
  }

  /* "pyproj/_crs.pyx":2989
 *             ))
 *         finally:
 *             proj_destroy(projobj)             # <<<<<<<<<<<<<<
 *         return crs_2d
 * 
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_projobj);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      if ( unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_8 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
      {
        proj_destroy(__pyx_v_projobj);
      }
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "pyproj/_crs.pyx":2990
 *         finally:
 *             proj_destroy(projobj)
 *         return crs_2d             # <<<<<<<<<<<<<<
 * 
 *     def _is_crs_property(
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_crs_2d);
  __pyx_r = ((PyObject *)__pyx_v_crs_2d);
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2954
 *         return crs_3d
 * 
 *     def to_2d(self, str name=None):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.6.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyproj._crs._CRS.to_2d", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_b_name);
  __Pyx_XDECREF((PyObject *)__pyx_v_crs_2d);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":2992
 *         return crs_2d
 * 
 *     def _is_crs_property(             # <<<<<<<<<<<<<<
 *         self, str property_name, tuple property_types, int sub_crs_index=0
 *     ):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_17_is_crs_property(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_16_is_crs_property, "_CRS._is_crs_property(self, str property_name, tuple property_types, int sub_crs_index=0)\n\n.. versionadded:: 2.2.0\n\nThis method will check for a property on the CRS.\nIt will check if it has the property on the sub CRS\nif it is a compound CRS and will check if the source CRS\nhas the property if it is a bound CRS.\n\nParameters\n----------\nproperty_name: str\n    The name of the CRS property.\nproperty_types: tuple(PJ_TYPE)\n    The types to check for for the property.\nsub_crs_index: int, default=0\n    THe index of the CRS in the sub CRS list.\n\nReturns\n-------\nbool:\n    True if the CRS has this property.");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_17_is_crs_property = {"_is_crs_property", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_17_is_crs_property, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_16_is_crs_property};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_17_is_crs_property(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_property_name = 0;
  PyObject *__pyx_v_property_types = 0;
  int __pyx_v_sub_crs_index;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_is_crs_property (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_property_name,&__pyx_mstate_global->__pyx_n_u_property_types,&__pyx_mstate_global->__pyx_n_u_sub_crs_index,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 2992, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 2992, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2992, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2992, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_is_crs_property", 0) < (0)) __PYX_ERR(0, 2992, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_is_crs_property", 0, 2, 3, i); __PYX_ERR(0, 2992, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(0, 2992, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 2992, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 2992, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_property_name = ((PyObject*)values[0]);
    __pyx_v_property_types = ((PyObject*)values[1]);
    if (values[2]) {
      __pyx_v_sub_crs_index = __Pyx_PyLong_As_int(values[2]); if (unlikely((__pyx_v_sub_crs_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2993, __pyx_L3_error)
    } else {
      __pyx_v_sub_crs_index = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_is_crs_property", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 2992, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS._is_crs_property", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_property_name), (&PyUnicode_Type), 1, "property_name", 1))) __PYX_ERR(0, 2993, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_property_types), (&PyTuple_Type), 1, "property_types", 1))) __PYX_ERR(0, 2993, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_16_is_crs_property(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_property_name, __pyx_v_property_types, __pyx_v_sub_crs_index);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_16_is_crs_property(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_property_name, PyObject *__pyx_v_property_types, int __pyx_v_sub_crs_index) {
  PyObject *__pyx_v_sub_crs = NULL;
  PyObject *__pyx_v_is_property = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_crs_property", 0);

  /* "pyproj/_crs.pyx":3017
 *             True if the CRS has this property.
 *         """
 *         if self.sub_crs_list:             # <<<<<<<<<<<<<<
 *             sub_crs = self.sub_crs_list[sub_crs_index]
 *             if sub_crs.is_bound:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_sub_crs_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":3018
 *         """
 *         if self.sub_crs_list:
 *             sub_crs = self.sub_crs_list[sub_crs_index]             # <<<<<<<<<<<<<<
 *             if sub_crs.is_bound:
 *                 is_property = getattr(sub_crs.source_crs, property_name)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_sub_crs_list); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_sub_crs_index, int, 1, __Pyx_PyLong_From_int, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_sub_crs = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pyproj/_crs.pyx":3019
 *         if self.sub_crs_list:
 *             sub_crs = self.sub_crs_list[sub_crs_index]
 *             if sub_crs.is_bound:             # <<<<<<<<<<<<<<
 *                 is_property = getattr(sub_crs.source_crs, property_name)
 *             else:
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_sub_crs, __pyx_mstate_global->__pyx_n_u_is_bound); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3019, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "pyproj/_crs.pyx":3020
 *             sub_crs = self.sub_crs_list[sub_crs_index]
 *             if sub_crs.is_bound:
 *                 is_property = getattr(sub_crs.source_crs, property_name)             # <<<<<<<<<<<<<<
 *             else:
 *                 is_property = getattr(sub_crs, property_name)
*/
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_sub_crs, __pyx_mstate_global->__pyx_n_u_source_crs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3020, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_GetAttr(__pyx_t_3, __pyx_v_property_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3020, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_is_property = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":3019
 *         if self.sub_crs_list:
 *             sub_crs = self.sub_crs_list[sub_crs_index]
 *             if sub_crs.is_bound:             # <<<<<<<<<<<<<<
 *                 is_property = getattr(sub_crs.source_crs, property_name)
 *             else:
*/
      goto __pyx_L4;
    }

    /* "pyproj/_crs.pyx":3022
 *                 is_property = getattr(sub_crs.source_crs, property_name)
 *             else:
 *                 is_property = getattr(sub_crs, property_name)             # <<<<<<<<<<<<<<
 *         elif self.is_bound:
 *             is_property = getattr(self.source_crs, property_name)
*/
    /*else*/ {
      __pyx_t_1 = __Pyx_GetAttr(__pyx_v_sub_crs, __pyx_v_property_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3022, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_is_property = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "pyproj/_crs.pyx":3017
 *             True if the CRS has this property.
 *         """
 *         if self.sub_crs_list:             # <<<<<<<<<<<<<<
 *             sub_crs = self.sub_crs_list[sub_crs_index]
 *             if sub_crs.is_bound:
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":3023
 *             else:
 *                 is_property = getattr(sub_crs, property_name)
 *         elif self.is_bound:             # <<<<<<<<<<<<<<
 *             is_property = getattr(self.source_crs, property_name)
 *         else:
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_bound); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":3024
 *                 is_property = getattr(sub_crs, property_name)
 *         elif self.is_bound:
 *             is_property = getattr(self.source_crs, property_name)             # <<<<<<<<<<<<<<
 *         else:
 *             is_property = self._type in property_types
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_source_crs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_property_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_is_property = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pyproj/_crs.pyx":3023
 *             else:
 *                 is_property = getattr(sub_crs, property_name)
 *         elif self.is_bound:             # <<<<<<<<<<<<<<
 *             is_property = getattr(self.source_crs, property_name)
 *         else:
*/
    goto __pyx_L3;
  }

  /* "pyproj/_crs.pyx":3026
 *             is_property = getattr(self.source_crs, property_name)
 *         else:
 *             is_property = self._type in property_types             # <<<<<<<<<<<<<<
 *         return is_property
 * 
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_PyLong_From_PJ_TYPE(__pyx_v_self->_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_property_types, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3026, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_is_property = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "pyproj/_crs.pyx":3027
 *         else:
 *             is_property = self._type in property_types
 *         return is_property             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_is_property);
  __pyx_r = __pyx_v_is_property;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":2992
 *         return crs_2d
 * 
 *     def _is_crs_property(             # <<<<<<<<<<<<<<
 *         self, str property_name, tuple property_types, int sub_crs_index=0
 *     ):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs._CRS._is_crs_property", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sub_crs);
  __Pyx_XDECREF(__pyx_v_is_property);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3029
 *         return is_property
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_geographic(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13is_geographic_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13is_geographic_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_13is_geographic___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13is_geographic___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3042
 *             True if the CRS is in geographic (lon/lat) coordinates.
 *         """
 *         return self._is_crs_property(             # <<<<<<<<<<<<<<
 *             "is_geographic",
 *             (
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":3045
 *             "is_geographic",
 *             (
 *                 PJ_TYPE_GEOGRAPHIC_CRS,             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_GEOGRAPHIC_2D_CRS,
 *                 PJ_TYPE_GEOGRAPHIC_3D_CRS
*/
  __pyx_t_3 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOGRAPHIC_CRS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pyproj/_crs.pyx":3046
 *             (
 *                 PJ_TYPE_GEOGRAPHIC_CRS,
 *                 PJ_TYPE_GEOGRAPHIC_2D_CRS,             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_GEOGRAPHIC_3D_CRS
 *             )
*/
  __pyx_t_4 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOGRAPHIC_2D_CRS); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pyproj/_crs.pyx":3047
 *                 PJ_TYPE_GEOGRAPHIC_CRS,
 *                 PJ_TYPE_GEOGRAPHIC_2D_CRS,
 *                 PJ_TYPE_GEOGRAPHIC_3D_CRS             # <<<<<<<<<<<<<<
 *             )
 *         )
*/
  __pyx_t_5 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOGRAPHIC_3D_CRS); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pyproj/_crs.pyx":3045
 *             "is_geographic",
 *             (
 *                 PJ_TYPE_GEOGRAPHIC_CRS,             # <<<<<<<<<<<<<<
 *                 PJ_TYPE_GEOGRAPHIC_2D_CRS,
 *                 PJ_TYPE_GEOGRAPHIC_3D_CRS
*/
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 3045, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4) != (0)) __PYX_ERR(0, 3045, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5) != (0)) __PYX_ERR(0, 3045, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_geographic, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_crs_property, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3042, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3029
 *         return is_property
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_geographic(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_geographic.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3051
 *         )
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_projected(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12is_projected_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12is_projected_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_12is_projected___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12is_projected___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3064
 *             True if CRS is projected.
 *         """
 *         return self._is_crs_property(             # <<<<<<<<<<<<<<
 *             "is_projected",
 *             (PJ_TYPE_PROJECTED_CRS,)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":3066
 *         return self._is_crs_property(
 *             "is_projected",
 *             (PJ_TYPE_PROJECTED_CRS,)             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_3 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_PROJECTED_CRS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 3066, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_projected, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_crs_property, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3051
 *         )
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_projected(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_projected.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3069
 *         )
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_vertical(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11is_vertical_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11is_vertical_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_11is_vertical___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11is_vertical___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3084
 *             True if CRS is vertical.
 *         """
 *         return self._is_crs_property(             # <<<<<<<<<<<<<<
 *             "is_vertical",
 *             (PJ_TYPE_VERTICAL_CRS,),
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);

  /* "pyproj/_crs.pyx":3086
 *         return self._is_crs_property(
 *             "is_vertical",
 *             (PJ_TYPE_VERTICAL_CRS,),             # <<<<<<<<<<<<<<
 *             sub_crs_index=1
 *         )
*/
  __pyx_t_3 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_VERTICAL_CRS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3) != (0)) __PYX_ERR(0, 3086, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[3 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_is_vertical, __pyx_t_4};
    __pyx_t_3 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_sub_crs_index, __pyx_mstate_global->__pyx_int_1, __pyx_t_3, __pyx_callargs+3, 0) < (0)) __PYX_ERR(0, 3084, __pyx_L1_error)
    __pyx_t_1 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_is_crs_property, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3069
 *         )
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_vertical(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_vertical.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3090
 *         )
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_bound(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_8is_bound_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_8is_bound_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_8is_bound___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_8is_bound___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3098
 *             True if CRS is bound.
 *         """
 *         return self._type == PJ_TYPE_BOUND_CRS             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->_type == PJ_TYPE_BOUND_CRS)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3090
 *         )
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_bound(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_bound.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3100
 *         return self._type == PJ_TYPE_BOUND_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_compound(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11is_compound_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11is_compound_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_11is_compound___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11is_compound___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3110
 *             True if CRS is compound.
 *         """
 *         return self._type == PJ_TYPE_COMPOUND_CRS             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->_type == PJ_TYPE_COMPOUND_CRS)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3100
 *         return self._type == PJ_TYPE_BOUND_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_compound(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_compound.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3112
 *         return self._type == PJ_TYPE_COMPOUND_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_engineering(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_14is_engineering_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_14is_engineering_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_14is_engineering___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_14is_engineering___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3122
 *             True if CRS is local/engineering.
 *         """
 *         return self._type == PJ_TYPE_ENGINEERING_CRS             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->_type == PJ_TYPE_ENGINEERING_CRS)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3112
 *         return self._type == PJ_TYPE_COMPOUND_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_engineering(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_engineering.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3124
 *         return self._type == PJ_TYPE_ENGINEERING_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_geocentric(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13is_geocentric_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13is_geocentric_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_13is_geocentric___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13is_geocentric___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3135
 *             True if CRS is in geocentric (x/y) coordinates.
 *         """
 *         if self.is_bound:             # <<<<<<<<<<<<<<
 *             return self.source_crs.is_geocentric
 *         return self._type == PJ_TYPE_GEOCENTRIC_CRS
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_is_bound); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":3136
 *         """
 *         if self.is_bound:
 *             return self.source_crs.is_geocentric             # <<<<<<<<<<<<<<
 *         return self._type == PJ_TYPE_GEOCENTRIC_CRS
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_source_crs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_is_geocentric); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":3135
 *             True if CRS is in geocentric (x/y) coordinates.
 *         """
 *         if self.is_bound:             # <<<<<<<<<<<<<<
 *             return self.source_crs.is_geocentric
 *         return self._type == PJ_TYPE_GEOCENTRIC_CRS
*/
  }

  /* "pyproj/_crs.pyx":3137
 *         if self.is_bound:
 *             return self.source_crs.is_geocentric
 *         return self._type == PJ_TYPE_GEOCENTRIC_CRS             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyBool_FromLong((__pyx_v_self->_type == PJ_TYPE_GEOCENTRIC_CRS)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3124
 *         return self._type == PJ_TYPE_ENGINEERING_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_geocentric(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_geocentric.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3139
 *         return self._type == PJ_TYPE_GEOCENTRIC_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_derived(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10is_derived_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10is_derived_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_10is_derived___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10is_derived___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3149
 *             True if CRS is a Derived CRS.
 *         """
 *         return proj_is_derived_crs(self.context, self.projobj) == 1             # <<<<<<<<<<<<<<
 * 
 *     def _equals(self, _CRS other, bint ignore_axis_order):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((proj_is_derived_crs(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj) == 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3139
 *         return self._type == PJ_TYPE_GEOCENTRIC_CRS
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_derived(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_derived.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3151
 *         return proj_is_derived_crs(self.context, self.projobj) == 1
 * 
 *     def _equals(self, _CRS other, bint ignore_axis_order):             # <<<<<<<<<<<<<<
 *         if ignore_axis_order:
 *             # Only to be used with DerivedCRS/ProjectedCRS/GeographicCRS
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_19_equals(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_18_equals, "_CRS._equals(self, _CRS other, bool ignore_axis_order)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_19_equals = {"_equals", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_19_equals, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_18_equals};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_19_equals(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_other = 0;
  int __pyx_v_ignore_axis_order;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_equals (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_other,&__pyx_mstate_global->__pyx_n_u_ignore_axis_order,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 3151, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3151, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3151, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "_equals", 0) < (0)) __PYX_ERR(0, 3151, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("_equals", 1, 2, 2, i); __PYX_ERR(0, 3151, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3151, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3151, __pyx_L3_error)
    }
    __pyx_v_other = ((struct __pyx_obj_6pyproj_4_crs__CRS *)values[0]);
    __pyx_v_ignore_axis_order = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_ignore_axis_order == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3151, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_equals", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3151, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS._equals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, 1, "other", 0))) __PYX_ERR(0, 3151, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_18_equals(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_other, __pyx_v_ignore_axis_order);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_18_equals(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_other, int __pyx_v_ignore_axis_order) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_equals", 0);

  /* "pyproj/_crs.pyx":3152
 * 
 *     def _equals(self, _CRS other, bint ignore_axis_order):
 *         if ignore_axis_order:             # <<<<<<<<<<<<<<
 *             # Only to be used with DerivedCRS/ProjectedCRS/GeographicCRS
 *             return proj_is_equivalent_to_with_ctx(
*/
  if (__pyx_v_ignore_axis_order) {

    /* "pyproj/_crs.pyx":3154
 *         if ignore_axis_order:
 *             # Only to be used with DerivedCRS/ProjectedCRS/GeographicCRS
 *             return proj_is_equivalent_to_with_ctx(             # <<<<<<<<<<<<<<
 *                 self.context,
 *                 self.projobj,
*/
    __Pyx_XDECREF(__pyx_r);

    /* "pyproj/_crs.pyx":3159
 *                 other.projobj,
 *                 PJ_COMP_EQUIVALENT_EXCEPT_AXIS_ORDER_GEOGCRS,
 *             ) == 1             # <<<<<<<<<<<<<<
 *         return self._is_equivalent(other)
 * 
*/
    __pyx_t_1 = __Pyx_PyBool_FromLong((proj_is_equivalent_to_with_ctx(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj, __pyx_v_other->__pyx_base.projobj, PJ_COMP_EQUIVALENT_EXCEPT_AXIS_ORDER_GEOGCRS) == 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":3152
 * 
 *     def _equals(self, _CRS other, bint ignore_axis_order):
 *         if ignore_axis_order:             # <<<<<<<<<<<<<<
 *             # Only to be used with DerivedCRS/ProjectedCRS/GeographicCRS
 *             return proj_is_equivalent_to_with_ctx(
*/
  }

  /* "pyproj/_crs.pyx":3160
 *                 PJ_COMP_EQUIVALENT_EXCEPT_AXIS_ORDER_GEOGCRS,
 *             ) == 1
 *         return self._is_equivalent(other)             # <<<<<<<<<<<<<<
 * 
 *     def equals(self, other, ignore_axis_order=False):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_other)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_is_equivalent, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3151
 *         return proj_is_derived_crs(self.context, self.projobj) == 1
 * 
 *     def _equals(self, _CRS other, bint ignore_axis_order):             # <<<<<<<<<<<<<<
 *         if ignore_axis_order:
 *             # Only to be used with DerivedCRS/ProjectedCRS/GeographicCRS
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyproj._crs._CRS._equals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3162
 *         return self._is_equivalent(other)
 * 
 *     def equals(self, other, ignore_axis_order=False):             # <<<<<<<<<<<<<<
 *         """
 *         Check if the projection objects are equivalent.
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_21equals(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_20equals, "_CRS.equals(self, other, ignore_axis_order=False)\n\nCheck if the projection objects are equivalent.\n\nProperties\n----------\nother: CRS\n    Check if the other object\nignore_axis_order: bool, default=False\n    If True, it will compare the CRS class and ignore the axis order.\n\nReturns\n-------\nbool");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_21equals = {"equals", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_21equals, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_20equals};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_21equals(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_v_ignore_axis_order = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("equals (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_other,&__pyx_mstate_global->__pyx_n_u_ignore_axis_order,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(0, 3162, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3162, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3162, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "equals", 0) < (0)) __PYX_ERR(0, 3162, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_False));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("equals", 0, 1, 2, i); __PYX_ERR(0, 3162, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(0, 3162, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(0, 3162, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_False));
    }
    __pyx_v_other = values[0];
    __pyx_v_ignore_axis_order = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("equals", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 3162, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.equals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_20equals(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v_other, __pyx_v_ignore_axis_order);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_20equals(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_ignore_axis_order) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("equals", 0);

  /* "pyproj/_crs.pyx":3177
 *         bool
 *         """
 *         if not isinstance(other, _CRS):             # <<<<<<<<<<<<<<
 *             return False
 *         return self._equals(other, ignore_axis_order=ignore_axis_order)
*/
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":3178
 *         """
 *         if not isinstance(other, _CRS):
 *             return False             # <<<<<<<<<<<<<<
 *         return self._equals(other, ignore_axis_order=ignore_axis_order)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pyproj/_crs.pyx":3177
 *         bool
 *         """
 *         if not isinstance(other, _CRS):             # <<<<<<<<<<<<<<
 *             return False
 *         return self._equals(other, ignore_axis_order=ignore_axis_order)
*/
  }

  /* "pyproj/_crs.pyx":3179
 *         if not isinstance(other, _CRS):
 *             return False
 *         return self._equals(other, ignore_axis_order=ignore_axis_order)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_4, __pyx_v_other};
    __pyx_t_6 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_ignore_axis_order, __pyx_v_ignore_axis_order, __pyx_t_6, __pyx_callargs+2, 0) < (0)) __PYX_ERR(0, 3179, __pyx_L1_error)
    __pyx_t_3 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_equals, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3162
 *         return self._is_equivalent(other)
 * 
 *     def equals(self, other, ignore_axis_order=False):             # <<<<<<<<<<<<<<
 *         """
 *         Check if the projection objects are equivalent.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyproj._crs._CRS.equals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3181
 *         return self._equals(other, ignore_axis_order=ignore_axis_order)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_deprecated(self):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13is_deprecated_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13is_deprecated_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_13is_deprecated___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13is_deprecated___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyproj/_crs.pyx":3192
 *         bool
 *         """
 *         return bool(proj_is_deprecated(self.projobj))             # <<<<<<<<<<<<<<
 * 
 *     def get_non_deprecated(self):
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = NULL;
  __pyx_t_3 = __Pyx_PyLong_From_int(proj_is_deprecated(__pyx_v_self->__pyx_base.projobj)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_7cpython_4bool_bool, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3192, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3181
 *         return self._equals(other, ignore_axis_order=ignore_axis_order)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def is_deprecated(self):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyproj._crs._CRS.is_deprecated.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pyx":3194
 *         return bool(proj_is_deprecated(self.projobj))
 * 
 *     def get_non_deprecated(self):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.7.0
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_23get_non_deprecated(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_22get_non_deprecated, "_CRS.get_non_deprecated(self)\n\n.. versionadded:: 3.7.0\n\nReturn a list of non-deprecated objects related to this.\n\nReturns\n-------\nlist[_CRS]");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_23get_non_deprecated = {"get_non_deprecated", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_23get_non_deprecated, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_22get_non_deprecated};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_23get_non_deprecated(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_non_deprecated (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("get_non_deprecated", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("get_non_deprecated", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_22get_non_deprecated(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_22get_non_deprecated(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_v_non_deprecated = NULL;
  PJ_OBJ_LIST *__pyx_v_proj_list;
  int __pyx_v_num_proj_objects;
  PJ *__pyx_v_proj;
  int __pyx_v_iii;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_non_deprecated", 0);

  /* "pyproj/_crs.pyx":3205
 *         """
 * 
 *         non_deprecated = []             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ_OBJ_LIST *proj_list = NULL
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_non_deprecated = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyproj/_crs.pyx":3207
 *         non_deprecated = []
 * 
 *         cdef PJ_OBJ_LIST *proj_list = NULL             # <<<<<<<<<<<<<<
 *         cdef int num_proj_objects = 0
 * 
*/
  __pyx_v_proj_list = NULL;

  /* "pyproj/_crs.pyx":3208
 * 
 *         cdef PJ_OBJ_LIST *proj_list = NULL
 *         cdef int num_proj_objects = 0             # <<<<<<<<<<<<<<
 * 
 *         proj_list = proj_get_non_deprecated(
*/
  __pyx_v_num_proj_objects = 0;

  /* "pyproj/_crs.pyx":3210
 *         cdef int num_proj_objects = 0
 * 
 *         proj_list = proj_get_non_deprecated(             # <<<<<<<<<<<<<<
 *             self.context,
 *             self.projobj
*/
  __pyx_v_proj_list = proj_get_non_deprecated(__pyx_v_self->__pyx_base.context, __pyx_v_self->__pyx_base.projobj);

  /* "pyproj/_crs.pyx":3214
 *             self.projobj
 *         )
 *         if proj_list != NULL:             # <<<<<<<<<<<<<<
 *             num_proj_objects = proj_list_get_count(proj_list)
 * 
*/
  __pyx_t_2 = (__pyx_v_proj_list != NULL);
  if (__pyx_t_2) {

    /* "pyproj/_crs.pyx":3215
 *         )
 *         if proj_list != NULL:
 *             num_proj_objects = proj_list_get_count(proj_list)             # <<<<<<<<<<<<<<
 * 
 *         cdef PJ* proj = NULL
*/
    __pyx_v_num_proj_objects = proj_list_get_count(__pyx_v_proj_list);

    /* "pyproj/_crs.pyx":3214
 *             self.projobj
 *         )
 *         if proj_list != NULL:             # <<<<<<<<<<<<<<
 *             num_proj_objects = proj_list_get_count(proj_list)
 * 
*/
  }

  /* "pyproj/_crs.pyx":3217
 *             num_proj_objects = proj_list_get_count(proj_list)
 * 
 *         cdef PJ* proj = NULL             # <<<<<<<<<<<<<<
 *         try:
 *             for iii in range(num_proj_objects):
*/
  __pyx_v_proj = NULL;

  /* "pyproj/_crs.pyx":3218
 * 
 *         cdef PJ* proj = NULL
 *         try:             # <<<<<<<<<<<<<<
 *             for iii in range(num_proj_objects):
 *                 proj = proj_list_get(self.context, proj_list, iii)
*/
  /*try:*/ {

    /* "pyproj/_crs.pyx":3219
 *         cdef PJ* proj = NULL
 *         try:
 *             for iii in range(num_proj_objects):             # <<<<<<<<<<<<<<
 *                 proj = proj_list_get(self.context, proj_list, iii)
 *                 non_deprecated.append(_CRS(_to_wkt(
*/
    __pyx_t_3 = __pyx_v_num_proj_objects;
    __pyx_t_4 = __pyx_t_3;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_iii = __pyx_t_5;

      /* "pyproj/_crs.pyx":3220
 *         try:
 *             for iii in range(num_proj_objects):
 *                 proj = proj_list_get(self.context, proj_list, iii)             # <<<<<<<<<<<<<<
 *                 non_deprecated.append(_CRS(_to_wkt(
 *                     self.context,
*/
      __pyx_v_proj = proj_list_get(__pyx_v_self->__pyx_base.context, __pyx_v_proj_list, __pyx_v_iii);

      /* "pyproj/_crs.pyx":3221
 *             for iii in range(num_proj_objects):
 *                 proj = proj_list_get(self.context, proj_list, iii)
 *                 non_deprecated.append(_CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     proj,
*/
      __pyx_t_6 = NULL;

      /* "pyproj/_crs.pyx":3224
 *                     self.context,
 *                     proj,
 *                     version=WktVersion.WKT2_2019,             # <<<<<<<<<<<<<<
 *                     pretty=False,
 *                 )))
*/
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3224, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3224, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pyproj/_crs.pyx":3221
 *             for iii in range(num_proj_objects):
 *                 proj = proj_list_get(self.context, proj_list, iii)
 *                 non_deprecated.append(_CRS(_to_wkt(             # <<<<<<<<<<<<<<
 *                     self.context,
 *                     proj,
*/
      __pyx_t_7 = __pyx_f_6pyproj_4_crs__to_wkt(__pyx_v_self->__pyx_base.context, __pyx_v_proj, __pyx_t_8, 0, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3221, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3221, __pyx_L5_error)
        __Pyx_GOTREF((PyObject *)__pyx_t_1);
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_non_deprecated, ((PyObject *)__pyx_t_1)); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 3221, __pyx_L5_error)
      __Pyx_DECREF((PyObject *)__pyx_t_1); __pyx_t_1 = 0;

      /* "pyproj/_crs.pyx":3227
 *                     pretty=False,
 *                 )))
 *                 proj_destroy(proj)             # <<<<<<<<<<<<<<
 *                 proj = NULL
 *         finally:
*/
      proj_destroy(__pyx_v_proj);

      /* "pyproj/_crs.pyx":3228
 *                 )))
 *                 proj_destroy(proj)
 *                 proj = NULL             # <<<<<<<<<<<<<<
 *         finally:
 *             # If there was an error we have to call proj_destroy
*/
      __pyx_v_proj = NULL;
    }
  }

  /* "pyproj/_crs.pyx":3232
 *             # If there was an error we have to call proj_destroy
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)             # <<<<<<<<<<<<<<
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()
*/
  /*finally:*/ {
    /*normal exit:*/{
      proj_destroy(__pyx_v_proj);

      /* "pyproj/_crs.pyx":3233
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)             # <<<<<<<<<<<<<<
 *             _clear_proj_error()
 * 
*/
      proj_list_destroy(__pyx_v_proj_list);

      /* "pyproj/_crs.pyx":3234
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()             # <<<<<<<<<<<<<<
 * 
 *         return non_deprecated
*/
      __pyx_f_6pyproj_8_context__clear_proj_error(0);
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
       __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
      if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __pyx_t_3 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
      {

        /* "pyproj/_crs.pyx":3232
 *             # If there was an error we have to call proj_destroy
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)             # <<<<<<<<<<<<<<
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()
*/
        proj_destroy(__pyx_v_proj);

        /* "pyproj/_crs.pyx":3233
 *             # If there was none, calling it on NULL does nothing
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)             # <<<<<<<<<<<<<<
 *             _clear_proj_error()
 * 
*/
        proj_list_destroy(__pyx_v_proj_list);

        /* "pyproj/_crs.pyx":3234
 *             proj_destroy(proj)
 *             proj_list_destroy(proj_list)
 *             _clear_proj_error()             # <<<<<<<<<<<<<<
 * 
 *         return non_deprecated
*/
        __pyx_f_6pyproj_8_context__clear_proj_error(0);
      }
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
      __pyx_lineno = __pyx_t_3; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_11;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "pyproj/_crs.pyx":3236
 *             _clear_proj_error()
 * 
 *         return non_deprecated             # <<<<<<<<<<<<<<
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_non_deprecated);
  __pyx_r = __pyx_v_non_deprecated;
  goto __pyx_L0;

  /* "pyproj/_crs.pyx":3194
 *         return bool(proj_is_deprecated(self.projobj))
 * 
 *     def get_non_deprecated(self):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.7.0
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pyproj._crs._CRS.get_non_deprecated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_non_deprecated);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":144
 *     cdef PJ_TYPE _type
 *     cdef PJ_PROJ_INFO projpj_info
 *     cdef readonly str srs             # <<<<<<<<<<<<<<
 *     cdef readonly str _type_name
 *     cdef readonly Ellipsoid _ellipsoid
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_3srs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_3srs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_3srs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_3srs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->srs);
  __pyx_r = __pyx_v_self->srs;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":145
 *     cdef PJ_PROJ_INFO projpj_info
 *     cdef readonly str srs
 *     cdef readonly str _type_name             # <<<<<<<<<<<<<<
 *     cdef readonly Ellipsoid _ellipsoid
 *     cdef readonly object _area_of_use
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10_type_name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10_type_name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_10_type_name___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10_type_name___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_type_name);
  __pyx_r = __pyx_v_self->_type_name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":146
 *     cdef readonly str srs
 *     cdef readonly str _type_name
 *     cdef readonly Ellipsoid _ellipsoid             # <<<<<<<<<<<<<<
 *     cdef readonly object _area_of_use
 *     cdef readonly PrimeMeridian _prime_meridian
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10_ellipsoid_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_10_ellipsoid_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_10_ellipsoid___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_10_ellipsoid___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_ellipsoid);
  __pyx_r = ((PyObject *)__pyx_v_self->_ellipsoid);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":147
 *     cdef readonly str _type_name
 *     cdef readonly Ellipsoid _ellipsoid
 *     cdef readonly object _area_of_use             # <<<<<<<<<<<<<<
 *     cdef readonly PrimeMeridian _prime_meridian
 *     cdef readonly Datum _datum
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12_area_of_use_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_12_area_of_use_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_12_area_of_use___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_12_area_of_use___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_area_of_use);
  __pyx_r = __pyx_v_self->_area_of_use;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":148
 *     cdef readonly Ellipsoid _ellipsoid
 *     cdef readonly object _area_of_use
 *     cdef readonly PrimeMeridian _prime_meridian             # <<<<<<<<<<<<<<
 *     cdef readonly Datum _datum
 *     cdef readonly list _sub_crs_list
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_15_prime_meridian_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_15_prime_meridian_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_15_prime_meridian___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_15_prime_meridian___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_prime_meridian);
  __pyx_r = ((PyObject *)__pyx_v_self->_prime_meridian);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":149
 *     cdef readonly object _area_of_use
 *     cdef readonly PrimeMeridian _prime_meridian
 *     cdef readonly Datum _datum             # <<<<<<<<<<<<<<
 *     cdef readonly list _sub_crs_list
 *     cdef readonly _CRS _source_crs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_6_datum_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_6_datum_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_6_datum___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_6_datum___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_datum);
  __pyx_r = ((PyObject *)__pyx_v_self->_datum);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":150
 *     cdef readonly PrimeMeridian _prime_meridian
 *     cdef readonly Datum _datum
 *     cdef readonly list _sub_crs_list             # <<<<<<<<<<<<<<
 *     cdef readonly _CRS _source_crs
 *     cdef readonly _CRS _target_crs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13_sub_crs_list_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13_sub_crs_list_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_13_sub_crs_list___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13_sub_crs_list___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_sub_crs_list);
  __pyx_r = __pyx_v_self->_sub_crs_list;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":151
 *     cdef readonly Datum _datum
 *     cdef readonly list _sub_crs_list
 *     cdef readonly _CRS _source_crs             # <<<<<<<<<<<<<<
 *     cdef readonly _CRS _target_crs
 *     cdef readonly _CRS _geodetic_crs
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11_source_crs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11_source_crs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_11_source_crs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11_source_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_source_crs);
  __pyx_r = ((PyObject *)__pyx_v_self->_source_crs);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":152
 *     cdef readonly list _sub_crs_list
 *     cdef readonly _CRS _source_crs
 *     cdef readonly _CRS _target_crs             # <<<<<<<<<<<<<<
 *     cdef readonly _CRS _geodetic_crs
 *     cdef readonly CoordinateSystem _coordinate_system
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11_target_crs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_11_target_crs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_11_target_crs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_11_target_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_target_crs);
  __pyx_r = ((PyObject *)__pyx_v_self->_target_crs);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":153
 *     cdef readonly _CRS _source_crs
 *     cdef readonly _CRS _target_crs
 *     cdef readonly _CRS _geodetic_crs             # <<<<<<<<<<<<<<
 *     cdef readonly CoordinateSystem _coordinate_system
 *     cdef readonly CoordinateOperation _coordinate_operation
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13_geodetic_crs_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_13_geodetic_crs_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_13_geodetic_crs___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_13_geodetic_crs___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_geodetic_crs);
  __pyx_r = ((PyObject *)__pyx_v_self->_geodetic_crs);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":154
 *     cdef readonly _CRS _target_crs
 *     cdef readonly _CRS _geodetic_crs
 *     cdef readonly CoordinateSystem _coordinate_system             # <<<<<<<<<<<<<<
 *     cdef readonly CoordinateOperation _coordinate_operation
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_18_coordinate_system_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_18_coordinate_system_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_18_coordinate_system___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_18_coordinate_system___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_coordinate_system);
  __pyx_r = ((PyObject *)__pyx_v_self->_coordinate_system);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyproj/_crs.pxd":155
 *     cdef readonly _CRS _geodetic_crs
 *     cdef readonly CoordinateSystem _coordinate_system
 *     cdef readonly CoordinateOperation _coordinate_operation             # <<<<<<<<<<<<<<
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_21_coordinate_operation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_21_coordinate_operation_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_21_coordinate_operation___get__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_21_coordinate_operation___get__(struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_coordinate_operation);
  __pyx_r = ((PyObject *)__pyx_v_self->_coordinate_operation);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_25__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_24__reduce_cython__, "_CRS.__reduce_cython__(self)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_25__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_25__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_24__reduce_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_25__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL; }
  const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len < 0)) return NULL;
  if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__reduce_cython__", __pyx_kwds); return NULL;}
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_24__reduce_cython__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_24__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs._CRS.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_27__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pyproj_4_crs_4_CRS_26__setstate_cython__, "_CRS.__setstate_cython__(self, __pyx_state)");
static PyMethodDef __pyx_mdef_6pyproj_4_crs_4_CRS_27__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_27__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_26__setstate_cython__};
static PyObject *__pyx_pw_6pyproj_4_crs_4_CRS_27__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(4, 3, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__setstate_cython__", 0) < (0)) __PYX_ERR(4, 3, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, i); __PYX_ERR(4, 3, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(4, 3, __pyx_L3_error)
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(4, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("pyproj._crs._CRS.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pyproj_4_crs_4_CRS_26__setstate_cython__(((struct __pyx_obj_6pyproj_4_crs__CRS *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pyproj_4_crs_4_CRS_26__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pyproj_4_crs__CRS *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(4, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyproj._crs._CRS.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
/* #### Code section: module_exttypes ### */
static struct __pyx_vtabstruct_6pyproj_4_crs_Axis __pyx_vtable_6pyproj_4_crs_Axis;

static PyObject *__pyx_tp_new_6pyproj_4_crs_Axis(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_Axis *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_Axis *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pyproj_4_crs_Axis;
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->abbrev = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->direction = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->unit_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->unit_auth_code = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->unit_code = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_4Axis_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_Axis(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_Axis *p = (struct __pyx_obj_6pyproj_4_crs_Axis *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_Axis) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  Py_CLEAR(p->name);
  Py_CLEAR(p->abbrev);
  Py_CLEAR(p->direction);
  Py_CLEAR(p->unit_name);
  Py_CLEAR(p->unit_auth_code);
  Py_CLEAR(p->unit_code);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_4name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_abbrev(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_6abbrev_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_direction(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_9direction_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_unit_conversion_factor(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_22unit_conversion_factor_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_unit_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_9unit_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_unit_auth_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_14unit_auth_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Axis_unit_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Axis_9unit_code_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_Axis[] = {
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Axis_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Axis_6__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Axis_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Axis_8__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_Axis[] = {
  {"name", __pyx_getprop_6pyproj_4_crs_4Axis_name, 0, 0, 0},
  {"abbrev", __pyx_getprop_6pyproj_4_crs_4Axis_abbrev, 0, 0, 0},
  {"direction", __pyx_getprop_6pyproj_4_crs_4Axis_direction, 0, 0, 0},
  {"unit_conversion_factor", __pyx_getprop_6pyproj_4_crs_4Axis_unit_conversion_factor, 0, 0, 0},
  {"unit_name", __pyx_getprop_6pyproj_4_crs_4Axis_unit_name, 0, 0, 0},
  {"unit_auth_code", __pyx_getprop_6pyproj_4_crs_4Axis_unit_auth_code, 0, 0, 0},
  {"unit_code", __pyx_getprop_6pyproj_4_crs_4Axis_unit_code, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_Axis_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Axis},
  {Py_tp_repr, (void *)__pyx_pw_6pyproj_4_crs_4Axis_5__repr__},
  {Py_tp_str, (void *)__pyx_pw_6pyproj_4_crs_4Axis_3__str__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    .. versionadded:: 2.0.0\n\n    Coordinate System Axis\n\n    Attributes\n    ----------\n    name: str\n    abbrev: str\n    direction: str\n    unit_conversion_factor: float\n    unit_name: str\n    unit_auth_code: str\n    unit_code: str\n\n    ")},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_Axis},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_Axis},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_Axis},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_Axis_spec = {
  "pyproj._crs.Axis",
  sizeof(struct __pyx_obj_6pyproj_4_crs_Axis),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pyproj_4_crs_Axis_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_Axis = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""Axis", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_Axis), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Axis, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6pyproj_4_crs_4Axis_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_6pyproj_4_crs_4Axis_3__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("\n    .. versionadded:: 2.0.0\n\n    Coordinate System Axis\n\n    Attributes\n    ----------\n    name: str\n    abbrev: str\n    direction: str\n    unit_conversion_factor: float\n    unit_name: str\n    unit_auth_code: str\n    unit_code: str\n\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_Axis, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_Axis, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_Axis, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_Base __pyx_vtable_6pyproj_4_crs_Base;

static PyObject *__pyx_tp_new_6pyproj_4_crs_Base(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_Base *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_Base *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pyproj_4_crs_Base;
  p->_context_manager = Py_None; Py_INCREF(Py_None);
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_remarks = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_scope = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_4Base_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_Base(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_Base *p = (struct __pyx_obj_6pyproj_4_crs_Base *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_Base) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pyproj_4_crs_4Base_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->_context_manager);
  Py_CLEAR(p->name);
  Py_CLEAR(p->_remarks);
  Py_CLEAR(p->_scope);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6pyproj_4_crs_Base(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pyproj_4_crs_Base *p = (struct __pyx_obj_6pyproj_4_crs_Base *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->_context_manager) {
    e = (*v)(p->_context_manager, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pyproj_4_crs_Base(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pyproj_4_crs_Base *p = (struct __pyx_obj_6pyproj_4_crs_Base *)o;
  tmp = ((PyObject*)p->_context_manager);
  p->_context_manager = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_richcompare_6pyproj_4_crs_Base(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_6pyproj_4_crs_4Base_19__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_6pyproj_4_crs_4Base_19__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret);
        Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Base_remarks(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Base_7remarks_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Base_scope(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Base_5scope_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Base__context_manager(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Base_16_context_manager_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Base_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Base_4name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Base__remarks(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Base_8_remarks_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Base__scope(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Base_6_scope_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_Base[] = {
  {"to_wkt", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_5to_wkt, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_4to_wkt},
  {"to_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_7to_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_6to_json},
  {"to_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_9to_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_8to_json_dict},
  {"_is_exact_same", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_15_is_exact_same, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_14_is_exact_same},
  {"_is_equivalent", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_17_is_equivalent, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_16_is_equivalent},
  {"is_exact_same", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_21is_exact_same, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_20is_exact_same},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_23__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_22__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Base_25__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Base_24__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_Base[] = {
  {"remarks", __pyx_getprop_6pyproj_4_crs_4Base_remarks, 0, PyDoc_STR("\n        .. versionadded:: 2.4.0\n\n        Returns\n        -------\n        str:\n            Remarks about object.\n        "), 0},
  {"scope", __pyx_getprop_6pyproj_4_crs_4Base_scope, 0, PyDoc_STR("\n        .. versionadded:: 2.4.0\n\n        Returns\n        -------\n        str:\n            Scope of object.\n        "), 0},
  {"_context_manager", __pyx_getprop_6pyproj_4_crs_4Base__context_manager, 0, 0, 0},
  {"name", __pyx_getprop_6pyproj_4_crs_4Base_name, 0, 0, 0},
  {"_remarks", __pyx_getprop_6pyproj_4_crs_4Base__remarks, 0, 0, 0},
  {"_scope", __pyx_getprop_6pyproj_4_crs_4Base__scope, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_Base_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Base},
  {Py_tp_repr, (void *)__pyx_pw_6pyproj_4_crs_4Base_13__repr__},
  {Py_tp_str, (void *)__pyx_pw_6pyproj_4_crs_4Base_11__str__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_Base},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_Base},
  {Py_tp_richcompare, (void *)__pyx_tp_richcompare_6pyproj_4_crs_Base},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_Base},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_Base},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_Base},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_Base_spec = {
  "pyproj._crs.Base",
  sizeof(struct __pyx_obj_6pyproj_4_crs_Base),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_Base_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_Base = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""Base", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_Base), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Base, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_Base, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_Base, /*tp_clear*/
  __pyx_tp_richcompare_6pyproj_4_crs_Base, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_Base, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_Base, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_Base, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs__CRSParts __pyx_vtable_6pyproj_4_crs__CRSParts;

static PyObject *__pyx_tp_new_6pyproj_4_crs__CRSParts(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs__CRSParts *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs_Base(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs__CRSParts *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs__CRSParts;
  return o;
}

static PyObject *__pyx_tp_richcompare_6pyproj_4_crs__CRSParts(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_6pyproj_4_crs_9_CRSParts_3__eq__(o1, o2);
    }
    case Py_NE: {
      PyObject *ret;
      ret = __pyx_pw_6pyproj_4_crs_9_CRSParts_3__eq__(o1, o2);
      if (likely(ret && ret != Py_NotImplemented)) {
        int b = __Pyx_PyObject_IsTrue(ret);
        Py_DECREF(ret);
        if (unlikely(b < 0)) return NULL;
        ret = (b) ? Py_False : Py_True;
        Py_INCREF(ret);
      }
      return ret;
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static PyMethodDef __pyx_methods_6pyproj_4_crs__CRSParts[] = {
  {"from_user_input", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9_CRSParts_1from_user_input, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9_CRSParts_from_user_input},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9_CRSParts_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9_CRSParts_4__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9_CRSParts_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9_CRSParts_6__setstate_cython__},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs__CRSParts_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Base},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_Base},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_Base},
  {Py_tp_richcompare, (void *)__pyx_tp_richcompare_6pyproj_4_crs__CRSParts},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs__CRSParts},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs__CRSParts},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs__CRSParts_spec = {
  "pyproj._crs._CRSParts",
  sizeof(struct __pyx_obj_6pyproj_4_crs__CRSParts),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs__CRSParts_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs__CRSParts = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""_CRSParts", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs__CRSParts), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Base, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_Base, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_Base, /*tp_clear*/
  __pyx_tp_richcompare_6pyproj_4_crs__CRSParts, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs__CRSParts, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs__CRSParts, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_Ellipsoid __pyx_vtable_6pyproj_4_crs_Ellipsoid;

static PyObject *__pyx_tp_new_6pyproj_4_crs_Ellipsoid(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_Ellipsoid *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs__CRSParts(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs_Ellipsoid;
  if (unlikely(__pyx_pw_6pyproj_4_crs_9Ellipsoid_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyObject *__pyx_getprop_6pyproj_4_crs_9Ellipsoid_semi_major_metre(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_9Ellipsoid_16semi_major_metre_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_9Ellipsoid_semi_minor_metre(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_9Ellipsoid_16semi_minor_metre_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_9Ellipsoid_is_semi_minor_computed(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_9Ellipsoid_22is_semi_minor_computed_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_9Ellipsoid_inverse_flattening(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_9Ellipsoid_18inverse_flattening_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_Ellipsoid[] = {
  {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_5from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_4from_authority},
  {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_7from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_6from_epsg},
  {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_9_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_8_from_string},
  {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_11from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_10from_string},
  {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_13from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_12from_json_dict},
  {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_15from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_14from_json},
  {"_from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_17_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_16_from_name},
  {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_19from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_18from_name},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_21__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_20__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_9Ellipsoid_23__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_9Ellipsoid_22__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_Ellipsoid[] = {
  {"semi_major_metre", __pyx_getprop_6pyproj_4_crs_9Ellipsoid_semi_major_metre, 0, 0, 0},
  {"semi_minor_metre", __pyx_getprop_6pyproj_4_crs_9Ellipsoid_semi_minor_metre, 0, 0, 0},
  {"is_semi_minor_computed", __pyx_getprop_6pyproj_4_crs_9Ellipsoid_is_semi_minor_computed, 0, 0, 0},
  {"inverse_flattening", __pyx_getprop_6pyproj_4_crs_9Ellipsoid_inverse_flattening, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_Ellipsoid_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Base},
  {Py_tp_doc, (void *)PyDoc_STR("Ellipsoid()\n\n.. versionadded:: 2.0.0\n\nEllipsoid for CRS\n\nAttributes\n----------\nname: str\n    The name of the ellipsoid.\nis_semi_minor_computed: int\n    1 if True, 0 if False\nsemi_major_metre: float\n    The semi major axis in meters of the ellipsoid.\nsemi_minor_metre: float\n    The semi minor axis in meters of the ellipsoid.\ninverse_flattening: float\n    The inverse flattening of the ellipsoid.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_Base},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_Base},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_Ellipsoid},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_Ellipsoid},
  {Py_tp_init, (void *)__pyx_pw_6pyproj_4_crs_9Ellipsoid_3__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_Ellipsoid},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_Ellipsoid_spec = {
  "pyproj._crs.Ellipsoid",
  sizeof(struct __pyx_obj_6pyproj_4_crs_Ellipsoid),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_Ellipsoid_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_Ellipsoid = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""Ellipsoid", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_Ellipsoid), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Base, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Ellipsoid()\n\n.. versionadded:: 2.0.0\n\nEllipsoid for CRS\n\nAttributes\n----------\nname: str\n    The name of the ellipsoid.\nis_semi_minor_computed: int\n    1 if True, 0 if False\nsemi_major_metre: float\n    The semi major axis in meters of the ellipsoid.\nsemi_minor_metre: float\n    The semi minor axis in meters of the ellipsoid.\ninverse_flattening: float\n    The inverse flattening of the ellipsoid."), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_Base, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_Base, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_Ellipsoid, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_Ellipsoid, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pyproj_4_crs_9Ellipsoid_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_Ellipsoid, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_PrimeMeridian __pyx_vtable_6pyproj_4_crs_PrimeMeridian;

static PyObject *__pyx_tp_new_6pyproj_4_crs_PrimeMeridian(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs__CRSParts(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs_PrimeMeridian;
  p->unit_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_13PrimeMeridian_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_PrimeMeridian(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *p = (struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_PrimeMeridian) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->unit_name);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pyproj_4_crs_Base(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_13PrimeMeridian_longitude(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_13PrimeMeridian_9longitude_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_13PrimeMeridian_unit_conversion_factor(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_13PrimeMeridian_22unit_conversion_factor_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_13PrimeMeridian_unit_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_13PrimeMeridian_9unit_name_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_PrimeMeridian[] = {
  {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_5from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_4from_authority},
  {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_7from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_6from_epsg},
  {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_9_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_8_from_string},
  {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_11from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_10from_string},
  {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_13from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_12from_json_dict},
  {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_15from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_14from_json},
  {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_17from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_16from_name},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_19__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_18__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_21__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_13PrimeMeridian_20__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_PrimeMeridian[] = {
  {"longitude", __pyx_getprop_6pyproj_4_crs_13PrimeMeridian_longitude, 0, 0, 0},
  {"unit_conversion_factor", __pyx_getprop_6pyproj_4_crs_13PrimeMeridian_unit_conversion_factor, 0, 0, 0},
  {"unit_name", __pyx_getprop_6pyproj_4_crs_13PrimeMeridian_unit_name, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_PrimeMeridian_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_PrimeMeridian},
  {Py_tp_doc, (void *)PyDoc_STR("PrimeMeridian()\n\n.. versionadded:: 2.0.0\n\nPrime Meridian for CRS\n\nAttributes\n----------\nname: str\n    The name of the prime meridian.\nunit_name: str\n    The unit name for the prime meridian.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_Base},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_Base},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_PrimeMeridian},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_PrimeMeridian},
  {Py_tp_init, (void *)__pyx_pw_6pyproj_4_crs_13PrimeMeridian_3__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_PrimeMeridian},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_PrimeMeridian_spec = {
  "pyproj._crs.PrimeMeridian",
  sizeof(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_PrimeMeridian_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_PrimeMeridian = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""PrimeMeridian", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_PrimeMeridian), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_PrimeMeridian, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("PrimeMeridian()\n\n.. versionadded:: 2.0.0\n\nPrime Meridian for CRS\n\nAttributes\n----------\nname: str\n    The name of the prime meridian.\nunit_name: str\n    The unit name for the prime meridian."), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_Base, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_Base, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_PrimeMeridian, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_PrimeMeridian, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pyproj_4_crs_13PrimeMeridian_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_PrimeMeridian, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_Datum __pyx_vtable_6pyproj_4_crs_Datum;

static PyObject *__pyx_tp_new_6pyproj_4_crs_Datum(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_Datum *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs__CRSParts(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_Datum *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs_Datum;
  p->type_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_ellipsoid = Py_None; Py_INCREF(Py_None);
  p->_prime_meridian = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_5Datum_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_Datum(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_Datum *p = (struct __pyx_obj_6pyproj_4_crs_Datum *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_Datum) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->type_name);
  Py_CLEAR(p->_ellipsoid);
  Py_CLEAR(p->_prime_meridian);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pyproj_4_crs_Base(o);
}

static int __pyx_tp_traverse_6pyproj_4_crs_Datum(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pyproj_4_crs_Datum *p = (struct __pyx_obj_6pyproj_4_crs_Datum *)o;
  e = __pyx_tp_traverse_6pyproj_4_crs_Base(o, v, a); if (e) return e;
  if (p->_ellipsoid) {
    e = (*v)(p->_ellipsoid, a); if (e) return e;
  }
  if (p->_prime_meridian) {
    e = (*v)(p->_prime_meridian, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pyproj_4_crs_Datum(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pyproj_4_crs_Datum *p = (struct __pyx_obj_6pyproj_4_crs_Datum *)o;
  __pyx_tp_clear_6pyproj_4_crs_Base(o);
  tmp = ((PyObject*)p->_ellipsoid);
  p->_ellipsoid = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_prime_meridian);
  p->_prime_meridian = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Datum_ellipsoid(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Datum_9ellipsoid_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Datum_prime_meridian(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Datum_14prime_meridian_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Datum_type_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Datum_9type_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Datum__ellipsoid(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Datum_10_ellipsoid_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Datum__prime_meridian(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Datum_15_prime_meridian_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_Datum[] = {
  {"_from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_5_from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_4_from_authority},
  {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_7from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_6from_authority},
  {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_9from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_8from_epsg},
  {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_11_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_10_from_string},
  {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_13from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_12from_string},
  {"_from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_15_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_14_from_name},
  {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_17from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_16from_name},
  {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_19from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_18from_json_dict},
  {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_21from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_20from_json},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_23__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_22__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Datum_25__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Datum_24__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_Datum[] = {
  {"ellipsoid", __pyx_getprop_6pyproj_4_crs_5Datum_ellipsoid, 0, PyDoc_STR("\n        Returns\n        -------\n        Ellipsoid:\n            The ellipsoid object with associated attributes.\n        "), 0},
  {"prime_meridian", __pyx_getprop_6pyproj_4_crs_5Datum_prime_meridian, 0, PyDoc_STR("\n        Returns\n        -------\n        PrimeMeridian:\n            The CRS prime meridian object with associated attributes.\n        "), 0},
  {"type_name", __pyx_getprop_6pyproj_4_crs_5Datum_type_name, 0, 0, 0},
  {"_ellipsoid", __pyx_getprop_6pyproj_4_crs_5Datum__ellipsoid, 0, 0, 0},
  {"_prime_meridian", __pyx_getprop_6pyproj_4_crs_5Datum__prime_meridian, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_Datum_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Datum},
  {Py_tp_doc, (void *)PyDoc_STR("Datum()\n\n.. versionadded:: 2.2.0\n\nDatum for CRS. If it is a compound CRS it is the horizontal datum.\n\nAttributes\n----------\nname: str\n    The name of the datum.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_Datum},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_Datum},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_Datum},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_Datum},
  {Py_tp_init, (void *)__pyx_pw_6pyproj_4_crs_5Datum_3__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_Datum},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_Datum_spec = {
  "pyproj._crs.Datum",
  sizeof(struct __pyx_obj_6pyproj_4_crs_Datum),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_Datum_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_Datum = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""Datum", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_Datum), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Datum, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("Datum()\n\n.. versionadded:: 2.2.0\n\nDatum for CRS. If it is a compound CRS it is the horizontal datum.\n\nAttributes\n----------\nname: str\n    The name of the datum."), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_Datum, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_Datum, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_Datum, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_Datum, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pyproj_4_crs_5Datum_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_Datum, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateSystem __pyx_vtable_6pyproj_4_crs_CoordinateSystem;

static PyObject *__pyx_tp_new_6pyproj_4_crs_CoordinateSystem(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs__CRSParts(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs_CoordinateSystem;
  p->_axis_list = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_16CoordinateSystem_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_CoordinateSystem(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *p = (struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_CoordinateSystem) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_axis_list);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pyproj_4_crs_Base(o);
}

static int __pyx_tp_traverse_6pyproj_4_crs_CoordinateSystem(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *p = (struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)o;
  e = __pyx_tp_traverse_6pyproj_4_crs_Base(o, v, a); if (e) return e;
  if (p->_axis_list) {
    e = (*v)(p->_axis_list, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pyproj_4_crs_CoordinateSystem(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *p = (struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)o;
  __pyx_tp_clear_6pyproj_4_crs_Base(o);
  tmp = ((PyObject*)p->_axis_list);
  p->_axis_list = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pyproj_4_crs_16CoordinateSystem_axis_list(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_16CoordinateSystem_9axis_list_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_16CoordinateSystem__axis_list(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_16CoordinateSystem_10_axis_list_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_CoordinateSystem[] = {
  {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_5from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_4from_string},
  {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_7from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_6from_json_dict},
  {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_9from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_8from_json},
  {"to_cf", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_11to_cf, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_10to_cf},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_13__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_12__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_15__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_16CoordinateSystem_14__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_CoordinateSystem[] = {
  {"axis_list", __pyx_getprop_6pyproj_4_crs_16CoordinateSystem_axis_list, 0, PyDoc_STR("\n        Returns\n        -------\n        list[Axis]:\n            The Axis list for the coordinate system.\n        "), 0},
  {"_axis_list", __pyx_getprop_6pyproj_4_crs_16CoordinateSystem__axis_list, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_CoordinateSystem_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_CoordinateSystem},
  {Py_tp_doc, (void *)PyDoc_STR("CoordinateSystem()\n\n.. versionadded:: 2.2.0\n\nCoordinate System for CRS\n\nAttributes\n----------\nname: str\n    The name of the coordinate system.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_CoordinateSystem},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_CoordinateSystem},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_CoordinateSystem},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_CoordinateSystem},
  {Py_tp_init, (void *)__pyx_pw_6pyproj_4_crs_16CoordinateSystem_3__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_CoordinateSystem},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_CoordinateSystem_spec = {
  "pyproj._crs.CoordinateSystem",
  sizeof(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_CoordinateSystem_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_CoordinateSystem = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""CoordinateSystem", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_CoordinateSystem), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_CoordinateSystem, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("CoordinateSystem()\n\n.. versionadded:: 2.2.0\n\nCoordinate System for CRS\n\nAttributes\n----------\nname: str\n    The name of the coordinate system."), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_CoordinateSystem, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_CoordinateSystem, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_CoordinateSystem, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_CoordinateSystem, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pyproj_4_crs_16CoordinateSystem_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_CoordinateSystem, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_Param __pyx_vtable_6pyproj_4_crs_Param;

static PyObject *__pyx_tp_new_6pyproj_4_crs_Param(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_Param *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_Param *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pyproj_4_crs_Param;
  p->name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->auth_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->code = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->value = Py_None; Py_INCREF(Py_None);
  p->unit_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->unit_auth_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->unit_code = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->unit_category = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_5Param_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_Param(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_Param *p = (struct __pyx_obj_6pyproj_4_crs_Param *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_Param) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->auth_name);
  Py_CLEAR(p->code);
  Py_CLEAR(p->value);
  Py_CLEAR(p->unit_name);
  Py_CLEAR(p->unit_auth_name);
  Py_CLEAR(p->unit_code);
  Py_CLEAR(p->unit_category);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_6pyproj_4_crs_Param(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pyproj_4_crs_Param *p = (struct __pyx_obj_6pyproj_4_crs_Param *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->value) {
    e = (*v)(p->value, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pyproj_4_crs_Param(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pyproj_4_crs_Param *p = (struct __pyx_obj_6pyproj_4_crs_Param *)o;
  tmp = ((PyObject*)p->value);
  p->value = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_4name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_auth_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_9auth_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_4code_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_value(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_5value_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_unit_conversion_factor(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_22unit_conversion_factor_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_unit_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_9unit_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_unit_auth_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_14unit_auth_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_unit_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_9unit_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_5Param_unit_category(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_5Param_13unit_category_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_Param[] = {
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Param_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Param_6__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_5Param_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_5Param_8__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_Param[] = {
  {"name", __pyx_getprop_6pyproj_4_crs_5Param_name, 0, 0, 0},
  {"auth_name", __pyx_getprop_6pyproj_4_crs_5Param_auth_name, 0, 0, 0},
  {"code", __pyx_getprop_6pyproj_4_crs_5Param_code, 0, 0, 0},
  {"value", __pyx_getprop_6pyproj_4_crs_5Param_value, 0, 0, 0},
  {"unit_conversion_factor", __pyx_getprop_6pyproj_4_crs_5Param_unit_conversion_factor, 0, 0, 0},
  {"unit_name", __pyx_getprop_6pyproj_4_crs_5Param_unit_name, 0, 0, 0},
  {"unit_auth_name", __pyx_getprop_6pyproj_4_crs_5Param_unit_auth_name, 0, 0, 0},
  {"unit_code", __pyx_getprop_6pyproj_4_crs_5Param_unit_code, 0, 0, 0},
  {"unit_category", __pyx_getprop_6pyproj_4_crs_5Param_unit_category, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_Param_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Param},
  {Py_tp_repr, (void *)__pyx_pw_6pyproj_4_crs_5Param_5__repr__},
  {Py_tp_str, (void *)__pyx_pw_6pyproj_4_crs_5Param_3__str__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    .. versionadded:: 2.2.0\n\n    Coordinate operation parameter.\n\n    Attributes\n    ----------\n    name: str\n        The name of the parameter.\n    auth_name: str\n        The authority name of the parameter (i.e. EPSG).\n    code: str\n        The code of the parameter (i.e. 9807).\n    value: str or double\n        The value of the parameter.\n    unit_conversion_factor: double\n        The factor to convert to meters.\n    unit_name: str\n        The name of the unit.\n    unit_auth_name: str\n        The authority name of the unit (i.e. EPSG).\n    unit_code: str\n        The code of the unit (i.e. 9807).\n    unit_category: str\n        The category of the unit (\342\200\234unknown\342\200\235, \342\200\234none\342\200\235, \342\200\234linear\342\200\235,\n        \342\200\234angular\342\200\235, \342\200\234scale\342\200\235, \342\200\234time\342\200\235 or \342\200\234parametric\342\200\235).\n\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_Param},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_Param},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_Param},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_Param},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_Param},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_Param_spec = {
  "pyproj._crs.Param",
  sizeof(struct __pyx_obj_6pyproj_4_crs_Param),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_Param_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_Param = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""Param", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_Param), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Param, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6pyproj_4_crs_5Param_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_6pyproj_4_crs_5Param_3__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    .. versionadded:: 2.2.0\n\n    Coordinate operation parameter.\n\n    Attributes\n    ----------\n    name: str\n        The name of the parameter.\n    auth_name: str\n        The authority name of the parameter (i.e. EPSG).\n    code: str\n        The code of the parameter (i.e. 9807).\n    value: str or double\n        The value of the parameter.\n    unit_conversion_factor: double\n        The factor to convert to meters.\n    unit_name: str\n        The name of the unit.\n    unit_auth_name: str\n        The authority name of the unit (i.e. EPSG).\n    unit_code: str\n        The code of the unit (i.e. 9807).\n    unit_category: str\n        The category of the unit (\342\200\234unknown\342\200\235, \342\200\234none\342\200\235, \342\200\234linear\342\200\235,\n        \342\200\234angular\342\200\235, \342\200\234scale\342\200\235, \342\200\234time\342\200\235 or \342\200\234parametric\342\200\235).\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_Param, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_Param, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_Param, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_Param, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_Param, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_Grid __pyx_vtable_6pyproj_4_crs_Grid;

static PyObject *__pyx_tp_new_6pyproj_4_crs_Grid(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_Grid *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_Grid *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pyproj_4_crs_Grid;
  p->short_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->full_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->package_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->url = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_4Grid_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_Grid(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_Grid *p = (struct __pyx_obj_6pyproj_4_crs_Grid *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_Grid) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  Py_CLEAR(p->short_name);
  Py_CLEAR(p->full_name);
  Py_CLEAR(p->package_name);
  Py_CLEAR(p->url);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_short_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_10short_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_full_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_9full_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_package_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_12package_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_url(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_3url_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_direct_download(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_15direct_download_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_open_license(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_12open_license_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4Grid_available(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4Grid_9available_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_Grid[] = {
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Grid_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Grid_6__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4Grid_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4Grid_8__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_Grid[] = {
  {"short_name", __pyx_getprop_6pyproj_4_crs_4Grid_short_name, 0, 0, 0},
  {"full_name", __pyx_getprop_6pyproj_4_crs_4Grid_full_name, 0, 0, 0},
  {"package_name", __pyx_getprop_6pyproj_4_crs_4Grid_package_name, 0, 0, 0},
  {"url", __pyx_getprop_6pyproj_4_crs_4Grid_url, 0, 0, 0},
  {"direct_download", __pyx_getprop_6pyproj_4_crs_4Grid_direct_download, 0, 0, 0},
  {"open_license", __pyx_getprop_6pyproj_4_crs_4Grid_open_license, 0, 0, 0},
  {"available", __pyx_getprop_6pyproj_4_crs_4Grid_available, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_Grid_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_Grid},
  {Py_tp_repr, (void *)__pyx_pw_6pyproj_4_crs_4Grid_5__repr__},
  {Py_tp_str, (void *)__pyx_pw_6pyproj_4_crs_4Grid_3__str__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    .. versionadded:: 2.2.0\n\n    Coordinate operation grid.\n\n    Attributes\n    ----------\n    short_name: str\n        The short name of the grid.\n    full_name: str\n        The full name of the grid.\n    package_name: str\n        The package name where the grid might be found.\n    url: str\n        The grid URL or the package URL where the grid might be found.\n    direct_download: int\n        If 1, *url* can be downloaded directly.\n    open_license: int\n        If 1, the grid is released with an open license.\n    available: int\n        If 1, the grid is available at runtime.\n\n    ")},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_Grid},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_Grid},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_Grid},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_Grid_spec = {
  "pyproj._crs.Grid",
  sizeof(struct __pyx_obj_6pyproj_4_crs_Grid),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pyproj_4_crs_Grid_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_Grid = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""Grid", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_Grid), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_Grid, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6pyproj_4_crs_4Grid_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_6pyproj_4_crs_4Grid_3__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  PyDoc_STR("\n    .. versionadded:: 2.2.0\n\n    Coordinate operation grid.\n\n    Attributes\n    ----------\n    short_name: str\n        The short name of the grid.\n    full_name: str\n        The full name of the grid.\n    package_name: str\n        The package name where the grid might be found.\n    url: str\n        The grid URL or the package URL where the grid might be found.\n    direct_download: int\n        If 1, *url* can be downloaded directly.\n    open_license: int\n        If 1, the grid is released with an open license.\n    available: int\n        If 1, the grid is available at runtime.\n\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_Grid, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_Grid, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_Grid, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs_CoordinateOperation __pyx_vtable_6pyproj_4_crs_CoordinateOperation;

static PyObject *__pyx_tp_new_6pyproj_4_crs_CoordinateOperation(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs__CRSParts(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs_CoordinateOperation;
  p->_params = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_grids = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_area_of_use = Py_None; Py_INCREF(Py_None);
  p->method_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->method_auth_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->method_code = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_towgs84 = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_operations = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->type_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_19CoordinateOperation_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs_CoordinateOperation(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *p = (struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs_CoordinateOperation) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_params);
  Py_CLEAR(p->_grids);
  Py_CLEAR(p->_area_of_use);
  Py_CLEAR(p->method_name);
  Py_CLEAR(p->method_auth_name);
  Py_CLEAR(p->method_code);
  Py_CLEAR(p->_towgs84);
  Py_CLEAR(p->_operations);
  Py_CLEAR(p->type_name);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pyproj_4_crs_Base(o);
}

static int __pyx_tp_traverse_6pyproj_4_crs_CoordinateOperation(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *p = (struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)o;
  e = __pyx_tp_traverse_6pyproj_4_crs_Base(o, v, a); if (e) return e;
  if (p->_params) {
    e = (*v)(p->_params, a); if (e) return e;
  }
  if (p->_grids) {
    e = (*v)(p->_grids, a); if (e) return e;
  }
  if (p->_area_of_use) {
    e = (*v)(p->_area_of_use, a); if (e) return e;
  }
  if (p->_towgs84) {
    e = (*v)(p->_towgs84, a); if (e) return e;
  }
  if (p->_operations) {
    e = (*v)(p->_operations, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pyproj_4_crs_CoordinateOperation(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *p = (struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)o;
  __pyx_tp_clear_6pyproj_4_crs_Base(o);
  tmp = ((PyObject*)p->_params);
  p->_params = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_grids);
  p->_grids = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_area_of_use);
  p->_area_of_use = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_towgs84);
  p->_towgs84 = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_operations);
  p->_operations = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_params(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_6params_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_grids(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_5grids_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_area_of_use(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_11area_of_use_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_towgs84(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_7towgs84_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_operations(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_10operations_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation__params(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_7_params_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation__grids(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_6_grids_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation__area_of_use(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_12_area_of_use_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_method_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_11method_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_method_auth_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_16method_auth_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_method_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_11method_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_accuracy(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_8accuracy_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_is_instantiable(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_15is_instantiable_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_has_ballpark_transformation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_27has_ballpark_transformation_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation__towgs84(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_8_towgs84_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation__operations(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_11_operations_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_19CoordinateOperation_type_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_19CoordinateOperation_9type_name_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs_CoordinateOperation[] = {
  {"from_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_5from_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_4from_authority},
  {"from_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_7from_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_6from_epsg},
  {"_from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_9_from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_8_from_string},
  {"from_string", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_11from_string, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_10from_string},
  {"from_json_dict", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_13from_json_dict, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_12from_json_dict},
  {"from_json", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_15from_json, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_14from_json},
  {"from_name", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_17from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_16from_name},
  {"to_proj4", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_19to_proj4, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_18to_proj4},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_23__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_22__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_25__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_19CoordinateOperation_24__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs_CoordinateOperation[] = {
  {"params", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_params, 0, PyDoc_STR("\n        Returns\n        -------\n        list[Param]:\n            The coordinate operation parameters.\n        "), 0},
  {"grids", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_grids, 0, PyDoc_STR("\n        Returns\n        -------\n        list[Grid]:\n            The coordinate operation grids.\n        "), 0},
  {"area_of_use", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_area_of_use, 0, PyDoc_STR("\n        Returns\n        -------\n        AreaOfUse:\n            The area of use object with associated attributes.\n        "), 0},
  {"towgs84", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_towgs84, 0, PyDoc_STR("\n        Returns\n        -------\n        list[float]:\n            A list of 3 or 7 towgs84 values if they exist.\n\n        "), 0},
  {"operations", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_operations, 0, PyDoc_STR("\n        .. versionadded:: 2.4.0\n\n        Returns\n        -------\n        tuple[CoordinateOperation]:\n            The operations in a concatenated operation.\n\n        "), 0},
  {"_params", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation__params, 0, 0, 0},
  {"_grids", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation__grids, 0, 0, 0},
  {"_area_of_use", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation__area_of_use, 0, 0, 0},
  {"method_name", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_method_name, 0, 0, 0},
  {"method_auth_name", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_method_auth_name, 0, 0, 0},
  {"method_code", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_method_code, 0, 0, 0},
  {"accuracy", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_accuracy, 0, 0, 0},
  {"is_instantiable", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_is_instantiable, 0, 0, 0},
  {"has_ballpark_transformation", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_has_ballpark_transformation, 0, 0, 0},
  {"_towgs84", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation__towgs84, 0, 0, 0},
  {"_operations", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation__operations, 0, 0, 0},
  {"type_name", __pyx_getprop_6pyproj_4_crs_19CoordinateOperation_type_name, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs_CoordinateOperation_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs_CoordinateOperation},
  {Py_tp_repr, (void *)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_21__repr__},
  {Py_tp_doc, (void *)PyDoc_STR("CoordinateOperation()\n\n.. versionadded:: 2.2.0\n\nCoordinate operation for CRS.\n\nAttributes\n----------\nname: str\n    The name of the method(projection) with authority information.\nmethod_name: str\n    The method (projection) name.\nmethod_auth_name: str\n    The method authority name.\nmethod_code: str\n    The method code.\nis_instantiable: int\n    If 1, a coordinate operation can be instantiated as a PROJ pipeline.\n    This also checks that referenced grids are available.\nhas_ballpark_transformation: int\n    If 1, the coordinate operation has a \342\200\234ballpark\342\200\235 transformation,\n    that is a very approximate one, due to lack of more accurate transformations.\naccuracy: float\n    The accuracy (in metre) of a coordinate operation.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs_CoordinateOperation},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs_CoordinateOperation},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs_CoordinateOperation},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs_CoordinateOperation},
  {Py_tp_init, (void *)__pyx_pw_6pyproj_4_crs_19CoordinateOperation_3__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs_CoordinateOperation},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs_CoordinateOperation_spec = {
  "pyproj._crs.CoordinateOperation",
  sizeof(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs_CoordinateOperation_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs_CoordinateOperation = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""CoordinateOperation", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs_CoordinateOperation), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs_CoordinateOperation, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  __pyx_pw_6pyproj_4_crs_19CoordinateOperation_21__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("CoordinateOperation()\n\n.. versionadded:: 2.2.0\n\nCoordinate operation for CRS.\n\nAttributes\n----------\nname: str\n    The name of the method(projection) with authority information.\nmethod_name: str\n    The method (projection) name.\nmethod_auth_name: str\n    The method authority name.\nmethod_code: str\n    The method code.\nis_instantiable: int\n    If 1, a coordinate operation can be instantiated as a PROJ pipeline.\n    This also checks that referenced grids are available.\nhas_ballpark_transformation: int\n    If 1, the coordinate operation has a \342\200\234ballpark\342\200\235 transformation,\n    that is a very approximate one, due to lack of more accurate transformations.\naccuracy: float\n    The accuracy (in metre) of a coordinate operation."), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs_CoordinateOperation, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs_CoordinateOperation, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs_CoordinateOperation, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs_CoordinateOperation, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pyproj_4_crs_19CoordinateOperation_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs_CoordinateOperation, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pyproj_4_crs__CRS __pyx_vtable_6pyproj_4_crs__CRS;

static PyObject *__pyx_tp_new_6pyproj_4_crs__CRS(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pyproj_4_crs__CRS *p;
  PyObject *o = __pyx_tp_new_6pyproj_4_crs_Base(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pyproj_4_crs__CRS *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pyproj_4_crs_Base*)__pyx_vtabptr_6pyproj_4_crs__CRS;
  p->srs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_type_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_ellipsoid = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)Py_None); Py_INCREF(Py_None);
  p->_area_of_use = Py_None; Py_INCREF(Py_None);
  p->_prime_meridian = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)Py_None); Py_INCREF(Py_None);
  p->_datum = ((struct __pyx_obj_6pyproj_4_crs_Datum *)Py_None); Py_INCREF(Py_None);
  p->_sub_crs_list = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_source_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None); Py_INCREF(Py_None);
  p->_target_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None); Py_INCREF(Py_None);
  p->_geodetic_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None); Py_INCREF(Py_None);
  p->_coordinate_system = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)Py_None); Py_INCREF(Py_None);
  p->_coordinate_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pyproj_4_crs_4_CRS_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pyproj_4_crs__CRS(PyObject *o) {
  struct __pyx_obj_6pyproj_4_crs__CRS *p = (struct __pyx_obj_6pyproj_4_crs__CRS *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pyproj_4_crs__CRS) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->srs);
  Py_CLEAR(p->_type_name);
  Py_CLEAR(p->_ellipsoid);
  Py_CLEAR(p->_area_of_use);
  Py_CLEAR(p->_prime_meridian);
  Py_CLEAR(p->_datum);
  Py_CLEAR(p->_sub_crs_list);
  Py_CLEAR(p->_source_crs);
  Py_CLEAR(p->_target_crs);
  Py_CLEAR(p->_geodetic_crs);
  Py_CLEAR(p->_coordinate_system);
  Py_CLEAR(p->_coordinate_operation);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pyproj_4_crs_Base(o);
}

static int __pyx_tp_traverse_6pyproj_4_crs__CRS(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pyproj_4_crs__CRS *p = (struct __pyx_obj_6pyproj_4_crs__CRS *)o;
  e = __pyx_tp_traverse_6pyproj_4_crs_Base(o, v, a); if (e) return e;
  if (p->_ellipsoid) {
    e = (*v)(((PyObject *)p->_ellipsoid), a); if (e) return e;
  }
  if (p->_area_of_use) {
    e = (*v)(p->_area_of_use, a); if (e) return e;
  }
  if (p->_prime_meridian) {
    e = (*v)(((PyObject *)p->_prime_meridian), a); if (e) return e;
  }
  if (p->_datum) {
    e = (*v)(((PyObject *)p->_datum), a); if (e) return e;
  }
  if (p->_sub_crs_list) {
    e = (*v)(p->_sub_crs_list, a); if (e) return e;
  }
  if (p->_source_crs) {
    e = (*v)(((PyObject *)p->_source_crs), a); if (e) return e;
  }
  if (p->_target_crs) {
    e = (*v)(((PyObject *)p->_target_crs), a); if (e) return e;
  }
  if (p->_geodetic_crs) {
    e = (*v)(((PyObject *)p->_geodetic_crs), a); if (e) return e;
  }
  if (p->_coordinate_system) {
    e = (*v)(((PyObject *)p->_coordinate_system), a); if (e) return e;
  }
  if (p->_coordinate_operation) {
    e = (*v)(((PyObject *)p->_coordinate_operation), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pyproj_4_crs__CRS(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pyproj_4_crs__CRS *p = (struct __pyx_obj_6pyproj_4_crs__CRS *)o;
  __pyx_tp_clear_6pyproj_4_crs_Base(o);
  tmp = ((PyObject*)p->_ellipsoid);
  p->_ellipsoid = ((struct __pyx_obj_6pyproj_4_crs_Ellipsoid *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_area_of_use);
  p->_area_of_use = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_prime_meridian);
  p->_prime_meridian = ((struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_datum);
  p->_datum = ((struct __pyx_obj_6pyproj_4_crs_Datum *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_sub_crs_list);
  p->_sub_crs_list = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_source_crs);
  p->_source_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_target_crs);
  p->_target_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_geodetic_crs);
  p->_geodetic_crs = ((struct __pyx_obj_6pyproj_4_crs__CRS *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_coordinate_system);
  p->_coordinate_system = ((struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_coordinate_operation);
  p->_coordinate_operation = ((struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_type_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_9type_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_axis_info(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_9axis_info_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_area_of_use(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_11area_of_use_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_ellipsoid(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_9ellipsoid_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_prime_meridian(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_14prime_meridian_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_datum(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_5datum_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_coordinate_system(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_17coordinate_system_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_coordinate_operation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_20coordinate_operation_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_source_crs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_10source_crs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_target_crs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_10target_crs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_sub_crs_list(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_12sub_crs_list_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_geodetic_crs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_12geodetic_crs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_geographic(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_13is_geographic_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_projected(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_12is_projected_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_vertical(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_11is_vertical_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_bound(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_8is_bound_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_compound(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_11is_compound_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_engineering(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_14is_engineering_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_geocentric(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_13is_geocentric_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_derived(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_10is_derived_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_is_deprecated(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_13is_deprecated_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS_srs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_3srs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__type_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_10_type_name_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__ellipsoid(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_10_ellipsoid_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__area_of_use(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_12_area_of_use_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__prime_meridian(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_15_prime_meridian_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__datum(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_6_datum_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__sub_crs_list(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_13_sub_crs_list_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__source_crs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_11_source_crs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__target_crs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_11_target_crs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__geodetic_crs(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_13_geodetic_crs_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__coordinate_system(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_18_coordinate_system_1__get__(o);
}

static PyObject *__pyx_getprop_6pyproj_4_crs_4_CRS__coordinate_operation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pyproj_4_crs_4_CRS_21_coordinate_operation_1__get__(o);
}

static PyMethodDef __pyx_methods_6pyproj_4_crs__CRS[] = {
  {"to_proj4", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_5to_proj4, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_4to_proj4},
  {"to_epsg", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_7to_epsg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_6to_epsg},
  {"to_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_9to_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_8to_authority},
  {"list_authority", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_11list_authority, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_10list_authority},
  {"to_3d", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_13to_3d, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_12to_3d},
  {"to_2d", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_15to_2d, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_14to_2d},
  {"_is_crs_property", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_17_is_crs_property, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_16_is_crs_property},
  {"_equals", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_19_equals, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_18_equals},
  {"equals", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_21equals, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_20equals},
  {"get_non_deprecated", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_23get_non_deprecated, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_22get_non_deprecated},
  {"__reduce_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_25__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_24__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pyproj_4_crs_4_CRS_27__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pyproj_4_crs_4_CRS_26__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pyproj_4_crs__CRS[] = {
  {"type_name", __pyx_getprop_6pyproj_4_crs_4_CRS_type_name, 0, PyDoc_STR("\n        Returns\n        -------\n        str:\n            The name of the type of the CRS object.\n        "), 0},
  {"axis_info", __pyx_getprop_6pyproj_4_crs_4_CRS_axis_info, 0, PyDoc_STR("\n        Retrieves all relevant axis information in the CRS.\n        If it is a Bound CRS, it gets the axis list from the Source CRS.\n        If it is a Compound CRS, it gets the axis list from the Sub CRS list.\n\n        Returns\n        -------\n        list[Axis]:\n            The list of axis information.\n        "), 0},
  {"area_of_use", __pyx_getprop_6pyproj_4_crs_4_CRS_area_of_use, 0, PyDoc_STR("\n        Returns\n        -------\n        AreaOfUse:\n            The area of use object with associated attributes.\n        "), 0},
  {"ellipsoid", __pyx_getprop_6pyproj_4_crs_4_CRS_ellipsoid, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        Ellipsoid:\n            The ellipsoid object with associated attributes.\n        "), 0},
  {"prime_meridian", __pyx_getprop_6pyproj_4_crs_4_CRS_prime_meridian, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        PrimeMeridian:\n            The prime meridian object with associated attributes.\n        "), 0},
  {"datum", __pyx_getprop_6pyproj_4_crs_4_CRS_datum, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        Datum\n        "), 0},
  {"coordinate_system", __pyx_getprop_6pyproj_4_crs_4_CRS_coordinate_system, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        CoordinateSystem\n        "), 0},
  {"coordinate_operation", __pyx_getprop_6pyproj_4_crs_4_CRS_coordinate_operation, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        CoordinateOperation\n        "), 0},
  {"source_crs", __pyx_getprop_6pyproj_4_crs_4_CRS_source_crs, 0, PyDoc_STR("\n        Returns\n        -------\n        _CRS:\n            The base CRS of a BoundCRS or a DerivedCRS/ProjectedCRS.\n        "), 0},
  {"target_crs", __pyx_getprop_6pyproj_4_crs_4_CRS_target_crs, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        _CRS:\n            The hub CRS of a BoundCRS.\n        "), 0},
  {"sub_crs_list", __pyx_getprop_6pyproj_4_crs_4_CRS_sub_crs_list, 0, PyDoc_STR("\n        If the CRS is a compound CRS, it will return a list of sub CRS objects.\n\n        Returns\n        -------\n        list[_CRS]\n        "), 0},
  {"geodetic_crs", __pyx_getprop_6pyproj_4_crs_4_CRS_geodetic_crs, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        The geodeticCRS / geographicCRS from the CRS.\n\n        Returns\n        -------\n        _CRS\n        "), 0},
  {"is_geographic", __pyx_getprop_6pyproj_4_crs_4_CRS_is_geographic, 0, PyDoc_STR("\n        This checks if the CRS is geographic.\n        It will check if it has a geographic CRS\n        in the sub CRS if it is a compound CRS and will check if\n        the source CRS is geographic if it is a bound CRS.\n\n        Returns\n        -------\n        bool:\n            True if the CRS is in geographic (lon/lat) coordinates.\n        "), 0},
  {"is_projected", __pyx_getprop_6pyproj_4_crs_4_CRS_is_projected, 0, PyDoc_STR("\n        This checks if the CRS is projected.\n        It will check if it has a projected CRS\n        in the sub CRS if it is a compound CRS and will check if\n        the source CRS is projected if it is a bound CRS.\n\n        Returns\n        -------\n        bool:\n            True if CRS is projected.\n        "), 0},
  {"is_vertical", __pyx_getprop_6pyproj_4_crs_4_CRS_is_vertical, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        This checks if the CRS is vertical.\n        It will check if it has a vertical CRS\n        in the sub CRS if it is a compound CRS and will check if\n        the source CRS is vertical if it is a bound CRS.\n\n        Returns\n        -------\n        bool:\n            True if CRS is vertical.\n        "), 0},
  {"is_bound", __pyx_getprop_6pyproj_4_crs_4_CRS_is_bound, 0, PyDoc_STR("\n        Returns\n        -------\n        bool:\n            True if CRS is bound.\n        "), 0},
  {"is_compound", __pyx_getprop_6pyproj_4_crs_4_CRS_is_compound, 0, PyDoc_STR("\n        .. versionadded:: 3.1.0\n\n        Returns\n        -------\n        bool:\n            True if CRS is compound.\n        "), 0},
  {"is_engineering", __pyx_getprop_6pyproj_4_crs_4_CRS_is_engineering, 0, PyDoc_STR("\n        .. versionadded:: 2.2.0\n\n        Returns\n        -------\n        bool:\n            True if CRS is local/engineering.\n        "), 0},
  {"is_geocentric", __pyx_getprop_6pyproj_4_crs_4_CRS_is_geocentric, 0, PyDoc_STR("\n        This checks if the CRS is geocentric and\n        takes into account if the CRS is bound.\n\n        Returns\n        -------\n        bool:\n            True if CRS is in geocentric (x/y) coordinates.\n        "), 0},
  {"is_derived", __pyx_getprop_6pyproj_4_crs_4_CRS_is_derived, 0, PyDoc_STR("\n        .. versionadded:: 3.2.0\n\n        Returns\n        -------\n        bool:\n            True if CRS is a Derived CRS.\n        "), 0},
  {"is_deprecated", __pyx_getprop_6pyproj_4_crs_4_CRS_is_deprecated, 0, PyDoc_STR("\n        .. versionadded:: 3.7.0\n\n        Check if the CRS is deprecated\n\n        Returns\n        -------\n        bool\n        "), 0},
  {"srs", __pyx_getprop_6pyproj_4_crs_4_CRS_srs, 0, 0, 0},
  {"_type_name", __pyx_getprop_6pyproj_4_crs_4_CRS__type_name, 0, 0, 0},
  {"_ellipsoid", __pyx_getprop_6pyproj_4_crs_4_CRS__ellipsoid, 0, 0, 0},
  {"_area_of_use", __pyx_getprop_6pyproj_4_crs_4_CRS__area_of_use, 0, 0, 0},
  {"_prime_meridian", __pyx_getprop_6pyproj_4_crs_4_CRS__prime_meridian, 0, 0, 0},
  {"_datum", __pyx_getprop_6pyproj_4_crs_4_CRS__datum, 0, 0, 0},
  {"_sub_crs_list", __pyx_getprop_6pyproj_4_crs_4_CRS__sub_crs_list, 0, 0, 0},
  {"_source_crs", __pyx_getprop_6pyproj_4_crs_4_CRS__source_crs, 0, 0, 0},
  {"_target_crs", __pyx_getprop_6pyproj_4_crs_4_CRS__target_crs, 0, 0, 0},
  {"_geodetic_crs", __pyx_getprop_6pyproj_4_crs_4_CRS__geodetic_crs, 0, 0, 0},
  {"_coordinate_system", __pyx_getprop_6pyproj_4_crs_4_CRS__coordinate_system, 0, 0, 0},
  {"_coordinate_operation", __pyx_getprop_6pyproj_4_crs_4_CRS__coordinate_operation, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pyproj_4_crs__CRS_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pyproj_4_crs__CRS},
  {Py_tp_doc, (void *)PyDoc_STR("_CRS(str proj_string)\n\n.. versionadded:: 2.0.0\n\nThe cython CRS class to be used as the base for the\npython CRS class.")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pyproj_4_crs__CRS},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pyproj_4_crs__CRS},
  {Py_tp_methods, (void *)__pyx_methods_6pyproj_4_crs__CRS},
  {Py_tp_getset, (void *)__pyx_getsets_6pyproj_4_crs__CRS},
  {Py_tp_init, (void *)__pyx_pw_6pyproj_4_crs_4_CRS_3__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pyproj_4_crs__CRS},
  {0, 0},
};
static PyType_Spec __pyx_type_6pyproj_4_crs__CRS_spec = {
  "pyproj._crs._CRS",
  sizeof(struct __pyx_obj_6pyproj_4_crs__CRS),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pyproj_4_crs__CRS_slots,
};
#else

static PyTypeObject __pyx_type_6pyproj_4_crs__CRS = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyproj._crs.""_CRS", /*tp_name*/
  sizeof(struct __pyx_obj_6pyproj_4_crs__CRS), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pyproj_4_crs__CRS, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_13__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pyproj_4_crs_4Base_11__str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("_CRS(str proj_string)\n\n.. versionadded:: 2.0.0\n\nThe cython CRS class to be used as the base for the\npython CRS class."), /*tp_doc*/
  __pyx_tp_traverse_6pyproj_4_crs__CRS, /*tp_traverse*/
  __pyx_tp_clear_6pyproj_4_crs__CRS, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pyproj_4_crs__CRS, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pyproj_4_crs__CRS, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pyproj_4_crs_4_CRS_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pyproj_4_crs__CRS, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6pyproj_4_crs__PJ_ELLPS_NAME_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6pyproj_4_crs__COORD_SYSTEM_TYPE_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6pyproj_4_crs__COORDINATE_OPERATION_TYPE_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6pyproj_4_crs__PJ_COORDINATE_OPERATION_TYPE_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6pyproj_4_crs__CRS_TYPE_MAP = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id = Py_None; Py_INCREF(Py_None);
  __pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  {
    __pyx_t_1 = __Pyx_ApiExport_GetApiDict(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_export_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PJ_CONTEXT_PJ_PyObject);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_export_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_export_name = __pyx_export_signature + 194;
    void (*const __pyx_export_pointers[])(void) = {(void (*)(void))&__pyx_f_6pyproj_4_crs__get_concatenated_operations, (void (*)(void))&__pyx_f_6pyproj_4_crs_create_area_of_use, (void (*)(void))&__pyx_f_6pyproj_4_crs__to_proj4, (void (*)(void))&__pyx_f_6pyproj_4_crs__to_wkt, (void (*)(void)) NULL};
    void (*const *__pyx_export_pointer)(void) = __pyx_export_pointers;
    const char *__pyx_export_current_signature = __pyx_export_signature;
    while (*__pyx_export_pointer) {
      if (__Pyx_ExportFunction(__pyx_t_1, __pyx_export_name, *__pyx_export_pointer, __pyx_export_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_export_pointer;
      __pyx_export_name = strchr(__pyx_export_name, '\0') + 1;
      __pyx_export_signature = strchr(__pyx_export_signature, '\0') + 1;
      if (*__pyx_export_signature != '\0') __pyx_export_current_signature = __pyx_export_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6pyproj_4_crs_Axis = &__pyx_vtable_6pyproj_4_crs_Axis;
  __pyx_vtable_6pyproj_4_crs_Axis.create = (struct __pyx_obj_6pyproj_4_crs_Axis *(*)(PJ_CONTEXT *, PJ *, int))__pyx_f_6pyproj_4_crs_4Axis_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_Axis_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis)) __PYX_ERR(0, 259, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_Axis_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis) < (0)) __PYX_ERR(0, 259, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis = &__pyx_type_6pyproj_4_crs_Axis;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis) < (0)) __PYX_ERR(0, 259, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis, __pyx_vtabptr_6pyproj_4_crs_Axis) < (0)) __PYX_ERR(0, 259, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis) < (0)) __PYX_ERR(0, 259, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Axis, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis) < (0)) __PYX_ERR(0, 259, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Axis) < (0)) __PYX_ERR(0, 259, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_Base = &__pyx_vtable_6pyproj_4_crs_Base;
  __pyx_vtable_6pyproj_4_crs_Base._set_base_info = (PyObject *(*)(struct __pyx_obj_6pyproj_4_crs_Base *))__pyx_f_6pyproj_4_crs_4Base__set_base_info;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_Base_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base)) __PYX_ERR(0, 353, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_Base_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base) < (0)) __PYX_ERR(0, 353, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base = &__pyx_type_6pyproj_4_crs_Base;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base) < (0)) __PYX_ERR(0, 353, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base, __pyx_vtabptr_6pyproj_4_crs_Base) < (0)) __PYX_ERR(0, 353, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base) < (0)) __PYX_ERR(0, 353, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Base, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base) < (0)) __PYX_ERR(0, 353, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Base) < (0)) __PYX_ERR(0, 353, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs__CRSParts = &__pyx_vtable_6pyproj_4_crs__CRSParts;
  __pyx_vtable_6pyproj_4_crs__CRSParts.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs_Base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs__CRSParts_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts)) __PYX_ERR(0, 505, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs__CRSParts_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts = &__pyx_type_6pyproj_4_crs__CRSParts;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts, __pyx_vtabptr_6pyproj_4_crs__CRSParts) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CRSParts, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRSParts) < (0)) __PYX_ERR(0, 505, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_Ellipsoid = &__pyx_vtable_6pyproj_4_crs_Ellipsoid;
  __pyx_vtable_6pyproj_4_crs_Ellipsoid.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs__CRSParts;
  __pyx_vtable_6pyproj_4_crs_Ellipsoid.create = (struct __pyx_obj_6pyproj_4_crs_Ellipsoid *(*)(PJ_CONTEXT *, PJ *))__pyx_f_6pyproj_4_crs_9Ellipsoid_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_Ellipsoid_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid)) __PYX_ERR(0, 783, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_Ellipsoid_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid = &__pyx_type_6pyproj_4_crs_Ellipsoid;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_vtabptr_6pyproj_4_crs_Ellipsoid) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Ellipsoid, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Ellipsoid) < (0)) __PYX_ERR(0, 783, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_PrimeMeridian = &__pyx_vtable_6pyproj_4_crs_PrimeMeridian;
  __pyx_vtable_6pyproj_4_crs_PrimeMeridian.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs__CRSParts;
  __pyx_vtable_6pyproj_4_crs_PrimeMeridian.create = (struct __pyx_obj_6pyproj_4_crs_PrimeMeridian *(*)(PJ_CONTEXT *, PJ *))__pyx_f_6pyproj_4_crs_13PrimeMeridian_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_PrimeMeridian_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian)) __PYX_ERR(0, 1070, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_PrimeMeridian_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian) < (0)) __PYX_ERR(0, 1070, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian = &__pyx_type_6pyproj_4_crs_PrimeMeridian;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian) < (0)) __PYX_ERR(0, 1070, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_vtabptr_6pyproj_4_crs_PrimeMeridian) < (0)) __PYX_ERR(0, 1070, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian) < (0)) __PYX_ERR(0, 1070, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_PrimeMeridian, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian) < (0)) __PYX_ERR(0, 1070, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_PrimeMeridian) < (0)) __PYX_ERR(0, 1070, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_Datum = &__pyx_vtable_6pyproj_4_crs_Datum;
  __pyx_vtable_6pyproj_4_crs_Datum.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs__CRSParts;
  __pyx_vtable_6pyproj_4_crs_Datum.create = (struct __pyx_obj_6pyproj_4_crs_Datum *(*)(PJ_CONTEXT *, PJ *))__pyx_f_6pyproj_4_crs_5Datum_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_Datum_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum)) __PYX_ERR(0, 1329, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_Datum_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum) < (0)) __PYX_ERR(0, 1329, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum = &__pyx_type_6pyproj_4_crs_Datum;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum) < (0)) __PYX_ERR(0, 1329, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_vtabptr_6pyproj_4_crs_Datum) < (0)) __PYX_ERR(0, 1329, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum) < (0)) __PYX_ERR(0, 1329, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Datum, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum) < (0)) __PYX_ERR(0, 1329, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Datum) < (0)) __PYX_ERR(0, 1329, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_CoordinateSystem = &__pyx_vtable_6pyproj_4_crs_CoordinateSystem;
  __pyx_vtable_6pyproj_4_crs_CoordinateSystem.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs__CRSParts;
  __pyx_vtable_6pyproj_4_crs_CoordinateSystem.create = (struct __pyx_obj_6pyproj_4_crs_CoordinateSystem *(*)(PJ_CONTEXT *, PJ *))__pyx_f_6pyproj_4_crs_16CoordinateSystem_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_CoordinateSystem_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem)) __PYX_ERR(0, 568, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_CoordinateSystem_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem) < (0)) __PYX_ERR(0, 568, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem = &__pyx_type_6pyproj_4_crs_CoordinateSystem;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem) < (0)) __PYX_ERR(0, 568, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_vtabptr_6pyproj_4_crs_CoordinateSystem) < (0)) __PYX_ERR(0, 568, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem) < (0)) __PYX_ERR(0, 568, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CoordinateSystem, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem) < (0)) __PYX_ERR(0, 568, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateSystem) < (0)) __PYX_ERR(0, 568, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_Param = &__pyx_vtable_6pyproj_4_crs_Param;
  __pyx_vtable_6pyproj_4_crs_Param.create = (struct __pyx_obj_6pyproj_4_crs_Param *(*)(PJ_CONTEXT *, PJ *, int))__pyx_f_6pyproj_4_crs_5Param_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_Param_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param)) __PYX_ERR(0, 1667, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_Param_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param) < (0)) __PYX_ERR(0, 1667, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param = &__pyx_type_6pyproj_4_crs_Param;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param) < (0)) __PYX_ERR(0, 1667, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param, __pyx_vtabptr_6pyproj_4_crs_Param) < (0)) __PYX_ERR(0, 1667, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param) < (0)) __PYX_ERR(0, 1667, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Param, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param) < (0)) __PYX_ERR(0, 1667, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Param) < (0)) __PYX_ERR(0, 1667, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_Grid = &__pyx_vtable_6pyproj_4_crs_Grid;
  __pyx_vtable_6pyproj_4_crs_Grid.create = (struct __pyx_obj_6pyproj_4_crs_Grid *(*)(PJ_CONTEXT *, PJ *, int))__pyx_f_6pyproj_4_crs_4Grid_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_Grid_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid)) __PYX_ERR(0, 1760, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_Grid_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid) < (0)) __PYX_ERR(0, 1760, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid = &__pyx_type_6pyproj_4_crs_Grid;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid) < (0)) __PYX_ERR(0, 1760, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid, __pyx_vtabptr_6pyproj_4_crs_Grid) < (0)) __PYX_ERR(0, 1760, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid) < (0)) __PYX_ERR(0, 1760, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Grid, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid) < (0)) __PYX_ERR(0, 1760, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_Grid) < (0)) __PYX_ERR(0, 1760, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs_CoordinateOperation = &__pyx_vtable_6pyproj_4_crs_CoordinateOperation;
  __pyx_vtable_6pyproj_4_crs_CoordinateOperation.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs__CRSParts;
  __pyx_vtable_6pyproj_4_crs_CoordinateOperation.create = (struct __pyx_obj_6pyproj_4_crs_CoordinateOperation *(*)(PJ_CONTEXT *, PJ *))__pyx_f_6pyproj_4_crs_19CoordinateOperation_create;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs_CoordinateOperation_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation)) __PYX_ERR(0, 1855, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs_CoordinateOperation_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation) < (0)) __PYX_ERR(0, 1855, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation = &__pyx_type_6pyproj_4_crs_CoordinateOperation;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation) < (0)) __PYX_ERR(0, 1855, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_vtabptr_6pyproj_4_crs_CoordinateOperation) < (0)) __PYX_ERR(0, 1855, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation) < (0)) __PYX_ERR(0, 1855, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CoordinateOperation, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation) < (0)) __PYX_ERR(0, 1855, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs_CoordinateOperation) < (0)) __PYX_ERR(0, 1855, __pyx_L1_error)
  __pyx_vtabptr_6pyproj_4_crs__CRS = &__pyx_vtable_6pyproj_4_crs__CRS;
  __pyx_vtable_6pyproj_4_crs__CRS.__pyx_base = *__pyx_vtabptr_6pyproj_4_crs_Base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pyproj_4_crs__CRS_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS)) __PYX_ERR(0, 2334, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pyproj_4_crs__CRS_spec, __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS) < (0)) __PYX_ERR(0, 2334, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS = &__pyx_type_6pyproj_4_crs__CRS;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS->tp_base = __pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS) < (0)) __PYX_ERR(0, 2334, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS->tp_dictoffset && __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_vtabptr_6pyproj_4_crs__CRS) < (0)) __PYX_ERR(0, 2334, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS) < (0)) __PYX_ERR(0, 2334, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CRS, (PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS) < (0)) __PYX_ERR(0, 2334, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_6pyproj_4_crs__CRS) < (0)) __PYX_ERR(0, 2334, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_3(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_3); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(5, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType_3_2_3(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyLongObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(PyLongObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyLongObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(PyLongObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_3); if (!__pyx_mstate->__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(6, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType_3_2_3(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(PyComplexObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(PyComplexObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_3); if (!__pyx_mstate->__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(7, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("array"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_5array_array = __Pyx_ImportType_3_2_3(__pyx_t_1, "array", "array",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(arrayobject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(arrayobject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(arrayobject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(arrayobject),
  #else
  sizeof(arrayobject), __PYX_GET_STRUCT_ALIGNMENT_3_2_3(arrayobject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_3); if (!__pyx_mstate->__pyx_ptype_7cpython_5array_array) __PYX_ERR(2, 69, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("pyproj._compat"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PyObject_PyObject_int___pyx_skip);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 73;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_6pyproj_7_compat_cstrencode, (void (**)(void))&__pyx_f_6pyproj_7_compat_cstrdecode, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_3(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  {
    __pyx_t_1 = PyImport_ImportModule("pyproj._context"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_PJ_CONTEXT_void_void_int___pyx_s);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 50;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_6pyproj_8_context_pyproj_context_create, (void (**)(void))&__pyx_f_6pyproj_8_context__clear_proj_error, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_3(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__crs(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__crs},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_crs",
      0, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__crs(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__crs(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec__crs(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  size_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_crs' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_crs" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_NOT_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__crs", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_pyproj___crs) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "pyproj._crs")) {
      if (unlikely((PyDict_SetItemString(modules, "pyproj._crs", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_function_export_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "pyproj/_crs.pyx":1
 * import json             # <<<<<<<<<<<<<<
 * import re
 * import warnings
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_json, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_json, __pyx_t_2) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":2
 * import json
 * import re             # <<<<<<<<<<<<<<
 * import warnings
 * from collections import OrderedDict, namedtuple
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_re, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_re, __pyx_t_2) < (0)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":3
 * import json
 * import re
 * import warnings             # <<<<<<<<<<<<<<
 * from collections import OrderedDict, namedtuple
 * 
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_warnings, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_warnings, __pyx_t_2) < (0)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":4
 * import re
 * import warnings
 * from collections import OrderedDict, namedtuple             # <<<<<<<<<<<<<<
 * 
 * from pyproj._compat cimport cstrdecode, cstrencode
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_OrderedDict,__pyx_mstate_global->__pyx_n_u_namedtuple};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_collections, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_OrderedDict,__pyx_mstate_global->__pyx_n_u_namedtuple};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":9
 * from pyproj._context cimport _clear_proj_error, pyproj_context_create
 * 
 * from pyproj._context import get_context_manager             # <<<<<<<<<<<<<<
 * from pyproj.aoi import AreaOfUse
 * from pyproj.crs.datum import CustomEllipsoid
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_context_manager};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj__context, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_get_context_manager};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 9, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 9, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":10
 * 
 * from pyproj._context import get_context_manager
 * from pyproj.aoi import AreaOfUse             # <<<<<<<<<<<<<<
 * from pyproj.crs.datum import CustomEllipsoid
 * from pyproj.crs.enums import CoordinateOperationType, DatumType
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_AreaOfUse};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_aoi, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 10, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_AreaOfUse};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 10, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 10, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":11
 * from pyproj._context import get_context_manager
 * from pyproj.aoi import AreaOfUse
 * from pyproj.crs.datum import CustomEllipsoid             # <<<<<<<<<<<<<<
 * from pyproj.crs.enums import CoordinateOperationType, DatumType
 * from pyproj.enums import ProjVersion, WktVersion
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CustomEllipsoid};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_crs_datum, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 11, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CustomEllipsoid};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 11, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":12
 * from pyproj.aoi import AreaOfUse
 * from pyproj.crs.datum import CustomEllipsoid
 * from pyproj.crs.enums import CoordinateOperationType, DatumType             # <<<<<<<<<<<<<<
 * from pyproj.enums import ProjVersion, WktVersion
 * from pyproj.exceptions import CRSError
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CoordinateOperationType,__pyx_mstate_global->__pyx_n_u_DatumType};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_crs_enums, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CoordinateOperationType,__pyx_mstate_global->__pyx_n_u_DatumType};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":13
 * from pyproj.crs.datum import CustomEllipsoid
 * from pyproj.crs.enums import CoordinateOperationType, DatumType
 * from pyproj.enums import ProjVersion, WktVersion             # <<<<<<<<<<<<<<
 * from pyproj.exceptions import CRSError
 * from pyproj.geod import pj_ellps
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ProjVersion,__pyx_mstate_global->__pyx_n_u_WktVersion};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_enums, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 13, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ProjVersion,__pyx_mstate_global->__pyx_n_u_WktVersion};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 13, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":14
 * from pyproj.crs.enums import CoordinateOperationType, DatumType
 * from pyproj.enums import ProjVersion, WktVersion
 * from pyproj.exceptions import CRSError             # <<<<<<<<<<<<<<
 * from pyproj.geod import pj_ellps
 * from pyproj.utils import NumpyEncoder
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CRSError};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_exceptions, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_CRSError};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 14, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":15
 * from pyproj.enums import ProjVersion, WktVersion
 * from pyproj.exceptions import CRSError
 * from pyproj.geod import pj_ellps             # <<<<<<<<<<<<<<
 * from pyproj.utils import NumpyEncoder
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_pj_ellps};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_geod, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_pj_ellps};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 15, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":16
 * from pyproj.exceptions import CRSError
 * from pyproj.geod import pj_ellps
 * from pyproj.utils import NumpyEncoder             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_NumpyEncoder};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_pyproj_utils, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_NumpyEncoder};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_4) < (0)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":21
 * # This is for looking up the ellipsoid parameters
 * # based on the long name
 * cdef dict _PJ_ELLPS_NAME_MAP = {             # <<<<<<<<<<<<<<
 *     ellps["description"]: ellps_id for ellps_id, ellps in pj_ellps.items()
 * }
*/
  { /* enter inner scope */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pyproj/_crs.pyx":22
 * # based on the long name
 * cdef dict _PJ_ELLPS_NAME_MAP = {
 *     ellps["description"]: ellps_id for ellps_id, ellps in pj_ellps.items()             # <<<<<<<<<<<<<<
 * }
 * 
*/
    __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_pj_ellps); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 22, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(__pyx_t_7 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
      __PYX_ERR(0, 22, __pyx_L4_error)
    }
    __pyx_t_8 = __Pyx_dict_iterator(__pyx_t_7, 0, __pyx_mstate_global->__pyx_n_u_items, (&__pyx_t_5), (&__pyx_t_6)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 22, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_4);
    __pyx_t_4 = __pyx_t_8;
    __pyx_t_8 = 0;
    while (1) {
      __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_4, __pyx_t_5, &__pyx_t_3, &__pyx_t_8, &__pyx_t_7, NULL, __pyx_t_6);
      if (unlikely(__pyx_t_9 == 0)) break;
      if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 22, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id);
      __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XGOTREF(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps);
      __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps, __pyx_mstate_global->__pyx_n_u_description); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 22, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (unlikely(PyDict_SetItem(__pyx_t_2, (PyObject*)__pyx_t_7, (PyObject*)__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id))) __PYX_ERR(0, 22, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps, Py_None);
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id, Py_None);
    goto __pyx_L7_exit_scope;
    __pyx_L4_error:;
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps, Py_None);
    __Pyx_GOTREF(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id);
    __Pyx_DECREF_SET(__pyx_7genexpr__pyx_v_6pyproj_4_crs_ellps_id, Py_None);
    goto __pyx_L1_error;
    __pyx_L7_exit_scope:;
  } /* exit inner scope */
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__PJ_ELLPS_NAME_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__PJ_ELLPS_NAME_MAP, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":33
 * 
 * 
 * def is_wkt(str proj_string not None):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.0.0
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_1is_wkt, 0, __pyx_mstate_global->__pyx_n_u_is_wkt, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_is_wkt, __pyx_t_2) < (0)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":52
 * 
 * 
 * def is_proj(str proj_string not None):             # <<<<<<<<<<<<<<
 *     """
 *     .. versionadded:: 2.2.2
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_3is_proj, 0, __pyx_mstate_global->__pyx_n_u_is_proj, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_is_proj, __pyx_t_2) < (0)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":252
 * 
 * 
 * def _load_proj_json(str in_proj_json):             # <<<<<<<<<<<<<<
 *     try:
 *         return json.loads(in_proj_json)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5_load_proj_json, 0, __pyx_mstate_global->__pyx_n_u_load_proj_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_load_proj_json, __pyx_t_2) < (0)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Axis_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Axis___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4])); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Axis_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Axis___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":404
 *         return self._scope
 * 
 *     def to_wkt(self, version=WktVersion.WKT2_2019, pretty=False, output_axis_rule=None):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a WKT string.
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_mstate_global->__pyx_k__7 = __pyx_t_4;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WktVersion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_WKT2_2019); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_Pack(3, __pyx_t_2, Py_False, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_5to_wkt, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base_to_wkt, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, __pyx_mstate_global->__pyx_n_u_to_wkt, __pyx_t_2) < (0)) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":434
 *         return _to_wkt(self.context, self.projobj, version, pretty=pretty, output_axis_rule=output_axis_rule)
 * 
 *     def to_json(self, bint pretty=False, int indentation=2):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_7to_json, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base_to_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[8]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, __pyx_mstate_global->__pyx_n_u_to_json, __pyx_t_2) < (0)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":467
 *         return cstrdecode(proj_json_string)
 * 
 *     def to_json_dict(self):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_9to_json_dict, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base_to_json_dict, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, __pyx_mstate_global->__pyx_n_u_to_json_dict, __pyx_t_2) < (0)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":485
 *         return self.to_wkt(pretty=True)
 * 
 *     def _is_exact_same(self, Base other):             # <<<<<<<<<<<<<<
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_15_is_exact_same, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base__is_exact_same, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, __pyx_mstate_global->__pyx_n_u_is_exact_same, __pyx_t_2) < (0)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":489
 *             self.context, self.projobj, other.projobj, PJ_COMP_STRICT) == 1
 * 
 *     def _is_equivalent(self, Base other):             # <<<<<<<<<<<<<<
 *         return proj_is_equivalent_to_with_ctx(
 *             self.context, self.projobj, other.projobj, PJ_COMP_EQUIVALENT) == 1
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_17_is_equivalent, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base__is_equivalent, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, __pyx_mstate_global->__pyx_n_u_is_equivalent, __pyx_t_2) < (0)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":498
 *         return self._is_equivalent(other)
 * 
 *     def is_exact_same(self, other):             # <<<<<<<<<<<<<<
 *         """Compares projection objects to see if they are exactly the same."""
 *         if not isinstance(other, Base):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_21is_exact_same, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base_is_exact_same, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Base, __pyx_mstate_global->__pyx_n_u_is_exact_same_2, __pyx_t_2) < (0)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_23__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Base_25__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Base___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":506
 * 
 * cdef class _CRSParts(Base):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_user_input(cls, user_input):
 *         """
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9_CRSParts_1from_user_input, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRSParts_from_user_input, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts, __pyx_mstate_global->__pyx_n_u_from_user_input, __pyx_t_2) < (0)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts, __pyx_mstate_global->__pyx_n_u_from_user_input); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRSParts, __pyx_mstate_global->__pyx_n_u_from_user_input, __pyx_t_4) < (0)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9_CRSParts_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRSParts___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9_CRSParts_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRSParts___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":556
 * 
 * cdef dict _COORD_SYSTEM_TYPE_MAP = {
 *     PJ_CS_TYPE_UNKNOWN: "unknown",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_CARTESIAN: "cartesian",
 *     PJ_CS_TYPE_ELLIPSOIDAL: "ellipsoidal",
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_UNKNOWN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_unknown) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":557
 * cdef dict _COORD_SYSTEM_TYPE_MAP = {
 *     PJ_CS_TYPE_UNKNOWN: "unknown",
 *     PJ_CS_TYPE_CARTESIAN: "cartesian",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_ELLIPSOIDAL: "ellipsoidal",
 *     PJ_CS_TYPE_VERTICAL: "vertical",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_CARTESIAN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_cartesian) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":558
 *     PJ_CS_TYPE_UNKNOWN: "unknown",
 *     PJ_CS_TYPE_CARTESIAN: "cartesian",
 *     PJ_CS_TYPE_ELLIPSOIDAL: "ellipsoidal",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_VERTICAL: "vertical",
 *     PJ_CS_TYPE_SPHERICAL: "spherical",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_ELLIPSOIDAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_ellipsoidal) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":559
 *     PJ_CS_TYPE_CARTESIAN: "cartesian",
 *     PJ_CS_TYPE_ELLIPSOIDAL: "ellipsoidal",
 *     PJ_CS_TYPE_VERTICAL: "vertical",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_SPHERICAL: "spherical",
 *     PJ_CS_TYPE_ORDINAL: "ordinal",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_VERTICAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_vertical) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":560
 *     PJ_CS_TYPE_ELLIPSOIDAL: "ellipsoidal",
 *     PJ_CS_TYPE_VERTICAL: "vertical",
 *     PJ_CS_TYPE_SPHERICAL: "spherical",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_ORDINAL: "ordinal",
 *     PJ_CS_TYPE_PARAMETRIC: "parametric",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_SPHERICAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_spherical) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":561
 *     PJ_CS_TYPE_VERTICAL: "vertical",
 *     PJ_CS_TYPE_SPHERICAL: "spherical",
 *     PJ_CS_TYPE_ORDINAL: "ordinal",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_PARAMETRIC: "parametric",
 *     PJ_CS_TYPE_DATETIMETEMPORAL: "datetimetemporal",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_ORDINAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_ordinal) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":562
 *     PJ_CS_TYPE_SPHERICAL: "spherical",
 *     PJ_CS_TYPE_ORDINAL: "ordinal",
 *     PJ_CS_TYPE_PARAMETRIC: "parametric",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_DATETIMETEMPORAL: "datetimetemporal",
 *     PJ_CS_TYPE_TEMPORALCOUNT: "temporalcount",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_PARAMETRIC); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_parametric) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":563
 *     PJ_CS_TYPE_ORDINAL: "ordinal",
 *     PJ_CS_TYPE_PARAMETRIC: "parametric",
 *     PJ_CS_TYPE_DATETIMETEMPORAL: "datetimetemporal",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_TEMPORALCOUNT: "temporalcount",
 *     PJ_CS_TYPE_TEMPORALMEASURE: "temporalmeasure",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_DATETIMETEMPORAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_datetimetemporal) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":564
 *     PJ_CS_TYPE_PARAMETRIC: "parametric",
 *     PJ_CS_TYPE_DATETIMETEMPORAL: "datetimetemporal",
 *     PJ_CS_TYPE_TEMPORALCOUNT: "temporalcount",             # <<<<<<<<<<<<<<
 *     PJ_CS_TYPE_TEMPORALMEASURE: "temporalmeasure",
 * }
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_TEMPORALCOUNT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_temporalcount) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":565
 *     PJ_CS_TYPE_DATETIMETEMPORAL: "datetimetemporal",
 *     PJ_CS_TYPE_TEMPORALCOUNT: "temporalcount",
 *     PJ_CS_TYPE_TEMPORALMEASURE: "temporalmeasure",             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_CS_TYPE_TEMPORALMEASURE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_n_u_temporalmeasure) < (0)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__COORD_SYSTEM_TYPE_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__COORD_SYSTEM_TYPE_MAP, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":626
 *         return self._axis_list
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str coordinate_system_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_5from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateSystem_from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":661
 *         return CoordinateSystem.create(context, coordinate_system_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict coordinate_system_dict not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_7from_json_dict, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateSystem_from_json_dict, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_json_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":681
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str coordinate_system_json_str not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_9from_json, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateSystem_from_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_json); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":701
 *         )
 * 
 *     def to_cf(self, bint rotated_pole=False):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.0.0
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_11to_cf, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateSystem_to_cf, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[9]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateSystem, __pyx_mstate_global->__pyx_n_u_to_cf, __pyx_t_4) < (0)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_13__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateSystem___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_16CoordinateSystem_15__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateSystem___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":835
 *         return ellips
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_5from_authority, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid_from_authority, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_authority); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 835, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":868
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_7from_epsg, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid_from_epsg, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_epsg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 868, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":886
 *         return Ellipsoid.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str ellipsoid_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_9_from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid__from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_string_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":919
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str ellipsoid_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_11from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid_from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":950
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict ellipsoid_dict not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_13from_json_dict, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid_from_json_dict, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_json_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":968
 *         return Ellipsoid._from_string(json.dumps(ellipsoid_dict, cls=NumpyEncoder))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str ellipsoid_json_str not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_15from_json, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid_from_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_json); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":986
 *         return Ellipsoid.from_json_dict(_load_proj_json(ellipsoid_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_name(
 *         str ellipsoid_name,
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_17_from_name, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid__from_name, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_name_2, __pyx_t_4) < (0)) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_name_2, __pyx_t_4) < (0)) __PYX_ERR(0, 986, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1020
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str ellipsoid_name not None,
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_19from_name, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid_from_name, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[10]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Ellipsoid, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_21__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_9Ellipsoid_23__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Ellipsoid___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1111
 *         return prime_meridian
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_5from_authority, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian_from_authority, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 1111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_authority); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 1111, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1144
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_7from_epsg, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian_from_epsg, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 1144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_epsg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 1144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1162
 *         return PrimeMeridian.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str prime_meridian_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_9_from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian__from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_string_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1198
 *         return PrimeMeridian.create(context, prime_meridian_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str prime_meridian_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_11from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian_from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 1198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1229
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict prime_meridian_dict not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_13from_json_dict, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian_from_json_dict, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_json_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 1229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1249
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str prime_meridian_json_str not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_15from_json, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian_from_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_json); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1267
 *         return PrimeMeridian.from_json_dict(_load_proj_json(prime_meridian_json_str))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str prime_meridian_name not None,
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_17from_name, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian_from_name, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[10]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1267, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_PrimeMeridian, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 1267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_19__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_13PrimeMeridian_21__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_PrimeMeridian___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1308
 * 
 * cdef dict _DATUM_TYPE_MAP = {
 *     PJ_TYPE_GEODETIC_REFERENCE_FRAME: "Geodetic Reference Frame",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME: "Dynamic Geodetic Reference Frame",
 *     PJ_TYPE_VERTICAL_REFERENCE_FRAME: "Vertical Reference Frame",
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEODETIC_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Geodetic_Reference_Frame) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1309
 * cdef dict _DATUM_TYPE_MAP = {
 *     PJ_TYPE_GEODETIC_REFERENCE_FRAME: "Geodetic Reference Frame",
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME: "Dynamic Geodetic Reference Frame",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_VERTICAL_REFERENCE_FRAME: "Vertical Reference Frame",
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME: "Dynamic Vertical Reference Frame",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Dynamic_Geodetic_Reference_Frame) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1310
 *     PJ_TYPE_GEODETIC_REFERENCE_FRAME: "Geodetic Reference Frame",
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME: "Dynamic Geodetic Reference Frame",
 *     PJ_TYPE_VERTICAL_REFERENCE_FRAME: "Vertical Reference Frame",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME: "Dynamic Vertical Reference Frame",
 *     PJ_TYPE_DATUM_ENSEMBLE: "Datum Ensemble",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_VERTICAL_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Vertical_Reference_Frame) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1311
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME: "Dynamic Geodetic Reference Frame",
 *     PJ_TYPE_VERTICAL_REFERENCE_FRAME: "Vertical Reference Frame",
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME: "Dynamic Vertical Reference Frame",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_DATUM_ENSEMBLE: "Datum Ensemble",
 *     PJ_TYPE_TEMPORAL_DATUM: "Temporal Datum",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Dynamic_Vertical_Reference_Frame) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1312
 *     PJ_TYPE_VERTICAL_REFERENCE_FRAME: "Vertical Reference Frame",
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME: "Dynamic Vertical Reference Frame",
 *     PJ_TYPE_DATUM_ENSEMBLE: "Datum Ensemble",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_TEMPORAL_DATUM: "Temporal Datum",
 *     PJ_TYPE_ENGINEERING_DATUM: "Engineering Datum",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DATUM_ENSEMBLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Datum_Ensemble) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1313
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME: "Dynamic Vertical Reference Frame",
 *     PJ_TYPE_DATUM_ENSEMBLE: "Datum Ensemble",
 *     PJ_TYPE_TEMPORAL_DATUM: "Temporal Datum",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_ENGINEERING_DATUM: "Engineering Datum",
 *     PJ_TYPE_PARAMETRIC_DATUM: "Parametric Datum",
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_TEMPORAL_DATUM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Temporal_Datum) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1314
 *     PJ_TYPE_DATUM_ENSEMBLE: "Datum Ensemble",
 *     PJ_TYPE_TEMPORAL_DATUM: "Temporal Datum",
 *     PJ_TYPE_ENGINEERING_DATUM: "Engineering Datum",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_PARAMETRIC_DATUM: "Parametric Datum",
 * }
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_ENGINEERING_DATUM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Engineering_Datum) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1315
 *     PJ_TYPE_TEMPORAL_DATUM: "Temporal Datum",
 *     PJ_TYPE_ENGINEERING_DATUM: "Engineering Datum",
 *     PJ_TYPE_PARAMETRIC_DATUM: "Parametric Datum",             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_PARAMETRIC_DATUM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Parametric_Datum) < (0)) __PYX_ERR(0, 1308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__DATUM_TYPE_MAP, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1319
 * 
 * cdef dict _PJ_DATUM_TYPE_MAP = {
 *     DatumType.DATUM_ENSEMBLE: PJ_TYPE_DATUM_ENSEMBLE,             # <<<<<<<<<<<<<<
 *     DatumType.GEODETIC_REFERENCE_FRAME: PJ_TYPE_GEODETIC_REFERENCE_FRAME,
 *     DatumType.DYNAMIC_GEODETIC_REFERENCE_FRAME:
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DatumType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DATUM_ENSEMBLE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DATUM_ENSEMBLE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_t_2) < (0)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1320
 * cdef dict _PJ_DATUM_TYPE_MAP = {
 *     DatumType.DATUM_ENSEMBLE: PJ_TYPE_DATUM_ENSEMBLE,
 *     DatumType.GEODETIC_REFERENCE_FRAME: PJ_TYPE_GEODETIC_REFERENCE_FRAME,             # <<<<<<<<<<<<<<
 *     DatumType.DYNAMIC_GEODETIC_REFERENCE_FRAME:
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DatumType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_GEODETIC_REFERENCE_FRAME); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEODETIC_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_t_2) < (0)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1321
 *     DatumType.DATUM_ENSEMBLE: PJ_TYPE_DATUM_ENSEMBLE,
 *     DatumType.GEODETIC_REFERENCE_FRAME: PJ_TYPE_GEODETIC_REFERENCE_FRAME,
 *     DatumType.DYNAMIC_GEODETIC_REFERENCE_FRAME:             # <<<<<<<<<<<<<<
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME,
 *     DatumType.VERTICAL_REFERENCE_FRAME: PJ_TYPE_VERTICAL_REFERENCE_FRAME,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DatumType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DYNAMIC_GEODETIC_REFERENCE_FRAME); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1322
 *     DatumType.GEODETIC_REFERENCE_FRAME: PJ_TYPE_GEODETIC_REFERENCE_FRAME,
 *     DatumType.DYNAMIC_GEODETIC_REFERENCE_FRAME:
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME,             # <<<<<<<<<<<<<<
 *     DatumType.VERTICAL_REFERENCE_FRAME: PJ_TYPE_VERTICAL_REFERENCE_FRAME,
 *     DatumType.DYNAMIC_VERTICAL_REFERENCE_FRAME:
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_t_2) < (0)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1323
 *     DatumType.DYNAMIC_GEODETIC_REFERENCE_FRAME:
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME,
 *     DatumType.VERTICAL_REFERENCE_FRAME: PJ_TYPE_VERTICAL_REFERENCE_FRAME,             # <<<<<<<<<<<<<<
 *     DatumType.DYNAMIC_VERTICAL_REFERENCE_FRAME:
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DatumType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_VERTICAL_REFERENCE_FRAME); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_VERTICAL_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_t_2) < (0)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1324
 *     PJ_TYPE_DYNAMIC_GEODETIC_REFERENCE_FRAME,
 *     DatumType.VERTICAL_REFERENCE_FRAME: PJ_TYPE_VERTICAL_REFERENCE_FRAME,
 *     DatumType.DYNAMIC_VERTICAL_REFERENCE_FRAME:             # <<<<<<<<<<<<<<
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME,
 * }
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DatumType); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DYNAMIC_VERTICAL_REFERENCE_FRAME); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyproj/_crs.pyx":1325
 *     DatumType.VERTICAL_REFERENCE_FRAME: PJ_TYPE_VERTICAL_REFERENCE_FRAME,
 *     DatumType.DYNAMIC_VERTICAL_REFERENCE_FRAME:
 *     PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME,             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_2 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DYNAMIC_VERTICAL_REFERENCE_FRAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_t_2) < (0)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__PJ_DATUM_TYPE_MAP, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1360
 *         return datum
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_authority(str auth_name not None, code not None, PJ_CATEGORY category):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_5_from_authority, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum__from_authority, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_authority_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_authority_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_authority_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1392
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(str auth_name not None, code not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_7from_authority, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum_from_authority, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 1392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_authority); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 1392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1413
 *             return Datum._from_authority(auth_name, code, PJ_CATEGORY_DATUM)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_9from_epsg, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum_from_epsg, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_epsg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1429
 *         return Datum.from_authority("EPSG", code)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str datum_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_11_from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum__from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_string_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1429, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1464
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str datum_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_13from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum_from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 1464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1494
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_name(
 *         str datum_name,
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_15_from_name, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum__from_name, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_name_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_name_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1532
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str datum_name not None,
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_17from_name, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum_from_name, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[11]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1583
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict datum_dict not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_19from_json_dict, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum_from_json_dict, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[49])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 1583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_json_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 1583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1601
 *         return Datum._from_string(json.dumps(datum_dict, cls=NumpyEncoder))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str datum_json_str not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_21from_json, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum_from_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[50])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 1601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_json); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_Datum, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 1601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_23__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[51])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Datum_25__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Datum___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[52])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Param_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Param___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[53])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_5Param_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Param___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[54])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Grid_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Grid___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[55])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4Grid_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Grid___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[56])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1840
 * 
 * cdef dict _COORDINATE_OPERATION_TYPE_MAP = {
 *     PJ_TYPE_UNKNOWN: "Unknown",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_CONVERSION: "Conversion",
 *     PJ_TYPE_TRANSFORMATION: "Transformation",
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_UNKNOWN); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_n_u_Unknown) < (0)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1841
 * cdef dict _COORDINATE_OPERATION_TYPE_MAP = {
 *     PJ_TYPE_UNKNOWN: "Unknown",
 *     PJ_TYPE_CONVERSION: "Conversion",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_TRANSFORMATION: "Transformation",
 *     PJ_TYPE_CONCATENATED_OPERATION: "Concatenated Operation",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_CONVERSION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_n_u_Conversion) < (0)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1842
 *     PJ_TYPE_UNKNOWN: "Unknown",
 *     PJ_TYPE_CONVERSION: "Conversion",
 *     PJ_TYPE_TRANSFORMATION: "Transformation",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_CONCATENATED_OPERATION: "Concatenated Operation",
 *     PJ_TYPE_OTHER_COORDINATE_OPERATION: "Other Coordinate Operation",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_TRANSFORMATION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_n_u_Transformation) < (0)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1843
 *     PJ_TYPE_CONVERSION: "Conversion",
 *     PJ_TYPE_TRANSFORMATION: "Transformation",
 *     PJ_TYPE_CONCATENATED_OPERATION: "Concatenated Operation",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_OTHER_COORDINATE_OPERATION: "Other Coordinate Operation",
 * }
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_CONCATENATED_OPERATION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Concatenated_Operation) < (0)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1844
 *     PJ_TYPE_TRANSFORMATION: "Transformation",
 *     PJ_TYPE_CONCATENATED_OPERATION: "Concatenated Operation",
 *     PJ_TYPE_OTHER_COORDINATE_OPERATION: "Other Coordinate Operation",             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_OTHER_COORDINATE_OPERATION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Other_Coordinate_Operation) < (0)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__COORDINATE_OPERATION_TYPE_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__COORDINATE_OPERATION_TYPE_MAP, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1848
 * 
 * cdef dict _PJ_COORDINATE_OPERATION_TYPE_MAP = {
 *     CoordinateOperationType.CONVERSION: PJ_TYPE_CONVERSION,             # <<<<<<<<<<<<<<
 *     CoordinateOperationType.TRANSFORMATION: PJ_TYPE_TRANSFORMATION,
 *     CoordinateOperationType.CONCATENATED_OPERATION: PJ_TYPE_CONCATENATED_OPERATION,
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CONVERSION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_CONVERSION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_7) < (0)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1849
 * cdef dict _PJ_COORDINATE_OPERATION_TYPE_MAP = {
 *     CoordinateOperationType.CONVERSION: PJ_TYPE_CONVERSION,
 *     CoordinateOperationType.TRANSFORMATION: PJ_TYPE_TRANSFORMATION,             # <<<<<<<<<<<<<<
 *     CoordinateOperationType.CONCATENATED_OPERATION: PJ_TYPE_CONCATENATED_OPERATION,
 *     CoordinateOperationType.OTHER_COORDINATE_OPERATION:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_TRANSFORMATION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_TRANSFORMATION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_7) < (0)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1850
 *     CoordinateOperationType.CONVERSION: PJ_TYPE_CONVERSION,
 *     CoordinateOperationType.TRANSFORMATION: PJ_TYPE_TRANSFORMATION,
 *     CoordinateOperationType.CONCATENATED_OPERATION: PJ_TYPE_CONCATENATED_OPERATION,             # <<<<<<<<<<<<<<
 *     CoordinateOperationType.OTHER_COORDINATE_OPERATION:
 *     PJ_TYPE_OTHER_COORDINATE_OPERATION,
*/
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CONCATENATED_OPERATION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_CONCATENATED_OPERATION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_7) < (0)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1851
 *     CoordinateOperationType.TRANSFORMATION: PJ_TYPE_TRANSFORMATION,
 *     CoordinateOperationType.CONCATENATED_OPERATION: PJ_TYPE_CONCATENATED_OPERATION,
 *     CoordinateOperationType.OTHER_COORDINATE_OPERATION:             # <<<<<<<<<<<<<<
 *     PJ_TYPE_OTHER_COORDINATE_OPERATION,
 * }
*/
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_OTHER_COORDINATE_OPERATION); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":1852
 *     CoordinateOperationType.CONCATENATED_OPERATION: PJ_TYPE_CONCATENATED_OPERATION,
 *     CoordinateOperationType.OTHER_COORDINATE_OPERATION:
 *     PJ_TYPE_OTHER_COORDINATE_OPERATION,             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_OTHER_COORDINATE_OPERATION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_2, __pyx_t_7) < (0)) __PYX_ERR(0, 1848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__PJ_COORDINATE_OPERATION_TYPE_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__PJ_COORDINATE_OPERATION_TYPE_MAP, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1940
 *         return coord_operation
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_authority(
 *         str auth_name not None,
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_5from_authority, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_from_authori, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[57])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[9]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_authority); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 1940, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1977
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_epsg(code not None, bint use_proj_alternative_grid_names= False):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_7from_epsg, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_from_epsg, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[58])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[9]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_epsg); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 1977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1997
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _from_string(str coordinate_operation_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_9_from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation__from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[59])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_string_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_string_2, __pyx_t_4) < (0)) __PYX_ERR(0, 1997, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2036
 *         return CoordinateOperation.create(context, coord_operation_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_string(str coordinate_operation_string not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_11from_string, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_from_string, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[60])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_string); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_string, __pyx_t_4) < (0)) __PYX_ERR(0, 2036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2063
 *                 raise crs_err
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json_dict(dict coordinate_operation_dict not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_13from_json_dict, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_from_json_di, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[61])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 2063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_json_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2063, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_json_dict, __pyx_t_4) < (0)) __PYX_ERR(0, 2063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2083
 *         )
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_json(str coordinate_operation_json_str not None):
 *         """
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_15from_json, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_from_json, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[62])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 2083, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = NULL;
  __Pyx_GetNameInClass(__pyx_t_7, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_json); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2083, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_json, __pyx_t_4) < (0)) __PYX_ERR(0, 2083, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2107
 *         str coordinate_operation_name not None,
 *         str auth_name=None,
 *         coordinate_operation_type not None=CoordinateOperationType.CONVERSION,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CONVERSION); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_mstate_global->__pyx_k__10 = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2106
 *     def from_name(
 *         str coordinate_operation_name not None,
 *         str auth_name=None,             # <<<<<<<<<<<<<<
 *         coordinate_operation_type not None=CoordinateOperationType.CONVERSION,
 *     ):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CoordinateOperationType); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "pyproj/_crs.pyx":2107
 *         str coordinate_operation_name not None,
 *         str auth_name=None,
 *         coordinate_operation_type not None=CoordinateOperationType.CONVERSION,             # <<<<<<<<<<<<<<
 *     ):
 *         """
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_CONVERSION); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2103
 *         ))
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str coordinate_operation_name not None,
*/
  __pyx_t_7 = PyTuple_Pack(2, Py_None, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_17from_name, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_from_name, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[63])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7 = NULL;
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject*)__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_builtin_staticmethod, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_from_name, __pyx_t_4) < (0)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2217
 *         return self._area_of_use
 * 
 *     def to_proj4(self, version not None=ProjVersion.PROJ_5, bint pretty=False):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a PROJ string.
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PROJ_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_mstate_global->__pyx_k__11 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_PROJ_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_Pack(2, __pyx_t_4, Py_False); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_19to_proj4, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation_to_proj4, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[64])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs_CoordinateOperation, __pyx_mstate_global->__pyx_n_u_to_proj4, __pyx_t_4) < (0)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_23__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[65])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_19CoordinateOperation_25__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CoordinateOperation___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[66])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2290
 *         )
 * 
 * AuthorityMatchInfo = namedtuple(             # <<<<<<<<<<<<<<
 *     "AuthorityMatchInfo",
 *     [
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_namedtuple); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "pyproj/_crs.pyx":2292
 * AuthorityMatchInfo = namedtuple(
 *     "AuthorityMatchInfo",
 *     [             # <<<<<<<<<<<<<<
 *         "auth_name",
 *         "code",
*/
  __pyx_t_8 = __Pyx_PyList_Pack(3, __pyx_mstate_global->__pyx_n_u_auth_name, __pyx_mstate_global->__pyx_n_u_code, __pyx_mstate_global->__pyx_n_u_confidence); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_10 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_AuthorityMatchInfo, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_10, (3-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_AuthorityMatchInfo, __pyx_t_4) < (0)) __PYX_ERR(0, 2290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2298
 *     ],
 * )
 * AuthorityMatchInfo.__doc__ = """             # <<<<<<<<<<<<<<
 * .. versionadded:: 3.2.0
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_AuthorityMatchInfo); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_PyObject_SetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_doc, __pyx_mstate_global->__pyx_kp_u_versionadded_3_2_0_CRS_Authorit) < (0)) __PYX_ERR(0, 2298, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2316
 * 
 * cdef dict _CRS_TYPE_MAP = {
 *     PJ_TYPE_UNKNOWN: "Unknown CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_CRS: "CRS",
 *     PJ_TYPE_GEODETIC_CRS: "Geodetic CRS",
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(15); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_UNKNOWN); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Unknown_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2317
 * cdef dict _CRS_TYPE_MAP = {
 *     PJ_TYPE_UNKNOWN: "Unknown CRS",
 *     PJ_TYPE_CRS: "CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_GEODETIC_CRS: "Geodetic CRS",
 *     PJ_TYPE_GEOCENTRIC_CRS: "Geocentric CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_n_u_CRS_2) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2318
 *     PJ_TYPE_UNKNOWN: "Unknown CRS",
 *     PJ_TYPE_CRS: "CRS",
 *     PJ_TYPE_GEODETIC_CRS: "Geodetic CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_GEOCENTRIC_CRS: "Geocentric CRS",
 *     PJ_TYPE_GEOGRAPHIC_CRS: "Geographic CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEODETIC_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Geodetic_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2319
 *     PJ_TYPE_CRS: "CRS",
 *     PJ_TYPE_GEODETIC_CRS: "Geodetic CRS",
 *     PJ_TYPE_GEOCENTRIC_CRS: "Geocentric CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_GEOGRAPHIC_CRS: "Geographic CRS",
 *     PJ_TYPE_GEOGRAPHIC_2D_CRS: "Geographic 2D CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOCENTRIC_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Geocentric_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2320
 *     PJ_TYPE_GEODETIC_CRS: "Geodetic CRS",
 *     PJ_TYPE_GEOCENTRIC_CRS: "Geocentric CRS",
 *     PJ_TYPE_GEOGRAPHIC_CRS: "Geographic CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_GEOGRAPHIC_2D_CRS: "Geographic 2D CRS",
 *     PJ_TYPE_GEOGRAPHIC_3D_CRS: "Geographic 3D CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOGRAPHIC_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Geographic_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2321
 *     PJ_TYPE_GEOCENTRIC_CRS: "Geocentric CRS",
 *     PJ_TYPE_GEOGRAPHIC_CRS: "Geographic CRS",
 *     PJ_TYPE_GEOGRAPHIC_2D_CRS: "Geographic 2D CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_GEOGRAPHIC_3D_CRS: "Geographic 3D CRS",
 *     PJ_TYPE_VERTICAL_CRS: "Vertical CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOGRAPHIC_2D_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Geographic_2D_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2322
 *     PJ_TYPE_GEOGRAPHIC_CRS: "Geographic CRS",
 *     PJ_TYPE_GEOGRAPHIC_2D_CRS: "Geographic 2D CRS",
 *     PJ_TYPE_GEOGRAPHIC_3D_CRS: "Geographic 3D CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_VERTICAL_CRS: "Vertical CRS",
 *     PJ_TYPE_PROJECTED_CRS: "Projected CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_GEOGRAPHIC_3D_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Geographic_3D_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2323
 *     PJ_TYPE_GEOGRAPHIC_2D_CRS: "Geographic 2D CRS",
 *     PJ_TYPE_GEOGRAPHIC_3D_CRS: "Geographic 3D CRS",
 *     PJ_TYPE_VERTICAL_CRS: "Vertical CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_PROJECTED_CRS: "Projected CRS",
 *     PJ_TYPE_COMPOUND_CRS: "Compound CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_VERTICAL_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Vertical_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2324
 *     PJ_TYPE_GEOGRAPHIC_3D_CRS: "Geographic 3D CRS",
 *     PJ_TYPE_VERTICAL_CRS: "Vertical CRS",
 *     PJ_TYPE_PROJECTED_CRS: "Projected CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_COMPOUND_CRS: "Compound CRS",
 *     PJ_TYPE_TEMPORAL_CRS: "Temporal CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_PROJECTED_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Projected_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2325
 *     PJ_TYPE_VERTICAL_CRS: "Vertical CRS",
 *     PJ_TYPE_PROJECTED_CRS: "Projected CRS",
 *     PJ_TYPE_COMPOUND_CRS: "Compound CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_TEMPORAL_CRS: "Temporal CRS",
 *     PJ_TYPE_ENGINEERING_CRS: "Engineering CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_COMPOUND_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Compound_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2326
 *     PJ_TYPE_PROJECTED_CRS: "Projected CRS",
 *     PJ_TYPE_COMPOUND_CRS: "Compound CRS",
 *     PJ_TYPE_TEMPORAL_CRS: "Temporal CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_ENGINEERING_CRS: "Engineering CRS",
 *     PJ_TYPE_BOUND_CRS: "Bound CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_TEMPORAL_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Temporal_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2327
 *     PJ_TYPE_COMPOUND_CRS: "Compound CRS",
 *     PJ_TYPE_TEMPORAL_CRS: "Temporal CRS",
 *     PJ_TYPE_ENGINEERING_CRS: "Engineering CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_BOUND_CRS: "Bound CRS",
 *     PJ_TYPE_OTHER_CRS: "Other CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_ENGINEERING_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Engineering_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2328
 *     PJ_TYPE_TEMPORAL_CRS: "Temporal CRS",
 *     PJ_TYPE_ENGINEERING_CRS: "Engineering CRS",
 *     PJ_TYPE_BOUND_CRS: "Bound CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_OTHER_CRS: "Other CRS",
 *     PJ_TYPE_DERIVED_PROJECTED_CRS: "Derived Projected CRS",
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_BOUND_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Bound_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2329
 *     PJ_TYPE_ENGINEERING_CRS: "Engineering CRS",
 *     PJ_TYPE_BOUND_CRS: "Bound CRS",
 *     PJ_TYPE_OTHER_CRS: "Other CRS",             # <<<<<<<<<<<<<<
 *     PJ_TYPE_DERIVED_PROJECTED_CRS: "Derived Projected CRS",
 * }
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_OTHER_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Other_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyproj/_crs.pyx":2330
 *     PJ_TYPE_BOUND_CRS: "Bound CRS",
 *     PJ_TYPE_OTHER_CRS: "Other CRS",
 *     PJ_TYPE_DERIVED_PROJECTED_CRS: "Derived Projected CRS",             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_7 = __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE_DERIVED_PROJECTED_CRS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_4, __pyx_t_7, __pyx_mstate_global->__pyx_kp_u_Derived_Projected_CRS) < (0)) __PYX_ERR(0, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XGOTREF(__pyx_v_6pyproj_4_crs__CRS_TYPE_MAP);
  __Pyx_DECREF_SET(__pyx_v_6pyproj_4_crs__CRS_TYPE_MAP, ((PyObject*)__pyx_t_4));
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2695
 *         return self._geodetic_crs
 * 
 *     def to_proj4(self, version=ProjVersion.PROJ_4):             # <<<<<<<<<<<<<<
 *         """
 *         Convert the projection to a PROJ string.
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PROJ_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_mstate_global->__pyx_k__12 = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_ProjVersion); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_PROJ_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_Pack(1, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_5to_proj4, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_to_proj4, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[67])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_to_proj4, __pyx_t_4) < (0)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2721
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=False)
 * 
 *     def to_epsg(self, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         Return the EPSG code best matching the CRS
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_7to_epsg, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_to_epsg, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[68])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[12]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_to_epsg, __pyx_t_4) < (0)) __PYX_ERR(0, 2721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2764
 *         return None
 * 
 *     def to_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.2.0
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_9to_authority, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_to_authority, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[69])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[13]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_to_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 2764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2810
 *             return None
 * 
 *     def list_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.2.0
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_11list_authority, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_list_authority, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[70])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[13]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_list_authority, __pyx_t_4) < (0)) __PYX_ERR(0, 2810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2911
 *         return authority_list
 * 
 *     def to_3d(self, str name=None):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.1.0
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_13to_3d, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_to_3d, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[71])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[10]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_to_3d, __pyx_t_4) < (0)) __PYX_ERR(0, 2911, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2954
 *         return crs_3d
 * 
 *     def to_2d(self, str name=None):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.6.0
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_15to_2d, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_to_2d, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[72])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[10]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_to_2d, __pyx_t_4) < (0)) __PYX_ERR(0, 2954, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":2992
 *         return crs_2d
 * 
 *     def _is_crs_property(             # <<<<<<<<<<<<<<
 *         self, str property_name, tuple property_types, int sub_crs_index=0
 *     ):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_17_is_crs_property, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS__is_crs_property, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[73])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[14]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_is_crs_property, __pyx_t_4) < (0)) __PYX_ERR(0, 2992, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":3151
 *         return proj_is_derived_crs(self.context, self.projobj) == 1
 * 
 *     def _equals(self, _CRS other, bint ignore_axis_order):             # <<<<<<<<<<<<<<
 *         if ignore_axis_order:
 *             # Only to be used with DerivedCRS/ProjectedCRS/GeographicCRS
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_19_equals, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS__equals, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[74])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_equals, __pyx_t_4) < (0)) __PYX_ERR(0, 3151, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":3162
 *         return self._is_equivalent(other)
 * 
 *     def equals(self, other, ignore_axis_order=False):             # <<<<<<<<<<<<<<
 *         """
 *         Check if the projection objects are equivalent.
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_21equals, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_equals, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[75])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[9]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_equals_2, __pyx_t_4) < (0)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":3194
 *         return bool(proj_is_deprecated(self.projobj))
 * 
 *     def get_non_deprecated(self):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.7.0
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_23get_non_deprecated, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS_get_non_deprecated, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[76])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_6pyproj_4_crs__CRS, __pyx_mstate_global->__pyx_n_u_get_non_deprecated, __pyx_t_4) < (0)) __PYX_ERR(0, 3194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_25__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[77])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pyproj_4_crs_4_CRS_27__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRS___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_pyproj__crs, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[78])); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(4, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyproj/_crs.pyx":1
 * import json             # <<<<<<<<<<<<<<
 * import re
 * import warnings
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_CRS_to_epsg_line_2721, __pyx_mstate_global->__pyx_kp_u_Return_the_EPSG_code_best_match) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_CRS_to_authority_line_2764, __pyx_mstate_global->__pyx_kp_u_versionadded_2_2_0_Return_the_a) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_CRS_list_authority_line_2810, __pyx_mstate_global->__pyx_kp_u_versionadded_3_2_0_Return_the_a) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_4) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init pyproj._crs", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pyproj._crs");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 626, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_get.method_name = &__pyx_mstate->__pyx_n_u_get;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__lower.type = (PyObject*)(&PyUnicode_Type);
  __pyx_mstate->__pyx_umethod_PyUnicode_Type__lower.method_name = &__pyx_mstate->__pyx_n_u_lower;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "pyproj/_crs.pyx":2251
 *         towgs84_dict = OrderedDict(
 *             (
 *                 ('X-axis translation', None),             # <<<<<<<<<<<<<<
 *                 ('Y-axis translation', None),
 *                 ('Z-axis translation', None),
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_X_axis_translation, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(0, 2251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "pyproj/_crs.pyx":2252
 *             (
 *                 ('X-axis translation', None),
 *                 ('Y-axis translation', None),             # <<<<<<<<<<<<<<
 *                 ('Z-axis translation', None),
 *                 ('X-axis rotation', None),
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_Y_axis_translation, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(0, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "pyproj/_crs.pyx":2253
 *                 ('X-axis translation', None),
 *                 ('Y-axis translation', None),
 *                 ('Z-axis translation', None),             # <<<<<<<<<<<<<<
 *                 ('X-axis rotation', None),
 *                 ('Y-axis rotation', None),
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_Z_axis_translation, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(0, 2253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "pyproj/_crs.pyx":2254
 *                 ('Y-axis translation', None),
 *                 ('Z-axis translation', None),
 *                 ('X-axis rotation', None),             # <<<<<<<<<<<<<<
 *                 ('Y-axis rotation', None),
 *                 ('Z-axis rotation', None),
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_X_axis_rotation, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(0, 2254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);

  /* "pyproj/_crs.pyx":2255
 *                 ('Z-axis translation', None),
 *                 ('X-axis rotation', None),
 *                 ('Y-axis rotation', None),             # <<<<<<<<<<<<<<
 *                 ('Z-axis rotation', None),
 *                 ('Scale difference', None),
*/
  __pyx_mstate_global->__pyx_tuple[4] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_Y_axis_rotation, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[4])) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[4]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[4]);

  /* "pyproj/_crs.pyx":2256
 *                 ('X-axis rotation', None),
 *                 ('Y-axis rotation', None),
 *                 ('Z-axis rotation', None),             # <<<<<<<<<<<<<<
 *                 ('Scale difference', None),
 *             )
*/
  __pyx_mstate_global->__pyx_tuple[5] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_Z_axis_rotation, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[5])) __PYX_ERR(0, 2256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[5]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[5]);

  /* "pyproj/_crs.pyx":2257
 *                 ('Y-axis rotation', None),
 *                 ('Z-axis rotation', None),
 *                 ('Scale difference', None),             # <<<<<<<<<<<<<<
 *             )
 *         )
*/
  __pyx_mstate_global->__pyx_tuple[6] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_u_Scale_difference, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[6])) __PYX_ERR(0, 2257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[6]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[6]);

  /* "pyproj/_crs.pyx":2251
 *         towgs84_dict = OrderedDict(
 *             (
 *                 ('X-axis translation', None),             # <<<<<<<<<<<<<<
 *                 ('Y-axis translation', None),
 *                 ('Z-axis translation', None),
*/
  __pyx_mstate_global->__pyx_tuple[7] = PyTuple_Pack(7, __pyx_mstate_global->__pyx_tuple[0], __pyx_mstate_global->__pyx_tuple[1], __pyx_mstate_global->__pyx_tuple[2], __pyx_mstate_global->__pyx_tuple[3], __pyx_mstate_global->__pyx_tuple[4], __pyx_mstate_global->__pyx_tuple[5], __pyx_mstate_global->__pyx_tuple[6]); if (unlikely(!__pyx_mstate_global->__pyx_tuple[7])) __PYX_ERR(0, 2251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[7]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[7]);

  /* "pyproj/_crs.pyx":434
 *         return _to_wkt(self.context, self.projobj, version, pretty=pretty, output_axis_rule=output_axis_rule)
 * 
 *     def to_json(self, bint pretty=False, int indentation=2):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.4.0
*/
  __pyx_mstate_global->__pyx_tuple[8] = PyTuple_Pack(2, Py_False, __pyx_mstate_global->__pyx_int_2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[8])) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[8]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[8]);

  /* "pyproj/_crs.pyx":701
 *         )
 * 
 *     def to_cf(self, bint rotated_pole=False):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 3.0.0
*/
  __pyx_mstate_global->__pyx_tuple[9] = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_mstate_global->__pyx_tuple[9])) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[9]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[9]);

  /* "pyproj/_crs.pyx":1020
 *         return Ellipsoid.create(context, ellipsoid_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str ellipsoid_name not None,
*/
  __pyx_mstate_global->__pyx_tuple[10] = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[10])) __PYX_ERR(0, 1020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[10]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[10]);

  /* "pyproj/_crs.pyx":1532
 *         return Datum.create(context, datum_pj)
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def from_name(
 *         str datum_name not None,
*/
  __pyx_mstate_global->__pyx_tuple[11] = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[11])) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[11]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[11]);

  /* "pyproj/_crs.pyx":2721
 *         return _to_proj4(self.context, self.projobj, version=version, pretty=False)
 * 
 *     def to_epsg(self, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         Return the EPSG code best matching the CRS
*/
  __pyx_mstate_global->__pyx_tuple[12] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_int_70); if (unlikely(!__pyx_mstate_global->__pyx_tuple[12])) __PYX_ERR(0, 2721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[12]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[12]);

  /* "pyproj/_crs.pyx":2764
 *         return None
 * 
 *     def to_authority(self, str auth_name=None, int min_confidence=70):             # <<<<<<<<<<<<<<
 *         """
 *         .. versionadded:: 2.2.0
*/
  __pyx_mstate_global->__pyx_tuple[13] = PyTuple_Pack(2, Py_None, __pyx_mstate_global->__pyx_int_70); if (unlikely(!__pyx_mstate_global->__pyx_tuple[13])) __PYX_ERR(0, 2764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[13]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[13]);

  /* "pyproj/_crs.pyx":2992
 *         return crs_2d
 * 
 *     def _is_crs_property(             # <<<<<<<<<<<<<<
 *         self, str property_name, tuple property_types, int sub_crs_index=0
 *     ):
*/
  __pyx_mstate_global->__pyx_tuple[14] = PyTuple_Pack(1, __pyx_mstate_global->__pyx_int_0); if (unlikely(!__pyx_mstate_global->__pyx_tuple[14])) __PYX_ERR(0, 2992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[14]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[14]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<15; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 11; } index[] = {{1},{3},{14},{10},{9},{31},{29},{24},{12},{22},{79},{38},{23},{14},{52},{8},{21},{32},{32},{60},{15},{17},{14},{12},{24},{17},{17},{14},{16},{18},{20},{8},{12},{27},{35},{37},{34},{20},{22},{24},{26},{29},{31},{20},{9},{8},{4},{179},{9},{26},{11},{16},{68},{13},{864},{16},{12},{14},{11},{12},{24},{15},{18},{15},{18},{206},{15},{18},{1},{1},{1},{3},{2},{1},{0},{2},{1},{9},{8},{12},{12},{7},{11},{18},{12},{7},{6},{12},{2},{21},{8},{9},{6},{50},{15},{15},{15},{14},{11},{17},{17},{16},{12},{12},{6},{8},{1057},{224},{1108},{9},{18},{4},{22},{24},{4},{22},{24},{19},{19},{18},{12},{17},{11},{22},{10},{4},{8},{9},{27},{29},{25},{3},{22},{24},{12},{21},{11},{23},{19},{10},{10},{17},{12},{13},{10},{19},{23},{37},{39},{32},{34},{29},{29},{34},{29},{31},{28},{16},{34},{36},{26},{31},{28},{22},{15},{1},{14},{32},{32},{5},{9},{23},{25},{21},{16},{18},{20},{15},{15},{20},{15},{17},{4},{9},{27},{29},{20},{22},{24},{19},{19},{24},{19},{21},{5},{24},{4},{22},{24},{1},{3},{12},{26},{11},{4},{6},{6},{5},{23},{25},{13},{31},{33},{26},{28},{23},{23},{28},{23},{25},{11},{20},{14},{14},{4},{7},{24},{9},{9},{9},{20},{9},{20},{9},{20},{10},{1},{1},{1},{1},{12},{11},{18},{9},{9},{9},{9},{14},{4},{9},{9},{1},{11},{6},{13},{6},{21},{9},{8},{7},{9},{17},{18},{3},{4},{11},{10},{7},{17},{18},{11},{25},{29},{25},{23},{27},{25},{17},{22},{26},{20},{24},{6},{6},{6},{7},{16},{10},{14},{10},{8},{12},{10},{7},{8},{11},{8},{9},{7},{5},{4},{7},{14},{18},{14},{16},{12},{16},{11},{7},{6},{3},{11},{14},{15},{9},{9},{14},{9},{10},{11},{12},{15},{8},{3},{19},{15},{18},{12},{5},{32},{17},{3},{12},{11},{17},{18},{8},{11},{13},{16},{10},{14},{14},{13},{13},{13},{7},{12},{11},{11},{6},{5},{4},{8},{14},{15},{5},{9},{9},{5},{8},{14},{10},{9},{4},{8},{10},{3},{14},{5},{16},{7},{7},{5},{13},{19},{16},{10},{6},{28},{13},{8},{3},{8},{8},{6},{19},{23},{19},{17},{21},{4},{16},{9},{11},{11},{7},{13},{14},{15},{11},{10},{16},{16},{12},{17},{11},{12},{12},{11},{14},{12},{2},{10},{17},{13},{2},{12},{4},{15},{15},{12},{10},{12},{19},{10},{5},{9},{13},{12},{7},{13},{12},{13},{15},{8},{5},{5},{12},{5},{30},{7},{7},{12},{8},{6},{9},{4},{5},{7},{5},{31},{14},{10},{5},{6},{7},{8},{4},{8},{4},{12},{13},{16},{14},{15},{89},{259},{94},{33},{23},{98},{82},{24},{90},{21},{49},{28},{121},{31},{42},{47},{70},{93},{85},{93},{93},{87},{74},{94},{88},{101},{99},{138},{47},{99},{27},{17},{19},{30},{30},{47},{171},{21},{159},{49},{28},{19},{25},{17},{19},{26},{17},{19},{56},{345},{70},{9},{117},{117},{42},{40},{41},{376},{34},{28},{29}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (5405 bytes) */
const char* const cstring = "(\265/\375`\2608\235\250\000\352\246d#G\340\316l\0030\314#\014\343c\026'\030\033a`v\314\216\3311;f3\004't\236\255LI\"\223\010\232\022LIR\225\017\026\005@ov\207\201o\335\273\001}J\274\r\216\305W-\347@[\365\2442\025E,o,\370\001\007\0029\0024\213\342\033c\210\315h\370n\347:\277\375\215\263\347\3438\352\233\016\243\337\270\377\216\203O\034\366\r\337$v\315\210s\355\246E\233G\034\322\306\274\313\243\265\251\251NX\020H\204\010\325-w\025\352\333\357y\316k\233{\266\271\261((\251\023\212\3359\337\374\322\202(-\253?\226\370\226Ek\372*Q\3376\017\357\326\271\223\357\331\245EB\017\257\te\265\342\342q7\374\233\320b6\254L,ne\022\366\222{\334'?6\331H%\020\227\024\225\025\025\010ie}\030\376\256-\217\264\366\345\345E\225G2\207q\\ \324M\333\233\266\235\333\204\037\347\354\36714\032\327\356\345\3173\013\232\241\311\230\246\307P\331\217\030&\357\272\026-\311\335\230\304\376\234I\313\277\025s\336\266\344<{{Y\224\317$\357\333\255\377\250K\233\317\336\3431\264\225\336\372\334\261]qY9\321\270h\354\356\2741\333\364\230\305\315c\331\217m>\207\345\315a0\320\213U\211y\006\204u\316\331\234\323\235\314\242\377\336\362\220dC\3339,F\303 \356\366\313\252\360/\311\375Z]\250\265^\033.,\366\252\2015\230\253\005{\335\357I\242\356*\255\024\033\022w\\\250\373\3379\304m\334v\211\232{R\217\243k\304=k\35006\207;\367|\313\263\237E\236cl\250y\255\374\303<\202w\232\235\356\271E\222\313~\273l\256\374\270eU\024Py\264\341\317\267\365\332\346\362\367<\032\212\244D*\2719\336o(\233I\350\261\204\036\261\376zk\233m\2267nn7\016\255\026;\347\254\315\365\307=\2231+\356\374q\2709\213\314qV)\225\202\363d^\211\320\302\177\t%\345\222b\363\326#\311\362\276\356\334\346\227\370~\257G\324\245\315XV\334%\267\260\3129\274I^\343\200 U\3665\366\306-\316\035\004\335PP\2537\334\243\266\371\242\276\271[o\315o\356|\343\364\275y\307m\370~\033\234\3166\375v\3343\016o\234\273\367\206\273\274\335\333\371\367]\337z\037\361\210\037\3620w\362\372\234;.\213\377\213\275g\0251%\367;\202\274\267\363\037\342\333\r\277\037G\036\3721\264\345\020\367""\177s\371\353\237q\367^O\336[\350\363\3578\274ah\2736\233\317[\377\222w\036\242\270\0167\317\343\033\2778w\254\261\207\016\034>\t\t.-\327\013\346%C3\363\242]\226\024J\312M\221\001[1\257\031\315uS\265\014\033r\331k\265\231Y\014\206\006\003g\265[\236}\234\014\2738<\r#8\313\312me\261\307^\255Y,\306\2723\327\205Z\254o\027\217\314\2250\030\206]\220\001g.\r3\340\014\346\272X0\327\314\005\343\232\325\\\255\230+\346\262^3 \254C\313%ca\306E\203\271\356LM\rl\265r\374\373\222u\0133\311\253\255\250\210)a\356d\3367\223\027u{\366\245\377\235\367\356\242\315\\\032f.\232\330m\301\\5\220\005\213\261>\211\233\037j\361n\356G\370\373C\214\363w\326\245._\257\263\307\026>\376\376g\177o\210\312\276\346\026\223\t\321\022\"Di\025\201\364\301\373\314\262\305@(\020\3505\003\252\200J/\024\254\351\205\002\251D*?\212g\033\365\355\306\307\257*\221\220X\023\t\t\t\204\202JA\245X\225J\314\336\242P\253\261\363:\307\231\304\274\365.\355\351\205\002\016\217<\3118L\"\304\244\3379\324\343\335\246{\303\335i\363]\212\366\226b\356\367Z\276\263\027u\307\331<r2\304\215cy\333\331kq\265\0221\037\305kZ\2156<j\2743\345+\212x\265\313\335f\303\326\244\262\246\022\311ZU\210\017\025P\036\374\251\237N6\335C\237\305\323\351t\362\372t\0232\346\276\rJ\207o'\270\316Q''*O\376o\223\003\004H\036\225ws>\370\311r4@&+\200\224\005\005\200Z\002\253\316TEB)\006\252;\007\234\036X\225\251,\251\023\300\271\322\260\"\034>\035Z\246\316\023\032\247\211c\3037\352\301\250\014ROJ\362XY@)\363\300\n6;\316\014f\211;\230\010>\277\321\210\207\212\350\204\331\301\361CA<|)4\304\3037JA(\313\311@\204\317\002\243\320\031\232\023D\007|\036\035\026\002\324\237\236t\254\330\024\220JO\234\017R\350\010\255`\376\002\276\020\207\0174E\034\251\003\353\001\220\201\245\211\374Rj\016\025AC(\311\271\300\014i\370t\251\376\215z!R\034*Cq\247\003\016\0376or6R\035z:E3\001\206\005\312\016\206\227\017\306\024e\370B\352\t\n\262\261:\330\271\020\343\003U\310\320\327\231:cL\321\307\027:\025||#5\244\246\030\254\243\223d\032\310\360\351L\226)\001A\317%d\r\371\370R\351(-""\361X\025`X\244\354\200*Fg\350,\361\323\360\230\034\031>\260G\301\264\232>?\231\031\300\324\345l||:\235\014\275To\002\311\212Q\014\347\307\307\3479=2|\251\034\002\037\037h\"\300\260\020\331\t\365$\200\254 \027+NU\322\217\256\2409Sf\356rVr2\002X8\330\361\250\220\255\230Y\255+\223\365\243\036N\321\3519y9\034\030\026#;\236\025\027TV\002)\351b\315b\370C\333\261Mx-\374\265(\335\225\010\327\343:\276aY\262\260(\225X\0144\326\304\243\031\303kaQ\"=\251I\330\2775\311Z\224v\244\022[\343\340b]\0144\260X\255\006\\\321^\034\300[\253\241\251\325\304h\256\0161\330\312\005{\311\274j2537\273\343\033\2177&\313\322\243^\370H\001\365\313\\\210sm\245\027s.\324\035\213\233\3646\177\353\316G\350\\\366\267{\303\311\271\377\335\275\232\304!9\2129\304\311(\315qG\371\334\375b\336\351\257='INz\322\223}\364\334\363\\\271m\376\026\257\036K\221\337\033\334\346\243\317b\211G\277\32381\357\002#\035\337\333\270(qZ\233\234\002\037_\006\201\000\037wO\216\256V+\001Q\200\216>>BRZ\362\321\241\373yz#\036\010d#\017\017\021\020\335p6\350\271\324\213]\0023\244\361[ \332\251\003T\224\210v\234\n~\"\000;\235\271\362\331e\354|f*K\310\032\343\222q\261\206\000\261\202`\255,\225Uu\376\033\227\035\332l\235\251V\025\311\352\001\024\032\245&\316\007\244\232\013\311\203\352N\017,\027\253\3144\311\001]\370<\036l\252\310z!=\257&P{\007T\204\272Z\036\230\235P\332 \344Qu\351I\203\017\017\237(D\2559\200\276\230`\357&\200\004\247\026\322\022\305(\007\207GG\327\203\320k\201P\022\351\200\350XH\2555\032\nA=\017\374B\246\007>\035\200\347\006\022\330\016\250\3232YM.\326TH\305HepN\001\215\213\232\\xdJk\351b\365\364t\352\206G\375l\310tD:`j\365\250#\032'/\226^\210}\364D=\020\267\031\324&tF0\277H\025QSt\351IV\222\226t\2549td\344\207O\331\331@\367\301\361\373`\360\341C \022\265\210\275\t\352\202\264&;A\014\325\2432\021\255\242\317\017DE\026`X$\330\301i\212\t\2455De?\235\212\023BA\230\032\006~\003d\314\224\t \205\371\311P\020-\351\325\250\240\272!\025\245\256\023\020\31585L\035\243\n\245Kq\212\001E\201SY\252\201\256\360\n\225\025\031F+""\274NL\313\352!\r\220\216\000m\2541P\275\220\246\322\030\n\033\"SU\251\311\257\005\rYq\201d%\215t,\230\200P\336h\006\005\252\017\326PK\226\202\251i\024ZCg\n5\202Nm\021AAp>\251\007\352\361;\037pH\010\351z\025F\326\023\224\305\247\224\206R\022\024D\201F\212\202\200\372\363AH%\201\216\200\214\324\024ZzZ\260\"@\303\323\201G\375@\302\275\027\010+\204\364\205\246\320\030\217\212\342Aig\003]\352\001\205\000\252+?0\335\200\252N\r\237\354\014p\32202\224\330\325b\035\231\316GO\302\350\364\037\353\307\347g\177\262\3644\322\361=\007\252G]\261\244\001\205\316\250c\370\242\230\245\310\231\221\021IR\220\2441\243`(D`.\024\217(t>\037\223cCR\230\244b\316\030H\014\241& \tF\002\211FAA\n\n\nR\350B\211\276\341,@\252\361\373\327\351\235Of\3577.\265l\267\020\317\345\317m\214\3455 YS\354\227x\273\3553\347\016\021&\344O\231\362\365\362e\247o\200\270\240\330<<\257M\n\305\315%<\377\306\354\271\253\267\235r\261\330\271<\333\311\261\214y]\016H\214\256\264k\311nF\372\006\251\3303.\351m\314O\241\366\246\211\270\330\364\020\337\030N\367\324W\206\374\033\016r\002r_\260\234IO\227\315\303Y\246\324`HP\261\250 \227\210\212zMc\345P\321:\256\352\245\307\014\345\360\022\3461\230\357m\033~\364\301Y\312E/)\330\266\345g\001\344.\362<Mh\036\243\210h'b\2652<\322q\312\201y\354\311q\\\222\242\004\377\037!\2465Cr\224\226;\333st\352t\301*aR\331z\211\252!o\353D\213l\016\033);\331\2108\204L\037'\r\374\177\312\233t\315\335k\271\030?\325\244\005\257\354&\200\275)w\2452y\304\210qr\257\244\354\215\204\345o\322\010\023\361DK\242\026b\376\0054v\252\234M\333Fl\372\315rH\034:\372\032%/$q\360\336b\216\253\315S\362q\245\221-\316N\225\371\005\271]\226}\225Cb\01768\231\036\020q\312\265LV\322G\005\264|\364\253\200\007CH\030\n\023m\023\030\367\246\025\370\313\312\244\246<mO\305\211\020\301\354\020L\3263\213\352o+oo1#\240\367\313\351\2579\000\332\3058\r\347*{ \243\254'\355N\205S\260\215\271\026\261\210\306'\242]\315\246\207\277\361\2544\364\256\014y\006\271}\016\222\331\350\013\307\355\367Z\037\351\366\241\333d\201L\234\226$o,\310""\r8\221\034\334\202X\310/[z;0\330\241\225`\352\211\t2\014\265=\010\212D\023B\244WE>\256{\300\246\343\227\251\346\240\275\022\376\026_\024\203\237<\335\220\323\227?+2vI\355\302|0\024\374)V\316U\023p\242\242\332g%I\326\037\354B\213=\367\033wL\034\2205&\371W\205\354\271v\232\264\345\240^z\214=\336\270,\310\340jB\201\256\202\201\264\001k\277\r\241*C\301\361\224\377\227\212\"\0012y\340\2545\331\347L_\230\277M\t.\363\335\020\354\304\313\317i]M\247V8\324\241\276\r\001f\363K7p\034eP#\377!b\210a\032\243\232\352f\372\003S\316\032q\016g\373\2176\035\2132$\306n\356\030#pF(\035\274\213\221\305;[\310\327\320MP+FI\340!`.\177a\226\237\004\334\020yY\334202,1\340\ngE#\252\266}\000\003\254pN\350\333\240\323\263\271\372\2470\266\211\313\351\355kI\352Pf\312\010a\026\370\335\315Z\221\213\344\000\262\021\313\301\340\345m\346 %\024\001\367\023\no\002o\026P$_\027\3018%\022\267\320\302\302;\031\352\231\372\242\215\020\201\350\272G\\\242\263w\214y\243\246 p\320+\265\240\343\231\372\342\325\255Y\034\217\332\343\204\331o\324%\245\242p\245\251\0303\220\345J\360\330\200`R#vt9\247\177X\245\313\350<\232\341\243\262i\320\273\320:\021\330\010\344`\025C0\"m\325\020&\225E\001P\312H\363Y\251Z\270$\262\233,\334D\215a{\372\003tk}\227\001\330\253\235\227\3612nm\020\3046>\026kH\235\031\361\001\031\313:-\233\224)6\214&\200\265[\361!\232)F%\376l,\036\232\214\207.m\377\023\232\000\363\374\277v\0065\222\214l\"\303\217#-\373\263\004\355\267]\376\212\033\354B\"z\314)\275\022\265\233Kj'\26053\t\316\031\277\003\305\033A\000'\316\377U\202\367\267S\030&3\214\035\214\216gmM\220u\005*b\236-\331F%!\"i`\210_\253\261\036\302=\023\251>\352M\325{\247V\264*\351\3462\230\313\235\334\335\301$\"\2011>\377&B\315\234\035\337C\025\206\250\2141\324\362\274i\010\263\205\253\211q\267\315\320\371&\310\2709^\234\2049\033^\010H\3407\376\3477\312[K[\023|\031CY\236\363\263\370J\271\2540s\226\373(\202uY\350\303zv\276\250[D\226\030\367\027\316\234\3658a!\305\343L\231;\215\323\r\255\376 \313\0070X?\314\210j\3742n\363=\r1A\243\364%\200\t\252""\004\336\241\032\314\342\365\213\026\240\227\201\343\033\020\306\315S\356_j\220\013\016\033>\351\211$&\020`\235\200N\340\211\366H,\005\267,L\222\256\253\"\221ZD\362)\t\013m_\354~\215=9\352\341a\225>\266\230\243H\343\300\237R\367B\252\000\266sw\263\235D\322\360;\001h\225\304H3Ap-\204ve\337\333\223\226\033\337\004d\301\356\302\332\333B5\022\225\223\275\367[\264=*\237S\251\342x\363Z\305\366\013iC\3553\364\314\276m\n4X\271@\024\324p\225-\214\356\210\2016\224+\215|\036\202\255$\212\304ls\206\352\355\243\251\271]X\255 \260A~?.0/\214Z\032u/\203\306\014d\240\233\0174\0230$E7\242\302\217\335\010~sU@\213\tc\362\247qW\r[\352R\355\273\003\355f\364\030\224\300U\331\023\362*\021zR]\022\242`\324\335c\276\324\206\017\363\\\335\274)EY\366rd\227e&\237\333\000\263 @\221\356\267U\271\350H\346\313\017\036\314n\2402\250\242\211[x\r?\320\322\205\001\324l\320\217Q\001\t\265\006\253\363\265\320\005\226\334~\344g\211\030\035\212\365\355 n\242s\330o@BxP\347x\\\233\355\215pG~\307b^\344|\264u{\345\320\227(\330\372\3451xd\322\206\375uC\337\302\r\271Bs;\360\250\321/gv\253\351\3353\361|\264l,\216:\021>\032\245\020\351\355L\305\345\2268W\342\246\341\221$\2664:N0\034]\031.\302dJEy\364\363pfa\254\"\271\205o\354F|b\270\330\334\007\004\303\324\274-\r\307t\221(\177\031\032^o\372-\304V=+\373z\"\345\016\356\255\022\003C\340\301w\325xm\037.\027\346SS\025\264\312\n\\\204\216\3234[\t\321/b\374\320\354\250\324\204\257\3745q7`\202`\316\347\212\317y\322\030I\221\350\017\374\370\325\000;\366\361\247c\356\205\301\247\020\350\217\367N\377\007bz\201\233n5\200\317\231\265*Qm\226$\321=\372\327\362s\013`/\302\245\352\344)\005-\246\376\241\001\3325\332\306\204\357\305,I\270\374\333\376\241E\017\352.\200\346\330\231g\006\002\\}\030\321\236\347\251\315\361\331\005W=y\322\262\010;zi\213\367d)$\003}\242$\2311\222\311m\340\335rl\234\275\305\226\246\025S\374\336!\003S$\206\255\2305\"\317\276\200\013\203\036\003\006;\261,C\267\206\305\344\3377\370\340d\325`\332\345\036\366\221k\371u\235b\217\017\352\234\370\205H\002\014\337""\314\005\337\017\246\353x\r\272s\302\255Y\267\262Aa\277\314\2129\342l|\360\370/\303'\365cB\370_\177\232&I\204\200\341\002a\353\025\201\3532\204\326IX5\325\320\200Ov\02475\261\310\375\216CK(pP\016p\200\360Z\266\350`A\307\335\220U\t\267\301\251<\310\217\231D\211\322\022\331{\211\330\257\006\002>\025CJ\321\341\n\n\016\215U\321BE\2161\n\323$+s!|\310\307H4~\350\215\3679n<\010\345I\302\243\316\320(\3555\037BO\305J\030\251\250\034\321\224/H\336Sz\303\005\274[\370R\004\335\231\330\226\226a\000\255w\030K\232w\326H\034A\214\004\262A\200j\272h\013\345 (\216\351\374\355\221\255&\213g\303W\017\230\210\017K~<\210\342\201dE\376\264%\203l\356!\302\005\002;3*\017U$\006\326Sb\301.O\324|w\211\275(\375f\333R\t\257\354\364<\307d\330\003\370\010U\343\300\313\343\362\ni`\267o\223ly\254\361|\022j\343R>\206\321=\372\375\3771xT%\247\017\237ML\326Y\330j\244\307\265\266\214\260\3660\222\377H\210!H\247V\330Q\224\231\273{\250\250\245\264\266\210Z\365\342\361\317\014<\2308\224*\302\277\034\365\250\344\242r\205\365\204\315\020@\214\330\350\356H\026+pm\021\242Io\342[\025\020\370\207\217\261\nj}@\332zh\245\027m\027\340\177e\021\020\264M.d\020\252\022?\021dhk\311:\332m\201\303`\327\t\002\000\206\210\304\030\252\353x\305\223\021\300U\244/\312p\210\367_\330\014t,\217\ti5\315\270\313y\307ZO;\351Z\364\204\274z\207\320\311$\007`\251\362\257\004\321\232\335\305\037\2414\262\260V\014\262\006\330o\204\034\347\"W\\\374\302<\205\247\205[\026\203\023\243\010bJ\255\305k\017\233Myu\013a\025a\025\217&\246Bk\321\312\350\355@\3025*8\273ay\\Ui<-\033L5`\366\023\254a1\221\244\013c\230\242\2707\253\305=\362CJ\321{\037\252\0134\036\325J,\2777\227\303u\005*\216\241 \254q\260\021\226\326|\340\2038\202\301\311\304j_0\"\256@\032(\300d\242\010\\\342\356\256\010\020\345\357\037\024\361\221ws\355\222/[o\3021\213\361\255\356\326V$\3753\020\316H\363E\204\350$\3750l\316\371\227\t\266\372\374\244\272\006\233+v\002;z\201'\002\300\027\260\377\201\361H\233\313\246}q9\271\376\327V`\3047\233\205v\336\201Dl-\235\020n\013\031W\024;J%\340""\261\275\210S7\241\362\016\356\326\277\023@\335p\315w\316\377\305\304H\217\000\266\326v\205\227\336\225\001\016pW\343\202G4V\221\213\006\355\240\354\301\301\364\362'\200\206~&z7\177\206;G\034p\205=\277\240\"\022\372\274\214s\217t\223A\322rc\366\031-\342\037F\250\245\377~{\212\341\020\2761\331\\m\344m@z\366\206\004|\027\350\214WqP\242\366\326\366#b\250Z\032JvkX.?\257\235\224\235\347\210\353D[%zb\305HP\370\256\212\360DU(\217\262r\356InYZ!#\250'6\325\206Y\2026I\016\306\003\254\\iVRU4\336\220t\301\365!H\251\306\320w\326\217-\014\301N\305[\222mw\342\310(\343\214sKa\325z\206\035j\206g\271\230\203Rm\n\370\217\215\331\203\367\031\"w\355\346I^\032\333 ~\224\\\233\213\023\3203\335\271\3227\275\360\031Uf\306\232&\327\034?$\277\253\270\361\367\251\203\310k\321\337\206\241\277\032\201\346\rSr\302\324P\265{8i\303\2311\367(\212\366\"t[D\366\262\024\364\\D\373jNW\036H\371F\025\202\037\273b\217)[D\333j\237\362\177A\201\010\206\236\241G\tV\367\373\020k\020\266\335\226\037\313S\n\n`\245}\212\217Ph\213\2104E+l}\200\320\035\0176\336\224TH\2433\362\\n\252o\360f\200\247U\274\247k\037\235\261!\246\"-\014?:\334\253\230\230o-\351\"\226\313\355\350\377\302\337\021fb\305\024\211\203Z\026\177c\302\037\354<t\031\300\206c\304e-]\244'@r\347\014\007\004\241O^\036\233\210\356\t\377F@\255v\260(\177\377\000\222Lw\"\214\311BG\374C?\356\034g\311\256M\206\203\261\333\302\034m\351\244\027\001";
    PyObject *data = __Pyx_DecompressString(cstring, 5405, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (5454 bytes) */
const char* const cstring = "BZh91AY&SY\253\334\305\206\000\006\355\377\377\357\377\377\377\377\377\377\377\277\377\377\376\377\377\377\376\300@@@@@@@@@@@@\000@\000`\027ow{\357\227.\303v\032n\335\312{\333\225\016\333\325\264\2730\267\275\335\273\225.\264]\246v\351S\233kT1J\331\233'\272\307v;\232\3504\357y\364p\350tw}\000I!\010F#\021\246\2312\010\323\325<4i\246\232j<Dj\236I\372j\201\243\315S\324z\236Pl\236\215M0\243jf\325?T\366\211?T\364\232\t\024\023\010\230I\204\211=O\322\236)\265\032d\003\023'\224h6D\320\000\000\000\000\000\006\200\017P\032b \221F\210z\207\250\36544\r=@\000\0004\000\006\3214\000\000\000\000\0004z\200$\322\204\204'\242e2\201\220z\232=@z\232i\351\036\243\322\017P\000\000\006\206\201\240\000\032h\001\240\000i\251$h\365\000\032\032\0004\000\001\352\000\r\001\220\323F@\000\323\324h\320\032\003@\030\200\t\022\010\2312\023\0012\004\325<\233S$\332\023\r!\247\2424\000\310\003@\000\0324\000h\000\000\263\\\325\320mr\314\223v(J\235%\267\005\\m&\275\217\224\364\022\333P\234\322\3466|z\366\250:G9\326$.\272\353\2018\204!h\215\233\010\004\261\324\245\240\235\324\rT\361\323\330\311\360\210\"\306\013\010\347\370\025 \310\021<\257\346\210\253\200w\214Ib\354U\331\255\345\221\216,^\321\230\310\361j\317\020\2400`6$\224\357\314\250D\242\362\177\362\003\020\232\223D\303v\241\310\177\346#\030\214\004\026Ad\021X\214Q\033lb`\300cChw$UYrBYTpAo\344\357\372\302e\253\351\253]l\232\322\207sP\367\3647S\036`\341q\314y\346\024\327Na\314(\nFNL(\231\017z\262n\014\362#\235A\352z\240\271\311\266>\370c\326\360\272l\302L\340\254\260\201\267\254\\\310S\347\205ds\325\t\035-$6\t6\222\033@\3066\2064\202\275\346.\330\317y.\333\300j\010z\340\214\273\340\221/{\236\266$j\202I,\033\032*\264\361\345#\000AF\201\261\264\031\211I h\273\323\014o\271S\323\257\250\314\000\314\025\021\211|\3216fh^\346\225r\243\004\256\256\007z\303Z1\200\333T\324\273;9\256\265\270\001\343\003\231DS\032N\224\204N\030\002\325\245L\266\240\251\005b\305\314}\234\375\024\033\367\253\335)\262\336\374\326a$\006\306\373\033\014\331\023\330v\306\312(a\026""\2662 X\r\355+'\340\250Y\331\301;[\302,\262F\270\024IT\334K!\230a&\234\316\013u\000\232\224\215\246\2211\265\205\205\300*Az\236\034\211\013\323\354\034LH\370F(\272e,\202\314\253n$H\245\216\356$\027\tv\200H\353`\t\026\000Hw\000m\204=\316\367;\244\272\217W\235\316N\034\227\002\276\245,f\\\316\037\023q\355PK\313\260\263\252'\347\n\003M\177\t\032\342}\341\367\274\315\036\021\256;\255ZS\ty\337\322!\207\227\352\332\255\003\347\222\361J\263y\360[J\006:7\227\237\030\354\215\031\203W\317\207=\371\323\010\030\300\334\311T \025i\251\354\177\205j\330\367b\t\307\362rp\317r\206D\010\254+5\322\315pY\326\007\325\3650+B\236\372\370\233\314s\320[\256^},\376\242{it\203\032\3324\371\225k\304\327\351\2537\027\027\007.\216&X\275\025UjLyc(G\257\267 \275\241b\201\254\006r\264+uW\210\235l\235\226\205Yn\314\352V\030T\2576_\231\2759QD\204p\t\341\034H\306\323U\360\\_\211>\245.J\224\024\354n\326\316\261i\273?\237\026\353%{p\3331#\260\213\321\200\341\314\346\030sI\tm\0262Mg,\025\265\276\013s\253\261\344|.\302\257\316\235\326y^O\030s\275]S9\357\301\231w\256\222\362\254s\357p\350\335\270\336\227\004@\344,;\351\031Rz\014\303\225\343r\236\214\261\310\364\350d\351\220\302]\335\301\350\013\357G\200<>\220<\3128\204\210\2236#g\300\330\031J\350\251\033\001\22032\343\t\217a\301tg\006\305\313{Qu\222Y\006qRmZ2j\336\232\367c\340\250\r\3068`qY\353\005\347\"\261\344\264\267\255kQ\242\232\306\360V@o[\367\276\303\257\256\354\353\325y\026\324\327\257~|\271\263\006\340\361\267qG\245\332\356\225\016\245):*y\304\032+\017\023*\302\245\223R\243P\302\226C\tQ\027nZ\373y\277\3278\347R\326\243E<\263\277Cp\273\375z\266\024\255\254\322\373\232\3415DMwiS)\376\237\342\263\333\316K\340\312\352\247\266;\237x\311\n\340\325\027\"\202U>0LU$\235\205v\304\\\0315{\240\222\230-\322\226\224\264\266\224\267Z\355m\375\370]GT,c\275\261\310\356\272\314\241\231\251\n\374\265\303\255g\352\224U\260\313\320\254\213\2053\257\275WW\023\322\260):\256\354D\265\324\227\013\311>Q\352,\315\370\265%\010\364O\227\263\340X\275Uj+\026\204N\002\013`\367rR""\033R\234\247\023\332\265-\036\200\267w\344438\246\271s\356\341S\304-p\354ZV+'\273\237T;v\272\235D\353\017ppF\2441\306\315D\322mx\264H\210\263\210\343\241\347\247\031\245[\032E,\353\n\236\320\267\027\3564\365uY\203\006\207\336\\{\353Y\254\321\241\n\202\2312\n\227j\210KZ\313\302\312\323\254-\247\305\025\241\231\231\231\205y\202fG\n\224\252n.\312\311\014\365V\253\370\035\350\31664\347\273\376\355\320\200\272\211\311d\262\302\306/F\202~biK5\307\2670\366\302\030\023\337\323b+I\252.\256\255Bn\360\n5\242\340\025\260\024\236\272\256>\315%\342\377'8y\206g3\216m\350\264/.\031\3248~\005&\212\224\235\333Gm\2665\326[\302\252 \240^\210\345\222\010Y5wQ&\037\243V\206\026\030\020\004\354\354k\034D8i\354\343\240\353\370\037\210\333\201\213B\036\344\033\030(CLC\006\327q\212\001\252>\313\003%y{\336\335\231\0318\303\357l\264Sc{\315=yC\343\212f\344\312\307\016&\277\247w3\234\324\314\270,jE\003)\335z\017|8N\2658\276OKu\251\304\352:\272\r\227\346\355yO\210;\306!\307\237I\363v:E\350.\264\017Pt.\277\031\215\214O\234\033`\324\352F:t\332\215^\274Y\324\243\316\247\226\333kc`\267\334\322\016\245M\341Um\230v\357r\211\0245\207\322\376\313|l\346\327*g\212\325zO\244\236~?[\273\272\247\026=\035K\266\265P\320\272<\272\023S~\302\361\270-\337\\\035\254\354\3700\203b\326\273\026\261\006\034\020P\320\242\005X\033\265\264\277\334\265(\370\036e\2752e-\030\205\"\324\310\227\223\250\032`\2749r\233M\036\344\307\014\260\016\023\366jD\3638\003\301\177fdc\302\303HG\203\016\247\000\333\037T\362\031{\177Z\331\033\000\360\351\304\026a\267w\225n\343r\352\3625d\300j\315%\250\237_\226\374\240Ykok3\237UW\320\236\021\311!\265v\263B~lp\251A\371\331\304\215\227\021\027\235\316\016\247\275\333dp\207\0108\001\366\202\200\253\264,\202\241{\370\215Z\2121k\031\022\244\021Hp\216\260\343\314u`\020\034\262\362\003\266$)\261\036(Z\364\207H\260\365\273\000G\240\230x\351\256\306<\240\241\031\223\356\345\206\301\264]\177H\032\326Q82\311.\207@\023\255\014\r\273N2q\272D\027\003}\316S\352\335\014o\230\326\242Q\242\250\226\314\371\264""\026j\227:\236L\275\031\365r,qR\226\333\n<\313\025-\326\343n\373U*\325\243\225B\242\232\016S\311f{\346K\341~\354\014r!\261\315\"\233tEfH\376o\234\342\342h|j\213D\033\204Q\320a\233[A\237\326Q\203\303WE\344W\331\375\307\264\366gu\372\321\310_ak\3618\321\010\331#\217U$\0375\323\261\276\316\316\311\343Tv_\334\t\003I40\366\346C\357\362s\315\317\316\2177}\232@_\036\361\014\023\336D\016^\236\223\020.\334\236}\362\\r\216\256\0321\234\360m\255Lm\237i\216\034\331\335:O\003\361\262\355x\2023\215\347\246q\315\346'\203Re%\026\002\245T\306+\275N\020Q\377C\311\326\272\005P\333\307\243\025Kl\220]\025\353d0\353\276\247$C)\213\227#\324\247m\034;\361\314\206\304\360B\267\355\241.\206\377L\213'\257j\326\200\331\033\350\211\034\nz\204U&9m\255sl\341\276\223\312dlC?H\311E\203\346k\273\246X\233\210A\357\n\360\224\247\265\2115\260Csx\205$\346\027A\270\207\033N\r\302o\206\307apiz\367)\2113-\364\305I\370/^%\300#\231\257\303-y?\336\375r\313\247G\035\272\003O!\341\310\243\375G\323\330Aw\006\316yq\231:\244\235\021/\325Y\301\360P\310\317`\242\241P7\262N\221\230\021T\222\214\224\214\350\226zm\275\t\314\322\240\3008\271\006\273~<\255\t\366\240-\327w\025\352 \336\032\364\341(?\331\222\241\362\220S\212\310\034\207J\3734\321B\201\236XI\321*\022\302V\362\026\331\316\234q\266c\311d\225\306\025\240'Sq\273\246\370\306\361\010\306\010\0350\351\354\365\275o|z\305\325\366:a\022@\304\273\256\326\022\373\202\213\253\006\206x\276\037z\017]\210=V#\212(\3141$9\343\023\016<\312B\303\214U\324\206\325\023,LD\245\344x\353B\303\311$r\007;F\226\243\344 \322Ut\265E\252/$\254\021\346\331\323\030Nx\035&\322p\343\264\273\346H\035\251I\027\234hP\225a\314\357\341\016\375\247\016\021\225\0073\002-\264\310K8\317\004\351\212]-P\350w\322z\t\220V\024\014T\200\202n\371ha\262\223\234y\332\354\331Z\322\264<\216\346iy\327`T\230Y\334\206\322\356\210,&\007+\310\201\354\010P\232iD@\352\002\351\351:\026u\331V\210\226 X++Q\260\260\236&&\374T~\007\322\2610\204\016\017HF#\244\t\313\244\372+\2179W\237=\374\264\3230\324\002\317U\230e\241\267""\031\3539\022\n\030\254\227\021\033\342\024\335\022\t\tY\025HD\022t\267\316\221\006:nu\323I\200Zt\217>k\232\333m\355v\027\264\216\365\275E/\031N\020\n\036\262)P\344\240u\342\352_\250,N\245\020\313\020L\227\227{\310s\204\351G>\020\031\310\\\303\243`\273'\013,\335\2660\272\030V\340\247\214\352\322a\204\337\300\222\240m\277\027s\221\2700\361Z\344\224UUT\020I$\221y\327\201!\300\333\264E\254\240T\\\014`Z\260\25258\271j$g,a\330A\203C\035\241\002%\333\363Bq\317,UdQ\227\274\tE\244\253\334r\367J\351\024G\253r\030A\005m \344\221;\314\3649NKk\232\272)\274\275\271Y%F\317\t\001Yn:!=v\300\314.\233\023m\211\301\361\010\251\014\201\3324_)\264\332zaL\212\256\211\233t4\214^/6jf7n4\r\371A*\252y\211g\227\233\210\322\032)\250\363H\313\\2\262A\240\366\006\206\232\334,/XT\225\371L\207\033\317Qm\033\235\215\226,\033\034Q\r\241\212\302QT\206\013g\001\\\251,\231H\344F\273\375\034\241\036\317Z\356\037-@\370kM\371pL\277\323\240\216gn\364\203\234\221\236\311\212g|pm\200\\\210\243U\210K\313b6\364W*\235T\242\252\362[\235\335\216\216M\273}\356^\263\026D\035\351+\024QT\356!\334K7s9\341/\035\372.&\375\375t\036r\317\010)\303\002\335I\340W\331#MPd\000\331F%\335\032\030\302\321\2005\332\204\310\006(\020\005\255j\317\207\237\227FN\223\267\221\035\t\005\362\335\247\266:\304Y!\260\256nqwC\266\254+=\006\321d\305\261\250\253 \252(s$\020\220F\234\345w<\305mF\373\355w\035uH%p\016\270\245\266\364\204u\310b\0302\3472\021\221m\261\033a.\035\311$\021e\330>\265\021\203\310\231\356\275\030E\365\310$nhl\033M\210i\240}\343\020\026]\273\303}\256\007\230\232a\333a\303\rWm\256\247\343\033QyP\244i\244bc\002\036\031!L\332-C\026\246F1\244\020p&Bn\304u\353\004\270\003\001\256\010 \\\221)\034b%\250H\301\235F\243\241\0233.\205\3543\014\240c\323\230\3172w^\257W\363Ug\321\240i\2556\335\"u)]f\006\232!I\035*\351\230\336\002\257O22TSEo\277\342ThM\005\014\366?\017%3V0\205~0\006X`\266\3318\006\307w\2556\\4\226\352\333mIU\025b\341\303(a\200\333\000\266\200\266\224\205\265\023\232xG)\006h\333\200\200\010FF\034\266I\243hY\2249sf\302tM""\277\222|\035U\025QjW\231d\3071\270+\206\342\265[\354D\245\n\023E\262\3069\346p\030UUUUV\021f\220\003\013#!\206:\265\037od\256P\310\3143\034\240r\001\331V\006\317]\222M\256\242vX!\020_\215\324&\222*\366P\24016X\233UC\027\004,\201\334\n-d\"\311\260\326\t\273\2067\021\203>\210\353F\213\224\276G+v{s\tN\235\325\245B\371\247\216\224\010\251\3112,PJ(f>4\031\262!V\241\223i\203GIFBIjPf\356rO*0\342\220Bn;Z\221i0\354\350M\241\032\263\241#\264]\00230B\370r\320\260gK$\340\250\305@\301\001`\216&\t\204H\202\214\206\265\343\301*\001\236\203Vs\205\014\303\032\270J0I\006\nKD\027FP\210\351\332\"pX\031p\2524\343{\300B0\247s`At`\\):\301\304\321=\212\201\221\017K)\316\0372\317S\306X\022\2143\201~\216YH\323\\\260\2608=\346\334\227\027\304\2573\206\306y\2200\006%\232D\370\"#%\243GW$\357\031\310\025Y;P3\251m7\317\257!/p\315\301\337P\203rg]\225v#\001\271V\004\367E\013\240\005\3069\305\204\270\206\016w\026\371:J\013\"\347%\233\023\220\346\246\351\242\271\2522L\215\204k#\177s\263\032\355A\361D\371\020G$Pk+\\\311\243\024\3528\035\230\2175)\200j\"3\023\030\205\016\3402\013\360UB4%\236\004\220#v{\315\027\202Dj\214\217\343%\035E\334]\200\254\252\205\314\334zk\317\227gJ\244\313\235\323m(\360\310\316\244Z\313\320\006D\021s\302\t\242\004\304,*\010\"\243\276(j6\202x\000\250\322\030\322\362\004\222h\311g\026\251R\320^\345\243\021&\201\256\211\201\213\220\240 \204WfyL\335\307\2716\261\013\320_1\203`\332\273\267\nL4\265\312\354;UAE\324\353\366\366\355\354k&\354\335i&\364\2518Z6\230\321\230J\004\361\212\343\025\243\330\0173\007\010\333\014\335r\257\035\331Z\200\342q\314K\306\256(^n[\200\327:\224^\306\240/!\002\350\226K\207\260U\323y\355\262\307M\"c\304\243$GU\202&\306\330\245\321\241\223\0059\252\371)'\306&\310\341U\230\314\364\234\220_gEC\0058\023q\246\231n\204\264h\347$u\254\352\232\331\224\021\220\312\373\326\341a9\033\267\3539\0252)\255\320+)o\t\n&\341:dR\266\371\300U\222\332\345+\335,\237\033\252Rbp_\003\311m.\231:\341%P\363\354\233Ib6\025 \263@Z\212\261\026\003\004)\262C\023i\270 \263GN\014\211L""\226%]B\355\225\274+KpIm\005\322\320y\313|w\314\347\031cq\320\202rI\003\226\030\231\207\036\215f\323=:9\331\"\251\016\305\260XX\324Af\331\315\344\333\225.\255o3C\353\214\355\033Y\267\242\311\023\210\177\027F/\314Q\025\325\302B\263\025\002\323\225\267\t\013{2l\0071-3\256\242T\325Y\023\0005\307.\312\0133SB\274i&\320\3063\020\305\231\347\345#\264y]\211\234\310\366\221\251\030\244\262\334s\25193\311\2519\363\352Ge\240\226\346\253\350D\212\345\003L\342\021\246N\314i2\310\002U\230\253{\2335x{Akf(\0171\241\261&\r\"\036\271\251s\016k\225\251\322j\205\250KY\027j#\232\232\323H\222\247o\277L\016\366\035\354\2341X\340\327\337\314\027\266\211\005\345\347t\314\322a\345'\310-\200\300\201S\243\000\304\030\332\033\021\320r\302\362\336\366\020\003\021&\274E\032\001p\200\022\010;q2L*\366@QE1\222\244\212\345Z\350z(\033\344\005CP\200+g\243\376\312\036\343/\217\264d\252m\260\377i-U\037\272\320V\330\306\355nK\267\311\363O8\022#\025\177\207\363?`~\244\235\346\240\3125\203D\226,7\234\315\017\252$1\017\362\001\347\371\304\362\306\036$`\210\203\330\204\336\n\n\002\375\271Gy\016}Q\252\002\263E\220\202\224Q\300rP#\375\265EE\024\307\373\275\243\265\374\177\327\245\243\354\214\031\014\214Q\210lR\\\026\263\372\245\177\261\201D\362JwO\321.~\234\271\361lg\213\273\275\226\231\363>\247}\247|\345<\364\361\306\021\221\275\373\254\224\276W\260\367!\360\367\240c\0060G\013\344\026\205,\006n&p\332\336\363c\302\257\207\340\027\010\231\237\033l\255\237\227\305\336M\310\016\202\210\"r\334_\371q\310\267.\003\2070\033\243|\277\037\313h\336z_S(\203\330m.o\220;m\307u\225\255\243`\272z#\333\202\215\357k\266-\372\277\306\325\307\037s\021\235-\340\213\342\376\3079qx7\010\320^\034]z\tG\236\352m\273\260^4\343\313\007\267\336l\215\247\336\334u\347\305x\031\277\272\372\373\3757~\210@\203\332\232I\275\323\"\205\233<}\335\357\317w\203\274\223\356D\361\032\344ri\222\315\201\206\036\317a\343\275\336\251^\023\014\374\016\365\271x7\307F\332\246,\003b\033\003}\244\r\350\307~+\367a\373\227\274\242\237\327w`\204X\r\365\276[\357t""\357\030\210C\215\343\236;\362h\231\354\233\t\207\351\265\213\373E\026\026\343b>\235\251\236\335\377\004\014F%\213d\353\261\205\335\374#\016\336\301\373p`\357{|\274\356\263~\177\327|\201\212/'\223\215\273\375\277\303\243{\003O\212\276\3373\247\227p\277\221\377\033\215\272\355\367\3644-\340[n\357n\335s\371\t\314\026.\224\352#0C\264~nu\216\224!p\036\332h\267\345f\276\020\t\\y3\313$\007\216\017\354\tW\035\0138\370q;\271\233\363\362Hb\344\315\345\247c \340\\\233\323\276\300\320\017\351\346\264K\177\210\342\216k6\233\275\317\354T\257\346\335f^\301SXyU/)9[=q\230@\314G\244\364\225\252\365K\242\031\264\255\315\375m\301\364\360x\370\017\037\212\307\350\356W\3077\376\203\331\313\206YV\263\264\312V\324\r6tVu\010\r\342\224>Q-\267\251\2772\26370\304\314X\315cY%|\2749\2745\303F\201!o4.\354\021\002\301\020,\267,\263e\234:>X\252\030\026CAw|\265y)\2709\304\201O\271&I\251b`]X\212\006\212\272;\321\3438c{V\270\301b\370a\204l/:\013\343'9\260E\032\312\023\t\206.\025\026\021Cp\0065\">&\256M\363\243\010\234I\322*\365\032G\277\214M\256\312\275\331iL\315\250\033 \325\205\235P8\244\376\202\030\324\205\304\351q\2301\245=5\"d*\305j\024\357\256\030F\216\262r\330\305T\335\033=\307\231\320\013g\003Po@\020\260\247m\205\014c\263\304\304F\231\2469\004^\310\rD\230\3666\026|\375\023\377\305\334\221N\024$*\3671a\200";
    PyObject *data = __Pyx_DecompressString(cstring, 5454, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (5499 bytes) */
const char* const cstring = "x\332\355ZKw\023\327\226\266V 1\306\016v\020\301\001'\224yY~\tlL\000\007s\227\260\005\230\340\267\010\201\204U\267,\225\354\002\271J\256*\3318\235\254\233\241\207\032\326\260\2065\324\320C\0173\254\241\206\376\t\374\204\376\3669\365\226\014t\367]\335\267{\265A\245\363>\373\371\355}Ni&{\263\334\225\323eI\320\312\302sC\236\356\312\275S\214\214*m\3113\017\265\232Z\022fW\327D|\262\025\3050E\251fnj\272b\356\t\231\212\242\312\302\344\335\211\233\303\254\333\324Z;\357|?\025t\312Uc#h\237\234\030\236\325\266\252\376\372\263\232Z\224LY\305\247$,Ue]2\025M\235\3254\275\244Pc\320$\024%U\320\324\312\236\260.\013\212\252\230\212TQ~\303\244\212\362V\026\332L\310\226umK\034\311\014\017e\303\336\265=\303\224\267\004\305\020T\315\014\227\221\326+r\366~8,\244dZ\230\223\314\332\226\220W\ry\013\243x\355\203\264\014\2611\221\355\347d]\331A\257\377\275\254ko\344\"1\014\001\314\355A\340JQx,k%\331DaU.\313\272\254\026e\341\221\016U\370\375?\311:z\245J\262?_\251(UCSJ\037!*\030\027!,\257n@)\240J\335 R\242U\306\003h*\312\252\251c{t\007\024F\313\tj\320\276\241K\325M\364L\316y\003\375\206[\311\006\252\351J)c\300tL\221\331\335\374\342\\~\261\220+\314/-\212/\346\347\nOf\346\325j\315\364\025&\321\234ia^\335\001o\245\340\373\351\332\322\242_\016-Q\323\205\"\250\0242~W1\324\257\026\230\025m\033\256\330v\210a\222H\332\0162\270=%G\224\230\225\304\227\346m\311\221r\240\276\370\350\260=9\243\252+[\262\260\0055\225\024)I\177\242\263u.\263<f\327]\0132$U\232\026\036t-\2625\0265U^\324\300\224\271)\231\302\354\036zU\022|I\256(\353$\013\031\266E+\302tu\032\244\n\313\371\345\361\251\273S\202\004g\326eZ\332\020\214\332z\261\"\031\206l\020\256\254\327\224\212\251\250\202\271W\225\215\2540_\026\366\264\232\000++\t\246&T1.:\301\334\224A\264lRA\030\222T\350\234\251@\304t02$\224\024\235\350\337\221i\366#\251b\310\331%\214\325\311.\274B\033'^\226`\233\034\330XQf&\315L|\231\004\266\340\313\353\303.\024\033\033q\243\230?w\t\336\337\252l\326t\225q\222_^{\314mq]6LaK2\213\233\344d\324\027\235\002\213%%\010JYP\310\330\331@""\337\366\313\004\231\331\256`p\376\235\264U\255\000\265\203\226\007\017\036\010D\225P\335#E\013\n`V7c;\320\220b\321\020f\2505s\231\010\233\236\2725y\367\362pr\210\017\334\231\260\207\006\206\273A\225\036\375D\341:Q7\306\224KB\224L\270E\325$-m@\235haA\200\311\200H\014V\241%\014\255\246\027\331J\377%fFi\334\314\006\307,a\224\371\333\314\213\307k\260\317QS\333\3350\356N\315\334\034\303\277Ob\326\357\341\304\211E\275\255D\356\335\271\333J\016\243\207\333\007\033O\243\3029\314jC>=\203\224u#h\032\017\376\202\246-E\025\213\232ZVJ\204\265\3230Ns\014\216Y\226j\025s\346\316\315`\034\375\345\0048{\215l\315\334\225\341O7\307'n\336\024v\341\034\262@%\205\371\231\260\245\301\024\3755\315ll\211i].O\377=\276\351\337\273\272\022\266\335BqP\007y\302\357\314\226\247c\353\0266\223.\020\272F\314+\302m\205\212\274#WB\362\326\020\003e\340@\331\213;\005\231\014\003q\0212\017\312\314\265\237\253oUmW\245\216 xF\313\211\320\365\363\270\204\364G\320=\310\361\252\246.\251F\205\265\274\214\017x\331:\000\306\277\253T*\014.\000\"\025\315\220=\273\225 \220\020|!\237\262\246o\361\350\262K\230\007~w\210.b_\203\347/\257.=\365\320\233{\201\004\010 x\343\363\262\302\232\014+\3304\315\2521}\343\006\255\234\325\364\215\033ei;\273inU\256\354\002\302\307\025c\034s\306I\340\343|\036}\215\227d\243\250+\353Xz<\214d\343\272/\215q\036\323\214Wqv_\265\260\233\375\333/\257\247\005!3<&L\217\t\322\372\272.\357\314H\245\222\010R\3451\026\210yPGyGR*\224d\241L\312\236\211\304\3201\017\324\305\022\224U\321\244\322\214\337\202=fJ\212A\363\220 \3429&\224k\225\n_t\243\010)r\352\000\274U\rF\261\001dF#\362\0058\210\301\247\224\004B{Y\325|o\021DQ\227K5\270\264(\224j,\216\250\232:\016Q\357\000\355\321[$\340\027\3051J\000T\261\242\000M\014\242\273*\025\337J\0332\337\235\203\322\r\006\013\325\275w\367\271\2528V<\030\027\200\205r\031\271\024\020\261F\2531Y0\306\243\r\236pX\003%\301\033\232\276\027\324#\203\375qz\005O\346\3333\201;d\263\002\014\307\200\250 y\2714=-Lf'\2637\273\332\205\24105\242\025Y\320\376_\030\224\002.\"8\234""\031\242ICc\302\020\315\033\032\376\304(\345\205\246P.\377\242\241\251\035\313\355\343\323G\204\203@44\374\301\200\305\027\300\374\343&\375\247\302W`\356\323\004j\344Z\344\334R\245%80\303\324\312\ts\205\217\226\221F\002\376\326\367\262\377b1\361SC\242Y\203_d\030\367x\014\373n\365\261\370\230\271\037\310\356\301\230p\237\374\365\3010E\201\217\204\311\256V`\270\305\201\201\\!\027\210v\201y\363|\030\217\272\272\"*\215\2502\256B\266O.\206'\331.\".\354]Z\247h\307\020\206\272bzb\003fC\342\331\211\303\334\204\026\210:\306\274\314E\0317\004\037\262\"\210s,\237\037\005@#X\316h\017\201\377\215\270\026\277a\2118\357/\201\220\231\246HQ\2310x\370N\312\242\005a\337\367\254\342\313u\006\246=\374\372\377\022\030\036/\247\327\037B\306\177\216x\t\010c\342\275C\322\375\1774\375\037@SRh\033\335\275\216\303\3513\214\"\376C\336=h\t\000\224yy\300\226.KK\345\347\206\334\2720\335\214\322'\033d\217Ev?\"\212^\253!\233\006\245\242A\373C\311\220\351\323:\303km;#+*\206(o\327\024\010\0302\013\233\336I\310\220\r\350\2235\265\266 \366\277145Z\026KJ\321\364\033v\337\232\263K\213\263\271B~\021\2379qi9\277\312\256\331\320\372S~u\215.\334\350:vu-\257\353\232Ne\030\243i\004\205V>\242]-\314\204\235\314\021j\206\254\213,5\367\357\224\333.w\334JY\222\t\\\205\227\301=\234Z\004\214Tqf\332c\215\221~\000\031\216 `_\256\342\024A\307\2036\227\330\376\335\364d\311/\335*\265\\fG/\260\3752\201\327\324,;\256\031\355o\252\3334\025\366\252r\273+\352\026!\264\037\324\"\223\266\303\230\240\371A\344\330\353\360\200\265cG\020\257\307v\222Y}\260\223\331\334\261#\010\217\216\355<\236\362P\352\361k\374d\375C\342\014F|@\226\336\2306\234&{\022lF\273\223lx}\340\241X\236\255\031\246\266\025\334\304\317\315\345\n\317\027\304\374\342Z~\341\341\263\374\334\313\305\334\302\374\254\3708\2774\227/\240\260\232\177\224_\315/\316\346\305G\253\271\205\240\037\356\212\336\334\263\226~\n\244\354A\346\306_B\264H\304on\021\203\327\021\267\222h#)/Z\347\214F\336u$f\005\326\024\251\222\354\022U&\312H[\270Md\027\212\236\201\330\3027\031-\334E""\273Z8\214t\006;%\333\274\355\342\357J\002\306\022\355\304\\\242\2118j\323\304\230L\264\307\267\217\354\316r\202\343\214\200^\230\320\247\225w\257\265\205\355'\213\322\342bm\253\272\227W)\217\321\227\nO\362\253\342\354\322\322\352\334<\305\2020\024,\351\350\226Ks\240\225\356\237\350#N\261\347m\226\230\260G\353\306~s\313\316\261\373\362\370\345y\353\"\211\356\017/\026\323V\233k\371@cm\372Hkm\232IM\30743\355\265\351#\r\266i\366\251\322\336\374\304c\004\210\337{\207\017\tV\\\224\337\231\253r\271\260\232[\\{\264\264\272\300$_\240[\265\340\010V\320k\262wyy\234\257\277\370\2610!\346\327V\347Y\341\361\\\356\031\n\223\342\344\315\211\333AA\\\233_X~6\377h>?\347\267\335\r\nm:\357\005\205h\347[\323\343\342\347\227\257$~\311\2470*%dK\242V\246\320.\031{jQ\321\262EM\327j\246\242\312Fp\341\305\nt\335\031$\255\201n\3020K\241\231n\027\351\303\007S\201Z\327\327\303\253\262u\357I\261\300\023r\2215\025E\354\032\311#\331\314\"\222\017\331\200R\374\233\265bY\244e\361U%\2035D\221\275u\022\221.(@h\252\202rl/\232\272T\224\327\245\342\333b\305 \036\212Z\245\302\257#\215p\023\224L\250\262\030d\002b\031\t\231\246\263\213M1xy(V\337\210\341]gX\212\214 \353j\333\301l\017\214\266\355d\214\267\353\250\276i\333\354\t\254]\027\275\233\213t\360\373\337\226\206$\235^k\033\"\275\236\030!^\233G\005L\007\302@\0167Y\242\347-\366\224u\035gAh\203N@\374\"\237\235\r\331\306\274\344o\306k$\002^\252\276\341\337|y^&\256J\362\206.\313\206\367%\362\233ovZ\022\331\252\364\364n\232Q\324\212x\000)\311\240M\372`\255\340=,\033\037\326|J\302\026\242&\254q\033\213\324\337\204eNeP\227*^v\353=u\275\254\350\310UeJ\304\343p\226\010\317\001\236\005P\025\307\254\000\245\302\200\027A\250(\206&\222tQ,\327TH\003\276A\331\264g\353\342\226\244J\033\262NM\344+\222.\322\375t\233|\233&r\370\026\351R^\334\224\225\215Md\337\353\332\216,\006o\032\304@\004\312\206\252\3512\363OQ\243(\244\340O\345\236N\334(*\235 \231\265F\212\342\256R27\025\346\200`\261B/\035\321\277\201E\330\335\006\235\023\274\237\232\2603\203\217N\311\003\204B\226\301~""\232\021?}\305\017^\311\312F\360\343\010^\361~\325\240\260u\337x_\354\265\260\022\333j\307{\377\204\"\016e\004=\006\261H\357T\314\032\275k\217\035S\350\205H(\007\252\031\025\r\272#]R\201\317\321v\2419\250\0072\023\343gj\324\265R\255B\3378\310+\2446f\020b\370,\261\253I\225\336\266G\225\010\215\230\233*9\027\355\256\261\333<\203_5\030\334\255+\354\225\024ao\200\321m\200\030MdQL\267:(\251\006o\340\271\217\304\0002\201J\350\013\235\031\025\030L\325\250j\325\252f(\364+\000\320\212E\344\022\276M\014\241X,\372?~`\036\220h\362\2756\321L\224'\232\252o\022\r\334OH\026\2016\"m\214\323H`\n\337\3651\361Az\301i\225o\346U\330\317\"\370\315Y\326w\263\240\252\373=\222\246x%\272\314b\022\211\324e(\311\037\031+\277+\312\\]^\003\214\264\344\025\341\0078-\213U\344%E\251\252\340\224\315\312\236\317Rq\307\244\327g\324A\250\304\255E\227\303\227g\255\347w\277A~\207b\331{3'\322\2339\340`\331\220\267\024X\350\033Mg\246\300\253\212\352UY\302\347\331$J\336\275S$\r\024\333\244\204\341\005\037J\346\246Q\2055\222ga\224Z\222t\016\3114E)n\261\337\272\030\265u6\232\177\211\004%\357\374\n)\320\017;E@FPA\306b\324\210s\244\023\240\210\335\031\260\353\202\350M\001;\336\261G\366~E#\032\036d\0230\351\335#x\2273\321;\032\377|\313\257i\202w\2074\211>F\215\347\202\265*l\006\030\315\035R\242\033<\270\014\274\200c,c\226Ax\340\215!\240\263\373:\3660\274t\305\207\241]IW\351C\257/w\301\341\302\363g\205\371g\363\213\371\231\305\245\260\3742\277\266\364\274\260\374\274 \346~\236_\233\311=/,E\353\213\261\032\006/?\305\tc\261\220\377\271 \214dv\200\360\303\035\364\0242\364\313\000\317\326\336*U\260oT\351\216m\270\203\033f\020jx\212\320\201\244\214\344\307\272X<\\\336\363\336+\214d\242{\214\t\313O\205\221\341\216\216\017\366\343\031t\217\321\r\347\360\177p<{wS+\372,\000\rEI\3370\304\357=\352\247\230)\211\\\221\302H0\212]\317\262\241\303\035\242\027Q\203\237=\206\230gtp\266\305Hn\335!\372\346\321\341\255\033%9N^{\311F\306\0277%\372Q\234j\230$\254\"\345/\354P\310\212\224\350\226d\367D\3069\355\336z\362W\352\375\365\216S""\275\373{V\312J[\257l\323\035\235qg\026\376Z\3713\365\376\273\216\223\335\373S\373;\365\225\372\226=e\233\316-GrO\\v/\337;\350{\177\265\343\324\271z\256\331yz\177\242\331\335o\245\232\235\003\326S[r\207~8\2308\370\361p\273\331yf\177\273~\262\276\322Z8\352\034s\307\356\037\344\232\335\275\365\224\367\3509B\357oV\2375\370g\356\375d\307\251o\334\376\021g\320\231hv^q\257\334=\360\227\307@\377\3779Z\350\364\376\275\372l}\273\331\375U=c\r\272\027'\032}\215\301f\3477V_\2633]\177lMX\363\366\312\237\271\346\343'\340\346T\257{\346\262}\243\321\327\354N\327\037\321N\315\371\247\357ov\234\".\261\306\327\365\2225no; \347\314\376n]j\366~gm\330+\366\206\363\372`\360\310\253(\316v\263\247\257\2165.XCv\237}\325\336jL\034\241r\025\335k\230K\\\202\007!\272\335E\020\222\373\223K\353\250\373\254{\026t6{\323\220\037\177\200\227fo_\363KZ\027\363\315\372\337\354A{\"X\345\222\365;$\001A}^\227\334\3637\034\263A}\237w\234\357o\236M\223\264\272\367\177\250\027\255>\"c\220\306}iI\264^\372\242u\333\356r\006\233\375W\354\211f\377e\233\227\216z\317\327\177GC\232\276nA\250\375\327I\262_\325\007\217:\317\325_26%\242\243V\377\321\202\\\316\327\231p$V\3723GR\237b\272\002\377\315\356\263\365\211\026\232\273\250\371\266\333\237qR\316\305\306\243\203\301\346\231\336d\023F\216\371#\255\036\177\313\337\255\t\322.(\254\221\276\355mp\330\354\305\346|\370U\317\030\004\306Vh\014=D\324\214\365\031\315\366L\341vc\245!y\246\320o}am\333\247\234>\254r5\\\005.\320`\333\021w\365m\254\341\236\026\354\317\354\333\316g\356(\354\330[\275\253g\177\205\3318\226\342\253\223p\317\246\217\370\342\227\254]\020\272\327Ha\361L\224\304\323N|qF\340m\254?\323H5\276;0\016\007\223\253\216;+G\255\024\013\376\242G\235\003\356\000\370\nW\345_\2065hM\004\242\200a\300 \342~q\357`\340p\345Pj\365\214\2508\004W\200g\177\312\342qI\307\027\217R>\022.>`\375\010eF\304q\212\\x\315:i\2554{`\266\326\264\375\302\311\035\305\004\342^\234j\344\332\320L\226\037\265\206k\366+g;a\r\356\351o\2555;\025\210\366f#\345\211v\300zlO\330\363N\202\373k\356\265""\007\007\322'p\037_9\311~t\365L\224\304_\032\251\004\373\337YE\373\034y\036&\272\027\306\2355\220\2300\210\311\306`\033\252/\207\353^\267\3376\372\022\353^\262\014\373\032\t\233\255\233u\030\026\370\377\301B\3177\307\231\362e{\310\351s\206\031\274tvdoD\345s\335\275\376\267\203\355O\222\0171\326w\214|\242[\370zd p\217\031H\357% N/\354\341\210\020\203BB\277\335\3570\302;\331\300K\326;\032v\031\300\213`s\247\261\315\006z[}\337` \362\017\300_w\237\3337\010|\206\217\301i\306\234\234\263\342\225\346\340}\240\356\222{\211!i\003\300\374>\033\020\261\000\352\006\343H\264G`\003_\016\221\210A\357\350\303\303A\002\337\214;\2040\332\354\276b\337\241aGA\304\032u\246=_\215F,\367\364\025\006\272\037\021?!\377\376\037DN\000\374\214\364\260k\311\231p\2360\352#\rK\210\276,\322\234q\317\214\023\313\275\365.\204\2467\316I\347\225{\347\361\241\361\327\340\261\275?\376u\353/)\"\214\031\273\307Yq\022\260\374\207\375\324\221\234(,g\t\021\246\221$TH\330\347a\022c\014\270{\020-\254n;\307\333n0\271zmy'\355\274h\344\032\317\017\274\031#v\316^9b\026\365\207\375\310aA\354\263\372D\375\031\320\222E\276/0\017Pq\344\255\365\025\324\321\203\320Y\377\225\014\315_\341\225\363\016\366\300\005\013<Y\261\213\3560\245#\271xP\276d\375\003\\\371A\371\375\327\035\247. vvR\020\354\274j#\276\245\335\364(\017\270<=!\354\236\006V\245\230\325\300'\021\361;Y\316s\212\323V\263r\2001&\235\234]p.4~8\010\262\207\022\214\342\016\222\2224MH\237k\016\320>\027\007\216z\007\374I\3330m\337'\277\265V\310x\361u\344\321|\235k\303={\2352\215F.\246\016\367\374\2103\002A\256D\364\341g\036\343\204\211\236\351L6\2566\250/M\226b\326\277G\360\276jm\332\376pD\372\005\226\313\224\341'\277\036\244\017\010e\006x\307\022`\347\211\223\013GR\303\222\3477\002\317\035{\030\237\327\033)w\"w\230>\\\t{\316 \237\352\014\255\2267\234il\037\244\334\023\303\3560\271\320\263\024\343\260\337:A\026L\316?j\213\340\263\347\313}\211\373\3443\347\024<\226\247\020\023\356\211Qwt\3560\367~\021\363\206Hg#\344\260\327`?\244\275f\347y\036l\247\353/\254\034ei""\314\266<\221~\007\341\222\322\372\211\344h\006\346\241c\0359\024\201\316YL\355\205\037\003P\032\220\"\334\345\032\222\273\223N\301\235xxx\371\020\235\244\305\3640\214\372\032@\344\316\301\265\203\355\303\024ak/\037\232j\366^c9\r\355K\260\010\375\322\327\005\362\363\270\3250\325Jv\315y\010\253\204\201$\315\010J\036\202\320>'\034G\210\246\274\246\014\223\356=[\177`\237e\256\364\274q\005\026\220f\360\321\244\274\2719\360-\373\177\303\331n\244`]}\337~\330\326\230\177@!N\337\373G)J\354\347\230|x\322\007?\361\345\231\267\323\366K\270\277\336\370\272a\034\\9X!\215\334\202\323\356\331)\273\217{Y\252y\242k\177\264\276\342\236 \316\221uco\232\177\233|\230@\360\025\322\203\224\207\206\000dJ\205\031\016e\010\322=$<\275\177\227\326\365\262K\226*\024\274\204\323\327\027Kg\021?\202x\306y\240M3\037\335\024>\374\317\334\364\222\365o\316 \005\313>v\320A \354j{\250\"\362^\271C\323\356\364\252\273\272\366\376.\r\302A\243n\002\255\240o\367\326\254;\373\253\373\353k\367\004\2426\311\256\273m\246}\027\310\365\330\275\002KpO\300t\370Y\214T\266\312N/\235Dl\347\251\367\335|\376\016G\256\336z'\276`5S\200\322/\254\035\030\351gp\2674\\\342\210\036\315\336o\254\363\220Q\232d\201\206\022\245\363dT\331\306\027\215\035\250:}\201\203\370\021\216?_S\340O\254y\306\336A\ns\242\221G\016\231\376\326z\001_d\007\213~\026\253\021\020\372\375E\373\007aG\344\034\375\3349\316\365\263\203\010G\312\353\010\235\374\250\202T\340((\321ie\233f\236\007\207\003#N\006\032\004\224\026a\361\0034f\000\301\036K}s\331\037\020\355\036\001\254\025\330\321\220\206\2652\340qN\353\204\234{\354\022/\005\226H\220d\310\207{\367\267\367S^8\324\031\222J\354\010\300\203\342yh\223\002\013\374\340$W\027\241\355`\363tw\263\363\313\375MJ\235\370\331Z\260~c\353\237@J@@r\275q\206\316\004\377\016\276\261\245@";
    PyObject *data = __Pyx_DecompressString(cstring, 5499, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (14768 bytes) */
const char* const bytes = "=.0f\nArea of Use:\nAxis(name=Bound CRS_CRS.list_authority (line 2810)_CRS.to_authority (line 2764)_CRS.to_epsg (line 2721)Compound CRSConcatenated OperationCoordinateOperation can only be initialized like CoordinateOperation.from_*()'.CoordinateSystem is not initializable.<Coordinate Operation: Datum EnsembleDatum can only be initialized like 'Datum.from_*()'.Derived Derived Projected CRSDynamic Geodetic Reference FrameDynamic Vertical Reference FrameEllipsoid can only be initialized like 'Ellipsoid.from_*()'.Engineering CRSEngineering DatumGeocentric CRSGeodetic CRSGeodetic Reference FrameGeographic 2D CRSGeographic 3D CRSGeographic CRSGrid(short_name=INDENTATION_WIDTH=Input is not a CRS: Invalid Invalid JSONInvalid authority or code (Invalid coordinate operation name: Invalid coordinate operation string: Invalid coordinate system string: Invalid datum name: Invalid datum string: Invalid ellipsoid name: Invalid ellipsoid string: Invalid prime meridian name: Invalid prime meridian string: Invalid projection: \nMethod: >\nName: NoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.Other CRSOther Coordinate OperationParam(name=Parametric DatumPrimeMeridian can only be initialized like 'PrimeMeridian.from_*()'.Projected CRS\n        Return the EPSG code best matching the CRS\n        or None if it a match is not found.\n\n        Example:\n\n        >>> from pyproj import CRS\n        >>> ccs = CRS(\"EPSG:4328\")\n        >>> ccs.to_epsg()\n        4328\n\n        If the CRS is bound, you can attempt to get an epsg code from\n        the source CRS:\n\n        >>> from pyproj import CRS\n        >>> ccs = CRS(\"+proj=geocent +datum=WGS84 +towgs84=0,0,0\")\n        >>> ccs.to_epsg()\n        >>> ccs.source_crs.to_epsg()\n        4978\n        >>> ccs == CRS.from_epsg(4978)\n        False\n\n        Parameters\n        ----------\n        min_""confidence: int, default=70\n            A value between 0-100 where 100 is the most confident.\n            :ref:`min_confidence`\n\n\n        Returns\n        -------\n        int | None:\n            The best matching EPSG code matching the confidence level.\n        Scale differenceTemporal CRSTemporal DatumUnknown CRSVertical CRSVertical Reference FrameX-axis rotationX-axis translationY-axis rotationY-axis translationYou will likely lose important projection information when converting to a PROJ string from another format. See: https://proj.org/faq.html#what-is-the-best-format-for-describing-coordinate-reference-systemsZ-axis rotationZ-axis translation.?[]:  (), :, abbrev=add_note, auth_name=, available=, code= coordinate, direct_download=, direction=disableenable, full_name=gc in rotated pole grid input: isenabled metreno default __reduce__ due to non-trivial __cinit__, open_license=, package_name=pyproj/_crs.pyx<stringsource>- undefined, unit_auth_code=, unit_auth_name=, unit_category=, unit_code=, unit_name=, url=, value=\n        .. versionadded:: 2.2.0\n\n        Return the authority name and code best matching the CRS\n        or None if it a match is not found.\n\n        Example:\n\n        >>> from pyproj import CRS\n        >>> ccs = CRS(\"EPSG:4328\")\n        >>> ccs.to_authority()\n        ('EPSG', '4328')\n\n        If the CRS is bound, you can get an authority from\n        the source CRS:\n\n        >>> from pyproj import CRS\n        >>> ccs = CRS(\"+proj=geocent +datum=WGS84 +towgs84=0,0,0\")\n        >>> ccs.to_authority()\n        >>> ccs.source_crs.to_authority()\n        ('EPSG', '4978')\n        >>> ccs == CRS.from_authorty('EPSG', '4978')\n        False\n\n        Parameters\n        ----------\n        auth_name: str, optional\n            The name of the authority to filter by.\n        min_confidence: int, default=70\n            A value between 0-100 where 100 is the most confident.\n            :ref:`min_confidence`\n\n        Retur""ns\n        -------\n        tuple(str, str) or None:\n            The best matching (<auth_name>, <code>) for the confidence level.\n        \n.. versionadded:: 3.2.0\n\nCRS Authority Match Information\n\nParameters\n----------\nauth_name: str\n    Authority name.\ncode: str\n    Object code.\nconfidence: int\n    Confidence that this CRS matches\n    the authority and code.\n\n        .. versionadded:: 3.2.0\n\n        Return the authority names and codes best matching the CRS.\n\n        Example:\n\n        >>> from pyproj import CRS\n        >>> ccs = CRS(\"EPSG:4328\")\n        >>> ccs.list_authority()\n        [AuthorityMatchInfo(auth_name='EPSG', code='4326', confidence=100)]\n\n        If the CRS is bound, you can get an authority from\n        the source CRS:\n\n        >>> from pyproj import CRS\n        >>> ccs = CRS(\"+proj=geocent +datum=WGS84 +towgs84=0,0,0\")\n        >>> ccs.list_authority()\n        []\n        >>> ccs.source_crs.list_authority()\n        [AuthorityMatchInfo(auth_name='EPSG', code='4978', confidence=70)]\n        >>> ccs == CRS.from_authorty('EPSG', '4978')\n        False\n\n        Parameters\n        ----------\n        auth_name: str, optional\n            The name of the authority to filter by.\n        min_confidence: int, default=70\n            A value between 0-100 where 100 is the most confident.\n            :ref:`min_confidence`\n\n        Returns\n        -------\n        list[AuthorityMatchInfo]:\n            List of authority matches for the CRS.\n        AreaOfUseAuthorityMatchInfoAxisAxis.__reduce_cython__Axis.__setstate_cython__BaseBase.__reduce_cython__Base.__setstate_cython__Base._is_equivalentBase._is_exact_sameBase.is_exact_sameBase.to_jsonBase.to_json_dictBase.to_wktCONCATENATED_OPERATIONCONVERSION_CRSCRSError_CRSParts_CRSParts.__reduce_cython___CRSParts.__setstate_cython___CRSParts.from_user_inputCRS_CRS.__reduce_cython___CRS.__setstate_cython___CRS._equals_CRS._is_crs_property_CRS.equals_CRS.get_non_deprecate""d_CRS.list_authority_CRS.to_2d_CRS.to_3d_CRS.to_authority_CRS.to_epsg_CRS.to_proj4ConversionCoordinateOperationCoordinateOperationTypeCoordinateOperation.__reduce_cython__CoordinateOperation.__setstate_cython__CoordinateOperation._from_stringCoordinateOperation.from_authorityCoordinateOperation.from_epsgCoordinateOperation.from_jsonCoordinateOperation.from_json_dictCoordinateOperation.from_nameCoordinateOperation.from_stringCoordinateOperation.to_proj4CoordinateSystemCoordinateSystem.__reduce_cython__CoordinateSystem.__setstate_cython__CoordinateSystem.from_jsonCoordinateSystem.from_json_dictCoordinateSystem.from_stringCoordinateSystem.to_cfCustomEllipsoidDDATUM_ENSEMBLEDYNAMIC_GEODETIC_REFERENCE_FRAMEDYNAMIC_VERTICAL_REFERENCE_FRAMEDatumDatumTypeDatum.__reduce_cython__Datum.__setstate_cython__Datum._from_authorityDatum._from_nameDatum._from_stringDatum.from_authorityDatum.from_epsgDatum.from_jsonDatum.from_json_dictDatum.from_nameDatum.from_stringEPSGEllipsoidEllipsoid.__reduce_cython__Ellipsoid.__setstate_cython__Ellipsoid._from_nameEllipsoid._from_stringEllipsoid.from_authorityEllipsoid.from_epsgEllipsoid.from_jsonEllipsoid.from_json_dictEllipsoid.from_nameEllipsoid.from_stringFalseGEODETIC_REFERENCE_FRAMEGridGrid.__reduce_cython__Grid.__setstate_cython__HNaNNumpyEncoderOTHER_COORDINATE_OPERATIONOrderedDictPROJPROJ_4PROJ_5ParamParam.__reduce_cython__Param.__setstate_cython__PrimeMeridianPrimeMeridian.__reduce_cython__PrimeMeridian.__setstate_cython__PrimeMeridian._from_stringPrimeMeridian.from_authorityPrimeMeridian.from_epsgPrimeMeridian.from_jsonPrimeMeridian.from_json_dictPrimeMeridian.from_namePrimeMeridian.from_stringProjVersion__Pyx_PyDict_NextRefTRANSFORMATIONTransformationTrueUnknownVERTICAL_REFERENCE_FRAMEWKT1_ESRIWKT1_GDALWKT2_2015WKT2_2015_SIMPLIFIEDWKT2_2018WKT2_2018_SIMPLIFIEDWKT2_2019WKT2_2019_SIMPLIFIEDWktVersionXYZaabbreviationarea_of_useasyncio.coroutinesauth_codeauth_infoauth_nameauthorityauthority_listaxisaxis_infoaxis_listbb_auth_nameb_nameb_p""roj_stringc_namec_out_confidence_listcartesiancategorycf_axiscf_params__class_getitem__cline_in_tracebackclscodecollectionsconfidencecontextconversion_factorcoord_operation_pj_coordinatecoordinate_operation_dictcoordinate_operation_json_strcoordinate_operation_namecoordinate_operation_pjcoordinate_operation_stringcoordinate_operation_typecoordinate_systemcoordinate_system_dictcoordinate_system_json_strcoordinate_system_pjcoordinate_system_stringcreatecrs_2dcrs_3dcrs_errdatetimetemporaldatum_dictdatum_json_strdatum_namedatum_pjdatum_stringdatum_typedegreesdegrees_description__dict__direction__doc__dumpseasteastingellipsoid_dictellipsoid_json_strellipsoid_nameellipsoid_paramsellipsoid_pjellipsoid_stringellipsoidal_equalsequalserrfirst_errorfrom_authority_from_authorityfrom_epsgfrom_jsonfrom_json_dictfrom_name_from_namefrom_string_from_stringfrom_user_input__func__getget_context_managerget_linear_unitget_non_deprecated__getstate__grid_height_above_reference_ellipsoidignore_axis_orderiiiin_proj_jsonindentationindentation_widthinverse_flatteningis_boundis_compound_is_coroutine_is_crs_propertyis_derived_is_equivalent_is_exact_sameis_exact_sameis_geocentricis_geographicis_projis_projectedis_propertyis_verticalis_wktitemsjsonlatitudelist_authority_load_proj_jsonloadslong_namelongitudelower__main__min_confidence__module__multilinename__name__namedtuplenannon_deprecatednorthnum_proj_objectsoptionsordinalotherout_auth_nameout_confidence_listoutput_axis_ruleparametricparamspj_coordinate_operation_typepj_datum_typepj_ellpspoppositivepreparedprettyprime_meridian_dictprime_meridian_json_strprime_meridian_nameprime_meridian_pjprime_meridian_stringprojproj_json_stringproj_listproj_stringprojection_projobjproperty_nameproperty_typespyproj._contextpyproj._crspyproj.aoipyproj.crs.datumpyproj.crs.enumspyproj.enumspyproj.exceptionspyproj.geodpyproj.utils__pyx_capi____pyx_state__pyx_vtable____qualname__re__reduce____reduce_cython____reduce_ex__rfrotated_poleselfsemi_major_axissemi_minor_a""xis__set_name__setdefault__setstate____setstate_cython__source_crssouthsphericalstandard_namestaticmethodsub_crssub_crs_indexsub_crs_listtemporalcounttemporalmeasure__test__to_2dto_3dto_authorityto_cfto_cf.<locals>.get_linear_unitto_epsgto_jsonto_json_dictto_proj4to_wktundefinedunitunitsunknownupperuse_proj_alternative_grid_namesuser_auth_nameuser_inputvaluevaluesversionverticalwarnwarningswestMULTILINE=NOMULTILINE=YESOUTPUT_AXIS=AUTOOUTPUT_AXIS=NOOUTPUT_AXIS=YESPJ_CONTEXT *(void)\000void (int __pyx_skip_dispatch)\000pyproj_context_create\000_clear_proj_errorPyObject *(PJ_CONTEXT *, PJ *)\000\000PyObject *(PJ_CONTEXT *, PJ *, PyObject *, int)\000PyObject *(PJ_CONTEXT *, PJ *, PyObject *, int, struct __pyx_opt_args_6pyproj_4_crs__to_wkt *__pyx_optional_args)\000_get_concatenated_operations\000create_area_of_use\000_to_proj4\000_to_wktPyObject *(PyObject *, int __pyx_skip_dispatch)\000PyObject *(char const *)\000cstrencode\000cstrdecode\320\004(\250\013\3203H\310\001\360&\000\t\020\210y\230\001\230\024\230Z\240t\320+=\320=M\310Q\200\001\360\036\000\005\014\2104\210v\220Q\220m\2404\240t\2503\250a\320\004\"\320\"9\270\021\360$\000\t\025\220A\330\010\013\2101\330\014\030\230\001\330\010\034\230J\240a\320';\2701\270K\300q\330\010\017\210q\220\005\220Q\330\010\017\210q\220\005\220Q\330\010\017\210q\220\005\220Q\340\010,\320,<\270A\330\014\020\220\001\330\014\020\220\001\330\014\r\340\010\017\210z\230\021\230!\200A\3602\000\t\031\320\030*\250!\2501\330\010#\320#8\270\001\330\010\034\230J\240a\330\014\r\330\014\r\330\014\r\330\014\025\220Q\340\010\013\2109\220C\220q\330\014\022\220(\230!\320\0331\260\021\260!\330\010\031\230\021\330\010\024\220G\2301\230I\240Q\200A\330GH\360\036\000\t\020\320\017\"\240/\260\021\330\014\024\220F\230!\200A\330IJ\3600\000\t\014\2104\210q\330\014\026\220d\230-\240q\250\001\330\014\017\210w\220a\330\020\036\230g\240Q\240g\250]\270!\340\020\036\230g\240Q\240i\250q\330\r\021\220\021\330\014\032\230'\240\021\240$\240m\2601\340\014\032\230$\230g\240S""\250\001\330\010\017\210q\200A\360 \000\t\020\320\017\"\240/\260\021\330\014\033\2301\230A\200A\330\010\013\2101\340\014\023\320\0231\260\021\330\020\024\220A\330\020\024\220A\330\020\025\220Q\330\020\021\330\016\021\220\021\330\010\017\210t\220?\240!\2401\200A\360 \000\t\020\320\017\037\230|\2501\330\014\020\220\006\220a\320\027/\250t\2601\200A\360\006\000\027\030\330\023\024\3602\000\t\014\210;\220c\230\021\340\014\032\230!\330\014\020\220\016\230a\330\020\021\330\024\033\2305\240\n\250!\330\030#\2401\330\030\"\240!\330\030#\2401\340\020\027\220|\2401\330\024\027\220|\2403\240a\330\030&\240a\330\014\022\220!\340\010\025\220Y\230g\240Q\240a\330\010\017\210u\220K\230q\330\014\027\220q\330\014\026\220a\330\014\027\220q\200A\340\010\013\2104\210z\230\021\230'\240\021\330\014\023\2201\330\010\017\210t\220?\240!\2401\200A\360 \000\t\n\330\014\023\2205\320\030(\250\001\250\033\260F\270!\330\017\020\330\014\023\2205\320\030(\250\001\250\033\260F\270!\200A\360,\000\t\n\330\014\023\2205\230\r\240Q\240a\330\010\017\210|\2301\330\014\r\330\020\027\220u\230J\240a\240q\330\023\024\330\020\026\220a\200A\360,\000\t$\320#8\270\001\330\010 \240\n\250!\330\014\r\330\014\r\330\014\r\330\014\r\340\010\013\210=\230\003\2301\330\014\022\220(\230!\320\0335\260Q\260a\330\010\031\230\021\330\010\030\230\007\230q\240\t\250\021\200A\360$\000\t$\320#8\270\001\330\010(\250\013\2601\330\014\r\330\014\026\220a\220q\340\010\013\320\013 \240\003\2405\250\003\320+;\2701\330\014\r\330\014\r\330\n\r\210Q\330\014\030\230\001\230\021\330\014\022\220(\230!\330\020\021\330\023\024\340\010\031\230\021\330\010\037\230w\240a\240y\260\001\200A\360(\000\t$\320#8\270\001\330\010 \240\013\2501\330\014\r\330\014\026\220a\220q\340\010\013\210=\230\003\2305\240\003\240=\260\001\260\036\270s\300!\330\014\030\230\001\230\021\330\014\022\220(\230!\330\020-\250Q\340\010\031\230\021\330\010\030\230\007\230q\240\t\250\021\200A\360 \000\t$\320#8\270\001\340\010\034\320\0345\260Q\330\014\r\330\014\026\220a\220q\330\014""\026\220a\220s\230!\2301\330\014\r\330\014\r\330\014\r\360\006\000\t\014\2109\220C\220q\330\014\022\220(\230!\320\0339\270\034\300Q\300a\330\010\031\230\021\330\010\024\220G\2301\230I\240Q\200A\360$\000\t$\320#8\270\001\330\010 \320 9\270\021\330\014\r\330\014\026\220a\220q\330\014\026\220a\220s\230!\2301\330\014\r\330\014\r\330\014\r\360\006\000\t\014\210=\230\003\2301\330\014\022\220(\230!\320\0339\270\034\300Q\300a\330\010\031\230\021\330\010\030\230\007\230q\240\t\250\021\200A\360*\000\t$\320#8\270\001\330\010\034\230K\240q\330\014\r\330\014\026\220a\220q\340\010\t\330\014\025\220S\230\005\230Q\330\r\032\230!\230:\240W\250A\340\014\030\230\001\230\021\330\014\022\220(\230!\320\0334\260A\330\010\031\230\021\330\010\024\220G\2301\230I\240Q\200A\360\006\000\027\030\360,\000\t$\320#8\270\001\330\010%\240Z\250q\330\014\r\330\014\r\330\014\r\330\014\r\340\010\013\320\013\035\230S\240\001\330\014\022\220(\230!\330\0200\260\001\340\010\031\230\021\330\010\034\230G\2401\240I\250Q\200A\360$\000\t$\320#8\270\001\330\010%\320%>\270a\330\014\r\330\014\026\220a\220q\330\014\026\220a\220s\230!\2301\330\014\r\330\014\r\330\014\r\360\006\000\t\014\320\013\035\230S\240\001\330\014\022\220(\230!\320\0339\270\034\300Q\300a\330\010\031\230\021\330\010\034\230G\2401\240I\250Q\200A\360(\000\t$\320#8\270\001\330\010%\240[\260\001\330\014\r\330\014\026\220a\220q\340\010\t\330\014\036\230c\240\025\240a\330\014\031\230\021\320\032-\250S\260\001\340\014\030\230\001\230\021\330\014\022\220(\230!\330\0202\260!\340\010\031\230\021\330\010\034\230G\2401\240I\250Q\200A\360\"\000\t$\320#8\270\001\330\010&\240k\260\021\330\014\r\330\014\026\220a\220q\340\010\t\330\014\037\230s\240%\240q\330\014\031\230\021\320\032.\250a\330\020\021\330\020\021\330\020\021\330\020\021\360\006\000\r\031\230\001\230\021\330\014\022\220(\230!\330\020\021\330\023\024\340\010\031\230\021\330\010\"\240'\250\021\250)\2601\200A\360\010\000./\360$\000\t$\320#8\270\001\330\010&\320&?\270q\330\014\r\330\014\026\220a\220q""\330\014\026\220a\220s\230!\2301\330\014\r\330\014\r\330\014\r\360\006\000\t\014\320\013\036\230c\240\021\330\014\022\220(\230!\320\0339\270\034\300Q\300a\330\010\031\230\021\330\010\"\240'\250\021\250)\2601\200A\360\006\000\027\030\360,\000\t\n\330\014\023\2209\230K\240q\330\020\037\230q\330\020\032\230!\340\017\020\330\014\017\210z\230\030\240\030\250\021\330\020\021\360\010\000\t\n\330\014\037\230x\240q\330\020\"\240$\240a\320'7\260q\340\017\020\330\014\022\220(\230!\320\0336\260a\330\010\017\210\177\230a\330\014\021\320\021!\240\021\240!\330\014\034\320\034,\250A\250Q\330\014\034\320\034,\250D\260\001\260\021\330\014\037\320\037/\250t\2601\260A\200A\360.\000\t\n\330\014\023\2209\230M\250\021\250!\330\010\017\210|\2301\330\014\r\330\020\027\220y\240\n\250!\2501\330\023\024\330\020\026\220a\200A\360\006\000\027\030\330+B\300!\3602\000\t(\320'H\310\001\330\014#\2407\250!\2501\340\010#\320#8\270\001\330\010+\250:\260Q\330\014\r\330\014\r\330\014\r\330\014\025\220Q\340\010\013\320\013#\2403\240a\330\014\022\220(\230!\330\020\021\330\023\024\340\010\031\230\021\330\010\"\240'\250\021\250)\2601\200A\360 \000\t\020\210}\230M\250\021\330\014\020\220\006\220a\320\027,\250D\260\001\200A\360 \000\t\020\210}\230O\2501\250H\260A\200A\360 \000\t\020\210}\230O\2501\250O\2701\270A\200A\330\010\017\320\017-\250Q\330\014\020\220\n\230$\230j\250\005\250Z\3207G\300s\310!\200A\330\010\017\320\017-\250Q\330\014\020\220\n\230$\230j\250\005\250Z\3207K\3103\310a\200A\360.\000\t\n\330\014\023\220=\240\r\250Q\250a\330\010\017\210|\2301\330\014\r\330\020\027\220}\240J\250a\250q\330\023\024\330\020\026\220a\200A\360.\000\t\014\210:\220Q\220l\240!\330\014\027\220s\230,\240a\240q\330\r\027\220q\230\014\240A\330\014\027\220s\230/\250\021\250!\330\r\027\220q\230\014\240E\250\024\250W\260A\260U\270!\330\014\027\220s\230*\240A\240Q\340\014\026\220a\220}\240F\250!\330\014\020\220\003\2201\220L\240\003\2401\330\014\020\220\007\220q\230\005\230Q\340\014\027\220s\230/\250\022\2501\330\r\024\220A\220""\\\240\021\330\014\027\220s\230*\240A\240Z\250x\260q\340\014\022\220(\230!\230:\240Q\240c\320);\2701\270A\330\010\017\210q\200A\360 \000\t\020\320\017\037\230\177\250a\330\014\033\2301\230A\200A\360\026\000\t\032\230\021\340\010&\240a\330\010$\240A\340\010\024\320\024+\2501\330\014\020\220\001\330\014\020\220\001\340\010\013\210:\220S\230\001\330\014\037\320\0372\260!\2601\340\010\030\230\001\330\010\t\330\014\020\220\007\220u\230A\230Q\330\020\027\220}\240A\240T\250\032\260;\270a\330\020\036\230g\240Q\240d\250!\2507\260!\330\024\030\230\001\330\024\025\330\034&\240a\330\033\034\340\020\034\230A\230Q\330\020\027\220q\360\010\000\r\031\230\001\230\021\330\014\035\230Q\230a\330\014\035\230Q\340\010\017\210q\200A\360&\000\t\n\330\014\023\320\023&\240m\2601\260A\330\010\017\210|\2301\330\014\r\330\020\027\320\027*\250*\260A\260Q\330\023\024\330\020\026\220a\200A\360 \000\t\020\320\017\"\240-\250q\330\014\020\220\006\220a\320\0272\260$\260a\200A\360\024\000\t\020\210t\2206\230\021\230$\230h\240a\200A\360 \000\t\020\210u\220M\240\021\240$\240f\250A\250\\\270\024\270Q\200A\360\034\000\t\020\210u\220O\2401\240H\250A\200A\360 \000\t\020\210u\220O\2401\240O\2601\260A\200A\360 \000\t\020\210y\230\r\240Q\240d\250&\260\001\3201A\300\024\300Q\200A\360 \000\t\020\210y\230\017\240q\250\010\260\001\200A\360 \000\t\020\210y\230\017\240q\250\017\260q\270\001\320\004)\320)B\300!\360L\001\000\t\n\330\014\030\230\004\230O\2501\330\020\032\230+\240_\260A\330\r\016\210a\330\014\023\2209\230L\250\t\260\021\330\017\020\330\014\023\2201\320\004+\320+D\300A\360N\001\000\t'\240a\330\010*\250!\330\010%\240Q\340\010$\240A\330\010\027\220q\340\010\013\210:\220W\230A\330\014\032\230*\240A\240Q\330\014\035\230Q\340\010\036\230a\330\010\t\330\014\030\230\r\240Q\330\020\024\220A\330\020\024\220A\330\020\021\330\020\021\330\020\021\220\021\340\014\017\210z\230\023\230A\330\020#\320#6\260a\260q\330\014\017\320\017%\240S\250\005\250T\3201B\300\"\300A\330\020&\240a\330\024)\250\021\250%\250t\2607\270%""\270q\300\001\360\006\000\r\020\320\017%\240S\250\001\330\020%\240Q\240a\330\014\035\230Q\360\006\000\t\031\230\001\360\006\000\t\032\230\021\330\010\t\330\014\020\220\007\220u\230A\230Q\330\020\023\320\023&\240a\240u\250B\250a\330\024\025\330\020\027\220}\240A\240T\250\032\260;\270a\330\020\027\320\027'\240q\250\006\250a\330\020 \320 5\260Q\260f\270A\330\020\023\220>\240\023\240E\250\024\250U\260#\260Q\330\024\"\240'\250\021\330\030*\250!\330\034\035\330\034\035\330\034/\250q\260\001\360\010\000\021\035\230A\230Q\330\020\027\220q\360\010\000\r\031\230\001\230\021\330\014\035\230Q\230a\330\014\035\230Q\330\010\017\210q\320\004)\250\021\360F\001\000\t\025\220D\230\r\240Q\330\014\026\220a\330\014\033\2301\340\010\013\210:\220W\230E\240\024\240Y\250a\250r\260\026\260s\270#\270Q\330\014\023\2203\220a\220y\240\001\240\021\330\010\017\210q\200\001\330\004\n\210+\220Q\320\004\035\230Q\360\036\000\t\035\230A\340\010\013\2105\220\007\220q\330\014\025\220Z\230q\240\001\330\014\025\220Q\340\010\034\320\0341\260\021\330\014\020\220\n\230(\240$\240a\340\010\031\230\021\330\010\013\2108\2203\220a\330\014\023\2201\330\010\t\330\014\025\220T\230\021\230'\240\021\330\020\024\220A\330\020\021\330\030\"\240!\330\027\030\360\006\000\r\031\230\001\230\021\330\010\017\210q\320\004\035\230Q\360(\000\t\035\230A\340\010\013\2105\220\007\220q\330\014\025\220Z\230q\240\001\330\014\025\220Q\340\010\034\320\0342\260!\330\014\020\220\n\230(\240$\240a\340\010\031\230\021\330\010\013\2108\2203\220a\330\014\023\2201\330\010\t\330\014\025\220T\230\021\230'\240\021\330\020\024\220A\330\020\021\330\030\"\240!\330\027\030\360\006\000\r\031\230\001\230\021\330\010\017\210q\320\004\037\230{\250!\360$\000\t\021\220\005\220Q\330\014\r\360\n\000\t\020\210y\230\001\230\024\230Z\240t\320+=\320=M\310Q\320\004\035\230Z\320':\320:R\320RS\3608\000\t\020\210w\220a\220t\230:\240T\250\032\3203C\320C\\\320\\]\320\004.\250a\360\036\000\t\014\2104\210z\230\021\230'\240\021\330\014\023\2201\330\010\017\210t\2208\2301""\230G\320#5\260Q\320\004&\240a\360$\000\t\025\220D\230\r\240R\240q\250\001\330\010\024\220A\330\010\t\360\014\000\t\014\2104\210v\220S\230\001\330\014\020\220\010\230\001\330\020\023\2204\220q\230\007\230v\240S\250\003\2501\330\024\036\230a\340\024\036\230a\330\020\031\230\027\240\001\330\024\031\230\021\330\024\036\230d\240!\2401\330\024\"\240.\260\007\260v\270Q\330\024\032\230/\250\021\250!\340\r\021\220\026\220s\230!\330\014\020\220\010\230\001\330\020\023\2204\220q\230\017\240v\250S\260\004\260E\270\021\330\024\035\230W\240A\330\030&\240a\330\030\"\240$\240a\240q\330\030\036\230d\240!\2401\330\030!\240\024\240Q\240a\330\030\035\230Q\360\006\000\025\030\220|\2403\240d\250!\2507\260&\270\001\330\030\"\240!\330\030\037\230q\340\030\"\240!\330\030\037\230q\330\024\027\220q\330\030!\240\027\250\001\330\034*\250(\260!\330\034&\240c\250\021\330\034\"\240!\330\034!\240\021\360\006\000\031\"\240\027\250\001\330\034*\250!\330\034&\240c\250\021\330\034\"\240*\250A\250T\260\021\260!\330\034!\240\021\340\r\021\220\026\220s\230!\330\014\020\220\010\230\001\330\020\031\230\027\240\001\330\024\"\240!\330\024\036\230d\240!\2401\330\024\032\230/\250\021\250!\330\024\035\230T\240\021\240!\330\024\031\230\021\360\006\000\t\020\210q\210\001\330\014\r\330\020\027\220r\230\021\230$\230a\230w\240a\240q\330\023\024\330\020\027\220t\2301\230A\200\001\330\004\005\330\010\017\210t\2206\230\021\230!\330\013\014\330\010\016\210h\220a\220q\200\001\360\036\000\005 \230z\250\021\250!\330\004\013\320\013)\250\021\250&\260\017\270s\300!";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 462; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 109) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 462; i < 528; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 528; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 462;
      for (Py_ssize_t i=0; i<66; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 0;
    int8_t const cint_constants_1[] = {0,1,2,70};
    for (int i = 0; i < 4; i++) {
      numbertab[i] = PyLong_FromLong(cint_constants_1[i - 0]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<4; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 12;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 721};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_axis};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_get_linear_unit, __pyx_mstate->__pyx_kp_b_iso88591_r_awaq_t1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 33};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_proj_string, __pyx_mstate->__pyx_n_u_b_proj_string};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_is_wkt, __pyx_mstate->__pyx_kp_b_iso88591_z_s, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 52};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_proj_string};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_is_proj, __pyx_mstate->__pyx_kp_b_iso88591_4vQm4t3a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 252};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_in_proj_json};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_load_proj_json, __pyx_mstate->__pyx_kp_b_iso88591_t6_haq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 404};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_version, __pyx_mstate->__pyx_n_u_pretty, __pyx_mstate->__pyx_n_u_output_axis_rule};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_wkt, __pyx_mstate->__pyx_kp_b_iso88591_Z_RRS8_wat_T_3CC, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 434};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pretty, __pyx_mstate->__pyx_n_u_indentation, __pyx_mstate->__pyx_n_u_options, __pyx_mstate->__pyx_n_u_multiline, __pyx_mstate->__pyx_n_u_indentation_width, __pyx_mstate->__pyx_n_u_proj_json_string};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_json, __pyx_mstate->__pyx_kp_b_iso88591_9_A_1_Ja_1Kq_q_Q_q_Q_q_Q_A_z, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 467};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_json_dict, __pyx_mstate->__pyx_kp_b_iso88591_A_t6_ha, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 485};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_is_exact_same, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_j_Z7Gs, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 489};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_is_equivalent, __pyx_mstate->__pyx_kp_b_iso88591_A_Q_j_Z7K3a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 498};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_is_exact_same_2, __pyx_mstate->__pyx_kp_b_iso88591_A_4z_1_t_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 506};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_user_input, __pyx_mstate->__pyx_n_u_prepared};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_user_input, __pyx_mstate->__pyx_kp_b_iso88591_A_Ql_s_aq_q_A_s_q_E_WAU_s_AQ_a_F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 626};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_system_string, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_coordinate_system_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string, __pyx_mstate->__pyx_kp_b_iso88591_A_8_1_aq_5_1_Q_way, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 661};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_system_dict};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json_dict, __pyx_mstate->__pyx_kp_b_iso88591_A_1_a_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 681};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_system_json_str};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json, __pyx_mstate->__pyx_kp_b_iso88591_A_a_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 701};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_rotated_pole, __pyx_mstate->__pyx_n_u_axis_list, __pyx_mstate->__pyx_n_u_cf_params, __pyx_mstate->__pyx_n_u_get_linear_unit, __pyx_mstate->__pyx_n_u_get_linear_unit, __pyx_mstate->__pyx_n_u_axis, __pyx_mstate->__pyx_n_u_cf_axis, __pyx_mstate->__pyx_n_u_name};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_cf, __pyx_mstate->__pyx_kp_b_iso88591_a_D_Rq_A_4vS_4q_vS_1_a_a_d_1_vQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 835};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_ellipsoid_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_authority, __pyx_mstate->__pyx_kp_b_iso88591_A_8_9_aq_as_1_1_9_Qa_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 868};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_code};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_epsg, __pyx_mstate->__pyx_kp_b_iso88591_A_y_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 886};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ellipsoid_string, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_ellipsoid_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string_2, __pyx_mstate->__pyx_kp_b_iso88591_A_8_1_aq_5_s_Q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 919};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ellipsoid_string, __pyx_mstate->__pyx_n_u_crs_err};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string, __pyx_mstate->__pyx_kp_b_iso88591_A_9M_1_y_1_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 950};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ellipsoid_dict};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json_dict, __pyx_mstate->__pyx_kp_b_iso88591_A_y_Qd_1A_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 968};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ellipsoid_json_str};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json, __pyx_mstate->__pyx_kp_b_iso88591_A_y_q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 986};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ellipsoid_name, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_ellipsoid_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_name_2, __pyx_mstate->__pyx_kp_b_iso88591_A_8_1_5Qa_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1020};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_ellipsoid_name, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_ellipsoid_params};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_name, __pyx_mstate->__pyx_kp_b_iso88591_A_9Kq_q_z_xq_a_7q_6a_a_AQ_D_t1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1111};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_prime_meridian_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_authority, __pyx_mstate->__pyx_kp_b_iso88591_A_8_a_aq_as_1_S_9_Qa_G1IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1144};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_code};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_epsg, __pyx_mstate->__pyx_kp_b_iso88591_A_O1HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1162};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_prime_meridian_string, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_prime_meridian_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string_2, __pyx_mstate->__pyx_kp_b_iso88591_A_8_aq_c_a_S_2_G1IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1198};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_prime_meridian_string, __pyx_mstate->__pyx_n_u_crs_err};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string, __pyx_mstate->__pyx_kp_b_iso88591_A_Qa_1_Jaq_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1229};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_prime_meridian_dict};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json_dict, __pyx_mstate->__pyx_kp_b_iso88591_A_M_a_D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1249};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_prime_meridian_json_str};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json, __pyx_mstate->__pyx_kp_b_iso88591_A_O1O1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1267};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_prime_meridian_name, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_prime_meridian_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_name, __pyx_mstate->__pyx_kp_b_iso88591_A_8_Zq_S_0_G1IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1360};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_category, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_datum_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_authority_2, __pyx_mstate->__pyx_kp_b_iso88591_A_8_5Q_aq_as_1_9Cq_9_Qa_G1IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1392};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_code};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_authority, __pyx_mstate->__pyx_kp_b_iso88591_A_5_F_5_F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1413};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_code};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_epsg, __pyx_mstate->__pyx_kp_b_iso88591_A_uO1HA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1429};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_datum_string, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_datum_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string_2, __pyx_mstate->__pyx_kp_b_iso88591_A_8_Kq_aq_S_Q_WA_4A_G1IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1464};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_datum_string, __pyx_mstate->__pyx_n_u_crs_err};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string, __pyx_mstate->__pyx_kp_b_iso88591_A_5_Qa_1_uJaq_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1494};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_datum_name, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_datum_type, __pyx_mstate->__pyx_n_u_pj_datum_type, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_datum_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_name_2, __pyx_mstate->__pyx_kp_b_iso88591_A2_1_8_Ja_Q_9Cq_1_G1IQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1532};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_datum_name, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_datum_type, __pyx_mstate->__pyx_n_u_first_error, __pyx_mstate->__pyx_n_u_err};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_name, __pyx_mstate->__pyx_kp_b_iso88591_A_2_c_a_5_1_1_1_3a_a_YgQa_uKq_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1583};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_datum_dict};
    __pyx_mstate_global->__pyx_codeobj_tab[49] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json_dict, __pyx_mstate->__pyx_kp_b_iso88591_A_uM_fA_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[49])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1601};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_datum_json_str};
    __pyx_mstate_global->__pyx_codeobj_tab[50] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json, __pyx_mstate->__pyx_kp_b_iso88591_A_uO1O1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[50])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[51] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[51])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[52] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[52])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[53] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[53])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[54] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[54])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[55] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[55])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[56] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[56])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1940};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_use_proj_alternative_grid_names, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_coord_operation_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[57] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_authority, __pyx_mstate->__pyx_kp_b_iso88591_A_8_q_aq_as_1_c_9_Qa_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[57])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1977};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_use_proj_alternative_grid_names};
    __pyx_mstate_global->__pyx_codeobj_tab[58] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_epsg, __pyx_mstate->__pyx_kp_b_iso88591_AGH_F, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[58])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1997};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_operation_string, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_coord_operation_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[59] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string_2, __pyx_mstate->__pyx_kp_b_iso88591_A_8_k_aq_s_q_a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[59])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2036};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_operation_string, __pyx_mstate->__pyx_n_u_crs_err};
    __pyx_mstate_global->__pyx_codeobj_tab[60] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_string, __pyx_mstate->__pyx_kp_b_iso88591_A_m1A_1_AQ_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[60])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2063};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_operation_dict};
    __pyx_mstate_global->__pyx_codeobj_tab[61] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json_dict, __pyx_mstate->__pyx_kp_b_iso88591_A_q_a_2_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[61])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2083};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_operation_json_str};
    __pyx_mstate_global->__pyx_codeobj_tab[62] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_json, __pyx_mstate->__pyx_kp_b_iso88591_A_1A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[62])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2103};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_coordinate_operation_name, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_coordinate_operation_type, __pyx_mstate->__pyx_n_u_pj_coordinate_operation_type, __pyx_mstate->__pyx_n_u_context, __pyx_mstate->__pyx_n_u_coordinate_operation_pj};
    __pyx_mstate_global->__pyx_codeobj_tab[63] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_from_name, __pyx_mstate->__pyx_kp_b_iso88591_A_B_2_H_7_1_8_Q_Q_3a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[63])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2217};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_version, __pyx_mstate->__pyx_n_u_pretty};
    __pyx_mstate_global->__pyx_codeobj_tab[64] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_proj4, __pyx_mstate->__pyx_kp_b_iso88591_3H_y_Zt_MQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[64])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[65] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[65])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[66] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[66])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2695};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_version};
    __pyx_mstate_global->__pyx_codeobj_tab[67] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_proj4, __pyx_mstate->__pyx_kp_b_iso88591_Q_y_Zt_MQ, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[67])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2721};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_min_confidence, __pyx_mstate->__pyx_n_u_auth_info};
    __pyx_mstate_global->__pyx_codeobj_tab[68] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_epsg, __pyx_mstate->__pyx_kp_b_iso88591_F_D_Q_a_1_WE_Yar_s_Q_3ay_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[68])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2764};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_min_confidence, __pyx_mstate->__pyx_n_u_authority};
    __pyx_mstate_global->__pyx_codeobj_tab[69] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_authority, __pyx_mstate->__pyx_kp_b_iso88591_B_L_O1__A_a_9L_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[69])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 15, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2810};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_auth_name, __pyx_mstate->__pyx_n_u_min_confidence, __pyx_mstate->__pyx_n_u_proj_list, __pyx_mstate->__pyx_n_u_c_out_confidence_list, __pyx_mstate->__pyx_n_u_num_proj_objects, __pyx_mstate->__pyx_n_u_b_auth_name, __pyx_mstate->__pyx_n_u_user_auth_name, __pyx_mstate->__pyx_n_u_iii, __pyx_mstate->__pyx_n_u_out_confidence_list, __pyx_mstate->__pyx_n_u_proj, __pyx_mstate->__pyx_n_u_code, __pyx_mstate->__pyx_n_u_out_auth_name, __pyx_mstate->__pyx_n_u_authority_list, __pyx_mstate->__pyx_n_u_iii};
    __pyx_mstate_global->__pyx_codeobj_tab[70] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_list_authority, __pyx_mstate->__pyx_kp_b_iso88591_DAN_a_Q_A_q_WA_AQ_Q_a_Q_A_A_z_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[70])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2911};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_c_name, __pyx_mstate->__pyx_n_u_b_name, __pyx_mstate->__pyx_n_u_projobj, __pyx_mstate->__pyx_n_u_crs_3d};
    __pyx_mstate_global->__pyx_codeobj_tab[71] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_3d, __pyx_mstate->__pyx_kp_b_iso88591_Q_A_5_q_Zq_Q_2_a_83a_1_T_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[71])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2954};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_name, __pyx_mstate->__pyx_n_u_c_name, __pyx_mstate->__pyx_n_u_b_name, __pyx_mstate->__pyx_n_u_projobj, __pyx_mstate->__pyx_n_u_crs_2d};
    __pyx_mstate_global->__pyx_codeobj_tab[72] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_to_2d, __pyx_mstate->__pyx_kp_b_iso88591_Q_A_5_q_Zq_Q_1_a_83a_1_T_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[72])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 2992};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_property_name, __pyx_mstate->__pyx_n_u_property_types, __pyx_mstate->__pyx_n_u_sub_crs_index, __pyx_mstate->__pyx_n_u_sub_crs, __pyx_mstate->__pyx_n_u_is_property};
    __pyx_mstate_global->__pyx_codeobj_tab[73] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_is_crs_property, __pyx_mstate->__pyx_kp_b_iso88591_AIJ0_4q_d_q_wa_gQg_gQiq_m1_gS_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[73])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3151};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other, __pyx_mstate->__pyx_n_u_ignore_axis_order};
    __pyx_mstate_global->__pyx_codeobj_tab[74] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_equals, __pyx_mstate->__pyx_kp_b_iso88591_A_1_1_A_A_Q_t_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[74])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3162};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_other, __pyx_mstate->__pyx_n_u_ignore_axis_order};
    __pyx_mstate_global->__pyx_codeobj_tab[75] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_equals_2, __pyx_mstate->__pyx_kp_b_iso88591_a_4z_1_t81G_5Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[75])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3194};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_non_deprecated, __pyx_mstate->__pyx_n_u_proj_list, __pyx_mstate->__pyx_n_u_num_proj_objects, __pyx_mstate->__pyx_n_u_proj, __pyx_mstate->__pyx_n_u_iii};
    __pyx_mstate_global->__pyx_codeobj_tab[76] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_pyproj__crs_pyx, __pyx_mstate->__pyx_n_u_get_non_deprecated, __pyx_mstate->__pyx_kp_b_iso88591_A_a_A_1_S_2_1_uAQ_AT_a_gQd_7_a_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[76])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[77] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[77])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[78] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_stringsource, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[78])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
    else state = (PyGILState_STATE)0;
    CYTHON_UNUSED_VAR(clineno);
    CYTHON_UNUSED_VAR(lineno);
    CYTHON_UNUSED_VAR(filename);
    CYTHON_MAYBE_UNUSED_VAR(nogil);
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(0);
    }
    ctx = PyUnicode_FromString(name);
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
    if (nogil)
        PyGILState_Release(state);
}

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyDictVersioning (used by GetModuleGlobalName) */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* pybytes_as_double (used by pyunicode_as_double) */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj) {
    PyObject *float_value = PyFloat_FromString(obj);
    if (likely(float_value)) {
        double value = __Pyx_PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
    return (double)-1;
}
static const char* __Pyx__PyBytes_AsDouble_Copy(const char* start, char* buffer, Py_ssize_t length) {
    int last_was_punctuation = 1;
    int parse_error_found = 0;
    Py_ssize_t i;
    for (i=0; i < length; i++) {
        char chr = start[i];
        int is_punctuation = (chr == '_') | (chr == '.') | (chr == 'e') | (chr == 'E');
        *buffer = chr;
        buffer += (chr != '_');
        parse_error_found |= last_was_punctuation & is_punctuation;
        last_was_punctuation = is_punctuation;
    }
    parse_error_found |= last_was_punctuation;
    *buffer = '\0';
    return unlikely(parse_error_found) ? NULL : buffer;
}
static double __Pyx__PyBytes_AsDouble_inf_nan(const char* start, Py_ssize_t length) {
    int matches = 1;
    char sign = start[0];
    int is_signed = (sign == '+') | (sign == '-');
    start += is_signed;
    length -= is_signed;
    switch (start[0]) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            matches &= (start[1] == 'a' || start[1] == 'A');
            matches &= (start[2] == 'n' || start[2] == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            matches &= (start[1] == 'n' || start[1] == 'N');
            matches &= (start[2] == 'f' || start[2] == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            matches &= (start[3] == 'i' || start[3] == 'I');
            matches &= (start[4] == 'n' || start[4] == 'N');
            matches &= (start[5] == 'i' || start[5] == 'I');
            matches &= (start[6] == 't' || start[6] == 'T');
            matches &= (start[7] == 'y' || start[7] == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static CYTHON_INLINE int __Pyx__PyBytes_AsDouble_IsSpace(char ch) {
    return (ch == 0x20) | !((ch < 0x9) | (ch > 0xd));
}
CYTHON_UNUSED static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length) {
    double value;
    Py_ssize_t i, digits;
    const char *last = start + length;
    char *end;
    while (__Pyx__PyBytes_AsDouble_IsSpace(*start))
        start++;
    while (start < last - 1 && __Pyx__PyBytes_AsDouble_IsSpace(last[-1]))
        last--;
    length = last - start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyBytes_AsDouble_inf_nan(start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    digits = 0;
    for (i=0; i < length; digits += start[i++] != '_');
    if (likely(digits == length)) {
        value = PyOS_string_to_double(start, &end, NULL);
    } else if (digits < 40) {
        char number[40];
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((digits + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* PyObjectVectorCallKwBuilder */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* PyObjectFormat */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* obj, PyObject* format_spec) {
    int ret;
    _PyUnicodeWriter writer;
    if (likely(PyFloat_CheckExact(obj))) {
        _PyUnicodeWriter_Init(&writer);
        ret = _PyFloat_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else if (likely(PyLong_CheckExact(obj))) {
        _PyUnicodeWriter_Init(&writer);
        ret = _PyLong_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else {
        return PyObject_Format(obj, format_spec);
    }
    if (unlikely(ret == -1)) {
        _PyUnicodeWriter_Dealloc(&writer);
        return NULL;
    }
    return _PyUnicodeWriter_Finish(&writer);
}
#endif

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON
static int
__Pyx_unicode_modifiable(PyObject *unicode, int unsafe_shared)
{
    if (!__Pyx_IS_UNIQUELY_REFERENCED(unicode, unsafe_shared))
        return 0;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030F0000
    if (PyUnstable_Unicode_GET_CACHED_HASH(unicode) != -1)
        return 0;
#endif
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left, unsafe_shared)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#elif PY_VERSION_HEX >= 0x030d0000
    PyDict_SetDefaultRef(d, key, default_value, &value);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CythonFunctionShared) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CythonFunctionShared) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectCall2Args (used by CallUnboundCMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    int was_initialized =  __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return __Pyx_CallCFunction(cfunc, self, arg);
        } else if (flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, &arg, 1);
        } else if (flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, &arg, 1, NULL);
        }
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod1(&tmp_cfunc, self, arg);
    }
#endif
    PyObject* result = __Pyx__CallUnboundCMethod1(cfunc, self, arg);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *args = PyTuple_New(1);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
    } else
#endif
    {
        result = __Pyx_PyObject_Call2Args(cfunc->method, self, arg);
    }
    return result;
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyBytes_CheckExact(key) || PyUnicode_CheckExact(key) || PyLong_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* IterFinish (used by dict_iter) */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectCallNoArg (used by PyObjectCallMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod0) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod0 (used by dict_iter) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* RaiseNeedMoreValuesToUnpack (used by UnpackTuple2) */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack (used by UnpackItemEndCheck) */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck (used by UnpackTuple2) */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError (used by UnpackTupleError) */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError (used by UnpackTuple2) */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else {
      Py_ssize_t size = __Pyx_PyTuple_GET_SIZE(t);
 #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely(size < 0)) return;
 #endif
      if (size < index) {
        __Pyx_RaiseNeedMoreValuesError(size);
      } else {
        __Pyx_RaiseTooManyValuesError(index);
      }
    }
}

/* UnpackTuple2 (used by dict_iter) */
static CYTHON_INLINE int __Pyx_unpack_tuple2(
        PyObject* tuple, PyObject** value1, PyObject** value2, int is_tuple, int has_known_size, int decref_tuple) {
    if (likely(is_tuple || PyTuple_Check(tuple))) {
        Py_ssize_t size;
        if (has_known_size) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        size = __Pyx_PyTuple_GET_SIZE(tuple);
        if (likely(size == 2)) {
            return __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple);
        }
        if (size >= 0) {
            __Pyx_UnpackTupleError(tuple, 2);
        }
        return -1;
    } else {
        return __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple);
    }
}
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
    value1 = __Pyx_PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = __Pyx_PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#else
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
#if !CYTHON_AVOID_BORROWED_REFS
static CYTHON_INLINE int __Pyx_dict_iter_next_source_is_dict(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem) {
    PyObject *key, *value;
    if (unlikely(orig_length != PyDict_Size(iter_obj))) {
        PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
        return -1;
    }
    if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
        return 0;
    }
    if (pitem) {
        PyObject* tuple = PyTuple_New(2);
        if (unlikely(!tuple)) {
            return -1;
        }
        Py_INCREF(key);
        Py_INCREF(value);
        #if CYTHON_ASSUME_SAFE_MACROS
        PyTuple_SET_ITEM(tuple, 0, key);
        PyTuple_SET_ITEM(tuple, 1, value);
        #else
        if (unlikely(PyTuple_SetItem(tuple, 0, key) < 0)) {
            Py_DECREF(value);
            Py_DECREF(tuple);
            return -1;
        }
        if (unlikely(PyTuple_SetItem(tuple, 1, value) < 0)) {
            Py_DECREF(tuple);
            return -1;
        }
        #endif
        *pitem = tuple;
    } else {
        if (pkey) {
            Py_INCREF(key);
            *pkey = key;
        }
        if (pvalue) {
            Py_INCREF(value);
            *pvalue = value;
        }
    }
    return 1;
}
#endif
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_AVOID_BORROWED_REFS
    if (source_is_dict) {
        int result;
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_BEGIN_CRITICAL_SECTION(iter_obj);
#endif
        result = __Pyx_dict_iter_next_source_is_dict(iter_obj, orig_length, ppos, pkey, pvalue, pitem);
#if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_END_CRITICAL_SECTION();
#endif
        return result;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(tuple_size < 0)) return -1;
        #endif
        if (unlikely(pos >= tuple_size)) return 0;
        *ppos = pos + 1;
        #if CYTHON_ASSUME_SAFE_MACROS
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        #else
        next_item = PyTuple_GetItem(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
        #endif
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        Py_ssize_t list_size = __Pyx_PyList_GET_SIZE(iter_obj);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(list_size < 0)) return -1;
        #endif
        if (unlikely(pos >= list_size)) return 0;
        *ppos = pos + 1;
        next_item = __Pyx_PyList_GetItemRef(iter_obj, pos);
        if (unlikely(!next_item)) return -1;
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n)))
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* FunctionExport */
static int __Pyx_ExportFunction(PyObject *api_dict, const char *name, void (*f)(void), const char *sig) {
    PyObject *cobj;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(api_dict, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(cobj);
    return -1;
}

/* GetApiDict */
static PyObject *__Pyx_ApiExport_GetApiDict(void) {
    PyObject *d;
    if (__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_capi, &d) == -1)
        return NULL;
    if (!d) {
        d = PyDict_New();
        if (!d)
            goto bad;
        if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_pyx_capi, d) < 0)
            goto bad;
    }
    return d;
bad:
    Py_XDECREF(d);
    return NULL;
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* DelItemOnTypeDict (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_DelItem(tp_dict, k);
    if (likely(!result)) PyType_Modified(tp);
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_mstate_global->__pyx_n_u_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_mstate_global->__pyx_n_u_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython);
            if (likely(reduce_cython)) {
                ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_mstate_global->__pyx_n_u_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetFullyQualifiedName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_3
#define __PYX_HAVE_RT_ImportType_3_2_3
static PyTypeObject *__Pyx_ImportType_3_2_3(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_3 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_3 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_3 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* PxdImportShared (used by FunctionImport) */
#ifndef __PYX_HAVE_RT_ImportFromPxd_3_2_3
#define __PYX_HAVE_RT_ImportFromPxd_3_2_3
static int __Pyx_ImportFromPxd_3_2_3(PyObject *module, const char *name, void **p, const char *sig, const char *what) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, "__pyx_capi__");
    if (!d)
        goto bad;
#if (defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030d0000) || (!defined(Py_LIMITED_API) && PY_VERSION_HEX >= 0x030d0000)
    PyDict_GetItemStringRef(d, name, &cobj);
#else
    cobj = PyDict_GetItemString(d, name);
    Py_XINCREF(cobj);
#endif
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C %.8s %.200s",
                PyModule_GetName(module), what, name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C %.8s %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             what, PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(d);
    Py_XDECREF(cobj);
    return -1;
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_3
#define __PYX_HAVE_RT_ImportFunction_3_2_3
static int __Pyx_ImportFunction_3_2_3(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_3(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__13);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    if (__Pyx_TypeCheck(method, &PyMethodDescr_Type))
#endif
    {
#if CYTHON_COMPILING_IN_LIMITED_API
        return PyErr_Format(
            PyExc_SystemError,
            "Cython cannot yet handle classmethod on a MethodDescriptorType (%S) in limited API mode. "
            "This is most likely a classmethod in a cdef class method with binding=False. "
            "Try setting 'binding' to True.",
            method);
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
        PyTypeObject *d_type = GraalPyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, GraalPyMethodDescrObject_GetMethod(method));
#elif CYTHON_COMPILING_IN_GRAAL
        PyTypeObject *d_type = PyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, PyMethodDescrObject_GetMethod(method));
#else
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        PyTypeObject *d_type = descr->d_common.d_type;
        return PyDescr_NewClassMethod(d_type, descr->d_method);
#endif
    }
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
#else
    {
        PyObject *func=NULL;
        PyObject *builtins, *classmethod, *classmethod_str, *result=NULL;
        if (__Pyx_TypeCheck(method, __pyx_mstate_global->__Pyx_CachedMethodType)) {
            func = PyObject_GetAttrString(method, "__func__");
            if (!func) goto bad;
        } else {
            func = method;
            Py_INCREF(func);
        }
        builtins = PyEval_GetBuiltins(); // borrowed
        if (unlikely(!builtins)) goto bad;
        classmethod_str = PyUnicode_FromString("classmethod");
        if (unlikely(!classmethod_str)) goto bad;
        classmethod = PyObject_GetItem(builtins, classmethod_str);
        Py_DECREF(classmethod_str);
        if (unlikely(!classmethod)) goto bad;
        result = PyObject_CallFunctionObjArgs(classmethod, func, NULL);
        Py_DECREF(classmethod);
        bad:
        Py_XDECREF(func);
        return result;
    }
#endif
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* ListPack */
static PyObject *__Pyx_PyList_Pack(Py_ssize_t n, ...) {
    va_list va;
    PyObject *l = PyList_New(n);
    va_start(va, n);
    if (unlikely(!l)) goto end;
    for (Py_ssize_t i=0; i<n; ++i) {
        PyObject *arg = va_arg(va, PyObject*);
        Py_INCREF(arg);
        if (__Pyx_PyList_SET_ITEM(l, i, arg) != (0)) {
            Py_CLEAR(l);
            goto end;
        }
    }
    end:
    va_end(va);
    return l;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_COORDINATE_SYSTEM_TYPE(PJ_COORDINATE_SYSTEM_TYPE value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_COORDINATE_SYSTEM_TYPE neg_one = (PJ_COORDINATE_SYSTEM_TYPE) -1, const_zero = (PJ_COORDINATE_SYSTEM_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PJ_COORDINATE_SYSTEM_TYPE) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_COORDINATE_SYSTEM_TYPE) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(PJ_COORDINATE_SYSTEM_TYPE) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PJ_COORDINATE_SYSTEM_TYPE) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_COORDINATE_SYSTEM_TYPE) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(PJ_COORDINATE_SYSTEM_TYPE),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(PJ_COORDINATE_SYSTEM_TYPE));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_TYPE(PJ_TYPE value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_TYPE neg_one = (PJ_TYPE) -1, const_zero = (PJ_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PJ_TYPE) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_TYPE) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(PJ_TYPE) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PJ_TYPE) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_TYPE) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(PJ_TYPE),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(PJ_TYPE));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE PJ_CATEGORY __Pyx_PyLong_As_PJ_CATEGORY(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_CATEGORY neg_one = (PJ_CATEGORY) -1, const_zero = (PJ_CATEGORY) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        PJ_CATEGORY val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (PJ_CATEGORY) -1;
        val = __Pyx_PyLong_As_PJ_CATEGORY(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(PJ_CATEGORY) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) >= 2 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) (((((PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_CATEGORY) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) >= 3 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) (((((((PJ_CATEGORY)digits[2]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_CATEGORY) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) >= 4 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) (((((((((PJ_CATEGORY)digits[3]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[2]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (PJ_CATEGORY) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(PJ_CATEGORY) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_CATEGORY, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(PJ_CATEGORY) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_CATEGORY, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(PJ_CATEGORY) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) (((PJ_CATEGORY)-1)*(((((PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(PJ_CATEGORY) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) ((((((PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(PJ_CATEGORY) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) (((PJ_CATEGORY)-1)*(((((((PJ_CATEGORY)digits[2]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_CATEGORY) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) ((((((((PJ_CATEGORY)digits[2]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(PJ_CATEGORY) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) (((PJ_CATEGORY)-1)*(((((((((PJ_CATEGORY)digits[3]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[2]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_CATEGORY) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_CATEGORY, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_CATEGORY) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_CATEGORY) ((((((((((PJ_CATEGORY)digits[3]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[2]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[1]) << PyLong_SHIFT) | (PJ_CATEGORY)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(PJ_CATEGORY) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_CATEGORY, long, PyLong_AsLong(x))
        } else if ((sizeof(PJ_CATEGORY) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_CATEGORY, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        PJ_CATEGORY val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() or PyLong_AsNativeBytes() not available, cannot convert large enums");
        val = (PJ_CATEGORY) -1;
#endif
        if (unlikely(ret))
            return (PJ_CATEGORY) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PJ_CATEGORY");
    return (PJ_CATEGORY) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PJ_CATEGORY");
    return (PJ_CATEGORY) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_WKT_TYPE(PJ_WKT_TYPE value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_WKT_TYPE neg_one = (PJ_WKT_TYPE) -1, const_zero = (PJ_WKT_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PJ_WKT_TYPE) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_WKT_TYPE) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(PJ_WKT_TYPE) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PJ_WKT_TYPE) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_WKT_TYPE) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(PJ_WKT_TYPE),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(PJ_WKT_TYPE));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE PJ_WKT_TYPE __Pyx_PyLong_As_PJ_WKT_TYPE(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_WKT_TYPE neg_one = (PJ_WKT_TYPE) -1, const_zero = (PJ_WKT_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        PJ_WKT_TYPE val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (PJ_WKT_TYPE) -1;
        val = __Pyx_PyLong_As_PJ_WKT_TYPE(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(PJ_WKT_TYPE) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) >= 2 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) (((((PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_WKT_TYPE) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) >= 3 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) (((((((PJ_WKT_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_WKT_TYPE) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) >= 4 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) (((((((((PJ_WKT_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (PJ_WKT_TYPE) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(PJ_WKT_TYPE) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_WKT_TYPE, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(PJ_WKT_TYPE) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_WKT_TYPE, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) (((PJ_WKT_TYPE)-1)*(((((PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(PJ_WKT_TYPE) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) ((((((PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) (((PJ_WKT_TYPE)-1)*(((((((PJ_WKT_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_WKT_TYPE) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) ((((((((PJ_WKT_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) (((PJ_WKT_TYPE)-1)*(((((((((PJ_WKT_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_WKT_TYPE) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_WKT_TYPE, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_WKT_TYPE) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_WKT_TYPE) ((((((((((PJ_WKT_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_WKT_TYPE)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(PJ_WKT_TYPE) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_WKT_TYPE, long, PyLong_AsLong(x))
        } else if ((sizeof(PJ_WKT_TYPE) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_WKT_TYPE, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        PJ_WKT_TYPE val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() or PyLong_AsNativeBytes() not available, cannot convert large enums");
        val = (PJ_WKT_TYPE) -1;
#endif
        if (unlikely(ret))
            return (PJ_WKT_TYPE) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PJ_WKT_TYPE");
    return (PJ_WKT_TYPE) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PJ_WKT_TYPE");
    return (PJ_WKT_TYPE) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_PROJ_STRING_TYPE(PJ_PROJ_STRING_TYPE value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_PROJ_STRING_TYPE neg_one = (PJ_PROJ_STRING_TYPE) -1, const_zero = (PJ_PROJ_STRING_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PJ_PROJ_STRING_TYPE) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(PJ_PROJ_STRING_TYPE),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(PJ_PROJ_STRING_TYPE));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE PJ_PROJ_STRING_TYPE __Pyx_PyLong_As_PJ_PROJ_STRING_TYPE(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_PROJ_STRING_TYPE neg_one = (PJ_PROJ_STRING_TYPE) -1, const_zero = (PJ_PROJ_STRING_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        PJ_PROJ_STRING_TYPE val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (PJ_PROJ_STRING_TYPE) -1;
        val = __Pyx_PyLong_As_PJ_PROJ_STRING_TYPE(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) >= 2 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) (((((PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) >= 3 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) (((((((PJ_PROJ_STRING_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) >= 4 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) (((((((((PJ_PROJ_STRING_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (PJ_PROJ_STRING_TYPE) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_PROJ_STRING_TYPE, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_PROJ_STRING_TYPE, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) (((PJ_PROJ_STRING_TYPE)-1)*(((((PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) ((((((PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) (((PJ_PROJ_STRING_TYPE)-1)*(((((((PJ_PROJ_STRING_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) ((((((((PJ_PROJ_STRING_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) (((PJ_PROJ_STRING_TYPE)-1)*(((((((((PJ_PROJ_STRING_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_PROJ_STRING_TYPE) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_PROJ_STRING_TYPE, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_PROJ_STRING_TYPE) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_PROJ_STRING_TYPE) ((((((((((PJ_PROJ_STRING_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_PROJ_STRING_TYPE)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_PROJ_STRING_TYPE, long, PyLong_AsLong(x))
        } else if ((sizeof(PJ_PROJ_STRING_TYPE) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_PROJ_STRING_TYPE, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        PJ_PROJ_STRING_TYPE val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() or PyLong_AsNativeBytes() not available, cannot convert large enums");
        val = (PJ_PROJ_STRING_TYPE) -1;
#endif
        if (unlikely(ret))
            return (PJ_PROJ_STRING_TYPE) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PJ_PROJ_STRING_TYPE");
    return (PJ_PROJ_STRING_TYPE) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PJ_PROJ_STRING_TYPE");
    return (PJ_PROJ_STRING_TYPE) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_PJ_CATEGORY(PJ_CATEGORY value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_CATEGORY neg_one = (PJ_CATEGORY) -1, const_zero = (PJ_CATEGORY) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(PJ_CATEGORY) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_CATEGORY) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(PJ_CATEGORY) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(PJ_CATEGORY) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(PJ_CATEGORY) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(PJ_CATEGORY),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(PJ_CATEGORY));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE PJ_TYPE __Pyx_PyLong_As_PJ_TYPE(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const PJ_TYPE neg_one = (PJ_TYPE) -1, const_zero = (PJ_TYPE) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        PJ_TYPE val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (PJ_TYPE) -1;
        val = __Pyx_PyLong_As_PJ_TYPE(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_TYPE, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(PJ_TYPE) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) >= 2 * PyLong_SHIFT)) {
                            return (PJ_TYPE) (((((PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_TYPE) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) >= 3 * PyLong_SHIFT)) {
                            return (PJ_TYPE) (((((((PJ_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_TYPE) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) >= 4 * PyLong_SHIFT)) {
                            return (PJ_TYPE) (((((((((PJ_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (PJ_TYPE) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(PJ_TYPE) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_TYPE, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(PJ_TYPE) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_TYPE, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(PJ_TYPE, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(PJ_TYPE) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_TYPE) (((PJ_TYPE)-1)*(((((PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(PJ_TYPE) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                            return (PJ_TYPE) ((((((PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(PJ_TYPE) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_TYPE) (((PJ_TYPE)-1)*(((((((PJ_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(PJ_TYPE) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                            return (PJ_TYPE) ((((((((PJ_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(PJ_TYPE) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_TYPE) (((PJ_TYPE)-1)*(((((((((PJ_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(PJ_TYPE) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(PJ_TYPE, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(PJ_TYPE) - 1 > 4 * PyLong_SHIFT)) {
                            return (PJ_TYPE) ((((((((((PJ_TYPE)digits[3]) << PyLong_SHIFT) | (PJ_TYPE)digits[2]) << PyLong_SHIFT) | (PJ_TYPE)digits[1]) << PyLong_SHIFT) | (PJ_TYPE)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(PJ_TYPE) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_TYPE, long, PyLong_AsLong(x))
        } else if ((sizeof(PJ_TYPE) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(PJ_TYPE, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        PJ_TYPE val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() or PyLong_AsNativeBytes() not available, cannot convert large enums");
        val = (PJ_TYPE) -1;
#endif
        if (unlikely(ret))
            return (PJ_TYPE) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to PJ_TYPE");
    return (PJ_TYPE) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to PJ_TYPE");
    return (PJ_TYPE) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__14);
    }
    goto done;
}
#endif

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) return NULL;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
